(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='%s' *)
(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       131,          6]
NotebookDataLength[  14688413,     246122]
NotebookOptionsPosition[  14684721,     246066]
NotebookOutlinePosition[  14685218,     246086]
CellTagsIndexPosition[  14685175,     246083]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6d91de60-c10c-41f5-bde9-287116780b4c"],

Cell["Chapter 2, Section 2.7, Animation of Figure 2.12", "Section",
 CellChangeTimes->{{3.8516824850054398`*^9, 3.8516824897129374`*^9}, {
  3.8521163574828167`*^9, 3.85211636131787*^9}, {3.8814765054247427`*^9, 
  3.881476508133231*^9}},ExpressionUUID->"e0c5f5c8-6081-4d1f-b6a3-\
e70fbf94be83"],

Cell[TextData[{
 "We start by defining a function ",
 StyleBox["r", "Input"],
 " using Eq.(2.20) to give us the radial distance for given values of \
semi-major axis, ",
 StyleBox["a", "Input"],
 ", eccentricity, ",
 StyleBox["e", "Input"],
 ", and true anomaly, ",
 StyleBox["t", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"037fe9f8-0973-4de7-8f87-9d81c9d6a588"],

Cell["r[a_,e_,t_]:=a(1-e^2)/(1+e Cos[t]);", "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"74d5f28f-491d-4df9-9a98-baf58f7ca2bb"],

Cell[TextData[{
 "Use the definition of ",
 StyleBox["r", "Input"],
 " to define a function ",
 StyleBox["ellipse",
  FontWeight->"Bold"],
 " to draw a planar ellipse with semi-major axis ",
 StyleBox["a", "Input"],
 " and eccentricity ",
 StyleBox["e ", "Input"],
 "(see Eq.(2.21))."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.852196917657197*^9, 3.852196933392804*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"15a06966-ec76-434f-8cbd-b97cea0e1abb"],

Cell["\<\
ellipse[a_,e_]:=
ParametricPlot[{r[a,e,t] Cos[t], r[a,e,t] Sin[t]},
               {t,0,2Pi},AspectRatio->Automatic];\
\>", "Input",
 CellLabel->"In[2]:=",ExpressionUUID->"1a2b4798-3239-4416-8e3f-8237e4351cfd"],

Cell[TextData[{
 "Now define two similar functions, ",
 StyleBox["ellipsecom1",
  FontWeight->"Bold"],
 " and ",
 StyleBox["ellipsecom2",
  FontWeight->"Bold"],
 ", to draw ellipses that will be used to draw (i) the path of the centre of \
mass in a frame centred on the central mass, and (i) the path of the central \
mass in a frame centred on the centre of mass.  Note that ",
 StyleBox["ellipsecom1",
  FontWeight->"Bold"],
 " is drawn with a thinner line and that ",
 StyleBox["ellipsecom2",
  FontWeight->"Bold"],
 " is rotated by 180\[Degree] with respect to the original ellipse."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.852196917657197*^9, 3.852196933392804*^9}, {
   3.852196975625827*^9, 3.852197078191415*^9}, {3.8521972131456738`*^9, 
   3.852197291702389*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1bc8946a-0165-4c8f-a798-407bae699c3c"],

Cell["\<\
ellipsecom1[a_,e_]:=
ParametricPlot[{r[a,e,t] Cos[t], r[a,e,t] Sin[t]},
               {t,0,2Pi},PlotStyle->Thickness[0.001],AspectRatio->Automatic];\
\
\>", "Input",
 CellChangeTimes->{{3.8521921094329243`*^9, 3.852192126375309*^9}, {
  3.852192365684702*^9, 3.852192367912116*^9}, {3.852192698029401*^9, 
  3.8521927161974983`*^9}, {3.852192751163292*^9, 3.852192761563353*^9}, {
  3.852192826869783*^9, 3.85219284354883*^9}, {3.852192888280081*^9, 
  3.852192925120772*^9}, {3.852193476869459*^9, 3.852193479482832*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"189049c2-9419-41be-929f-57b64959f251"],

Cell["\<\
ellipsecom2[a_,e_]:=
ParametricPlot[{r[a,e,t+Pi] Cos[t], r[a,e,t+Pi] Sin[t]},
               {t,0,2Pi},AspectRatio->Automatic];\
\>", "Input",
 CellChangeTimes->{{3.8521921094329243`*^9, 3.852192126375309*^9}, {
   3.852192365684702*^9, 3.852192367912116*^9}, {3.852192698029401*^9, 
   3.8521927161974983`*^9}, {3.852192751163292*^9, 3.852192761563353*^9}, {
   3.852192826869783*^9, 3.85219284354883*^9}, {3.852192888280081*^9, 
   3.852192925120772*^9}, {3.852193476869459*^9, 3.852193550126199*^9}, {
   3.852193657954417*^9, 3.852193662093746*^9}, 3.852196345666122*^9},
 CellLabel->"In[4]:=",ExpressionUUID->"78be983d-800c-4e63-a839-32a0d43a5c31"],

Cell[TextData[{
 "Define a function ",
 StyleBox["ksolve", "Input"],
 " to solve Kepler\[CloseCurlyQuote]s Equation to find the eccentric anomaly \
for given values of the mean anomaly ",
 StyleBox["ma", "Input"],
 " and eccentricity ",
 StyleBox["e", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518565908155117`*^9, 3.851856663384062*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"499ef0d3-896f-43ff-ad87-a50c6bd576da"],

Cell["ksolve[ma_,e_]:=FindRoot[ea - e Sin[ea] == ma, {ea,ma}];", "Input",
 CellLabel->"In[5]:=",ExpressionUUID->"e98c7a92-aae2-4838-8992-553373aaa41c"],

Cell[TextData[{
 "Define the function ",
 StyleBox["position",
  FontWeight->"Bold"],
 " to calculate the 2D position vectors of the orbiting mass for given values \
of the mean anomaly ",
 StyleBox["ma", "Input"],
 ", semi-major axis ",
 StyleBox["a", "Input"],
 " and eccentricity ",
 StyleBox["e", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.852116498403043*^9, 
   3.8521165521772747`*^9}, {3.852117652666978*^9, 3.852117655681035*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"038f3591-2174-494e-ae16-414cdb11af73"],

Cell["\<\
position[ma_,a_,e_]:=
Module[
{eca,esq=Sqrt[1-e^2],x,y,r,xd,yd},
eca=ea/.ksolve[ma,e];
ceca=Cos[eca]; seca=Sin[eca];
x=a(ceca-e); y=a*esq*seca;
r=Sqrt[x^2+y^2];
{x,y,r}
]\
\>", "Input",
 CellChangeTimes->{{3.851755150729423*^9, 3.851755153583551*^9}, {
   3.8517552030090723`*^9, 3.851755331050675*^9}, {3.851755386351788*^9, 
   3.851755426371717*^9}, {3.85175553015672*^9, 3.8517556246146727`*^9}, {
   3.851755665965542*^9, 3.8517556784154997`*^9}, {3.851755722935534*^9, 
   3.8517557882609673`*^9}, 3.851755909237783*^9, {3.8517575132539043`*^9, 
   3.8517575290476427`*^9}, {3.851757580153109*^9, 3.8517575886870604`*^9}, {
   3.85211650444783*^9, 3.8521165058873577`*^9}, {3.8521176980564632`*^9, 
   3.852117704176052*^9}, {3.852118416533043*^9, 3.852118417234187*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"6dc29f0b-b5a3-4d3b-abbd-998f5350a3f8"],

Cell["Draw the 2D ellipse.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.8518577960228558`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7c6a061f-df2a-45cd-b45d-24af7e38b1f7"],

Cell["ell=ellipse[1.0,0.5];", "Input",
 CellChangeTimes->{3.812187616753561*^9, 3.85176071108153*^9},
 CellLabel->"In[7]:=",ExpressionUUID->"23829646-9796-4147-80ef-8e664b956745"],

Cell["Define a point for the sun (at the origin) in 2D.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.851857810152133*^9}, {3.8518579015457363`*^9, 3.851857946979704*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"38e13c9d-f70b-439d-bfae-efa7ca65c07b"],

Cell["sun=Graphics[{PointSize[0.025],Point[{0,0}]}];", "Input",
 CellChangeTimes->{3.812188009931479*^9, 3.852188945393114*^9},
 CellLabel->"In[8]:=",ExpressionUUID->"25ed41c2-df98-41e4-8ace-b58988592b4f"],

Cell[TextData[{
 "Define the value of the mass ratio, ",
 StyleBox["m2m1",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.851857810152133*^9}, {3.8518579015457363`*^9, 3.85185796324026*^9}, {
   3.851857994126542*^9, 3.851858010685014*^9}, {3.8518580568281803`*^9, 
   3.8518580698580112`*^9}, {3.8521179488724127`*^9, 3.852117988966939*^9}, {
   3.852192205494658*^9, 3.852192206493499*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"17c4fb23-07c4-4a1f-b239-9a70e3e05ba2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m2m1", "=", "0.2"}], ";"}]], "Input",
 CellChangeTimes->{{3.851757606778563*^9, 3.851757611696493*^9}, {
  3.851761249417083*^9, 3.8517612503290977`*^9}, {3.852117977402968*^9, 
  3.852117983281823*^9}, {3.852118358795034*^9, 3.852118368514513*^9}, {
  3.8521215483830967`*^9, 3.852121548893025*^9}, {3.852189529136189*^9, 
  3.8521895402051353`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"921bc2f3-947f-49de-ad90-fadf1c1b4231"],

Cell["\<\
Prepare the required ellipses.  Note that ell2 is the elliptical path taken \
by the orbiting mass with rewpect to the centre of mass.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.851857810152133*^9}, {3.8518579015457363`*^9, 3.85185796324026*^9}, {
   3.851857994126542*^9, 3.851858010685014*^9}, {3.8518580568281803`*^9, 
   3.8518580698580112`*^9}, {3.8521179488724127`*^9, 3.852117988966939*^9}, {
   3.852192205494658*^9, 3.852192206493499*^9}, {3.852197351187242*^9, 
   3.852197409016316*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"cf9c9ae6-a21e-42f4-a9b4-60449524145a"],

Cell["ellcom1=ellipsecom1[m2m1/(1+m2m1),0.5];", "Input",
 CellChangeTimes->{
  3.812187616753561*^9, 3.85176071108153*^9, {3.852192144408927*^9, 
   3.8521921725512114`*^9}, {3.852192484956386*^9, 3.8521924859314623`*^9}, {
   3.8521925695577087`*^9, 3.852192576892569*^9}, {3.852193564980401*^9, 
   3.852193575301079*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"6c569547-aadc-428e-bdeb-d50d12cfd9b1"],

Cell["ellcom2=ellipsecom2[m2m1/(1+m2m1),0.5];", "Input",
 CellChangeTimes->{
  3.812187616753561*^9, 3.85176071108153*^9, {3.852192144408927*^9, 
   3.8521921725512114`*^9}, {3.852192484956386*^9, 3.8521924859314623`*^9}, {
   3.8521925695577087`*^9, 3.852192576892569*^9}, {3.852193564980401*^9, 
   3.8521935879530487`*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"f9e35473-3695-4300-a082-610a2f24b370"],

Cell["ell2=ellipse[1-m2m1/(1+m2m1),0.5];", "Input",
 CellChangeTimes->{
  3.812187616753561*^9, 3.85176071108153*^9, {3.85219536296113*^9, 
   3.852195399539137*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"ceba9e33-0370-4480-9c48-437d46024358"],

Cell["\<\
Draw the 2D varying position of the orbiting planet and its associated \
vectors for 100 values of the mean anomaly for the frame centred on the \
central mass (Sun).\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.851857810152133*^9}, {3.8518579015457363`*^9, 3.85185796324026*^9}, {
   3.851857994126542*^9, 3.851858010685014*^9}, {3.8518580568281803`*^9, 
   3.8518580698580112`*^9}, {3.851858121478053*^9, 3.851858198847193*^9}, {
   3.852197421601698*^9, 3.8521974383087263`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"377e75f5-1ae8-46ab-ba50-f66e2c17a174"],

Cell["\<\
plots1=
Table[
m=(i-1)*Pi/50;
posv=position[m,1.0,0.5];
posvec=Take[posv,{1,2}];
rad=Last[posv];
com=(rad-rad/(1+m2m1))*posvec/Norm[posvec];
planline=Graphics[Line[{{0,0},posvec}]];
planet=Graphics[{PointSize[0.015],Point[posvec]}];
compt=Graphics[{EdgeForm[Black],White,Disk[com,0.025]}];
Show[ell,ellcom1,sun,planet,planline,compt,Axes->None,PlotRange->{{-2.2,1.2},{\
-1.2,1.2}}],
{i,0,100}];\
\>", "Input",
 CellChangeTimes->{{3.81218776738144*^9, 3.812187806561784*^9}, {
   3.812187839457335*^9, 3.812187886015627*^9}, {3.85175337730943*^9, 
   3.851753381956236*^9}, {3.851756272938218*^9, 3.851756374502733*^9}, {
   3.851756738242207*^9, 3.851756826933384*^9}, {3.8517568647346773`*^9, 
   3.8517568654522943`*^9}, {3.851756973762414*^9, 3.851756998621937*^9}, {
   3.851757424108417*^9, 3.851757460662208*^9}, {3.8517575408532543`*^9, 
   3.85175754517625*^9}, {3.851757625602386*^9, 3.851757631897231*^9}, {
   3.851757750130831*^9, 3.851757751060164*^9}, {3.851757869480734*^9, 
   3.851757938973566*^9}, {3.851758022079694*^9, 3.851758036345688*^9}, {
   3.851758134286305*^9, 3.851758194022518*^9}, {3.851758412582055*^9, 
   3.8517584587720137`*^9}, {3.8517603710023527`*^9, 3.851760410976789*^9}, {
   3.851769275728834*^9, 3.851769325407998*^9}, {3.851769473360655*^9, 
   3.851769474148532*^9}, {3.8517695255689793`*^9, 3.8517695294677362`*^9}, {
   3.852117731539773*^9, 3.852117753360544*^9}, {3.852118426338582*^9, 
   3.852118440244215*^9}, {3.852121666707611*^9, 3.852121679000989*^9}, {
   3.852188964790765*^9, 3.852188991186961*^9}, {3.8521891026380043`*^9, 
   3.85218910893758*^9}, {3.852189516325194*^9, 3.8521895555196743`*^9}, {
   3.8521895916259823`*^9, 3.8521896864558163`*^9}, {3.852190552435647*^9, 
   3.852190558779806*^9}, {3.852190650266115*^9, 3.852190682740521*^9}, {
   3.852191382774794*^9, 3.85219138314088*^9}, {3.8521916720279827`*^9, 
   3.8521917858507757`*^9}, {3.852191986161977*^9, 3.8521920570190773`*^9}, {
   3.852192185675724*^9, 3.852192188898676*^9}, {3.852192273905651*^9, 
   3.852192278167666*^9}, 3.8521926636832733`*^9, {3.852193682326067*^9, 
   3.8521937107173023`*^9}, {3.8521937564898977`*^9, 
   3.8521937763442373`*^9}, {3.8521938772862797`*^9, 3.852193900088661*^9}, 
   3.852194264566958*^9, {3.852195407785874*^9, 3.8521954156230288`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"5379821f-f57f-4040-ae58-e6e690f5d55c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"ListAnimate", "[", "plots1", "]"}]}]], "Input",
 CellChangeTimes->{{3.8121878902475367`*^9, 3.812187944500083*^9}, {
   3.8521929112396507`*^9, 3.852192915895495*^9}, 3.852193779380034*^9, {
   3.8814758722503767`*^9, 3.881475873055388*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"62895743-474f-408f-8c10-c0ea2cd2bfce"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i11$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i11$$ = 1}, 
     "\"max\"" :> {$CellContext`i11$$ = 101}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i11$$], 1, ""}, 1, 101, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    PaneBox[
     PanelBox[GridBox[{
        {
         ItemBox[
          ItemBox[
           TagBox[
            StyleBox[GridBox[{
               {"\<\"\"\>", 
                AnimatorBox[Dynamic[$CellContext`i11$$], {1, 101, 1},
                 AnimationRate->Automatic,
                 AnimationRunTime->0.,
                 
                 AppearanceElements->{
                  "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
                   "DirectionButton"},
                 AutoAction->False,
                 DisplayAllSteps->True]}
              },
              AutoDelete->False,
              
              GridBoxAlignment->{
               "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
             "ListAnimateLabel",
             StripOnInput->False],
            {"ControlArea", Top}],
           Alignment->{Automatic, Inherited},
           StripOnInput->False],
          Background->None,
          StripOnInput->False]},
        {
         ItemBox[
          TagBox[
           StyleBox[
            PaneBox[
             TagBox[
              PaneSelectorBox[{1->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.492155743967018, -0.10826003318371857`}]}, 
                 LineBox[{{0, 0}, {
                   0.492155743967018, -0.10826003318371857`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.0820259573278363, -0.01804333886395309}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 2->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], PointBox[{0.5, 0.}]}, 
                 LineBox[{{0, 0}, {0.5, 0.}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.08333333333333331, 0.}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 3->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.492155743967018, 0.10826003318371857`}]}, 
                 LineBox[{{0, 0}, {0.492155743967018, 0.10826003318371857`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.0820259573278363, 0.01804333886395309}, 0.025]}},
                
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 4->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.4692161335313525, 0.21322538516063588`}]}, 
                 LineBox[{{0, 0}, {0.4692161335313525, 
                   0.21322538516063588`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.07820268892189206, 0.0355375641934393}, 0.025]}},
                
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 5->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.4327986097863661, 0.312113865737277}]}, 
                 LineBox[{{0, 0}, {0.4327986097863661, 0.312113865737277}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.07213310163106101, 0.052018977622879506}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 6->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.38514978210373463`, 0.40296699297992544`}]}, 
                 LineBox[{{0, 0}, {0.38514978210373463`, 
                   0.40296699297992544`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.06419163035062243, 0.06716116549665424}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 7->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.328709139778379, 0.4846966796212186}]}, 
                 LineBox[{{0, 0}, {0.328709139778379, 0.4846966796212186}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.054784856629729824, 0.08078277993686975}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 8->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.2657805913708785, 0.5569426042329233}]}, 
                 LineBox[{{0, 0}, {0.2657805913708785, 
                   0.5569426042329233}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.044296765228479744, 0.09282376737215386}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 9->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.19835604197962298`, 0.619858152300118}]}, 
                 LineBox[{{0, 0}, {0.19835604197962298`, 0.619858152300118}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.03305934032993715, 0.10330969205001961}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 10->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.12806158059460881`, 0.6739094807433348}]}, 
                 LineBox[{{0, 0}, {0.12806158059460881`, 
                   0.6739094807433348}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.02134359676576813, 0.11231824679055576}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 11->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.0561760381787445, 0.7197229751208771}]}, 
                 LineBox[{{0, 0}, {0.0561760381787445, 
                   0.7197229751208771}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.009362673029790745, 0.11995382918681279}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 12->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.016318902361279364`, 0.7579838038113029}]}, 
                 LineBox[{{0, 0}, {-0.016318902361279364`, 
                   0.7579838038113029}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.0027198170602132266, 0.12633063396855046}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 13->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.08868152321242107, 0.7893749634931801}]}, 
                 LineBox[{{0, 0}, {-0.08868152321242107, 
                   0.7893749634931801}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.014780253868736838, 0.13156249391552996}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 14->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.16035748982863224`, 0.814544181713533}]}, 
                 LineBox[{{0, 0}, {-0.16035748982863224`, 
                   0.814544181713533}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.02672624830477203, 0.13575736361892213}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 15->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.23093597003587674`, 0.8340883711181921}]}, 
                 LineBox[{{0, 0}, {-0.23093597003587674`, 
                   0.8340883711181921}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.03848932833931277, 0.1390147285196986}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 16->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.3001148358393738, 0.8485484316533497}]}, 
                 LineBox[{{0, 0}, {-0.3001148358393738, 0.8485484316533497}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.05001913930656231, 0.14142473860889163}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 17->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.36767383476578275`, 0.8584097736488121}]}, 
                 LineBox[{{0, 0}, {-0.36767383476578275`, 
                   0.8584097736488121}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.06127897246096378, 0.14306829560813533}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 18->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.4334542215314058, 0.8641057484625401}]}, 
                 LineBox[{{0, 0}, {-0.4334542215314058, 0.8641057484625401}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.07224237025523425, 0.1440176247437566}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 19->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.4973434141852686, 0.8660223478143371}]}, 
                 LineBox[{{0, 0}, {-0.4973434141852686, 0.8660223478143371}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.0828905690308781, 0.14433705796905616}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 20->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.5592634710391886, 0.8645032566452775}]}, 
                 LineBox[{{0, 0}, {-0.5592634710391886, 0.8645032566452775}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.09321057850653142, 0.14408387610754622}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 21->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.6191624387065942, 0.8598547754714878}]}, 
                 LineBox[{{0, 0}, {-0.6191624387065942, 0.8598547754714878}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.10319373978443233, 0.14330912924524794}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 22->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.6770078456935679, 0.8523503780266608}]}, 
                 LineBox[{{0, 0}, {-0.6770078456935679, 0.8523503780266608}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.11283464094892794, 0.14205839633777675}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 23->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.7327817967637447, 0.8422348106802413}]}, 
                 LineBox[{{0, 0}, {-0.7327817967637447, 0.8422348106802413}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.12213029946062405, 0.14037246844670684}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 24->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.7864772626556263, 0.8297277164745097}]}, 
                 LineBox[{{0, 0}, {-0.7864772626556263, 0.8297277164745097}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.13107954377593767, 0.13828795274575156}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 25->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.8380952645626045, 0.8150268057311101}]}, 
                 LineBox[{{0, 0}, {-0.8380952645626045, 0.8150268057311101}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.13968254409376732, 0.13583780095518494}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 26->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.8876427306174102, 0.7983106131385255}]}, 
                 LineBox[{{0, 0}, {-0.8876427306174102, 0.7983106131385255}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.14794045510290166, 0.13305176885642087}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 27->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.9351308590367096, 0.7797408874975592}]}, 
                 LineBox[{{0, 0}, {-0.9351308590367096, 0.7797408874975592}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.15585514317278482, 0.12995681458292643}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 28->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.9805738648370391, 0.7594646603540506}]}, 
                 LineBox[{{0, 0}, {-0.9805738648370391, 0.7594646603540506}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.1634289774728398, 0.1265774433923417}, 0.025]}},
                
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 29->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.023988018144005, 0.7376160367231304}]}, 
                 LineBox[{{0, 0}, {-1.023988018144005, 
                   0.7376160367231304}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.1706646696906674, 0.12293600612052168}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 30->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.065390905069891, 0.714317746768332}]}, 
                 LineBox[{{0, 0}, {-1.065390905069891, 0.714317746768332}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.1775651508449818, 0.11905295779472197}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 31->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.1048008591242793`, 0.6896824926021394}]}, 
                 LineBox[{{0, 0}, {-1.1048008591242793`, 
                   0.6896824926021394}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.1841334765207132, 0.11494708210035659}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 32->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.1422365237470857`, 0.6638141198211621}]}, 
                 LineBox[{{0, 0}, {-1.1422365237470857`, 
                   0.6638141198211621}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.19037275395784767, 0.11063568663686038}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 33->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.1777165159761105`, 0.636808639215818}]}, 
                 LineBox[{{0, 0}, {-1.1777165159761105`, 0.636808639215818}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.19628608599601846, 0.10613477320263635}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 34->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.211259168326599, 0.6087551203920308}]}, 
                 LineBox[{{0, 0}, {-1.211259168326599, 
                   0.6087551203920308}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.2018765280544331, 0.1014591867320051}, 0.025]}},
                
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 35->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.242882331283387, 0.5797364758234728}]}, 
                 LineBox[{{0, 0}, {-1.242882331283387, 
                   0.5797364758234728}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.20714705521389784, 0.0966227459705788}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 36->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2726032228357413`, 0.5498301510901975}]}, 
                 LineBox[{{0, 0}, {-1.2726032228357413`, 
                   0.5498301510901975}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.21210053713929025, 0.09163835851503294}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 37->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.3004383145498146`, 0.5191087347083355}]}, 
                 LineBox[{{0, 0}, {-1.3004383145498146`, 
                   0.5191087347083355}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.2167397190916357, 0.08651812245138922}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 38->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.3264032460154382`, 0.48764049896553946`}]}, 
                 LineBox[{{0, 0}, {-1.3264032460154382`, 
                   0.48764049896553946`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.22106720766923968, 0.08127341649425658}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 39->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.3505127613014443`, 0.4554898814985294}]}, 
                 LineBox[{{0, 0}, {-1.3505127613014443`, 
                   0.4554898814985294}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.2250854602169073, 0.07591498024975489}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 40->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.3727806624393712`, 0.42271791593676183`}]}, 
                 LineBox[{{0, 0}, {-1.3727806624393712`, 
                   0.42271791593676183`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.22879677707322846, 0.07045298598946029}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 41->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.3932197760281557`, 0.3893826187494229}]}, 
                 LineBox[{{0, 0}, {-1.3932197760281557`, 
                   0.3893826187494229}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.23220329600469256, 0.06489710312490381}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 42->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.411841929886298, 0.35553933843658364`}]}, 
                 LineBox[{{0, 0}, {-1.411841929886298, 
                   0.35553933843658364`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.23530698831438296, 0.059256556406097255}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 43->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4286579373288415`, 0.32124107236949995`}]}, 
                 LineBox[{{0, 0}, {-1.4286579373288415`, 
                   0.32124107236949995`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.23810965622147343, 0.05354017872824996}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 44->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4436775871565208`, 0.28653875588449673`}]}, 
                 LineBox[{{0, 0}, {-1.4436775871565208`, 
                   0.28653875588449673`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24061293119275334, 0.04775645931408276}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 45->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4569096378457398`, 0.2514815276485562}]}, 
                 LineBox[{{0, 0}, {-1.4569096378457398`, 
                   0.2514815276485562}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24281827297428998, 0.041913587941426036}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 46->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4683618147452409`, 0.21611697482492656`}]}, 
                 LineBox[{{0, 0}, {-1.4683618147452409`, 
                   0.21611697482492656`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24472696912420674, 0.03601949580415442}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 47->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4780408093372164`, 0.18049136115961847`}]}, 
                 LineBox[{{0, 0}, {-1.4780408093372164`, 
                   0.18049136115961847`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24634013488953602, 0.030081893526603072}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 48->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4859522798219786`, 0.14464984077205914`}]}, 
                 LineBox[{{0, 0}, {-1.4859522798219786`, 
                   0.14464984077205914`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24765871330366315, 0.024108306795343194}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 49->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4921008524473636`, 0.10863666015627868`}]}, 
                 LineBox[{{0, 0}, {-1.4921008524473636`, 
                   0.10863666015627868`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24868347540789384, 0.01810611002604644}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 50->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4964901231359269`, 0.072495350674433}]}, 
                 LineBox[{{0, 0}, {-1.4964901231359269`, 0.072495350674433}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24941502052265432, 0.012082558445738826}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 51->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4991226590717335`, 0.03626891364614408}]}, 
                 LineBox[{{0, 0}, {-1.4991226590717335`, 
                   0.03626891364614408}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24985377651195556, 0.0060448189410240135}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 52->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.5, 1.0605752387249068`*^-16}]}, 
                 LineBox[{{0, 0}, {-1.5, 1.0605752387249068`*^-16}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.25, 1.7676253978748444*^-17}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 53->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4991226590717335`, -0.03626891364614386}]}, 
                 LineBox[{{0, 
                   0}, {-1.4991226590717335`, -0.03626891364614386}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24985377651195556, -0.006044818941023976}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 54->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4964901231359269`, -0.07249535067443279}]}, 
                 LineBox[{{0, 
                   0}, {-1.4964901231359269`, -0.07249535067443279}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24941502052265432, -0.012082558445738792}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 55->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4921008524473636`, -0.10863666015627887`}]}, 
                 LineBox[{{0, 
                   0}, {-1.4921008524473636`, -0.10863666015627887`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24868347540789384, -0.018106110026046472}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 56->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4859522798219786`, -0.14464984077205933`}]}, 
                 LineBox[{{0, 
                   0}, {-1.4859522798219786`, -0.14464984077205933`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24765871330366315, -0.024108306795343225}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 57->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4780408093372166`, -0.18049136115961828`}]}, 
                 LineBox[{{0, 
                   0}, {-1.4780408093372166`, -0.18049136115961828`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24634013488953604, -0.030081893526603037}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 58->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4683618147452409`, -0.21611697482492673`}]}, 
                 LineBox[{{0, 
                   0}, {-1.4683618147452409`, -0.21611697482492673`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24472696912420674, -0.03601949580415445}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 59->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4569096378457398`, -0.25148152764855564`}]}, 
                 LineBox[{{0, 
                   0}, {-1.4569096378457398`, -0.25148152764855564`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24281827297428998, -0.041913587941425946}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 60->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.443677587156521, -0.2865387558844961}]}, 
                 LineBox[{{0, 0}, {-1.443677587156521, -0.2865387558844961}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.24061293119275334, -0.04775645931408265}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 61->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.4286579373288415`, -0.3212410723694994}]}, 
                 LineBox[{{0, 
                   0}, {-1.4286579373288415`, -0.3212410723694994}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.23810965622147343, -0.053540178728249864}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 62->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.411841929886298, -0.35553933843658353`}]}, 
                 LineBox[{{0, 
                   0}, {-1.411841929886298, -0.35553933843658353`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.23530698831438296, -0.05925655640609724}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 63->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.3932197760281557`, -0.38938261874942276`}]}, 
                 LineBox[{{0, 
                   0}, {-1.3932197760281557`, -0.38938261874942276`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.23220329600469256, -0.06489710312490378}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 64->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.3727806624393715`, -0.42271791593676167`}]}, 
                 LineBox[{{0, 
                   0}, {-1.3727806624393715`, -0.42271791593676167`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.22879677707322846, -0.07045298598946025}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 65->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.3505127613014443`, -0.4554898814985292}]}, 
                 LineBox[{{0, 
                   0}, {-1.3505127613014443`, -0.4554898814985292}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.2250854602169073, -0.07591498024975485}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 66->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.3264032460154382`, -0.4876404989655397}]}, 
                 LineBox[{{0, 
                   0}, {-1.3264032460154382`, -0.4876404989655397}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.22106720766923968, -0.0812734164942566}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 67->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.3004383145498144`, -0.5191087347083356}]}, 
                 LineBox[{{0, 
                   0}, {-1.3004383145498144`, -0.5191087347083356}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.2167397190916357, -0.08651812245138925}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 68->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2726032228357411`, -0.5498301510901976}]}, 
                 LineBox[{{0, 
                   0}, {-1.2726032228357411`, -0.5498301510901976}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.21210053713929006, -0.09163835851503288}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 69->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2428823312833868`, -0.579736475823473}]}, 
                 LineBox[{{0, 
                   0}, {-1.2428823312833868`, -0.579736475823473}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.20714705521389784, -0.09662274597057885}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 70->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2112591683265985`, -0.6087551203920312}]}, 
                 LineBox[{{0, 
                   0}, {-1.2112591683265985`, -0.6087551203920312}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.20187652805443304, -0.10145918673200517}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 71->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.1777165159761107`, -0.6368086392158177}]}, 
                 LineBox[{{0, 
                   0}, {-1.1777165159761107`, -0.6368086392158177}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.1962860859960185, -0.1061347732026363}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 72->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.1422365237470864`, -0.6638141198211617}]}, 
                 LineBox[{{0, 
                   0}, {-1.1422365237470864`, -0.6638141198211617}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.19037275395784775, -0.11063568663686028}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 73->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.10480085912428, -0.6896824926021391}]}, 
                 LineBox[{{0, 
                   0}, {-1.10480085912428, -0.6896824926021391}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.1841334765207133, -0.11494708210035652}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 74->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.0653909050698913`, -0.7143177467683319}]}, 
                 LineBox[{{0, 
                   0}, {-1.0653909050698913`, -0.7143177467683319}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.17756515084498187, -0.11905295779472197}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 75->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.0239880181440053`, -0.7376160367231301}]}, 
                 LineBox[{{0, 
                   0}, {-1.0239880181440053`, -0.7376160367231301}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.17066466969066746, -0.12293600612052162}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 76->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.9805738648370395, -0.7594646603540504}]}, 
                 LineBox[{{0, 
                   0}, {-0.9805738648370395, -0.7594646603540504}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.16342897747283985, -0.1265774433923417}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 77->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.9351308590367094, -0.7797408874975592}]}, 
                 LineBox[{{0, 
                   0}, {-0.9351308590367094, -0.7797408874975592}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.1558551431727848, -0.12995681458292643}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 78->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.887642730617411, -0.7983106131385251}]}, 
                 LineBox[{{0, 0}, {-0.887642730617411, -0.7983106131385251}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.14794045510290182, -0.13305176885642084}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 79->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.8380952645626041, -0.8150268057311103}]}, 
                 LineBox[{{0, 
                   0}, {-0.8380952645626041, -0.8150268057311103}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.13968254409376732, -0.13583780095518502}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 80->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.78647726265563, -0.8297277164745087}]}, 
                 LineBox[{{0, 
                   0}, {-0.78647726265563, -0.8297277164745087}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.13107954377593828, -0.1382879527457514}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 81->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.7327817967637449, -0.8422348106802412}]}, 
                 LineBox[{{0, 
                   0}, {-0.7327817967637449, -0.8422348106802412}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.12213029946062418, -0.1403724684467069}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 82->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.6770078456935684, -0.8523503780266607}]}, 
                 LineBox[{{0, 
                   0}, {-0.6770078456935684, -0.8523503780266607}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.11283464094892807, -0.14205839633777678}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 83->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.6191624387065942, -0.8598547754714878}]}, 
                 LineBox[{{0, 
                   0}, {-0.6191624387065942, -0.8598547754714878}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.10319373978443233, -0.14330912924524794}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 84->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.5592634710391897, -0.8645032566452774}]}, 
                 LineBox[{{0, 
                   0}, {-0.5592634710391897, -0.8645032566452774}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.09321057850653161, -0.14408387610754622}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 85->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.4973434141852689, -0.8660223478143371}]}, 
                 LineBox[{{0, 
                   0}, {-0.4973434141852689, -0.8660223478143371}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.08289056903087814, -0.14433705796905616}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 86->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.43345422153140667`, -0.8641057484625401}]}, 
                 LineBox[{{0, 
                   0}, {-0.43345422153140667`, -0.8641057484625401}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.07224237025523444, -0.14401762474375668}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 87->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.36767383476578275`, -0.8584097736488121}]}, 
                 LineBox[{{0, 
                   0}, {-0.36767383476578275`, -0.8584097736488121}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.06127897246096378, -0.14306829560813533}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 88->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.30011483583937404`, -0.8485484316533498}]}, 
                 LineBox[{{0, 
                   0}, {-0.30011483583937404`, -0.8485484316533498}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.05001913930656235, -0.14142473860889165}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 89->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.23093597003587696`, -0.8340883711181922}]}, 
                 LineBox[{{0, 
                   0}, {-0.23093597003587696`, -0.8340883711181922}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.038489328339312824, -0.13901472851969868}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 90->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.16035748982863307`, -0.8145441817135334}]}, 
                 LineBox[{{0, 
                   0}, {-0.16035748982863307`, -0.8145441817135334}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.02672624830477217, -0.13575736361892218}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 91->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.08868152321242145, -0.7893749634931801}]}, 
                 LineBox[{{0, 
                   0}, {-0.08868152321242145, -0.7893749634931801}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.014780253868736914, -0.13156249391553007}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 92->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.01631890236128003, -0.7579838038113033}]}, 
                 LineBox[{{0, 
                   0}, {-0.01631890236128003, -0.7579838038113033}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{-0.0027198170602133363, -0.12633063396855046}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 93->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.056176038178744725`, -0.719722975120877}]}, 
                 LineBox[{{0, 0}, {
                   0.056176038178744725`, -0.719722975120877}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.009362673029790783, -0.11995382918681279}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 94->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.12806158059460893`, -0.6739094807433348}]}, 
                 LineBox[{{0, 0}, {
                   0.12806158059460893`, -0.6739094807433348}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.02134359676576815, -0.11231824679055576}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 95->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.1983560419796233, -0.6198581523001176}]}, 
                 LineBox[{{0, 0}, {0.1983560419796233, -0.6198581523001176}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.0330593403299372, -0.10330969205001957}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 96->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.2657805913708775, -0.5569426042329243}]}, 
                 LineBox[{{0, 0}, {0.2657805913708775, -0.5569426042329243}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.04429676522847959, -0.09282376737215406}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 97->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.3287091397783787, -0.4846966796212191}]}, 
                 LineBox[{{0, 0}, {0.3287091397783787, -0.4846966796212191}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.05478485662972975, -0.0807827799368698}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 98->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.3851497821037342, -0.40296699297992616`}]}, 
                 LineBox[{{0, 0}, {
                   0.3851497821037342, -0.40296699297992616`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.06419163035062234, -0.06716116549665432}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 99->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.4327986097863663, -0.31211386573727673`}]}, 
                 LineBox[{{0, 0}, {
                   0.4327986097863663, -0.31211386573727673`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.07213310163106106, -0.05201897762287946}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 100->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.4692161335313524, -0.21322538516063658`}]}, 
                 LineBox[{{0, 0}, {
                   0.4692161335313524, -0.21322538516063658`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.07820268892189204, -0.03553756419343942}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 101->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{0, 0}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.492155743967018, -0.10826003318371841`}]}, 
                 LineBox[{{0, 0}, {
                   0.492155743967018, -0.10826003318371841`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0.08202595732783631, -0.018043338863953064}, 
                   0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}]}, Dynamic[$CellContext`i11$$],
               Alignment->Automatic,
               BaseStyle->"ListAnimateCore",
               ImageSize->All,
               TransitionDirection->Horizontal,
               TransitionDuration->0.5,
               TransitionEffect->Automatic],
              Identity,
              Editable->True,
              Selectable->True],
             ImageMargins->10],
            Deployed->False,
            StripOnInput->False,
            ScriptLevel->0,
            GraphicsBoxOptions->{PreserveImageOptions->True},
            Graphics3DBoxOptions->{PreserveImageOptions->True}],
           Identity,
           Editable->False,
           Selectable->False],
          Alignment->{Left, Center},
          Background->GrayLevel[1],
          Frame->1,
          FrameStyle->GrayLevel[0, 0.2],
          ItemSize->Automatic,
          StripOnInput->False]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
       GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {
           Offset[0.7], {
            Offset[0.5599999999999999]}, 
           Offset[0.7]}, "Rows" -> {
           Offset[0.4], {
            Offset[0.8]}, 
           Offset[0.4]}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.8121878957474546`*^9, 3.8121879455719357`*^9}, 
   3.81218803698907*^9, {3.851753368679755*^9, 3.851753387309258*^9}, 
   3.851756392505612*^9, 3.851756943429625*^9, 3.851757003951313*^9, 
   3.851757435536717*^9, 3.851757473832941*^9, 3.851757562866273*^9, 
   3.851757639593557*^9, {3.8517577289734697`*^9, 3.851757755841049*^9}, {
   3.8517579033133574`*^9, 3.8517579426161613`*^9}, 3.851758041159957*^9, {
   3.8517581425478907`*^9, 3.85175819957152*^9}, 3.8517606346178503`*^9, 
   3.8517694782006197`*^9, 3.851769533744479*^9, 3.8517696979869967`*^9, 
   3.851769802668839*^9, 3.8518472412901773`*^9, 3.851849595963212*^9, 
   3.851850431745277*^9, 3.851858887881947*^9, 3.8519664203545628`*^9, {
   3.85196645585706*^9, 3.8519664716992273`*^9}, 3.8519665205990877`*^9, 
   3.852189714294421*^9, 3.852190564267267*^9, 3.852190698686198*^9, 
   3.8521913886117563`*^9, {3.852191731689749*^9, 3.852191790173222*^9}, 
   3.852192061658464*^9, 3.852192191731077*^9, {3.852192282450675*^9, 
   3.852192302720662*^9}, 3.852192493258628*^9, 3.8521925841654987`*^9, 
   3.852192669545429*^9, 3.8521928082348213`*^9, 3.852192856996648*^9, {
   3.852192917898354*^9, 3.8521929390312243`*^9}, {3.852193690343691*^9, 
   3.852193714994421*^9}, {3.852193762382668*^9, 3.852193784246551*^9}, 
   3.852195420862771*^9, 3.852197733617859*^9, 3.8521978650383453`*^9, 
   3.852198220940433*^9, 3.881475897311308*^9, 3.8814773222853947`*^9, 
   3.881477559137086*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"cc933150-8628-46ea-b751-edcc7ea3fd56"]
}, Open  ]],

Cell["\<\
Now draw the 2D varying position of the orbiting planet and its associated \
vectors for 100 values of the mean anomaly for the frame centred on the \
centre of mass.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.851857810152133*^9}, {3.8518579015457363`*^9, 3.85185796324026*^9}, {
   3.851857994126542*^9, 3.851858010685014*^9}, {3.8518580568281803`*^9, 
   3.8518580698580112`*^9}, {3.851858121478053*^9, 3.851858198847193*^9}, {
   3.852197421601698*^9, 3.852197476725752*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c29eb8c8-9051-49fd-b3cf-7d258507870f"],

Cell["\<\
plots2=
Table[
m=(i-1)*Pi/50;
posv=position[m,1.0,0.5];
posvec=Take[posv,{1,2}];
rad=Last[posv];
com=(rad-rad/(1+m2m1))*posvec/Norm[posvec];
sun2=Graphics[{PointSize[0.025],Point[-com]}];
planline=Graphics[Line[{-com,posvec-com}]];
planet=Graphics[{PointSize[0.015],Point[posvec-com]}];
compt=Graphics[{EdgeForm[Black],White,Disk[{0,0},0.025]}];
Show[ell2,ellcom2,sun2,planet,planline,compt,Axes->None,PlotRange->{{-2.2,1.2}\
,{-1.2,1.2}}],
{i,0,100}];\
\>", "Input",
 CellChangeTimes->{{3.81218776738144*^9, 3.812187806561784*^9}, {
   3.812187839457335*^9, 3.812187886015627*^9}, {3.85175337730943*^9, 
   3.851753381956236*^9}, {3.851756272938218*^9, 3.851756374502733*^9}, {
   3.851756738242207*^9, 3.851756826933384*^9}, {3.8517568647346773`*^9, 
   3.8517568654522943`*^9}, {3.851756973762414*^9, 3.851756998621937*^9}, {
   3.851757424108417*^9, 3.851757460662208*^9}, {3.8517575408532543`*^9, 
   3.85175754517625*^9}, {3.851757625602386*^9, 3.851757631897231*^9}, {
   3.851757750130831*^9, 3.851757751060164*^9}, {3.851757869480734*^9, 
   3.851757938973566*^9}, {3.851758022079694*^9, 3.851758036345688*^9}, {
   3.851758134286305*^9, 3.851758194022518*^9}, {3.851758412582055*^9, 
   3.8517584587720137`*^9}, {3.8517603710023527`*^9, 3.851760410976789*^9}, {
   3.851769275728834*^9, 3.851769325407998*^9}, {3.851769473360655*^9, 
   3.851769474148532*^9}, {3.8517695255689793`*^9, 3.8517695294677362`*^9}, {
   3.852117731539773*^9, 3.852117753360544*^9}, {3.852118426338582*^9, 
   3.852118440244215*^9}, {3.852121666707611*^9, 3.852121679000989*^9}, {
   3.852188964790765*^9, 3.852188991186961*^9}, {3.8521891026380043`*^9, 
   3.85218910893758*^9}, {3.852189516325194*^9, 3.8521895555196743`*^9}, {
   3.8521895916259823`*^9, 3.8521896864558163`*^9}, {3.852190552435647*^9, 
   3.852190558779806*^9}, {3.852190650266115*^9, 3.852190682740521*^9}, {
   3.852191382774794*^9, 3.85219138314088*^9}, {3.8521916720279827`*^9, 
   3.8521917858507757`*^9}, {3.852191986161977*^9, 3.8521920570190773`*^9}, {
   3.852192185675724*^9, 3.852192188898676*^9}, {3.852192273905651*^9, 
   3.852192278167666*^9}, 3.8521926636832733`*^9, {3.852193682326067*^9, 
   3.8521937107173023`*^9}, {3.8521937564898977`*^9, 3.852193757026637*^9}, 
   3.852193787332144*^9, {3.852194271329784*^9, 3.852194274051474*^9}, {
   3.852194451933967*^9, 3.852194488716524*^9}, {3.8521945462154493`*^9, 
   3.852194548363082*^9}, {3.852194715735697*^9, 3.852194716949091*^9}, 
   3.852195425860371*^9, {3.852195980490164*^9, 3.8521959860900087`*^9}, {
   3.852196063919574*^9, 3.852196079222624*^9}, {3.8521962791328907`*^9, 
   3.8521963093060503`*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"07cff80a-df47-49a2-951a-4fd7d951b15c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2", "=", 
  RowBox[{"ListAnimate", "[", "plots2", "]"}]}]], "Input",
 CellChangeTimes->{{3.8521944929470587`*^9, 3.852194493300408*^9}, {
  3.8814758805819597`*^9, 3.8814758815552464`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"e9a5b3fb-6184-40e7-995c-9c43d06e7dee"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i12$$ = 60, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i12$$ = 1}, 
     "\"max\"" :> {$CellContext`i12$$ = 101}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i12$$], 1, ""}, 1, 101, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    PaneBox[
     PanelBox[GridBox[{
        {
         ItemBox[
          ItemBox[
           TagBox[
            StyleBox[GridBox[{
               {"\<\"\"\>", 
                AnimatorBox[Dynamic[$CellContext`i12$$], {1, 101, 1},
                 AnimationRate->Automatic,
                 AnimationRunTime->21.095776081085205`,
                 AnimationTimeIndex->2.9702970297028912`,
                 
                 AppearanceElements->{
                  "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
                   "DirectionButton"},
                 AutoAction->False,
                 DisplayAllSteps->True]}
              },
              AutoDelete->False,
              
              GridBoxAlignment->{
               "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
             "ListAnimateLabel",
             StripOnInput->False],
            {"ControlArea", Top}],
           Alignment->{Automatic, Inherited},
           StripOnInput->False],
          Background->None,
          StripOnInput->False]},
        {
         ItemBox[
          TagBox[
           StyleBox[
            PaneBox[
             TagBox[
              PaneSelectorBox[{1->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.0820259573278363, 0.01804333886395309}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.4101297866391817, -0.09021669431976548}]}, 
                 LineBox[{{-0.0820259573278363, 0.01804333886395309}, {
                  0.4101297866391817, -0.09021669431976548}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 2->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], PointBox[{-0.08333333333333331, 0.}]}, 
                 {PointSize[0.015], PointBox[{0.4166666666666667, 0.}]}, 
                 LineBox[{{-0.08333333333333331, 0.}, {0.4166666666666667, 
                  0.}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 3->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.0820259573278363, -0.01804333886395309}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.4101297866391817, 0.09021669431976548}]}, 
                 LineBox[{{-0.0820259573278363, -0.01804333886395309}, {
                  0.4101297866391817, 0.09021669431976548}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 4->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW
LJGOfc/OmLEzi+yMKFLv9/c+7zv/zPN55nvvfOfec8498zwzO4ysLt1jWbVq
1RHWVav+e0793wcFVv3f4+GbgWcphOsLvOqdLpwDapELazzhV2H/WR+qQj3l
wwkPVI6QoouNQcZtituHcJKHJ/H6Q0irKQq1J+wt/+ZWho01nMkZqbtJ+NxQ
D3G9HdjZG6cqEo5pE9fxY3cEniMHFbYT5lA1IsY/BSteTevljxS4/DJMxSzC
BTT546+0EZZ8bEDM9wxqju9jJBLOr6eKJgl5gNUTqqQd4RsfDIj5PeFgbuGG
U4RTSyqCQ257wY1vMYkshBOWeS/6sb+AeYPbHc9SKLBVW7vW6cJLqNffanmM
sGCJ7HO7+VfQ8DsjdzKZAtfpJDCL8IcwvUWls4Ql8w7cyLB5Awr8vi9nPlDA
JDHs6G7VQPhwL9o1mPCicZ1gklAQaO+feNCYRIGugCfN0cXBcOjwr1tGhEdr
aGnCr0Pg8LjkqvlECghfW3kRcjsUosftVDgJ/9RnBT/2cOAqyqtniadAMJ0r
2elCJFRKRgs5vKeA/Mknbos7ooC3O3M9LY4CZl0S1+zmoyCRXL+QF0uB7CI6
q1lEDMg//vZNIoYCARqW0hk2ceD0ZfqafTQF8NJTnnFKHDy/LBhZGkUBuYCG
RWnV95D0xl/4fCQFwvvYKhOF4kGxcufvfeEUOH50q050cQKI9Cx03AyjgPL3
hAMUyUTIrgA971AKZF4a4xF+nQgjcg8vNwZTQNzDtCH4dhLsPbVbTPINBXz+
Ncq+Yk8Gk32CJSw+xPpwSgQ9uZAKa9jkj7d7UyCscI9XYFkqLCxrhb/zosDg
0XL7jwfTYP7b9hkpTwpwd41rkDelA4eJLN+iCwWkh4bw6GAGGPbPlMfbUqAt
2/SmU2EWHPrygH+HDTE+Xnbfi9kssBJJOxVpRYFJS5s/QXuyYbqhSczFnAJb
vjD8U6Oz4eSO5X9sJhRYl230jPwsB5I/Xx/eokcB9ag+1yNnPwPjGzlc4yoF
xs2D2JU9PkNcpsM2q8sUMNTn9tYq/gwmIqPx6RcpwPz5zO6ubB60iTqb/dCg
wHZhraVA3nwQ0hb3Mj1KAQsRmsc4uQDqJoQj3fgp0FPQHRb2sBgiSjmz9/FS
4GiLsiw5thhqUqvlyRsoQNG+kL+5sxheVJ6x385JgYs7+WPj4CsUiff2O66i
AHVUv/yjQAnECvysOztBhtK1Zmxfvn2D1pPUx49KyXBa0ObhXY4yyB89k/Om
hAw2LtPebJJl0FASo5RcRIZTN1+GJZ4uA+VIBcPqz2SQ/7b1NdWuDP5u8nVv
TCEDy1QXybi/DPZtXvqyGEAGUHkZZZhbDiOZLxwr9ckQGH989KxBJbQXGz7R
v0aG+ZQiBSPHSrgfyccY1yVDWi3D5mlgJUSaf2NZrUUGI61fialVlXAgZlRi
/jQZWmR8/3Dsq4IHbWUXVnaQodFVXKLybxU4jn6WCqV2w4czZ1Ml4mqgU0Bm
IWywGzb/jo48WlQDRkd5hUJ6u+HNFQ1TrY4aUPh3RfFZRzdkLZNiHdbVAtks
VmJ7ZTec3P7nbo11LTg3O2q4xHeDZXMN9Y5SHfCwJY8l3eiGv3r6exyH64E3
+eLvtKvdcHDVounXv/WwVO56M12nG8gjty1Xb24Au/Ja0egz3aAU/7r8pW4D
cN2+dUHhYDfMP3jtEVnZAAezC6/c4OiG93UCGRkfGuH30h2LC9kkuO2b8zH6
YRNMbx06HTDdBaKL38/n/moBewWLcL8fXZBZF7yHwt4KFbopH56PdIHen6C2
VfytcNf4/MhdUhc09Um6acm2guWqiTTaty7oZ887Qb3TCq2CjjIMvy7gsbpU
u6ahFQxc6nYPSHbB1IHu3Vti2mDgl8LRs6qdcKSKy/KuYgdc2Z9pf/ZkJwyz
XrEI1O4AbW5crXKoE64vmf8pudkBNO8YNnHJTjigt1gl+KQDDinfswhg7QS3
q+E/MLsD/PV2VEuVdcDY9YPeK+KdABpuPPsVOmAyJ0FLiL0L7L3tZQ9saAcl
iyzrJzUk0DCalI5ja4eTbI3Z0EmChO0NIuuW20CbaXGMfYQEGz8+bi1ntEFi
tpPQ678k+P0v4uJIaRvIh5f3hx3uhpHRFI0mmzZw+lWi55nQDcIjUvHHmlrh
3gfBf19dyVDIX09vtG4BuSGKva58D8wWCMVLm7SA3wjd+efpHogxm05wudEC
lulJHmGaPbD3aZ4Nv3oLCGQ9ftZ5twemEkznJkVbYG1SguCZ8B54J8FBKvRu
hmst27YvLveAm2jv0S1bm+CoVvd618peGLxhLWYt3gBXLOdYi3T6gbZDOe3V
2gboN79TLGTYD9cMb0yGTtTDi/ynGTbm/aCaaWvnkF8PExfbD4u/6AcxCYF6
k7P18NH0oqfF137YQnPM+mtWB+n1tHupOwfgUWfI/Z6EGtiZt0cg+fcATH8P
3VXeWwHJqj4CDo2DYLF+5q0ZVkBW0yCxLINQddzSli2+AvS/exiZdw+CgvcT
dbb7FbDO6s+GW9RB2Fol3HxiphyOcNRrHfwzCKXn85S9/pWBhIk9NUFmCOKT
eiL0eEvB5f11kUDfIRAwMl9vtboQ+BR2th1QGgYTvo2/zbEALmWtiHxRH4Ym
qYl9Gi4F8Orih5bT54ch0uz+ubBf+dDvLOqhdm0YphPOc7+ZzAO53X1FYDEM
LpayB2ZacqHxVesH2tth2P/7Q6fsUiZcPnRt7ejUMDw0uFOrY5EJJcZ8i0fn
h8HrsvVbWaKOV+fkbvD5PQzPSYlO66vSIdVGJn072wg8jphdufsqFW7I/bp5
QmQElqR+vbLk/AALFqIOAiojID15Qj8pPgKy8mJWq4aOACR1T3IavIWAN6wX
KyJHgGm0IaRUKBzkOjX5FeNGgKL+RmuzTwiUeX4dO5A2Ahd6L9F4q17DmpcU
p4XSEYivujx1r9sOnIqf8qyaGIHDwboWKqZvsG3g3vNloEJBdbbz8apAPME0
eyquRoUt2yweM3YEo5l2hZX6OSpknxZkGPeFouLiRw2vy1Q4993JdvxmFNpF
aav2P6BCdEyUiywkYPUR6b7fb6iwIbiodjIpE92e/XhZ1E+F+DM6f1h1P+Gx
I4pa0iNUKHWSrT+8KgvN/Hn+BjGokLouPXRTZhbWrY7dYjhDhfQbl0sruXIw
KfY0o3U1DUo96vQbmj5juCDj0VZJGhhuNo/OsyvC33Psw0dNaJCt8S/WuLkI
BcKv7zv1kAaPVB6InJApxufGRVOnLGkwwDH9zGSkGEc1rIoPOdBgYu/VxE9X
SjBzzp5v0YtGnKdfXdfuKEVeoV6RhkQa5L+95MUtVoG5D5PHgwZooHREbyFQ
pwIpt30DTEdosCSxi0XOuwI5I8bvn2DQgF9BcSpnugKvSJ2JbZmiwdY3nfuH
Kyox/dqgd+kKDYx9/Ab6ravxyLSFWLYoHcL9DbUnP1Tjq6T3F45upYNPPJ+h
QF81bkdzvaIddKj4wribfrYGayTiOjOl6VCTMTvPKlmL1uvUOvSO0CG61sPy
Yl8d9m6zeJZ2kQ53hvYnjwrUozZt9mSfLh3OiKjZRpyvx9SqnRYc14j3mzAq
VP1aj9KPj27UMaDD392bG8uiGxBzOJOjTemwNcZ0UdfoO9aqv3PZ5k4H14kA
dfuo7/jXPtH6pycdUmS5/qV3fEeWgKdWVd50eGU+FXP/TBM2sc490vWjw8Jn
zz2r9zVjR53z2M5wOsx4N44NurWg1j5vr6Q0Ovhbc65PjW5BlhKl99yZdBAL
F2h2/dKCYlsuh1tl0SH3kPp+TWYLOllL/tqeR4fTG7r5re63Yq7Kxvaj3+gg
GR/YNqjThiG/YgQUmulQmHLiq5FVG8rX6eQfa6VD5LTnphm/NhRSWVVzuJ0O
Aq8zBWRr23BFcVBElESHo3oLZXLQjqTrNZVB/XTQ4RS3vyzXgafTH4ueniDW
lxSX8kqrAx+KuJh3TNLBN5bG3WTWgeayYyXG03S4aCmiZ5/SgaTvfsoWc8T1
jc/uqot3YuyNf5wyv+gQq7QmokuxE6ni1m98ftPBykWUZGPYiWXTq3v7l+hw
2PKHfl10J27Si055tEKHgrU5P5Y3deErI5PzmiwMqKJVto8c6cKZvlwFS1YG
3DC6EdV1pQvZJ35k+rIxIHxNUFpvcBfmZWVKpK5hgGP06dHpnC604HrO92kt
A2ZsXoxxt3Vhk3azVfo6BrROSOx6yEPCyZB9em84GVDp2H85RY6ENn4WHQ5c
DMhuZZGb1SYh3n38/sp6BuxttWyK9yehbrQ4zx9uBtRssvfmyiChwZ62+IoN
DLh88FaLayMJd62xfOC5kQGmQlZ/n3N149KF+5bjPAxIY2uuW5DuxnmHFF8f
XgYE7+rKtFHvxtbMo+Vb+Rgg98kj08O9G9/aVtse4WdAiO6lEuHYbnyh7tpf
QBjcxZoKvnajc81vbXkBBlxfr9jH86sbl63DpfgEGWCneay5XpCMsf133BwJ
K6bbpPofJKP0G8WqTsLvul4/uK5DxpRjLLN7hRhgvizJus+KjFmWdn+cCXNh
vh2XPxknUm4NVRFuksjLnU0lY5u2X8TaTQx4bO/2dbCWjNZF5VuVCafvM37R
TSfjYcXqh48Iu05GcZPZKDh++Lrje8JUXV2NYXEKfv594nQ1YfbFuP3zihTc
/HvvlxHCzRovcYMhBVULR4d+Ezb1YJk64EJBKfLunHXCDIh9PfbZIIqCfeIf
JXgIq8zzcAd9Icb7iu3/z6mlB6abSBQMO3iy9b/rd9su6AosUDDGq3DVEjGf
1/DPg0YCPdgmpVr43/udPfD5RaF8D1awB8xWEdbNjD+zSacHyaZnPsQRvl65
zdzVqgf3zoq02BFWGnGYnPTvwZcx2Q+AcMzDwYp76T3o0VNgyvrf+BB3Bq2+
B1+97GhEYr2ot8wvWv7oQRX2zFf2hNkfxy78XduLpbt/xO4grLprTVv4zl5c
vrObtYbYjxtHH1OOqvWiZjrPp7uEu2lf1g4b9+JCAsQsEfvbWuGkE+zRi+O+
V2p8CH+OHRDeUNqLPKHpef5EPEhWunmR+nvRokbKgo3w9RPREykrvXhLYEHd
jognsurDF8Yn+rB/6O+ZY0S8hdk++Xhevw8NWEyM3hDx6P4P40896cOfAe5e
A0S8dkc1LRwp6MPJ4F2N94h4buLXAejqw8j73cPRRLx/D3Q7fuFnH953eDna
QOTD1B8bCe+D/RjCcTiZl8iXVc7n/qZf6kdq/3ldaSKfWJYX7/XY9KNaUmLH
EQ4GnOQWyNPO6sfJB+dOnSDycf7rlE9wcz+WTGRvOkDk6yZnh/KBqX4M9vTL
2MrOAK1vT0+/lh3AGvea2UEi/4P/bj2lnDaA6Xttd63+S9QH444Ys+8D+Ocq
9W34HzpsX6d+MWZ6AKVucvJLLtNhMz/ly3rRQYz7arVqG1F/jq39FP7l1iCq
aLzojpqlw8a9+Y1TVoOoq+mRMkTULxez23O73AfxeMweEJsi6nWs3lxSwiD2
zbjHPhqjQ0fw0/nm0UHU0LuuljpMB+mO1H6JpUFc9m0wjhkk6jX1iosT1xAy
tH+u8SbqZ9sbUuHhfUM43uVepEChgy5j07lOuyHU1VKY2UzU442reNO//BtC
t+SV+4Nf6WBqOcqrxjuMxW6vfu0qosOkQVZyu/gwigzmvLxbQAfF8URYUhtG
hqZq8NdsOqiUmEqZ+w2j8Ae5S4wkOkCUYA5FZATxXPGj7cR5M+8T0hgiM4Jm
jmuvfPYh6u9xF3edUyMox1j5fNKLDmF6VUFtt0dQ0EaMtMeVDkey+o7OJY9g
3rBptZMVHVaYNV7vjlCxhLJi/eMCHTLMLkedP0PFhGDH0XXn6fDl1727f65R
cXID97SYBh12sGyZvP2Eiop2kW+kFelACx0in/xKxT4MckQ5OohLXFtWUKYh
i6SYw9R6Oli25s7/uUTDP4YSf4zX0WFx3XmuCmMaJqj7fmpipUPLlU8PLnnR
ULo+y9tziQa8EimNzrU0nJg+q/OQ6CcSnlC1FrXpaLByRWkX0kCz9PXNOkM6
+gkfHpz4QoPT/CzUKGs6uu9bezH5M9GPGB2UVw6io6Sqqt/SRxqIeMhEBXXS
cdp2uFckhAaVdxrGj95k4KrSfZIKRL90uLZk+ZzpKKrbCnDXEv0VRy84uTiN
ooyhlenrJSoUxfW0ZfqPYqPlGqo6kwpzTs713DmjeG5ycMtrKhV0OWc2FS+N
ov2ujf/sq6kQ6s7dWvnqB3aYipfHvqBCUtHUmq3pYyhTeU9V/d8IpJ9uleP6
NoYbFHquqC+MgHFDGvfP5jEEKeExhckRqDqzOfYbcwwZpJ5X0xSiP7ZpF9h1
Yhy/9KldyMobgR9pfXMn68bx0OUzY/YPRqDlwlnthaEJ5Cy6enixfBjsFX89
ZWNO4BH/KNPLhUR/fytXmpttEpP5L19LyBiGrSe8i7h3TqIMZ7W+ENG/x1Vd
i6ozncSq5n+Mi+bDIJWar755ZhLv7Q8L38Q3DJ9fXA+IWpzCdc43RscvDcHO
HyIN7Wun0XH4b6+b+hD07P7IxSY8jV57NUPYjw/BHlehs+ePTmNNndkl+vYh
iNv3wf7J42lU5b92ZmVyEI7dLrI9tDiN9Tlmpz29iO8/hg8ff3eYQSGRuKfr
Lw/APcmSlx0uM/hXf/P5t8cGwMu2YDXp+QwejzojtH7bAPyJvLj8PWgGL1yT
KUj70Q/cMt/2embOYKE6+85Gl35o4QF2VtoMzmw32h75vg86Ff28tmjP4oCW
83I+qQcC9+8IcLs8iwsH/fuvFPUAX7rDeK/+LJayGEn0R/dACpfLU+/7s7gt
/x5X2p0eMO2SZw95Novf869MKYxR4K3nWuvA7Fm8dafSWGaRDB3WIYY9G+bw
3KW9nyZXdcOPVh31WYE5zNxYekqinwQ/ywI0/onOYf7ao4WKxSSwsG9xYN01
hy+c9pEOPiKB24nxW2mn51D0sHf4CqMLCva+i7Y2n8MqC7WKI3Wd8HD1Py9W
2zks36AduJjYCTTeT+P+jnNoH7F7dfyzTkjdasXu6zGHI+r6Jz8rdMKaniqT
TW/n0H+C70FrYge4K+t98CubQ4ENLeEcTu1gJtFAC6qew4urj3TaXmmH+bX7
179pmEOVrvHkGrl2+LCLa8yycw6zNmgGHaK2wX4no7mS0TlUDErcs+18Gxyx
W5sQwc1E1nvkhCvCraCUKneCk4+J0smeKj6zLfAiUfyAjRATRfONPqTUt0CT
MKuQ+DYmsks2a+Q6t4BCyA7qhv1MdJNYJTGKzTD/7W4N90UmfpmifvdV/w4r
11ZmY3WZqHR1YbXQn0YoLD5yfvc1JvLG6b7xzm4Envd6j3fcYuLpngUU3NII
Qf24MdmMiVL25DDmdD2YB2uZsngxsVvs7ENGUC2wZ4zNsPkwkewRo92tXguL
1Rd1/r5kovEDkZLspRrYu+qdT+cbJjYuxmttM6qBLgnDs4LRTCwyedA/IVcN
Oz43snZlMVGzQ/RNQE0FvJTfMqySy8QLm4Q37HlaAf5x1y6m5DHx8Z4mr+y9
FaBGu9N4uYiJyfMLXj6B5aAbXNdxooKJ3L+tvt/SLwOlmwKVBlVMXH9qbrPp
+jIgfXsi6VDDxK3PrLKMvpVC2ZdLe142MFEih69TUrwUlkZpP063E+vVX/mI
0loC994prhboZGJMUkYD81AJXI5tshzoYuIWuwcGM+FfQS9OUfE6hYkLJp5B
oQbFcL9k78PuQSbKPgxlxDEKocHrzqDhMBON3vJ/o54tBD+v0dC+ESZmqdiH
8KQXgCkt93MxnYmKjgdSxK3zQbBF24VlgolBv9doKS3mwq3jnlGHJ5lY228S
MXcjFzYJSmoYTjHx0dpgh8DSHAh5sqIaNsPEnMLt+yJ9s0FLwDswYZaJlDGj
fexTWeB2cfO95DkmTkXJcd2+lAUdXgWRQfNMPLd88GLz4UywDX31+8lPJt4J
mdsq8zcdPj1bQ762QKz3zWoVs+o0yPmpILC4yEQSP9f+mKsfoc7imEXhLyZm
yxtoBG5NAdWPjkrWv5m4FPhMz5L+AQZ3TF2tWCLu93A92+ijRLhPmg69tczE
SnI90/tUAsC5Ms0ZwhZSms/42eNBn2Hp+PgPE3W/n+x43RgH6qyCwouEJWLc
D87vioXBvoG95itM7HfWWEjPj4bsJK48EuFw+SK1c2qRsNOJ+unYXyZe2bHB
sak9HB7aVW8JIrwxq3TghFEobIwSWx4kfIfq1xkyEwT2v+6d2/mPidG/7mX2
uL6BIX8ZTiPCGkNDz6RE/cDyBufxEMJhd/5UPD7yAt7eziR/JawmvqY975IH
xMa0j/YQji/Xyi/vewrvBdTvzxJe2GrBv0rIBqzrhy6vEI4N87zz+agBSNUE
Zf8j/HBX1IrJdxV8JHTF5RdhvXXyzHWeD7Cy5lAh47/5KrbpX+RwQNqkltF3
wkWpCjvXtrph0btGp4+Ex296lV1ofI5WcxNszoQLdLi41mX54guW5RVVwvlK
CeXJwa/xw+il+2yEk6QqxEKLA3F9yW2lIuLz7/397q6abAh2hcT5mRCedu42
HH4XhuuevTvLQbhQ7O0XU54IVHyx8DieWN81xUpbyO5ReOTj5c3yhKM2Osnv
Y8Ygk2R/oJDYn59cEboH5eNwe9vxr8nEfv41z9p7MiEec6VS5HkJ16fJOH7o
ScDVASbbbYh4EBl9WLvCn4SGzwRMBIh4YU+ldFs+T8bJqHOl14h4WpQ0U/P+
moLNY7fCAol42zTgxe89/xHfXjAoHiXi8+mWxgPH76ajpuV67jWEv7wxODAR
lYFu1RKDIkQ8N1przrq3Z6LNmXIeKSLeWV+Kc+55n4VPZjPq64j8CQyI1D22
MRfp+vST7kR+qa6/+fVbQS5qVp0Olh0n6l2mDPe+259Roq1m4e4oEb+rx51q
svJQQGU/Q5vIX56lnQdaLxZickBNTQaR3xwTeU6Bvwox69fbhNUDRP5Z7Rs8
HPcFz/1ep+/Tw8QbLZxC0tNFeJ3dR5yvg4kng/ZLvntVgtn91SdF2pjY9O/h
HjP5b+j3M9JSsIWJlqOfgoTI3/B6cqH0JFGPAva7Ulj4S3HrziOmokQ922O5
v0rYsAwjL/jPWH1iYsiyQ2IgswJvi+32qk9n4tnDRafL1Crxhbn6E9FUJkqa
qDhTwiuxwzkzJDKRWK+N0d61J6owZuD33i0RRH3MPm/p61GN36TGqnc/Y6J5
beS+y1x1mIRH6L3OTPTgv7/080Yd0vYKlXo9YeJqO6cdzul1uNGl7muhLVHf
bj45fkirHgsmLF8n3mViWfTbL+f8G1CyMNMiQp2Jm9vpWxvWNuHbXcHtU8pE
vYoJEtfUacIMDUw6AUxMq+KrzYxsQh7lqg/FCkwcWtJevV22Gb+5zFdekWZi
qbtUiY50C+LuuOHFtcR45a8LfzRa0fVc/3Q1K1Gf5NaSG8xbkTN08Lv/vzk0
lhb69PJNK3LUNAixLs6hn/u7ShKpFemPM9760eawOFbSPf1eG6adeH57B3E+
d7nO75R2bcc59o/p1l/nMG8HTflHXDvOvzM7WlgwhxnNSzFvK9ox90SVzP7M
Ofx4ViW1bF0HlvH6aFdGzmH2+lid40EdSNp1nf050S+wq93dlvW+E90287SG
bZnDXfRGXo4cEv7bOCH7XGgOe16yvRbuJKHzd8EgU545fFekXbPxFwnv/vwa
sYWN6Ce00zjzTnWjTDy5TnJ8FlviEwS7a7rxy4zfQHXBLGpejhE1I5FRfPFt
UrTmLHLc8pfdPdKDvhfDbWNVZ9G48N5TVtZeNJayiIk6NYsxxr2N5eK9uLks
4OgzuVlMO1BycuZOL7bPtRQu883i1xBhC7aBXvzmy+Fb1T2DEp4hHGwdfZjf
JEmfNZxBz/BpjpWUAVxKF1urrzeD0r+rQ7sqB3ByWF245OIMenXucAoZHMCS
oj+H7JVm8HTb77B+rkF8ZGnonCw+gxHTsXG3lQexpGNT6dXaaQw0+vmuOn0Q
H0uHFw/VTOEau1xdNschfB3GfyysYAp/cPFR5TyHUJjks0cleQq/iG5V0QoY
wnWJP794e0/h1imNBwbJQ2j5Y+FrvuoUuk8HH2jvGkI+Cb3KBpxErbRGSYGD
wximILxbN3sC1wf0eIwPDuPc1MYfRu8nMKIoNydmbBhtss4csQycwJXsBX+V
+WHc8VQhz9FmAi+ojmo+XDuClef5Jq4dmMDl2+u5JWVHMLvu1SX9rHFMEyvh
O+cwgquH1xt9TxvD5TLuaMt/I5gsbGVqFjWGFup/2yLWUvHRo4WmNa/GUOe6
91LhRioeGXUeP/xwDCW3v97Vvo2KS2E/Rh2kx3AfyUvHEaioFLmIAYk/UFq5
s9HdmYoD85eCHkeNYqsv90LhJBWt7vUz7H1HMdxZjf/3PBULOGU2WjuOYv2l
G69l/lDxnNAwj7HuKKaf+/D5PicNP1qn+J/iGkXr2d1Gp3bSUOyuUFjrUwa6
zxabG9+goZGj8/byBwzkfygh1XiHhhnJr8xyrjKw7u6aqF0PaFgxXe8cJM9A
uxsF3fn2NJzflrnp0hgdK5VuXVTwp+Hj/KoLPdfpWB+dsVBVTMNj8xSrpjN0
3Hx+/VuDMhou1obuLT9MR0P6pTuj1TRMbTbKSuOlY6HykxekVhqeqGI571NH
Q2dXWcYWBg1HGM/HbI/RcPfI5yPnNtIxudj0vZEoFcUFLD8aXaXjncOyBdkc
VMwxUadL69NRR4USz/J7BEujlpFqQMeY6ytbU0kjuLfwtvGpe8R9meRF84SO
oIZN9BY7Ozo6VMryq/CMoH2D5K+f/nTkfWjhnftvGH+ue88qEkhHPkO/Kzun
h9H473p++RA6Up5w7OJvGkbZxYFr6pF0vJn41IbTbxgHq+UO/Eqio5PF3fMO
64Zx5GIDw7uYjqJzDCGeX0P4V1dOg/sbHYeVG/LSGUMYUXZQ6GUpHW+3rvGf
qh5CV/sGwftVdCybIN0N9RpCMVb1W5+a6Lhn+niY+qMhlGnIpv9ooWOU6Y32
pbtDeK3pJB9RQ3G0J/CVueoQBox5W9wh0bHEVTH9EesQWt34O+M6QEeBNt15
YA7iDN1S22qIjrv2XnfmHhnE7dTy51dH6Jil+uBeTvkgZr1mD+dgEPc/JntW
0mMQZS4lbWCdomP+YslpDttBPKzbO506TcfaE4ZJs3cGMcJqZODsLB1PbXLr
a1QaRKberbUW83R8V30iOmP1IGZqMvefXaKj2CG13L8jA9iTzX8/YZmIE54x
iY9EnWCr5Tj28w8dD0f68vB7D2DCqeE6t390PJ+4Q+EkxwByiUvqHGBj4Akl
ZXfhsX4Mam7bdJadgSfbPvH9qe/HdZ5SGXprGHjzepQ82a8fU4WEDAzXMVCE
+5z9BE8//noY7cm1noEqEctr2Ob68Lsgw3qYsGGDvKxEex8W3fQ0zOYm4ly4
Tu9xaB+y3v99XWEjAwV3KVlnOvShm+Yj2ynC5ZPWMHGtD7WXvZNieBg4yTwv
7Sbah6u8k+ypvAwMFbfV7VjuxaLP58Wc+RjoyqN0/UBfLx5S/fabi5+B17pV
lcO+9WJaoipPCOHjy/NCrHG9KLFt930BAQaaPsobcHTvRf/GXDZ/wsttXYnz
Rr241l9meoWwz2cxtTU7ezHMcbGiVpCBvRTP/VFre1HmV1uRuBAD+y41Hj36
owepu1I3PSIc/Ylxr6++B++dKxlEwrVvcvFleg8WK2huYd3EwDcFS1qKr3tQ
/nJgy2nC3psfCf+16kE1nwZWO8LO/2p2Vur0YPTRQ19jCVuv8X4WdLAHt55m
W1VF+J6GnKypYA+K9dt2DhO+fP/AIY1FCgaX5yn/JiyVyIiWI1PQZW6V9jph
BrowIy23FVPwYL33ykbCtXweWZtiKPiL6XiNh/CWmDJTYTcKOt9mNeIgvGe7
+fsddyjoC1cllon5dh3wuHVQhYJffkW9pxFucJ9L1pKioJrk3+FawvI/I55b
r6XgqGfiZCLhrs8qy1E/yNi+/LnmCWEbtY98LQ1kzH+l63iG8FKUbev6TDL2
nYln2UDYU/7I6UtvyHj/UpnVd2K99oo9MYyzJaNbR1OlF2G2bZ9OLF4mY8ki
fa0C4aVvx8lXFcgYOCABQ8R+FN60OI0iZCyOj7F+TthD7YXN/j/dOKT6MH47
4R11BY9T+7vxYFYMJY/Yz2xtMX3Zsm7c+ensNlXCzqZVm78kdON+uotDAxEf
i+yl18YfdCNXeo59FRFP+mlfBvnOdmOqdWiLDGHn5Se/VXd3o5PQzR0vifhr
r7JfrP1BQgNbndJ9RHzO9XGMi9aTcPBul9gjIn43bN78yjGVhHZx469zNzAw
wdJm4qIZCVujL9QLE/HvvXSr+LsmCc/doyQAkR/HO0QuXdlLQh4Hi0+3uBiY
PHBt9vlkF4Zo/nvqxcHAeNpQqol1FxZSdQsciHxcqEDz4zpdKJ5eNG9I5GuX
8j9pEfku3BRgH6fEysD1BTdTFpmd2LK/4vbUKiJfPkncPfa4Ez/KS1+ZIuqB
yp2DUfeud2Lt/ZjOKKJevNzNthR9vBN5ZWr/Kf2mo/NhUVXZlQ6Uzky2fLxA
R8vPkpEdHh3YeinM8/UMHbV9O2P173Zg7U3KVhaiPp1Lzvw5rtaBvnTFd5aT
dFwbFZe4n6MDD7veNpEnzqmksz2vld+0Y+BLO9o9ov4ZMA7q+sW1oeZsVp9H
Bx2VzV8+qPNow8l/O4V82oj6tbGXh4/oCw+CX6I3UX85Eoqkq3e3YfFT1gGr
Rjr6nyro/JLbivX/GvyYFXS8pDo001rXgts+RDRVZdNR/TXvseLMFrQ3N87x
+0RHb75MzAxuQa4bs7u0M+g4K+r55rNBC4peEO4vTaFj8a35GQdqMz46u26D
SSwdI1d1L1gdb8LaxPK9n1/RcY27jKgfexM+aFnJ3ulLx4fefXNfW75jSNa9
rSHedNS/4tV88/53PHguqszQnY5Vb2zcQkMbcUF6obzIgY7WsaYVEz/rUSvV
d//z23RsZl9z50p5PUactA1OJs7Lx0N2pLbX9cjV8VCumjhP+YV/Xl4vXY/A
7bPz52U6/ohu+/KE6Ps5cvyjRc/S0f2syW6oriHa8I75F/vpaHNsZNWTtErc
1dK0esMfGl6KpZrccajEV1MXtuj9omF9TrqhkVIl3mQZ14qZp6FZSdGaTFIF
/tsQzi0ySfQjMc/5zNkrUFS4Lrarj4Y03zoxj3tlOJP6YK3VNxpSaZG7Bay/
YqXuw9gTzjTkvOPEx7b+K+aKKToyHWnYCKvTJVOK0VeNSyjZjoZa263Ji4NF
eED+SMlqMxruXdS1pV3+gjk5pUpe12l4w2i2n6SWj5ddWYPrDtOwf4yVha6Z
hbQekW7TcSpyy6tf2zf6CStru+AnnYpRdwunRo5+wtwAZXeXYSqSvAwyNXoy
8IGBaNxzMhUnIy9WL0ikofRCTp5FDRX/2SxHkiqT0Jjb1T4znoon/XSUrHzC
cMPZelnWa1RM+LnGiTc0EFR0123LLxjBN/MHXiVVBcHx12v4MnJGcM3gXb34
n8GgEPiz/n3GCIruGKjt0g0Dvf1ZEc8TRpCyyv6OHEcU/LFRW5QLGEGdTWnG
QzLxQL7xYON2kxE80Gu5p045DaoLrDkf841g96FTp9Q186EkBO8E3iP63cdg
PR+cDxXXdFTCDIexaLRH9UlvPqz3Uz4dcX0YOV7Ycq21KID1LtteRWgNo7Ba
VOQhv0Jwuyrc6Hl4GA33schSy4sg7Kv1idXsw9jS5kj7xYsgHErOyY4fQi13
pfz1MRWQWeLvY0keRMFIlw69ogrQ/WRw7Gn7IIZucnMKIVXAwRzPquffB/Hq
YepTCm8lFFzWdwgrI/qIlReD770q4eWix/30j4NYWzGmLfGwCmoXpCYSngzi
Jm27cuFdNaDG36HUKDyI16+dsOK0rQcnc4FfiSn96OQbSvX0rwf/Xlm+o1H9
eDv8etp4Sj3k7dC9VOffj5Pe3zW8B+phfoJHh27bj4UXY5+PajZA6LH4GM5T
/ajV/3L1/R2NsPvsZp5/LX24/YVWqBN+B6FOV7u0xV5UlMgXK77bAgdMPxd8
UOxB6VeXT++0boGEpm+vRYhzszvXN9HXqQWKJG6cfiXVgzl/HbWOBbXAM/kX
cmacPfgv4YLxSWyB+JNFQWIdFFzHdmd3x6ZW0DN+t1n7PgU75F5K3KpoBefC
B+/G/cjIp32T7sDWDsHPslmciO+Lx1q6Fe5xtwOtx+hFbC0JvTKqHmgJtcOB
O7FmFcUktLBTsOGSbof7qQbXOOJJqFOy6+ppzXaIus3d629JwhXud8fc37RD
agMp9OlaEnoKZtj4CnVA62+hK2NHu3D6O4O5kbcTCnl17+tHduDODS7GO0U6
4XSXa626XwfW/Homd2RHJ+z7+iRf3rUD1fObaUoHOuFQ/tRJDqMOVKxi5+TU
6YTirNmN2bs78KOs1DbDgE4QEM/+OFHYjizmFqEya4ncynuzX5TUhh9bbCdK
R7qAf71mjAtfK4bUZdBafnRBC3UvU5W9FXfv3vmiZ7oLylyL+Nb/asFD5d9q
B5e7YLX+fFZEXwuiaJdVGj8JBk5bPM5JacFKhU/Bysok4NtSkEg53YI9qa+3
e0SR4DnzfCRvVxMqT5f8+BFHgiC5irchxU04S1byOf+BBBSfFo1N75uQtSTs
HEs2CT6uZi/bbN6EO+l6HPurSSB/qk56B0sThmZpB4VOk8C+TcJn677vKB+Q
9DHwdDd8FxOqHfVqQNuhrYmnVbrh7LWm2VGzBmxMZH6nn+kGsvM4fVSnAVky
N3+W1umGFfXyw6NiDRi7ccsPW+NuqGiNdKDm1aNmxSBjx4tuUNn6YU0HrQ53
7G31n63vhjNmovuC1Wrxtv+cx5rmbuDYcofiL1OL1sWZtULt3bDhiYyxD28t
Jo13nN3dQ8z3QHy9S18NbmhOOSU03g2P/aD27qMa/MOq+42HkwxFWYvn9iVV
o8v1o+6vVcmwNL9NN52tCj98nDp/Q4MMtPiJQxajldikSsoXP08GUQ7OP7KN
lWh92cn0vS4ZOLZOn/gUXIksibfu3zIiwyrbna+zxCsxfGpnGsmVDKu1HLsy
FSvwlunmA025ZLhq6/Aq2rkMlV2mcmfyydAZfbZL/3YZvq5cZnIXkeGG1BKv
iGoZ3olT/nS0lAz981sMQrnKMHN97J4LjWTw5b56zj+yFMN/ps88GyGDFU/q
k5/WiA9+CmqvcFOgrGLdg6jRYvwxvSpXm4cCLAO0nt7cYlzcLBIRxUeBvSYv
lbe6FaMbY+P4rk0UkMm79iNOsBiHmYF5nNspcGKWLSlJuQjZhiQNfu+nwK5P
XLwZ0YWocuKPIOtBCqg1WbZN3i9E+mEXvXWHKRCm3fJy38FCPPTD3pn9GAVu
czgOfaorQMb5Rq16xf9+r+64N2chH3s38rq5XqDAjNzx+3kX85B0y4xLSYcC
cbtKs39uzkMfvw7pf5cocE7BceEw4zNuaPcWtrxKzHdZyirf5TNmBQiShAyI
z/OdU7wgNRcVtifsCTGlQG1X4KcCthz8JJT9a6MZBax7Mz8tNmfj+SyxWy/M
KbCeTSddISob2eafzTywosBSw7uoggPZGPTkyKlFewqksAdcKbiVhbuAq0zR
jQItfxejzG0ysKzXYCjiGQXSdgZJJS+n4zfpTt9Jdwp0OnqmDnml44YDTfbP
n1Mggvtc8tXINLzr2V5i7UuBv6EitooVH9EQFfe8e0kB8N/b+1TrI17dM7ij
+hUFfNJ2quSRUlAge8tn9tcUkFz3ZN2eiWR88XC1pUoQBT5a9NnzC37AZ2nP
TqkFU4BfxLleKzYJf8t1RiqFUGDZZu9Wn91JSFu1f9WeMAoEhZws/XMqEaPr
Mly+RFAgQ1BmjmYSj0caRyoCIon1vGhzYvvse7Sf3BV5O4oC+y7EeOo7vcfN
T0mLs9EUOHNsiac5IA4Lne64tsdS4NbTNBVrmxgU+/5e0zWOAoXKpbVUr2ik
cmCqxHsKSGR9OX89MgpjFfS23YqngPtKuY5yRQRG/z14mElYdYSlPZ/0Fg8Y
pPd5JFDgUPgLXZmJcPyrv50RmEiBnE2ZlwQEw7AgxFKDN4kC0UF2rT67Q1Ey
6u/JV4RbrlRdWDkVgtv4HQctPxD7dVxdk24ShIdoiQHdhFd8X9fqOwWitFps
28lkCuyMCFVrDniDIUq2Aj8Jl//hcrW28cdpdk/+sykU+Jz6z+F65CtkSWn5
EE6YuSnXSrnCF8+L2jUNEpZWkX8gM/ECzVKevZT8SIE9wS9uCwh6I+8id48R
4XPMYr2VU89RgG1faRThmumui3QTD7TfOXesmbBvZ79Gc8AzvLXhocYK4ZNR
2e7WNi64vyphXCqVAuGzgTbKFU/waUaaxFnCTVvu3REQdEBuT78ZE8LWC3I6
dBNbXNC/cMmNcB9znBhvga4JyxpBhM8v2hLXm6C8ZHhHLGH1yGnidQOkrUj9
TP7v/zLN/1kL////NFyqjqnwMObr/wBDP+3J
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.07820268892189206, -0.0355375641934393}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.3910134446094604, 0.1776878209671966}]}, 
                 LineBox[{{-0.07820268892189206, -0.0355375641934393}, {
                  0.3910134446094604, 0.1776878209671966}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 5->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.07213310163106101, -0.052018977622879506`}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.36066550815530507`, 0.2600948881143975}]}, 
                 LineBox[{{-0.07213310163106101, -0.052018977622879506`}, {
                  0.36066550815530507`, 0.2600948881143975}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 6->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.06419163035062243, -0.06716116549665424}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.3209581517531122, 0.3358058274832712}]}, 
                 LineBox[{{-0.06419163035062243, -0.06716116549665424}, {
                  0.3209581517531122, 0.3358058274832712}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 7->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.054784856629729824`, -0.08078277993686975}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.2739242831486492, 0.4039138996843489}]}, 
                 LineBox[{{-0.054784856629729824`, -0.08078277993686975}, {
                  0.2739242831486492, 0.4039138996843489}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 8->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.044296765228479744`, -0.09282376737215386}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.22148382614239875`, 0.46411883686076943`}]}, 
                 LineBox[{{-0.044296765228479744`, -0.09282376737215386}, {
                  0.22148382614239875`, 0.46411883686076943`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 9->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.03305934032993715, -0.10330969205001961`}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.16529670164968582`, 0.5165484602500984}]}, 
                 LineBox[{{-0.03305934032993715, -0.10330969205001961`}, {
                  0.16529670164968582`, 0.5165484602500984}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 10->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.02134359676576813, -0.11231824679055576`}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.10671798382884068`, 0.561591233952779}]}, 
                 LineBox[{{-0.02134359676576813, -0.11231824679055576`}, {
                  0.10671798382884068`, 0.561591233952779}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 11->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.009362673029790745, -0.11995382918681279`}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.04681336514895376, 0.5997691459340644}]}, 
                 LineBox[{{-0.009362673029790745, -0.11995382918681279`}, {
                  0.04681336514895376, 0.5997691459340644}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 12->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{
                   0.0027198170602132266`, -0.12633063396855046`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.013599085301066138`, 0.6316531698427524}]}, 
                 LineBox[{{
                  0.0027198170602132266`, -0.12633063396855046`}, \
{-0.013599085301066138`, 0.6316531698427524}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 13->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.014780253868736838`, -0.13156249391552996`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.07390126934368423, 0.6578124695776502}]}, 
                 LineBox[{{
                  0.014780253868736838`, -0.13156249391552996`}, \
{-0.07390126934368423, 0.6578124695776502}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 14->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.02672624830477203, -0.13575736361892213`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.13363124152386022`, 0.6787868180946109}]}, 
                 LineBox[{{
                  0.02672624830477203, -0.13575736361892213`}, \
{-0.13363124152386022`, 0.6787868180946109}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 15->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.03848932833931277, -0.1390147285196986}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.19244664169656397`, 0.6950736425984936}]}, 
                 LineBox[{{
                  0.03848932833931277, -0.1390147285196986}, \
{-0.19244664169656397`, 0.6950736425984936}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 16->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.05001913930656231, -0.14142473860889163`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.2500956965328115, 0.7071236930444581}]}, 
                 LineBox[{{
                  0.05001913930656231, -0.14142473860889163`}, \
{-0.2500956965328115, 0.7071236930444581}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 17->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.06127897246096378, -0.14306829560813533`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.30639486230481894`, 0.7153414780406768}]}, 
                 LineBox[{{
                  0.06127897246096378, -0.14306829560813533`}, \
{-0.30639486230481894`, 0.7153414780406768}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 18->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.07224237025523425, -0.1440176247437566}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.3612118512761715, 0.7200881237187835}]}, 
                 LineBox[{{
                  0.07224237025523425, -0.1440176247437566}, \
{-0.3612118512761715, 0.7200881237187835}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 19->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.0828905690308781, -0.14433705796905616`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.4144528451543905, 0.7216852898452809}]}, 
                 LineBox[{{
                  0.0828905690308781, -0.14433705796905616`}, \
{-0.4144528451543905, 0.7216852898452809}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 20->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW
LJGOfc/OmLEzi+yMKFLv9/c+7zv/zPN55nvvfOfec8498zwzO4ysLt1jWbVq
1RHWVav+e0793wcFVv3f4+GbgWcphOsLvOqdLpwDapELazzhV2H/WR+qQj3l
wwkPVI6QoouNQcZtituHcJKHJ/H6Q0irKQq1J+wt/+ZWho01nMkZqbtJ+NxQ
D3G9HdjZG6cqEo5pE9fxY3cEniMHFbYT5lA1IsY/BSteTevljxS4/DJMxSzC
BTT546+0EZZ8bEDM9wxqju9jJBLOr6eKJgl5gNUTqqQd4RsfDIj5PeFgbuGG
U4RTSyqCQ257wY1vMYkshBOWeS/6sb+AeYPbHc9SKLBVW7vW6cJLqNffanmM
sGCJ7HO7+VfQ8DsjdzKZAtfpJDCL8IcwvUWls4Ql8w7cyLB5Awr8vi9nPlDA
JDHs6G7VQPhwL9o1mPCicZ1gklAQaO+feNCYRIGugCfN0cXBcOjwr1tGhEdr
aGnCr0Pg8LjkqvlECghfW3kRcjsUosftVDgJ/9RnBT/2cOAqyqtniadAMJ0r
2elCJFRKRgs5vKeA/Mknbos7ooC3O3M9LY4CZl0S1+zmoyCRXL+QF0uB7CI6
q1lEDMg//vZNIoYCARqW0hk2ceD0ZfqafTQF8NJTnnFKHDy/LBhZGkUBuYCG
RWnV95D0xl/4fCQFwvvYKhOF4kGxcufvfeEUOH50q050cQKI9Cx03AyjgPL3
hAMUyUTIrgA971AKZF4a4xF+nQgjcg8vNwZTQNzDtCH4dhLsPbVbTPINBXz+
Ncq+Yk8Gk32CJSw+xPpwSgQ9uZAKa9jkj7d7UyCscI9XYFkqLCxrhb/zosDg
0XL7jwfTYP7b9hkpTwpwd41rkDelA4eJLN+iCwWkh4bw6GAGGPbPlMfbUqAt
2/SmU2EWHPrygH+HDTE+Xnbfi9kssBJJOxVpRYFJS5s/QXuyYbqhSczFnAJb
vjD8U6Oz4eSO5X9sJhRYl230jPwsB5I/Xx/eokcB9ag+1yNnPwPjGzlc4yoF
xs2D2JU9PkNcpsM2q8sUMNTn9tYq/gwmIqPx6RcpwPz5zO6ubB60iTqb/dCg
wHZhraVA3nwQ0hb3Mj1KAQsRmsc4uQDqJoQj3fgp0FPQHRb2sBgiSjmz9/FS
4GiLsiw5thhqUqvlyRsoQNG+kL+5sxheVJ6x385JgYs7+WPj4CsUiff2O66i
AHVUv/yjQAnECvysOztBhtK1Zmxfvn2D1pPUx49KyXBa0ObhXY4yyB89k/Om
hAw2LtPebJJl0FASo5RcRIZTN1+GJZ4uA+VIBcPqz2SQ/7b1NdWuDP5u8nVv
TCEDy1QXybi/DPZtXvqyGEAGUHkZZZhbDiOZLxwr9ckQGH989KxBJbQXGz7R
v0aG+ZQiBSPHSrgfyccY1yVDWi3D5mlgJUSaf2NZrUUGI61fialVlXAgZlRi
/jQZWmR8/3Dsq4IHbWUXVnaQodFVXKLybxU4jn6WCqV2w4czZ1Ml4mqgU0Bm
IWywGzb/jo48WlQDRkd5hUJ6u+HNFQ1TrY4aUPh3RfFZRzdkLZNiHdbVAtks
VmJ7ZTec3P7nbo11LTg3O2q4xHeDZXMN9Y5SHfCwJY8l3eiGv3r6exyH64E3
+eLvtKvdcHDVounXv/WwVO56M12nG8gjty1Xb24Au/Ja0egz3aAU/7r8pW4D
cN2+dUHhYDfMP3jtEVnZAAezC6/c4OiG93UCGRkfGuH30h2LC9kkuO2b8zH6
YRNMbx06HTDdBaKL38/n/moBewWLcL8fXZBZF7yHwt4KFbopH56PdIHen6C2
VfytcNf4/MhdUhc09Um6acm2guWqiTTaty7oZ887Qb3TCq2CjjIMvy7gsbpU
u6ahFQxc6nYPSHbB1IHu3Vti2mDgl8LRs6qdcKSKy/KuYgdc2Z9pf/ZkJwyz
XrEI1O4AbW5crXKoE64vmf8pudkBNO8YNnHJTjigt1gl+KQDDinfswhg7QS3
q+E/MLsD/PV2VEuVdcDY9YPeK+KdABpuPPsVOmAyJ0FLiL0L7L3tZQ9saAcl
iyzrJzUk0DCalI5ja4eTbI3Z0EmChO0NIuuW20CbaXGMfYQEGz8+bi1ntEFi
tpPQ678k+P0v4uJIaRvIh5f3hx3uhpHRFI0mmzZw+lWi55nQDcIjUvHHmlrh
3gfBf19dyVDIX09vtG4BuSGKva58D8wWCMVLm7SA3wjd+efpHogxm05wudEC
lulJHmGaPbD3aZ4Nv3oLCGQ9ftZ5twemEkznJkVbYG1SguCZ8B54J8FBKvRu
hmst27YvLveAm2jv0S1bm+CoVvd618peGLxhLWYt3gBXLOdYi3T6gbZDOe3V
2gboN79TLGTYD9cMb0yGTtTDi/ynGTbm/aCaaWvnkF8PExfbD4u/6AcxCYF6
k7P18NH0oqfF137YQnPM+mtWB+n1tHupOwfgUWfI/Z6EGtiZt0cg+fcATH8P
3VXeWwHJqj4CDo2DYLF+5q0ZVkBW0yCxLINQddzSli2+AvS/exiZdw+CgvcT
dbb7FbDO6s+GW9RB2Fol3HxiphyOcNRrHfwzCKXn85S9/pWBhIk9NUFmCOKT
eiL0eEvB5f11kUDfIRAwMl9vtboQ+BR2th1QGgYTvo2/zbEALmWtiHxRH4Ym
qYl9Gi4F8Orih5bT54ch0uz+ubBf+dDvLOqhdm0YphPOc7+ZzAO53X1FYDEM
LpayB2ZacqHxVesH2tth2P/7Q6fsUiZcPnRt7ejUMDw0uFOrY5EJJcZ8i0fn
h8HrsvVbWaKOV+fkbvD5PQzPSYlO66vSIdVGJn072wg8jphdufsqFW7I/bp5
QmQElqR+vbLk/AALFqIOAiojID15Qj8pPgKy8mJWq4aOACR1T3IavIWAN6wX
KyJHgGm0IaRUKBzkOjX5FeNGgKL+RmuzTwiUeX4dO5A2Ahd6L9F4q17DmpcU
p4XSEYivujx1r9sOnIqf8qyaGIHDwboWKqZvsG3g3vNloEJBdbbz8apAPME0
eyquRoUt2yweM3YEo5l2hZX6OSpknxZkGPeFouLiRw2vy1Q4993JdvxmFNpF
aav2P6BCdEyUiywkYPUR6b7fb6iwIbiodjIpE92e/XhZ1E+F+DM6f1h1P+Gx
I4pa0iNUKHWSrT+8KgvN/Hn+BjGokLouPXRTZhbWrY7dYjhDhfQbl0sruXIw
KfY0o3U1DUo96vQbmj5juCDj0VZJGhhuNo/OsyvC33Psw0dNaJCt8S/WuLkI
BcKv7zv1kAaPVB6InJApxufGRVOnLGkwwDH9zGSkGEc1rIoPOdBgYu/VxE9X
SjBzzp5v0YtGnKdfXdfuKEVeoV6RhkQa5L+95MUtVoG5D5PHgwZooHREbyFQ
pwIpt30DTEdosCSxi0XOuwI5I8bvn2DQgF9BcSpnugKvSJ2JbZmiwdY3nfuH
Kyox/dqgd+kKDYx9/Ab6ravxyLSFWLYoHcL9DbUnP1Tjq6T3F45upYNPPJ+h
QF81bkdzvaIddKj4wribfrYGayTiOjOl6VCTMTvPKlmL1uvUOvSO0CG61sPy
Yl8d9m6zeJZ2kQ53hvYnjwrUozZt9mSfLh3OiKjZRpyvx9SqnRYc14j3mzAq
VP1aj9KPj27UMaDD392bG8uiGxBzOJOjTemwNcZ0UdfoO9aqv3PZ5k4H14kA
dfuo7/jXPtH6pycdUmS5/qV3fEeWgKdWVd50eGU+FXP/TBM2sc490vWjw8Jn
zz2r9zVjR53z2M5wOsx4N44NurWg1j5vr6Q0Ovhbc65PjW5BlhKl99yZdBAL
F2h2/dKCYlsuh1tl0SH3kPp+TWYLOllL/tqeR4fTG7r5re63Yq7Kxvaj3+gg
GR/YNqjThiG/YgQUmulQmHLiq5FVG8rX6eQfa6VD5LTnphm/NhRSWVVzuJ0O
Aq8zBWRr23BFcVBElESHo3oLZXLQjqTrNZVB/XTQ4RS3vyzXgafTH4ueniDW
lxSX8kqrAx+KuJh3TNLBN5bG3WTWgeayYyXG03S4aCmiZ5/SgaTvfsoWc8T1
jc/uqot3YuyNf5wyv+gQq7QmokuxE6ni1m98ftPBykWUZGPYiWXTq3v7l+hw
2PKHfl10J27Si055tEKHgrU5P5Y3deErI5PzmiwMqKJVto8c6cKZvlwFS1YG
3DC6EdV1pQvZJ35k+rIxIHxNUFpvcBfmZWVKpK5hgGP06dHpnC604HrO92kt
A2ZsXoxxt3Vhk3azVfo6BrROSOx6yEPCyZB9em84GVDp2H85RY6ENn4WHQ5c
DMhuZZGb1SYh3n38/sp6BuxttWyK9yehbrQ4zx9uBtRssvfmyiChwZ62+IoN
DLh88FaLayMJd62xfOC5kQGmQlZ/n3N149KF+5bjPAxIY2uuW5DuxnmHFF8f
XgYE7+rKtFHvxtbMo+Vb+Rgg98kj08O9G9/aVtse4WdAiO6lEuHYbnyh7tpf
QBjcxZoKvnajc81vbXkBBlxfr9jH86sbl63DpfgEGWCneay5XpCMsf133BwJ
K6bbpPofJKP0G8WqTsLvul4/uK5DxpRjLLN7hRhgvizJus+KjFmWdn+cCXNh
vh2XPxknUm4NVRFuksjLnU0lY5u2X8TaTQx4bO/2dbCWjNZF5VuVCafvM37R
TSfjYcXqh48Iu05GcZPZKDh++Lrje8JUXV2NYXEKfv594nQ1YfbFuP3zihTc
/HvvlxHCzRovcYMhBVULR4d+Ezb1YJk64EJBKfLunHXCDIh9PfbZIIqCfeIf
JXgIq8zzcAd9Icb7iu3/z6mlB6abSBQMO3iy9b/rd9su6AosUDDGq3DVEjGf
1/DPg0YCPdgmpVr43/udPfD5RaF8D1awB8xWEdbNjD+zSacHyaZnPsQRvl65
zdzVqgf3zoq02BFWGnGYnPTvwZcx2Q+AcMzDwYp76T3o0VNgyvrf+BB3Bq2+
B1+97GhEYr2ot8wvWv7oQRX2zFf2hNkfxy78XduLpbt/xO4grLprTVv4zl5c
vrObtYbYjxtHH1OOqvWiZjrPp7uEu2lf1g4b9+JCAsQsEfvbWuGkE+zRi+O+
V2p8CH+OHRDeUNqLPKHpef5EPEhWunmR+nvRokbKgo3w9RPREykrvXhLYEHd
jognsurDF8Yn+rB/6O+ZY0S8hdk++Xhevw8NWEyM3hDx6P4P40896cOfAe5e
A0S8dkc1LRwp6MPJ4F2N94h4buLXAejqw8j73cPRRLx/D3Q7fuFnH953eDna
QOTD1B8bCe+D/RjCcTiZl8iXVc7n/qZf6kdq/3ldaSKfWJYX7/XY9KNaUmLH
EQ4GnOQWyNPO6sfJB+dOnSDycf7rlE9wcz+WTGRvOkDk6yZnh/KBqX4M9vTL
2MrOAK1vT0+/lh3AGvea2UEi/4P/bj2lnDaA6Xttd63+S9QH444Ys+8D+Ocq
9W34HzpsX6d+MWZ6AKVucvJLLtNhMz/ly3rRQYz7arVqG1F/jq39FP7l1iCq
aLzojpqlw8a9+Y1TVoOoq+mRMkTULxez23O73AfxeMweEJsi6nWs3lxSwiD2
zbjHPhqjQ0fw0/nm0UHU0LuuljpMB+mO1H6JpUFc9m0wjhkk6jX1iosT1xAy
tH+u8SbqZ9sbUuHhfUM43uVepEChgy5j07lOuyHU1VKY2UzU442reNO//BtC
t+SV+4Nf6WBqOcqrxjuMxW6vfu0qosOkQVZyu/gwigzmvLxbQAfF8URYUhtG
hqZq8NdsOqiUmEqZ+w2j8Ae5S4wkOkCUYA5FZATxXPGj7cR5M+8T0hgiM4Jm
jmuvfPYh6u9xF3edUyMox1j5fNKLDmF6VUFtt0dQ0EaMtMeVDkey+o7OJY9g
3rBptZMVHVaYNV7vjlCxhLJi/eMCHTLMLkedP0PFhGDH0XXn6fDl1727f65R
cXID97SYBh12sGyZvP2Eiop2kW+kFelACx0in/xKxT4MckQ5OohLXFtWUKYh
i6SYw9R6Oli25s7/uUTDP4YSf4zX0WFx3XmuCmMaJqj7fmpipUPLlU8PLnnR
ULo+y9tziQa8EimNzrU0nJg+q/OQ6CcSnlC1FrXpaLByRWkX0kCz9PXNOkM6
+gkfHpz4QoPT/CzUKGs6uu9bezH5M9GPGB2UVw6io6Sqqt/SRxqIeMhEBXXS
cdp2uFckhAaVdxrGj95k4KrSfZIKRL90uLZk+ZzpKKrbCnDXEv0VRy84uTiN
ooyhlenrJSoUxfW0ZfqPYqPlGqo6kwpzTs713DmjeG5ycMtrKhV0OWc2FS+N
ov2ujf/sq6kQ6s7dWvnqB3aYipfHvqBCUtHUmq3pYyhTeU9V/d8IpJ9uleP6
NoYbFHquqC+MgHFDGvfP5jEEKeExhckRqDqzOfYbcwwZpJ5X0xSiP7ZpF9h1
Yhy/9KldyMobgR9pfXMn68bx0OUzY/YPRqDlwlnthaEJ5Cy6enixfBjsFX89
ZWNO4BH/KNPLhUR/fytXmpttEpP5L19LyBiGrSe8i7h3TqIMZ7W+ENG/x1Vd
i6ozncSq5n+Mi+bDIJWar755ZhLv7Q8L38Q3DJ9fXA+IWpzCdc43RscvDcHO
HyIN7Wun0XH4b6+b+hD07P7IxSY8jV57NUPYjw/BHlehs+ePTmNNndkl+vYh
iNv3wf7J42lU5b92ZmVyEI7dLrI9tDiN9Tlmpz29iO8/hg8ff3eYQSGRuKfr
Lw/APcmSlx0uM/hXf/P5t8cGwMu2YDXp+QwejzojtH7bAPyJvLj8PWgGL1yT
KUj70Q/cMt/2embOYKE6+85Gl35o4QF2VtoMzmw32h75vg86Ff28tmjP4oCW
83I+qQcC9+8IcLs8iwsH/fuvFPUAX7rDeK/+LJayGEn0R/dACpfLU+/7s7gt
/x5X2p0eMO2SZw95Novf869MKYxR4K3nWuvA7Fm8dafSWGaRDB3WIYY9G+bw
3KW9nyZXdcOPVh31WYE5zNxYekqinwQ/ywI0/onOYf7ao4WKxSSwsG9xYN01
hy+c9pEOPiKB24nxW2mn51D0sHf4CqMLCva+i7Y2n8MqC7WKI3Wd8HD1Py9W
2zks36AduJjYCTTeT+P+jnNoH7F7dfyzTkjdasXu6zGHI+r6Jz8rdMKaniqT
TW/n0H+C70FrYge4K+t98CubQ4ENLeEcTu1gJtFAC6qew4urj3TaXmmH+bX7
179pmEOVrvHkGrl2+LCLa8yycw6zNmgGHaK2wX4no7mS0TlUDErcs+18Gxyx
W5sQwc1E1nvkhCvCraCUKneCk4+J0smeKj6zLfAiUfyAjRATRfONPqTUt0CT
MKuQ+DYmsks2a+Q6t4BCyA7qhv1MdJNYJTGKzTD/7W4N90UmfpmifvdV/w4r
11ZmY3WZqHR1YbXQn0YoLD5yfvc1JvLG6b7xzm4Envd6j3fcYuLpngUU3NII
Qf24MdmMiVL25DDmdD2YB2uZsngxsVvs7ENGUC2wZ4zNsPkwkewRo92tXguL
1Rd1/r5kovEDkZLspRrYu+qdT+cbJjYuxmttM6qBLgnDs4LRTCwyedA/IVcN
Oz43snZlMVGzQ/RNQE0FvJTfMqySy8QLm4Q37HlaAf5x1y6m5DHx8Z4mr+y9
FaBGu9N4uYiJyfMLXj6B5aAbXNdxooKJ3L+tvt/SLwOlmwKVBlVMXH9qbrPp
+jIgfXsi6VDDxK3PrLKMvpVC2ZdLe142MFEih69TUrwUlkZpP063E+vVX/mI
0loC994prhboZGJMUkYD81AJXI5tshzoYuIWuwcGM+FfQS9OUfE6hYkLJp5B
oQbFcL9k78PuQSbKPgxlxDEKocHrzqDhMBON3vJ/o54tBD+v0dC+ESZmqdiH
8KQXgCkt93MxnYmKjgdSxK3zQbBF24VlgolBv9doKS3mwq3jnlGHJ5lY228S
MXcjFzYJSmoYTjHx0dpgh8DSHAh5sqIaNsPEnMLt+yJ9s0FLwDswYZaJlDGj
fexTWeB2cfO95DkmTkXJcd2+lAUdXgWRQfNMPLd88GLz4UywDX31+8lPJt4J
mdsq8zcdPj1bQ762QKz3zWoVs+o0yPmpILC4yEQSP9f+mKsfoc7imEXhLyZm
yxtoBG5NAdWPjkrWv5m4FPhMz5L+AQZ3TF2tWCLu93A92+ijRLhPmg69tczE
SnI90/tUAsC5Ms0ZwhZSms/42eNBn2Hp+PgPE3W/n+x43RgH6qyCwouEJWLc
D87vioXBvoG95itM7HfWWEjPj4bsJK48EuFw+SK1c2qRsNOJ+unYXyZe2bHB
sak9HB7aVW8JIrwxq3TghFEobIwSWx4kfIfq1xkyEwT2v+6d2/mPidG/7mX2
uL6BIX8ZTiPCGkNDz6RE/cDyBufxEMJhd/5UPD7yAt7eziR/JawmvqY975IH
xMa0j/YQji/Xyi/vewrvBdTvzxJe2GrBv0rIBqzrhy6vEI4N87zz+agBSNUE
Zf8j/HBX1IrJdxV8JHTF5RdhvXXyzHWeD7Cy5lAh47/5KrbpX+RwQNqkltF3
wkWpCjvXtrph0btGp4+Ex296lV1ofI5WcxNszoQLdLi41mX54guW5RVVwvlK
CeXJwa/xw+il+2yEk6QqxEKLA3F9yW2lIuLz7/397q6abAh2hcT5mRCedu42
HH4XhuuevTvLQbhQ7O0XU54IVHyx8DieWN81xUpbyO5ReOTj5c3yhKM2Osnv
Y8Ygk2R/oJDYn59cEboH5eNwe9vxr8nEfv41z9p7MiEec6VS5HkJ16fJOH7o
ScDVASbbbYh4EBl9WLvCn4SGzwRMBIh4YU+ldFs+T8bJqHOl14h4WpQ0U/P+
moLNY7fCAol42zTgxe89/xHfXjAoHiXi8+mWxgPH76ajpuV67jWEv7wxODAR
lYFu1RKDIkQ8N1przrq3Z6LNmXIeKSLeWV+Kc+55n4VPZjPq64j8CQyI1D22
MRfp+vST7kR+qa6/+fVbQS5qVp0Olh0n6l2mDPe+259Roq1m4e4oEb+rx51q
svJQQGU/Q5vIX56lnQdaLxZickBNTQaR3xwTeU6Bvwox69fbhNUDRP5Z7Rs8
HPcFz/1ep+/Tw8QbLZxC0tNFeJ3dR5yvg4kng/ZLvntVgtn91SdF2pjY9O/h
HjP5b+j3M9JSsIWJlqOfgoTI3/B6cqH0JFGPAva7Ulj4S3HrziOmokQ922O5
v0rYsAwjL/jPWH1iYsiyQ2IgswJvi+32qk9n4tnDRafL1Crxhbn6E9FUJkqa
qDhTwiuxwzkzJDKRWK+N0d61J6owZuD33i0RRH3MPm/p61GN36TGqnc/Y6J5
beS+y1x1mIRH6L3OTPTgv7/080Yd0vYKlXo9YeJqO6cdzul1uNGl7muhLVHf
bj45fkirHgsmLF8n3mViWfTbL+f8G1CyMNMiQp2Jm9vpWxvWNuHbXcHtU8pE
vYoJEtfUacIMDUw6AUxMq+KrzYxsQh7lqg/FCkwcWtJevV22Gb+5zFdekWZi
qbtUiY50C+LuuOHFtcR45a8LfzRa0fVc/3Q1K1Gf5NaSG8xbkTN08Lv/vzk0
lhb69PJNK3LUNAixLs6hn/u7ShKpFemPM9760eawOFbSPf1eG6adeH57B3E+
d7nO75R2bcc59o/p1l/nMG8HTflHXDvOvzM7WlgwhxnNSzFvK9ox90SVzP7M
Ofx4ViW1bF0HlvH6aFdGzmH2+lid40EdSNp1nf050S+wq93dlvW+E90287SG
bZnDXfRGXo4cEv7bOCH7XGgOe16yvRbuJKHzd8EgU545fFekXbPxFwnv/vwa
sYWN6Ce00zjzTnWjTDy5TnJ8FlviEwS7a7rxy4zfQHXBLGpejhE1I5FRfPFt
UrTmLHLc8pfdPdKDvhfDbWNVZ9G48N5TVtZeNJayiIk6NYsxxr2N5eK9uLks
4OgzuVlMO1BycuZOL7bPtRQu883i1xBhC7aBXvzmy+Fb1T2DEp4hHGwdfZjf
JEmfNZxBz/BpjpWUAVxKF1urrzeD0r+rQ7sqB3ByWF245OIMenXucAoZHMCS
oj+H7JVm8HTb77B+rkF8ZGnonCw+gxHTsXG3lQexpGNT6dXaaQw0+vmuOn0Q
H0uHFw/VTOEau1xdNschfB3GfyysYAp/cPFR5TyHUJjks0cleQq/iG5V0QoY
wnWJP794e0/h1imNBwbJQ2j5Y+FrvuoUuk8HH2jvGkI+Cb3KBpxErbRGSYGD
wximILxbN3sC1wf0eIwPDuPc1MYfRu8nMKIoNydmbBhtss4csQycwJXsBX+V
+WHc8VQhz9FmAi+ojmo+XDuClef5Jq4dmMDl2+u5JWVHMLvu1SX9rHFMEyvh
O+cwgquH1xt9TxvD5TLuaMt/I5gsbGVqFjWGFup/2yLWUvHRo4WmNa/GUOe6
91LhRioeGXUeP/xwDCW3v97Vvo2KS2E/Rh2kx3AfyUvHEaioFLmIAYk/UFq5
s9HdmYoD85eCHkeNYqsv90LhJBWt7vUz7H1HMdxZjf/3PBULOGU2WjuOYv2l
G69l/lDxnNAwj7HuKKaf+/D5PicNP1qn+J/iGkXr2d1Gp3bSUOyuUFjrUwa6
zxabG9+goZGj8/byBwzkfygh1XiHhhnJr8xyrjKw7u6aqF0PaFgxXe8cJM9A
uxsF3fn2NJzflrnp0hgdK5VuXVTwp+Hj/KoLPdfpWB+dsVBVTMNj8xSrpjN0
3Hx+/VuDMhou1obuLT9MR0P6pTuj1TRMbTbKSuOlY6HykxekVhqeqGI571NH
Q2dXWcYWBg1HGM/HbI/RcPfI5yPnNtIxudj0vZEoFcUFLD8aXaXjncOyBdkc
VMwxUadL69NRR4USz/J7BEujlpFqQMeY6ytbU0kjuLfwtvGpe8R9meRF84SO
oIZN9BY7Ozo6VMryq/CMoH2D5K+f/nTkfWjhnftvGH+ue88qEkhHPkO/Kzun
h9H473p++RA6Up5w7OJvGkbZxYFr6pF0vJn41IbTbxgHq+UO/Eqio5PF3fMO
64Zx5GIDw7uYjqJzDCGeX0P4V1dOg/sbHYeVG/LSGUMYUXZQ6GUpHW+3rvGf
qh5CV/sGwftVdCybIN0N9RpCMVb1W5+a6Lhn+niY+qMhlGnIpv9ooWOU6Y32
pbtDeK3pJB9RQ3G0J/CVueoQBox5W9wh0bHEVTH9EesQWt34O+M6QEeBNt15
YA7iDN1S22qIjrv2XnfmHhnE7dTy51dH6Jil+uBeTvkgZr1mD+dgEPc/JntW
0mMQZS4lbWCdomP+YslpDttBPKzbO506TcfaE4ZJs3cGMcJqZODsLB1PbXLr
a1QaRKberbUW83R8V30iOmP1IGZqMvefXaKj2CG13L8jA9iTzX8/YZmIE54x
iY9EnWCr5Tj28w8dD0f68vB7D2DCqeE6t390PJ+4Q+EkxwByiUvqHGBj4Akl
ZXfhsX4Mam7bdJadgSfbPvH9qe/HdZ5SGXprGHjzepQ82a8fU4WEDAzXMVCE
+5z9BE8//noY7cm1noEqEctr2Ob68Lsgw3qYsGGDvKxEex8W3fQ0zOYm4ly4
Tu9xaB+y3v99XWEjAwV3KVlnOvShm+Yj2ynC5ZPWMHGtD7WXvZNieBg4yTwv
7Sbah6u8k+ypvAwMFbfV7VjuxaLP58Wc+RjoyqN0/UBfLx5S/fabi5+B17pV
lcO+9WJaoipPCOHjy/NCrHG9KLFt930BAQaaPsobcHTvRf/GXDZ/wsttXYnz
Rr241l9meoWwz2cxtTU7ezHMcbGiVpCBvRTP/VFre1HmV1uRuBAD+y41Hj36
owepu1I3PSIc/Ylxr6++B++dKxlEwrVvcvFleg8WK2huYd3EwDcFS1qKr3tQ
/nJgy2nC3psfCf+16kE1nwZWO8LO/2p2Vur0YPTRQ19jCVuv8X4WdLAHt55m
W1VF+J6GnKypYA+K9dt2DhO+fP/AIY1FCgaX5yn/JiyVyIiWI1PQZW6V9jph
BrowIy23FVPwYL33ykbCtXweWZtiKPiL6XiNh/CWmDJTYTcKOt9mNeIgvGe7
+fsddyjoC1cllon5dh3wuHVQhYJffkW9pxFucJ9L1pKioJrk3+FawvI/I55b
r6XgqGfiZCLhrs8qy1E/yNi+/LnmCWEbtY98LQ1kzH+l63iG8FKUbev6TDL2
nYln2UDYU/7I6UtvyHj/UpnVd2K99oo9MYyzJaNbR1OlF2G2bZ9OLF4mY8ki
fa0C4aVvx8lXFcgYOCABQ8R+FN60OI0iZCyOj7F+TthD7YXN/j/dOKT6MH47
4R11BY9T+7vxYFYMJY/Yz2xtMX3Zsm7c+ensNlXCzqZVm78kdON+uotDAxEf
i+yl18YfdCNXeo59FRFP+mlfBvnOdmOqdWiLDGHn5Se/VXd3o5PQzR0vifhr
r7JfrP1BQgNbndJ9RHzO9XGMi9aTcPBul9gjIn43bN78yjGVhHZx469zNzAw
wdJm4qIZCVujL9QLE/HvvXSr+LsmCc/doyQAkR/HO0QuXdlLQh4Hi0+3uBiY
PHBt9vlkF4Zo/nvqxcHAeNpQqol1FxZSdQsciHxcqEDz4zpdKJ5eNG9I5GuX
8j9pEfku3BRgH6fEysD1BTdTFpmd2LK/4vbUKiJfPkncPfa4Ez/KS1+ZIuqB
yp2DUfeud2Lt/ZjOKKJevNzNthR9vBN5ZWr/Kf2mo/NhUVXZlQ6Uzky2fLxA
R8vPkpEdHh3YeinM8/UMHbV9O2P173Zg7U3KVhaiPp1Lzvw5rtaBvnTFd5aT
dFwbFZe4n6MDD7veNpEnzqmksz2vld+0Y+BLO9o9ov4ZMA7q+sW1oeZsVp9H
Bx2VzV8+qPNow8l/O4V82oj6tbGXh4/oCw+CX6I3UX85Eoqkq3e3YfFT1gGr
Rjr6nyro/JLbivX/GvyYFXS8pDo001rXgts+RDRVZdNR/TXvseLMFrQ3N87x
+0RHb75MzAxuQa4bs7u0M+g4K+r55rNBC4peEO4vTaFj8a35GQdqMz46u26D
SSwdI1d1L1gdb8LaxPK9n1/RcY27jKgfexM+aFnJ3ulLx4fefXNfW75jSNa9
rSHedNS/4tV88/53PHguqszQnY5Vb2zcQkMbcUF6obzIgY7WsaYVEz/rUSvV
d//z23RsZl9z50p5PUactA1OJs7Lx0N2pLbX9cjV8VCumjhP+YV/Xl4vXY/A
7bPz52U6/ohu+/KE6Ps5cvyjRc/S0f2syW6oriHa8I75F/vpaHNsZNWTtErc
1dK0esMfGl6KpZrccajEV1MXtuj9omF9TrqhkVIl3mQZ14qZp6FZSdGaTFIF
/tsQzi0ySfQjMc/5zNkrUFS4Lrarj4Y03zoxj3tlOJP6YK3VNxpSaZG7Bay/
YqXuw9gTzjTkvOPEx7b+K+aKKToyHWnYCKvTJVOK0VeNSyjZjoZa263Ji4NF
eED+SMlqMxruXdS1pV3+gjk5pUpe12l4w2i2n6SWj5ddWYPrDtOwf4yVha6Z
hbQekW7TcSpyy6tf2zf6CStru+AnnYpRdwunRo5+wtwAZXeXYSqSvAwyNXoy
8IGBaNxzMhUnIy9WL0ikofRCTp5FDRX/2SxHkiqT0Jjb1T4znoon/XSUrHzC
cMPZelnWa1RM+LnGiTc0EFR0123LLxjBN/MHXiVVBcHx12v4MnJGcM3gXb34
n8GgEPiz/n3GCIruGKjt0g0Dvf1ZEc8TRpCyyv6OHEcU/LFRW5QLGEGdTWnG
QzLxQL7xYON2kxE80Gu5p045DaoLrDkf841g96FTp9Q186EkBO8E3iP63cdg
PR+cDxXXdFTCDIexaLRH9UlvPqz3Uz4dcX0YOV7Ycq21KID1LtteRWgNo7Ba
VOQhv0Jwuyrc6Hl4GA33schSy4sg7Kv1idXsw9jS5kj7xYsgHErOyY4fQi13
pfz1MRWQWeLvY0keRMFIlw69ogrQ/WRw7Gn7IIZucnMKIVXAwRzPquffB/Hq
YepTCm8lFFzWdwgrI/qIlReD770q4eWix/30j4NYWzGmLfGwCmoXpCYSngzi
Jm27cuFdNaDG36HUKDyI16+dsOK0rQcnc4FfiSn96OQbSvX0rwf/Xlm+o1H9
eDv8etp4Sj3k7dC9VOffj5Pe3zW8B+phfoJHh27bj4UXY5+PajZA6LH4GM5T
/ajV/3L1/R2NsPvsZp5/LX24/YVWqBN+B6FOV7u0xV5UlMgXK77bAgdMPxd8
UOxB6VeXT++0boGEpm+vRYhzszvXN9HXqQWKJG6cfiXVgzl/HbWOBbXAM/kX
cmacPfgv4YLxSWyB+JNFQWIdFFzHdmd3x6ZW0DN+t1n7PgU75F5K3KpoBefC
B+/G/cjIp32T7sDWDsHPslmciO+Lx1q6Fe5xtwOtx+hFbC0JvTKqHmgJtcOB
O7FmFcUktLBTsOGSbof7qQbXOOJJqFOy6+ppzXaIus3d629JwhXud8fc37RD
agMp9OlaEnoKZtj4CnVA62+hK2NHu3D6O4O5kbcTCnl17+tHduDODS7GO0U6
4XSXa626XwfW/Homd2RHJ+z7+iRf3rUD1fObaUoHOuFQ/tRJDqMOVKxi5+TU
6YTirNmN2bs78KOs1DbDgE4QEM/+OFHYjizmFqEya4ncynuzX5TUhh9bbCdK
R7qAf71mjAtfK4bUZdBafnRBC3UvU5W9FXfv3vmiZ7oLylyL+Nb/asFD5d9q
B5e7YLX+fFZEXwuiaJdVGj8JBk5bPM5JacFKhU/Bysok4NtSkEg53YI9qa+3
e0SR4DnzfCRvVxMqT5f8+BFHgiC5irchxU04S1byOf+BBBSfFo1N75uQtSTs
HEs2CT6uZi/bbN6EO+l6HPurSSB/qk56B0sThmZpB4VOk8C+TcJn677vKB+Q
9DHwdDd8FxOqHfVqQNuhrYmnVbrh7LWm2VGzBmxMZH6nn+kGsvM4fVSnAVky
N3+W1umGFfXyw6NiDRi7ccsPW+NuqGiNdKDm1aNmxSBjx4tuUNn6YU0HrQ53
7G31n63vhjNmovuC1Wrxtv+cx5rmbuDYcofiL1OL1sWZtULt3bDhiYyxD28t
Jo13nN3dQ8z3QHy9S18NbmhOOSU03g2P/aD27qMa/MOq+42HkwxFWYvn9iVV
o8v1o+6vVcmwNL9NN52tCj98nDp/Q4MMtPiJQxajldikSsoXP08GUQ7OP7KN
lWh92cn0vS4ZOLZOn/gUXIksibfu3zIiwyrbna+zxCsxfGpnGsmVDKu1HLsy
FSvwlunmA025ZLhq6/Aq2rkMlV2mcmfyydAZfbZL/3YZvq5cZnIXkeGG1BKv
iGoZ3olT/nS0lAz981sMQrnKMHN97J4LjWTw5b56zj+yFMN/ps88GyGDFU/q
k5/WiA9+CmqvcFOgrGLdg6jRYvwxvSpXm4cCLAO0nt7cYlzcLBIRxUeBvSYv
lbe6FaMbY+P4rk0UkMm79iNOsBiHmYF5nNspcGKWLSlJuQjZhiQNfu+nwK5P
XLwZ0YWocuKPIOtBCqg1WbZN3i9E+mEXvXWHKRCm3fJy38FCPPTD3pn9GAVu
czgOfaorQMb5Rq16xf9+r+64N2chH3s38rq5XqDAjNzx+3kX85B0y4xLSYcC
cbtKs39uzkMfvw7pf5cocE7BceEw4zNuaPcWtrxKzHdZyirf5TNmBQiShAyI
z/OdU7wgNRcVtifsCTGlQG1X4KcCthz8JJT9a6MZBax7Mz8tNmfj+SyxWy/M
KbCeTSddISob2eafzTywosBSw7uoggPZGPTkyKlFewqksAdcKbiVhbuAq0zR
jQItfxejzG0ysKzXYCjiGQXSdgZJJS+n4zfpTt9Jdwp0OnqmDnml44YDTfbP
n1Mggvtc8tXINLzr2V5i7UuBv6EitooVH9EQFfe8e0kB8N/b+1TrI17dM7ij
+hUFfNJ2quSRUlAge8tn9tcUkFz3ZN2eiWR88XC1pUoQBT5a9NnzC37AZ2nP
TqkFU4BfxLleKzYJf8t1RiqFUGDZZu9Wn91JSFu1f9WeMAoEhZws/XMqEaPr
Mly+RFAgQ1BmjmYSj0caRyoCIon1vGhzYvvse7Sf3BV5O4oC+y7EeOo7vcfN
T0mLs9EUOHNsiac5IA4Lne64tsdS4NbTNBVrmxgU+/5e0zWOAoXKpbVUr2ik
cmCqxHsKSGR9OX89MgpjFfS23YqngPtKuY5yRQRG/z14mElYdYSlPZ/0Fg8Y
pPd5JFDgUPgLXZmJcPyrv50RmEiBnE2ZlwQEw7AgxFKDN4kC0UF2rT67Q1Ey
6u/JV4RbrlRdWDkVgtv4HQctPxD7dVxdk24ShIdoiQHdhFd8X9fqOwWitFps
28lkCuyMCFVrDniDIUq2Aj8Jl//hcrW28cdpdk/+sykU+Jz6z+F65CtkSWn5
EE6YuSnXSrnCF8+L2jUNEpZWkX8gM/ECzVKevZT8SIE9wS9uCwh6I+8id48R
4XPMYr2VU89RgG1faRThmumui3QTD7TfOXesmbBvZ79Gc8AzvLXhocYK4ZNR
2e7WNi64vyphXCqVAuGzgTbKFU/waUaaxFnCTVvu3REQdEBuT78ZE8LWC3I6
dBNbXNC/cMmNcB9znBhvga4JyxpBhM8v2hLXm6C8ZHhHLGH1yGnidQOkrUj9
TP7v/zLN/1kL////NFyqjqnwMObr/wBDP+3J
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.09321057850653142, -0.14408387610754622`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.4660528925326572, 0.7204193805377312}]}, 
                 LineBox[{{
                  0.09321057850653142, -0.14408387610754622`}, \
{-0.4660528925326572, 0.7204193805377312}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 21->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.10319373978443233`, -0.14330912924524794`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.5159686989221618, 0.7165456462262398}]}, 
                 LineBox[{{
                  0.10319373978443233`, -0.14330912924524794`}, \
{-0.5159686989221618, 0.7165456462262398}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 22->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.11283464094892794`, -0.14205839633777675`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.56417320474464, 0.7102919816888841}]}, 
                 LineBox[{{
                  0.11283464094892794`, -0.14205839633777675`}, \
{-0.56417320474464, 0.7102919816888841}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 23->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.12213029946062405`, -0.14037246844670684`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.6106514973031206, 0.7018623422335345}]}, 
                 LineBox[{{
                  0.12213029946062405`, -0.14037246844670684`}, \
{-0.6106514973031206, 0.7018623422335345}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 24->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW
LJGOfc/OmLEzi+yMKFLv9/c+7zv/zPN55nvvfOfec8498zwzO4ysLt1jWbVq
1RHWVav+e0793wcFVv3f4+GbgWcphOsLvOqdLpwDapELazzhV2H/WR+qQj3l
wwkPVI6QoouNQcZtituHcJKHJ/H6Q0irKQq1J+wt/+ZWho01nMkZqbtJ+NxQ
D3G9HdjZG6cqEo5pE9fxY3cEniMHFbYT5lA1IsY/BSteTevljxS4/DJMxSzC
BTT546+0EZZ8bEDM9wxqju9jJBLOr6eKJgl5gNUTqqQd4RsfDIj5PeFgbuGG
U4RTSyqCQ257wY1vMYkshBOWeS/6sb+AeYPbHc9SKLBVW7vW6cJLqNffanmM
sGCJ7HO7+VfQ8DsjdzKZAtfpJDCL8IcwvUWls4Ql8w7cyLB5Awr8vi9nPlDA
JDHs6G7VQPhwL9o1mPCicZ1gklAQaO+feNCYRIGugCfN0cXBcOjwr1tGhEdr
aGnCr0Pg8LjkqvlECghfW3kRcjsUosftVDgJ/9RnBT/2cOAqyqtniadAMJ0r
2elCJFRKRgs5vKeA/Mknbos7ooC3O3M9LY4CZl0S1+zmoyCRXL+QF0uB7CI6
q1lEDMg//vZNIoYCARqW0hk2ceD0ZfqafTQF8NJTnnFKHDy/LBhZGkUBuYCG
RWnV95D0xl/4fCQFwvvYKhOF4kGxcufvfeEUOH50q050cQKI9Cx03AyjgPL3
hAMUyUTIrgA971AKZF4a4xF+nQgjcg8vNwZTQNzDtCH4dhLsPbVbTPINBXz+
Ncq+Yk8Gk32CJSw+xPpwSgQ9uZAKa9jkj7d7UyCscI9XYFkqLCxrhb/zosDg
0XL7jwfTYP7b9hkpTwpwd41rkDelA4eJLN+iCwWkh4bw6GAGGPbPlMfbUqAt
2/SmU2EWHPrygH+HDTE+Xnbfi9kssBJJOxVpRYFJS5s/QXuyYbqhSczFnAJb
vjD8U6Oz4eSO5X9sJhRYl230jPwsB5I/Xx/eokcB9ag+1yNnPwPjGzlc4yoF
xs2D2JU9PkNcpsM2q8sUMNTn9tYq/gwmIqPx6RcpwPz5zO6ubB60iTqb/dCg
wHZhraVA3nwQ0hb3Mj1KAQsRmsc4uQDqJoQj3fgp0FPQHRb2sBgiSjmz9/FS
4GiLsiw5thhqUqvlyRsoQNG+kL+5sxheVJ6x385JgYs7+WPj4CsUiff2O66i
AHVUv/yjQAnECvysOztBhtK1Zmxfvn2D1pPUx49KyXBa0ObhXY4yyB89k/Om
hAw2LtPebJJl0FASo5RcRIZTN1+GJZ4uA+VIBcPqz2SQ/7b1NdWuDP5u8nVv
TCEDy1QXybi/DPZtXvqyGEAGUHkZZZhbDiOZLxwr9ckQGH989KxBJbQXGz7R
v0aG+ZQiBSPHSrgfyccY1yVDWi3D5mlgJUSaf2NZrUUGI61fialVlXAgZlRi
/jQZWmR8/3Dsq4IHbWUXVnaQodFVXKLybxU4jn6WCqV2w4czZ1Ml4mqgU0Bm
IWywGzb/jo48WlQDRkd5hUJ6u+HNFQ1TrY4aUPh3RfFZRzdkLZNiHdbVAtks
VmJ7ZTec3P7nbo11LTg3O2q4xHeDZXMN9Y5SHfCwJY8l3eiGv3r6exyH64E3
+eLvtKvdcHDVounXv/WwVO56M12nG8gjty1Xb24Au/Ja0egz3aAU/7r8pW4D
cN2+dUHhYDfMP3jtEVnZAAezC6/c4OiG93UCGRkfGuH30h2LC9kkuO2b8zH6
YRNMbx06HTDdBaKL38/n/moBewWLcL8fXZBZF7yHwt4KFbopH56PdIHen6C2
VfytcNf4/MhdUhc09Um6acm2guWqiTTaty7oZ887Qb3TCq2CjjIMvy7gsbpU
u6ahFQxc6nYPSHbB1IHu3Vti2mDgl8LRs6qdcKSKy/KuYgdc2Z9pf/ZkJwyz
XrEI1O4AbW5crXKoE64vmf8pudkBNO8YNnHJTjigt1gl+KQDDinfswhg7QS3
q+E/MLsD/PV2VEuVdcDY9YPeK+KdABpuPPsVOmAyJ0FLiL0L7L3tZQ9saAcl
iyzrJzUk0DCalI5ja4eTbI3Z0EmChO0NIuuW20CbaXGMfYQEGz8+bi1ntEFi
tpPQ678k+P0v4uJIaRvIh5f3hx3uhpHRFI0mmzZw+lWi55nQDcIjUvHHmlrh
3gfBf19dyVDIX09vtG4BuSGKva58D8wWCMVLm7SA3wjd+efpHogxm05wudEC
lulJHmGaPbD3aZ4Nv3oLCGQ9ftZ5twemEkznJkVbYG1SguCZ8B54J8FBKvRu
hmst27YvLveAm2jv0S1bm+CoVvd618peGLxhLWYt3gBXLOdYi3T6gbZDOe3V
2gboN79TLGTYD9cMb0yGTtTDi/ynGTbm/aCaaWvnkF8PExfbD4u/6AcxCYF6
k7P18NH0oqfF137YQnPM+mtWB+n1tHupOwfgUWfI/Z6EGtiZt0cg+fcATH8P
3VXeWwHJqj4CDo2DYLF+5q0ZVkBW0yCxLINQddzSli2+AvS/exiZdw+CgvcT
dbb7FbDO6s+GW9RB2Fol3HxiphyOcNRrHfwzCKXn85S9/pWBhIk9NUFmCOKT
eiL0eEvB5f11kUDfIRAwMl9vtboQ+BR2th1QGgYTvo2/zbEALmWtiHxRH4Ym
qYl9Gi4F8Orih5bT54ch0uz+ubBf+dDvLOqhdm0YphPOc7+ZzAO53X1FYDEM
LpayB2ZacqHxVesH2tth2P/7Q6fsUiZcPnRt7ejUMDw0uFOrY5EJJcZ8i0fn
h8HrsvVbWaKOV+fkbvD5PQzPSYlO66vSIdVGJn072wg8jphdufsqFW7I/bp5
QmQElqR+vbLk/AALFqIOAiojID15Qj8pPgKy8mJWq4aOACR1T3IavIWAN6wX
KyJHgGm0IaRUKBzkOjX5FeNGgKL+RmuzTwiUeX4dO5A2Ahd6L9F4q17DmpcU
p4XSEYivujx1r9sOnIqf8qyaGIHDwboWKqZvsG3g3vNloEJBdbbz8apAPME0
eyquRoUt2yweM3YEo5l2hZX6OSpknxZkGPeFouLiRw2vy1Q4993JdvxmFNpF
aav2P6BCdEyUiywkYPUR6b7fb6iwIbiodjIpE92e/XhZ1E+F+DM6f1h1P+Gx
I4pa0iNUKHWSrT+8KgvN/Hn+BjGokLouPXRTZhbWrY7dYjhDhfQbl0sruXIw
KfY0o3U1DUo96vQbmj5juCDj0VZJGhhuNo/OsyvC33Psw0dNaJCt8S/WuLkI
BcKv7zv1kAaPVB6InJApxufGRVOnLGkwwDH9zGSkGEc1rIoPOdBgYu/VxE9X
SjBzzp5v0YtGnKdfXdfuKEVeoV6RhkQa5L+95MUtVoG5D5PHgwZooHREbyFQ
pwIpt30DTEdosCSxi0XOuwI5I8bvn2DQgF9BcSpnugKvSJ2JbZmiwdY3nfuH
Kyox/dqgd+kKDYx9/Ab6ravxyLSFWLYoHcL9DbUnP1Tjq6T3F45upYNPPJ+h
QF81bkdzvaIddKj4wribfrYGayTiOjOl6VCTMTvPKlmL1uvUOvSO0CG61sPy
Yl8d9m6zeJZ2kQ53hvYnjwrUozZt9mSfLh3OiKjZRpyvx9SqnRYc14j3mzAq
VP1aj9KPj27UMaDD392bG8uiGxBzOJOjTemwNcZ0UdfoO9aqv3PZ5k4H14kA
dfuo7/jXPtH6pycdUmS5/qV3fEeWgKdWVd50eGU+FXP/TBM2sc490vWjw8Jn
zz2r9zVjR53z2M5wOsx4N44NurWg1j5vr6Q0Ovhbc65PjW5BlhKl99yZdBAL
F2h2/dKCYlsuh1tl0SH3kPp+TWYLOllL/tqeR4fTG7r5re63Yq7Kxvaj3+gg
GR/YNqjThiG/YgQUmulQmHLiq5FVG8rX6eQfa6VD5LTnphm/NhRSWVVzuJ0O
Aq8zBWRr23BFcVBElESHo3oLZXLQjqTrNZVB/XTQ4RS3vyzXgafTH4ueniDW
lxSX8kqrAx+KuJh3TNLBN5bG3WTWgeayYyXG03S4aCmiZ5/SgaTvfsoWc8T1
jc/uqot3YuyNf5wyv+gQq7QmokuxE6ni1m98ftPBykWUZGPYiWXTq3v7l+hw
2PKHfl10J27Si055tEKHgrU5P5Y3deErI5PzmiwMqKJVto8c6cKZvlwFS1YG
3DC6EdV1pQvZJ35k+rIxIHxNUFpvcBfmZWVKpK5hgGP06dHpnC604HrO92kt
A2ZsXoxxt3Vhk3azVfo6BrROSOx6yEPCyZB9em84GVDp2H85RY6ENn4WHQ5c
DMhuZZGb1SYh3n38/sp6BuxttWyK9yehbrQ4zx9uBtRssvfmyiChwZ62+IoN
DLh88FaLayMJd62xfOC5kQGmQlZ/n3N149KF+5bjPAxIY2uuW5DuxnmHFF8f
XgYE7+rKtFHvxtbMo+Vb+Rgg98kj08O9G9/aVtse4WdAiO6lEuHYbnyh7tpf
QBjcxZoKvnajc81vbXkBBlxfr9jH86sbl63DpfgEGWCneay5XpCMsf133BwJ
K6bbpPofJKP0G8WqTsLvul4/uK5DxpRjLLN7hRhgvizJus+KjFmWdn+cCXNh
vh2XPxknUm4NVRFuksjLnU0lY5u2X8TaTQx4bO/2dbCWjNZF5VuVCafvM37R
TSfjYcXqh48Iu05GcZPZKDh++Lrje8JUXV2NYXEKfv594nQ1YfbFuP3zihTc
/HvvlxHCzRovcYMhBVULR4d+Ezb1YJk64EJBKfLunHXCDIh9PfbZIIqCfeIf
JXgIq8zzcAd9Icb7iu3/z6mlB6abSBQMO3iy9b/rd9su6AosUDDGq3DVEjGf
1/DPg0YCPdgmpVr43/udPfD5RaF8D1awB8xWEdbNjD+zSacHyaZnPsQRvl65
zdzVqgf3zoq02BFWGnGYnPTvwZcx2Q+AcMzDwYp76T3o0VNgyvrf+BB3Bq2+
B1+97GhEYr2ot8wvWv7oQRX2zFf2hNkfxy78XduLpbt/xO4grLprTVv4zl5c
vrObtYbYjxtHH1OOqvWiZjrPp7uEu2lf1g4b9+JCAsQsEfvbWuGkE+zRi+O+
V2p8CH+OHRDeUNqLPKHpef5EPEhWunmR+nvRokbKgo3w9RPREykrvXhLYEHd
jognsurDF8Yn+rB/6O+ZY0S8hdk++Xhevw8NWEyM3hDx6P4P40896cOfAe5e
A0S8dkc1LRwp6MPJ4F2N94h4buLXAejqw8j73cPRRLx/D3Q7fuFnH953eDna
QOTD1B8bCe+D/RjCcTiZl8iXVc7n/qZf6kdq/3ldaSKfWJYX7/XY9KNaUmLH
EQ4GnOQWyNPO6sfJB+dOnSDycf7rlE9wcz+WTGRvOkDk6yZnh/KBqX4M9vTL
2MrOAK1vT0+/lh3AGvea2UEi/4P/bj2lnDaA6Xttd63+S9QH444Ys+8D+Ocq
9W34HzpsX6d+MWZ6AKVucvJLLtNhMz/ly3rRQYz7arVqG1F/jq39FP7l1iCq
aLzojpqlw8a9+Y1TVoOoq+mRMkTULxez23O73AfxeMweEJsi6nWs3lxSwiD2
zbjHPhqjQ0fw0/nm0UHU0LuuljpMB+mO1H6JpUFc9m0wjhkk6jX1iosT1xAy
tH+u8SbqZ9sbUuHhfUM43uVepEChgy5j07lOuyHU1VKY2UzU442reNO//BtC
t+SV+4Nf6WBqOcqrxjuMxW6vfu0qosOkQVZyu/gwigzmvLxbQAfF8URYUhtG
hqZq8NdsOqiUmEqZ+w2j8Ae5S4wkOkCUYA5FZATxXPGj7cR5M+8T0hgiM4Jm
jmuvfPYh6u9xF3edUyMox1j5fNKLDmF6VUFtt0dQ0EaMtMeVDkey+o7OJY9g
3rBptZMVHVaYNV7vjlCxhLJi/eMCHTLMLkedP0PFhGDH0XXn6fDl1727f65R
cXID97SYBh12sGyZvP2Eiop2kW+kFelACx0in/xKxT4MckQ5OohLXFtWUKYh
i6SYw9R6Oli25s7/uUTDP4YSf4zX0WFx3XmuCmMaJqj7fmpipUPLlU8PLnnR
ULo+y9tziQa8EimNzrU0nJg+q/OQ6CcSnlC1FrXpaLByRWkX0kCz9PXNOkM6
+gkfHpz4QoPT/CzUKGs6uu9bezH5M9GPGB2UVw6io6Sqqt/SRxqIeMhEBXXS
cdp2uFckhAaVdxrGj95k4KrSfZIKRL90uLZk+ZzpKKrbCnDXEv0VRy84uTiN
ooyhlenrJSoUxfW0ZfqPYqPlGqo6kwpzTs713DmjeG5ycMtrKhV0OWc2FS+N
ov2ujf/sq6kQ6s7dWvnqB3aYipfHvqBCUtHUmq3pYyhTeU9V/d8IpJ9uleP6
NoYbFHquqC+MgHFDGvfP5jEEKeExhckRqDqzOfYbcwwZpJ5X0xSiP7ZpF9h1
Yhy/9KldyMobgR9pfXMn68bx0OUzY/YPRqDlwlnthaEJ5Cy6enixfBjsFX89
ZWNO4BH/KNPLhUR/fytXmpttEpP5L19LyBiGrSe8i7h3TqIMZ7W+ENG/x1Vd
i6ozncSq5n+Mi+bDIJWar755ZhLv7Q8L38Q3DJ9fXA+IWpzCdc43RscvDcHO
HyIN7Wun0XH4b6+b+hD07P7IxSY8jV57NUPYjw/BHlehs+ePTmNNndkl+vYh
iNv3wf7J42lU5b92ZmVyEI7dLrI9tDiN9Tlmpz29iO8/hg8ff3eYQSGRuKfr
Lw/APcmSlx0uM/hXf/P5t8cGwMu2YDXp+QwejzojtH7bAPyJvLj8PWgGL1yT
KUj70Q/cMt/2embOYKE6+85Gl35o4QF2VtoMzmw32h75vg86Ff28tmjP4oCW
83I+qQcC9+8IcLs8iwsH/fuvFPUAX7rDeK/+LJayGEn0R/dACpfLU+/7s7gt
/x5X2p0eMO2SZw95Novf869MKYxR4K3nWuvA7Fm8dafSWGaRDB3WIYY9G+bw
3KW9nyZXdcOPVh31WYE5zNxYekqinwQ/ywI0/onOYf7ao4WKxSSwsG9xYN01
hy+c9pEOPiKB24nxW2mn51D0sHf4CqMLCva+i7Y2n8MqC7WKI3Wd8HD1Py9W
2zks36AduJjYCTTeT+P+jnNoH7F7dfyzTkjdasXu6zGHI+r6Jz8rdMKaniqT
TW/n0H+C70FrYge4K+t98CubQ4ENLeEcTu1gJtFAC6qew4urj3TaXmmH+bX7
179pmEOVrvHkGrl2+LCLa8yycw6zNmgGHaK2wX4no7mS0TlUDErcs+18Gxyx
W5sQwc1E1nvkhCvCraCUKneCk4+J0smeKj6zLfAiUfyAjRATRfONPqTUt0CT
MKuQ+DYmsks2a+Q6t4BCyA7qhv1MdJNYJTGKzTD/7W4N90UmfpmifvdV/w4r
11ZmY3WZqHR1YbXQn0YoLD5yfvc1JvLG6b7xzm4Envd6j3fcYuLpngUU3NII
Qf24MdmMiVL25DDmdD2YB2uZsngxsVvs7ENGUC2wZ4zNsPkwkewRo92tXguL
1Rd1/r5kovEDkZLspRrYu+qdT+cbJjYuxmttM6qBLgnDs4LRTCwyedA/IVcN
Oz43snZlMVGzQ/RNQE0FvJTfMqySy8QLm4Q37HlaAf5x1y6m5DHx8Z4mr+y9
FaBGu9N4uYiJyfMLXj6B5aAbXNdxooKJ3L+tvt/SLwOlmwKVBlVMXH9qbrPp
+jIgfXsi6VDDxK3PrLKMvpVC2ZdLe142MFEih69TUrwUlkZpP063E+vVX/mI
0loC994prhboZGJMUkYD81AJXI5tshzoYuIWuwcGM+FfQS9OUfE6hYkLJp5B
oQbFcL9k78PuQSbKPgxlxDEKocHrzqDhMBON3vJ/o54tBD+v0dC+ESZmqdiH
8KQXgCkt93MxnYmKjgdSxK3zQbBF24VlgolBv9doKS3mwq3jnlGHJ5lY228S
MXcjFzYJSmoYTjHx0dpgh8DSHAh5sqIaNsPEnMLt+yJ9s0FLwDswYZaJlDGj
fexTWeB2cfO95DkmTkXJcd2+lAUdXgWRQfNMPLd88GLz4UywDX31+8lPJt4J
mdsq8zcdPj1bQ762QKz3zWoVs+o0yPmpILC4yEQSP9f+mKsfoc7imEXhLyZm
yxtoBG5NAdWPjkrWv5m4FPhMz5L+AQZ3TF2tWCLu93A92+ijRLhPmg69tczE
SnI90/tUAsC5Ms0ZwhZSms/42eNBn2Hp+PgPE3W/n+x43RgH6qyCwouEJWLc
D87vioXBvoG95itM7HfWWEjPj4bsJK48EuFw+SK1c2qRsNOJ+unYXyZe2bHB
sak9HB7aVW8JIrwxq3TghFEobIwSWx4kfIfq1xkyEwT2v+6d2/mPidG/7mX2
uL6BIX8ZTiPCGkNDz6RE/cDyBufxEMJhd/5UPD7yAt7eziR/JawmvqY975IH
xMa0j/YQji/Xyi/vewrvBdTvzxJe2GrBv0rIBqzrhy6vEI4N87zz+agBSNUE
Zf8j/HBX1IrJdxV8JHTF5RdhvXXyzHWeD7Cy5lAh47/5KrbpX+RwQNqkltF3
wkWpCjvXtrph0btGp4+Ex296lV1ofI5WcxNszoQLdLi41mX54guW5RVVwvlK
CeXJwa/xw+il+2yEk6QqxEKLA3F9yW2lIuLz7/397q6abAh2hcT5mRCedu42
HH4XhuuevTvLQbhQ7O0XU54IVHyx8DieWN81xUpbyO5ReOTj5c3yhKM2Osnv
Y8Ygk2R/oJDYn59cEboH5eNwe9vxr8nEfv41z9p7MiEec6VS5HkJ16fJOH7o
ScDVASbbbYh4EBl9WLvCn4SGzwRMBIh4YU+ldFs+T8bJqHOl14h4WpQ0U/P+
moLNY7fCAol42zTgxe89/xHfXjAoHiXi8+mWxgPH76ajpuV67jWEv7wxODAR
lYFu1RKDIkQ8N1przrq3Z6LNmXIeKSLeWV+Kc+55n4VPZjPq64j8CQyI1D22
MRfp+vST7kR+qa6/+fVbQS5qVp0Olh0n6l2mDPe+259Roq1m4e4oEb+rx51q
svJQQGU/Q5vIX56lnQdaLxZickBNTQaR3xwTeU6Bvwox69fbhNUDRP5Z7Rs8
HPcFz/1ep+/Tw8QbLZxC0tNFeJ3dR5yvg4kng/ZLvntVgtn91SdF2pjY9O/h
HjP5b+j3M9JSsIWJlqOfgoTI3/B6cqH0JFGPAva7Ulj4S3HrziOmokQ922O5
v0rYsAwjL/jPWH1iYsiyQ2IgswJvi+32qk9n4tnDRafL1Crxhbn6E9FUJkqa
qDhTwiuxwzkzJDKRWK+N0d61J6owZuD33i0RRH3MPm/p61GN36TGqnc/Y6J5
beS+y1x1mIRH6L3OTPTgv7/080Yd0vYKlXo9YeJqO6cdzul1uNGl7muhLVHf
bj45fkirHgsmLF8n3mViWfTbL+f8G1CyMNMiQp2Jm9vpWxvWNuHbXcHtU8pE
vYoJEtfUacIMDUw6AUxMq+KrzYxsQh7lqg/FCkwcWtJevV22Gb+5zFdekWZi
qbtUiY50C+LuuOHFtcR45a8LfzRa0fVc/3Q1K1Gf5NaSG8xbkTN08Lv/vzk0
lhb69PJNK3LUNAixLs6hn/u7ShKpFemPM9760eawOFbSPf1eG6adeH57B3E+
d7nO75R2bcc59o/p1l/nMG8HTflHXDvOvzM7WlgwhxnNSzFvK9ox90SVzP7M
Ofx4ViW1bF0HlvH6aFdGzmH2+lid40EdSNp1nf050S+wq93dlvW+E90287SG
bZnDXfRGXo4cEv7bOCH7XGgOe16yvRbuJKHzd8EgU545fFekXbPxFwnv/vwa
sYWN6Ce00zjzTnWjTDy5TnJ8FlviEwS7a7rxy4zfQHXBLGpejhE1I5FRfPFt
UrTmLHLc8pfdPdKDvhfDbWNVZ9G48N5TVtZeNJayiIk6NYsxxr2N5eK9uLks
4OgzuVlMO1BycuZOL7bPtRQu883i1xBhC7aBXvzmy+Fb1T2DEp4hHGwdfZjf
JEmfNZxBz/BpjpWUAVxKF1urrzeD0r+rQ7sqB3ByWF245OIMenXucAoZHMCS
oj+H7JVm8HTb77B+rkF8ZGnonCw+gxHTsXG3lQexpGNT6dXaaQw0+vmuOn0Q
H0uHFw/VTOEau1xdNschfB3GfyysYAp/cPFR5TyHUJjks0cleQq/iG5V0QoY
wnWJP794e0/h1imNBwbJQ2j5Y+FrvuoUuk8HH2jvGkI+Cb3KBpxErbRGSYGD
wximILxbN3sC1wf0eIwPDuPc1MYfRu8nMKIoNydmbBhtss4csQycwJXsBX+V
+WHc8VQhz9FmAi+ojmo+XDuClef5Jq4dmMDl2+u5JWVHMLvu1SX9rHFMEyvh
O+cwgquH1xt9TxvD5TLuaMt/I5gsbGVqFjWGFup/2yLWUvHRo4WmNa/GUOe6
91LhRioeGXUeP/xwDCW3v97Vvo2KS2E/Rh2kx3AfyUvHEaioFLmIAYk/UFq5
s9HdmYoD85eCHkeNYqsv90LhJBWt7vUz7H1HMdxZjf/3PBULOGU2WjuOYv2l
G69l/lDxnNAwj7HuKKaf+/D5PicNP1qn+J/iGkXr2d1Gp3bSUOyuUFjrUwa6
zxabG9+goZGj8/byBwzkfygh1XiHhhnJr8xyrjKw7u6aqF0PaFgxXe8cJM9A
uxsF3fn2NJzflrnp0hgdK5VuXVTwp+Hj/KoLPdfpWB+dsVBVTMNj8xSrpjN0
3Hx+/VuDMhou1obuLT9MR0P6pTuj1TRMbTbKSuOlY6HykxekVhqeqGI571NH
Q2dXWcYWBg1HGM/HbI/RcPfI5yPnNtIxudj0vZEoFcUFLD8aXaXjncOyBdkc
VMwxUadL69NRR4USz/J7BEujlpFqQMeY6ytbU0kjuLfwtvGpe8R9meRF84SO
oIZN9BY7Ozo6VMryq/CMoH2D5K+f/nTkfWjhnftvGH+ue88qEkhHPkO/Kzun
h9H473p++RA6Up5w7OJvGkbZxYFr6pF0vJn41IbTbxgHq+UO/Eqio5PF3fMO
64Zx5GIDw7uYjqJzDCGeX0P4V1dOg/sbHYeVG/LSGUMYUXZQ6GUpHW+3rvGf
qh5CV/sGwftVdCybIN0N9RpCMVb1W5+a6Lhn+niY+qMhlGnIpv9ooWOU6Y32
pbtDeK3pJB9RQ3G0J/CVueoQBox5W9wh0bHEVTH9EesQWt34O+M6QEeBNt15
YA7iDN1S22qIjrv2XnfmHhnE7dTy51dH6Jil+uBeTvkgZr1mD+dgEPc/JntW
0mMQZS4lbWCdomP+YslpDttBPKzbO506TcfaE4ZJs3cGMcJqZODsLB1PbXLr
a1QaRKberbUW83R8V30iOmP1IGZqMvefXaKj2CG13L8jA9iTzX8/YZmIE54x
iY9EnWCr5Tj28w8dD0f68vB7D2DCqeE6t390PJ+4Q+EkxwByiUvqHGBj4Akl
ZXfhsX4Mam7bdJadgSfbPvH9qe/HdZ5SGXprGHjzepQ82a8fU4WEDAzXMVCE
+5z9BE8//noY7cm1noEqEctr2Ob68Lsgw3qYsGGDvKxEex8W3fQ0zOYm4ly4
Tu9xaB+y3v99XWEjAwV3KVlnOvShm+Yj2ynC5ZPWMHGtD7WXvZNieBg4yTwv
7Sbah6u8k+ypvAwMFbfV7VjuxaLP58Wc+RjoyqN0/UBfLx5S/fabi5+B17pV
lcO+9WJaoipPCOHjy/NCrHG9KLFt930BAQaaPsobcHTvRf/GXDZ/wsttXYnz
Rr241l9meoWwz2cxtTU7ezHMcbGiVpCBvRTP/VFre1HmV1uRuBAD+y41Hj36
owepu1I3PSIc/Ylxr6++B++dKxlEwrVvcvFleg8WK2huYd3EwDcFS1qKr3tQ
/nJgy2nC3psfCf+16kE1nwZWO8LO/2p2Vur0YPTRQ19jCVuv8X4WdLAHt55m
W1VF+J6GnKypYA+K9dt2DhO+fP/AIY1FCgaX5yn/JiyVyIiWI1PQZW6V9jph
BrowIy23FVPwYL33ykbCtXweWZtiKPiL6XiNh/CWmDJTYTcKOt9mNeIgvGe7
+fsddyjoC1cllon5dh3wuHVQhYJffkW9pxFucJ9L1pKioJrk3+FawvI/I55b
r6XgqGfiZCLhrs8qy1E/yNi+/LnmCWEbtY98LQ1kzH+l63iG8FKUbev6TDL2
nYln2UDYU/7I6UtvyHj/UpnVd2K99oo9MYyzJaNbR1OlF2G2bZ9OLF4mY8ki
fa0C4aVvx8lXFcgYOCABQ8R+FN60OI0iZCyOj7F+TthD7YXN/j/dOKT6MH47
4R11BY9T+7vxYFYMJY/Yz2xtMX3Zsm7c+ensNlXCzqZVm78kdON+uotDAxEf
i+yl18YfdCNXeo59FRFP+mlfBvnOdmOqdWiLDGHn5Se/VXd3o5PQzR0vifhr
r7JfrP1BQgNbndJ9RHzO9XGMi9aTcPBul9gjIn43bN78yjGVhHZx469zNzAw
wdJm4qIZCVujL9QLE/HvvXSr+LsmCc/doyQAkR/HO0QuXdlLQh4Hi0+3uBiY
PHBt9vlkF4Zo/nvqxcHAeNpQqol1FxZSdQsciHxcqEDz4zpdKJ5eNG9I5GuX
8j9pEfku3BRgH6fEysD1BTdTFpmd2LK/4vbUKiJfPkncPfa4Ez/KS1+ZIuqB
yp2DUfeud2Lt/ZjOKKJevNzNthR9vBN5ZWr/Kf2mo/NhUVXZlQ6Uzky2fLxA
R8vPkpEdHh3YeinM8/UMHbV9O2P173Zg7U3KVhaiPp1Lzvw5rtaBvnTFd5aT
dFwbFZe4n6MDD7veNpEnzqmksz2vld+0Y+BLO9o9ov4ZMA7q+sW1oeZsVp9H
Bx2VzV8+qPNow8l/O4V82oj6tbGXh4/oCw+CX6I3UX85Eoqkq3e3YfFT1gGr
Rjr6nyro/JLbivX/GvyYFXS8pDo001rXgts+RDRVZdNR/TXvseLMFrQ3N87x
+0RHb75MzAxuQa4bs7u0M+g4K+r55rNBC4peEO4vTaFj8a35GQdqMz46u26D
SSwdI1d1L1gdb8LaxPK9n1/RcY27jKgfexM+aFnJ3ulLx4fefXNfW75jSNa9
rSHedNS/4tV88/53PHguqszQnY5Vb2zcQkMbcUF6obzIgY7WsaYVEz/rUSvV
d//z23RsZl9z50p5PUactA1OJs7Lx0N2pLbX9cjV8VCumjhP+YV/Xl4vXY/A
7bPz52U6/ohu+/KE6Ps5cvyjRc/S0f2syW6oriHa8I75F/vpaHNsZNWTtErc
1dK0esMfGl6KpZrccajEV1MXtuj9omF9TrqhkVIl3mQZ14qZp6FZSdGaTFIF
/tsQzi0ySfQjMc/5zNkrUFS4Lrarj4Y03zoxj3tlOJP6YK3VNxpSaZG7Bay/
YqXuw9gTzjTkvOPEx7b+K+aKKToyHWnYCKvTJVOK0VeNSyjZjoZa263Ji4NF
eED+SMlqMxruXdS1pV3+gjk5pUpe12l4w2i2n6SWj5ddWYPrDtOwf4yVha6Z
hbQekW7TcSpyy6tf2zf6CStru+AnnYpRdwunRo5+wtwAZXeXYSqSvAwyNXoy
8IGBaNxzMhUnIy9WL0ikofRCTp5FDRX/2SxHkiqT0Jjb1T4znoon/XSUrHzC
cMPZelnWa1RM+LnGiTc0EFR0123LLxjBN/MHXiVVBcHx12v4MnJGcM3gXb34
n8GgEPiz/n3GCIruGKjt0g0Dvf1ZEc8TRpCyyv6OHEcU/LFRW5QLGEGdTWnG
QzLxQL7xYON2kxE80Gu5p045DaoLrDkf841g96FTp9Q186EkBO8E3iP63cdg
PR+cDxXXdFTCDIexaLRH9UlvPqz3Uz4dcX0YOV7Ycq21KID1LtteRWgNo7Ba
VOQhv0Jwuyrc6Hl4GA33schSy4sg7Kv1idXsw9jS5kj7xYsgHErOyY4fQi13
pfz1MRWQWeLvY0keRMFIlw69ogrQ/WRw7Gn7IIZucnMKIVXAwRzPquffB/Hq
YepTCm8lFFzWdwgrI/qIlReD770q4eWix/30j4NYWzGmLfGwCmoXpCYSngzi
Jm27cuFdNaDG36HUKDyI16+dsOK0rQcnc4FfiSn96OQbSvX0rwf/Xlm+o1H9
eDv8etp4Sj3k7dC9VOffj5Pe3zW8B+phfoJHh27bj4UXY5+PajZA6LH4GM5T
/ajV/3L1/R2NsPvsZp5/LX24/YVWqBN+B6FOV7u0xV5UlMgXK77bAgdMPxd8
UOxB6VeXT++0boGEpm+vRYhzszvXN9HXqQWKJG6cfiXVgzl/HbWOBbXAM/kX
cmacPfgv4YLxSWyB+JNFQWIdFFzHdmd3x6ZW0DN+t1n7PgU75F5K3KpoBefC
B+/G/cjIp32T7sDWDsHPslmciO+Lx1q6Fe5xtwOtx+hFbC0JvTKqHmgJtcOB
O7FmFcUktLBTsOGSbof7qQbXOOJJqFOy6+ppzXaIus3d629JwhXud8fc37RD
agMp9OlaEnoKZtj4CnVA62+hK2NHu3D6O4O5kbcTCnl17+tHduDODS7GO0U6
4XSXa626XwfW/Homd2RHJ+z7+iRf3rUD1fObaUoHOuFQ/tRJDqMOVKxi5+TU
6YTirNmN2bs78KOs1DbDgE4QEM/+OFHYjizmFqEya4ncynuzX5TUhh9bbCdK
R7qAf71mjAtfK4bUZdBafnRBC3UvU5W9FXfv3vmiZ7oLylyL+Nb/asFD5d9q
B5e7YLX+fFZEXwuiaJdVGj8JBk5bPM5JacFKhU/Bysok4NtSkEg53YI9qa+3
e0SR4DnzfCRvVxMqT5f8+BFHgiC5irchxU04S1byOf+BBBSfFo1N75uQtSTs
HEs2CT6uZi/bbN6EO+l6HPurSSB/qk56B0sThmZpB4VOk8C+TcJn677vKB+Q
9DHwdDd8FxOqHfVqQNuhrYmnVbrh7LWm2VGzBmxMZH6nn+kGsvM4fVSnAVky
N3+W1umGFfXyw6NiDRi7ccsPW+NuqGiNdKDm1aNmxSBjx4tuUNn6YU0HrQ53
7G31n63vhjNmovuC1Wrxtv+cx5rmbuDYcofiL1OL1sWZtULt3bDhiYyxD28t
Jo13nN3dQ8z3QHy9S18NbmhOOSU03g2P/aD27qMa/MOq+42HkwxFWYvn9iVV
o8v1o+6vVcmwNL9NN52tCj98nDp/Q4MMtPiJQxajldikSsoXP08GUQ7OP7KN
lWh92cn0vS4ZOLZOn/gUXIksibfu3zIiwyrbna+zxCsxfGpnGsmVDKu1HLsy
FSvwlunmA025ZLhq6/Aq2rkMlV2mcmfyydAZfbZL/3YZvq5cZnIXkeGG1BKv
iGoZ3olT/nS0lAz981sMQrnKMHN97J4LjWTw5b56zj+yFMN/ps88GyGDFU/q
k5/WiA9+CmqvcFOgrGLdg6jRYvwxvSpXm4cCLAO0nt7cYlzcLBIRxUeBvSYv
lbe6FaMbY+P4rk0UkMm79iNOsBiHmYF5nNspcGKWLSlJuQjZhiQNfu+nwK5P
XLwZ0YWocuKPIOtBCqg1WbZN3i9E+mEXvXWHKRCm3fJy38FCPPTD3pn9GAVu
czgOfaorQMb5Rq16xf9+r+64N2chH3s38rq5XqDAjNzx+3kX85B0y4xLSYcC
cbtKs39uzkMfvw7pf5cocE7BceEw4zNuaPcWtrxKzHdZyirf5TNmBQiShAyI
z/OdU7wgNRcVtifsCTGlQG1X4KcCthz8JJT9a6MZBax7Mz8tNmfj+SyxWy/M
KbCeTSddISob2eafzTywosBSw7uoggPZGPTkyKlFewqksAdcKbiVhbuAq0zR
jQItfxejzG0ysKzXYCjiGQXSdgZJJS+n4zfpTt9Jdwp0OnqmDnml44YDTfbP
n1Mggvtc8tXINLzr2V5i7UuBv6EitooVH9EQFfe8e0kB8N/b+1TrI17dM7ij
+hUFfNJ2quSRUlAge8tn9tcUkFz3ZN2eiWR88XC1pUoQBT5a9NnzC37AZ2nP
TqkFU4BfxLleKzYJf8t1RiqFUGDZZu9Wn91JSFu1f9WeMAoEhZws/XMqEaPr
Mly+RFAgQ1BmjmYSj0caRyoCIon1vGhzYvvse7Sf3BV5O4oC+y7EeOo7vcfN
T0mLs9EUOHNsiac5IA4Lne64tsdS4NbTNBVrmxgU+/5e0zWOAoXKpbVUr2ik
cmCqxHsKSGR9OX89MgpjFfS23YqngPtKuY5yRQRG/z14mElYdYSlPZ/0Fg8Y
pPd5JFDgUPgLXZmJcPyrv50RmEiBnE2ZlwQEw7AgxFKDN4kC0UF2rT67Q1Ey
6u/JV4RbrlRdWDkVgtv4HQctPxD7dVxdk24ShIdoiQHdhFd8X9fqOwWitFps
28lkCuyMCFVrDniDIUq2Aj8Jl//hcrW28cdpdk/+sykU+Jz6z+F65CtkSWn5
EE6YuSnXSrnCF8+L2jUNEpZWkX8gM/ECzVKevZT8SIE9wS9uCwh6I+8id48R
4XPMYr2VU89RgG1faRThmumui3QTD7TfOXesmbBvZ79Gc8AzvLXhocYK4ZNR
2e7WNi64vyphXCqVAuGzgTbKFU/waUaaxFnCTVvu3REQdEBuT78ZE8LWC3I6
dBNbXNC/cMmNcB9znBhvga4JyxpBhM8v2hLXm6C8ZHhHLGH1yGnidQOkrUj9
TP7v/zLN/1kL////NFyqjqnwMObr/wBDP+3J
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.13107954377593767`, -0.13828795274575156`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.6553977188796887, 0.6914397637287581}]}, 
                 LineBox[{{
                  0.13107954377593767`, -0.13828795274575156`}, \
{-0.6553977188796887, 0.6914397637287581}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 25->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.13968254409376732`, -0.13583780095518494`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.6984127204688372, 0.6791890047759251}]}, 
                 LineBox[{{
                  0.13968254409376732`, -0.13583780095518494`}, \
{-0.6984127204688372, 0.6791890047759251}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 26->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.14794045510290166`, -0.13305176885642087`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.7397022755145085, 0.6652588442821046}]}, 
                 LineBox[{{
                  0.14794045510290166`, -0.13305176885642087`}, \
{-0.7397022755145085, 0.6652588442821046}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 27->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.15585514317278482`, -0.12995681458292643`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.7792757158639247, 0.6497840729146328}]}, 
                 LineBox[{{
                  0.15585514317278482`, -0.12995681458292643`}, \
{-0.7792757158639247, 0.6497840729146328}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 28->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.1634289774728398, -0.1265774433923417}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.8171448873641993, 0.6328872169617089}]}, 
                 LineBox[{{
                  0.1634289774728398, -0.1265774433923417}, \
{-0.8171448873641993, 0.6328872169617089}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 29->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.1706646696906674, -0.12293600612052168`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.8533233484533377, 0.6146800306026087}]}, 
                 LineBox[{{
                  0.1706646696906674, -0.12293600612052168`}, \
{-0.8533233484533377, 0.6146800306026087}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 30->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.1775651508449818, -0.11905295779472197`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.8878257542249093, 0.59526478897361}]}, 
                 LineBox[{{
                  0.1775651508449818, -0.11905295779472197`}, \
{-0.8878257542249093, 0.59526478897361}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 31->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.1841334765207132, -0.11494708210035659`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.9206673826035661, 0.5747354105017828}]}, 
                 LineBox[{{
                  0.1841334765207132, -0.11494708210035659`}, \
{-0.9206673826035661, 0.5747354105017828}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 32->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.19037275395784767`, -0.11063568663686038`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.951863769789238, 0.5531784331843017}]}, 
                 LineBox[{{
                  0.19037275395784767`, -0.11063568663686038`}, \
{-0.951863769789238, 0.5531784331843017}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 33->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.19628608599601846`, -0.10613477320263635`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.981430429980092, 0.5306738660131817}]}, 
                 LineBox[{{
                  0.19628608599601846`, -0.10613477320263635`}, \
{-0.981430429980092, 0.5306738660131817}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 34->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.2018765280544331, -0.1014591867320051}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.009382640272166, 0.5072959336600258}]}, 
                 LineBox[{{
                  0.2018765280544331, -0.1014591867320051}, \
{-1.009382640272166, 0.5072959336600258}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 35->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.20714705521389784`, -0.0966227459705788}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.0357352760694891`, 0.48311372985289397`}]}, 
                 LineBox[{{
                  0.20714705521389784`, -0.0966227459705788}, \
{-1.0357352760694891`, 0.48311372985289397`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 36->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.21210053713929025`, -0.09163835851503294}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.060502685696451, 0.45819179257516457`}]}, 
                 LineBox[{{
                  0.21210053713929025`, -0.09163835851503294}, \
{-1.060502685696451, 0.45819179257516457`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 37->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.2167397190916357, -0.08651812245138922}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.0836985954581788`, 0.4325906122569463}]}, 
                 LineBox[{{
                  0.2167397190916357, -0.08651812245138922}, \
{-1.0836985954581788`, 0.4325906122569463}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 38->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.22106720766923968`, -0.08127341649425658}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.1053360383461985`, 0.4063670824712829}]}, 
                 LineBox[{{
                  0.22106720766923968`, -0.08127341649425658}, \
{-1.1053360383461985`, 0.4063670824712829}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 39->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.2250854602169073, -0.07591498024975489}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.125427301084537, 0.3795749012487745}]}, 
                 LineBox[{{
                  0.2250854602169073, -0.07591498024975489}, \
{-1.125427301084537, 0.3795749012487745}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 40->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.22879677707322846`, -0.07045298598946029}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.1439838853661428`, 0.3522649299473015}]}, 
                 LineBox[{{
                  0.22879677707322846`, -0.07045298598946029}, \
{-1.1439838853661428`, 0.3522649299473015}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 41->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.23220329600469256`, -0.06489710312490381}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.1610164800234632`, 0.3244855156245191}]}, 
                 LineBox[{{
                  0.23220329600469256`, -0.06489710312490381}, \
{-1.1610164800234632`, 0.3244855156245191}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 42->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.23530698831438296`, -0.059256556406097255`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.176534941571915, 0.2962827820304864}]}, 
                 LineBox[{{
                  0.23530698831438296`, -0.059256556406097255`}, \
{-1.176534941571915, 0.2962827820304864}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 43->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.23810965622147343`, -0.05354017872824996}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.190548281107368, 0.26770089364125}]}, 
                 LineBox[{{
                  0.23810965622147343`, -0.05354017872824996}, \
{-1.190548281107368, 0.26770089364125}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 44->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24061293119275334`, -0.04775645931408276}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2030646559637674`, 0.23878229657041397`}]}, 
                 LineBox[{{
                  0.24061293119275334`, -0.04775645931408276}, \
{-1.2030646559637674`, 0.23878229657041397`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 45->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24281827297428998`, -0.041913587941426036`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2140913648714498`, 0.20956793970713017`}]}, 
                 LineBox[{{
                  0.24281827297428998`, -0.041913587941426036`}, \
{-1.2140913648714498`, 0.20956793970713017`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 46->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24472696912420674`, -0.03601949580415442}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2236348456210342`, 0.18009747902077214`}]}, 
                 LineBox[{{
                  0.24472696912420674`, -0.03601949580415442}, \
{-1.2236348456210342`, 0.18009747902077214`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 47->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24634013488953602`, -0.030081893526603072`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2317006744476804`, 0.1504094676330154}]}, 
                 LineBox[{{
                  0.24634013488953602`, -0.030081893526603072`}, \
{-1.2317006744476804`, 0.1504094676330154}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 48->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24765871330366315`, -0.024108306795343194`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2382935665183155`, 0.12054153397671595`}]}, 
                 LineBox[{{
                  0.24765871330366315`, -0.024108306795343194`}, \
{-1.2382935665183155`, 0.12054153397671595`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 49->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24868347540789384`, -0.01810611002604644}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2434173770394696`, 0.09053055013023224}]}, 
                 LineBox[{{
                  0.24868347540789384`, -0.01810611002604644}, \
{-1.2434173770394696`, 0.09053055013023224}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 50->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24941502052265432`, -0.012082558445738826`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2470751026132725`, 0.06041279222869417}]}, 
                 LineBox[{{
                  0.24941502052265432`, -0.012082558445738826`}, \
{-1.2470751026132725`, 0.06041279222869417}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 51->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{
                   0.24985377651195556`, -0.0060448189410240135`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.249268882559778, 0.03022409470512007}]}, 
                 LineBox[{{
                  0.24985377651195556`, -0.0060448189410240135`}, \
{-1.249268882559778, 0.03022409470512007}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 52->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.25, -1.7676253978748444`*^-17}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.25, 8.838126989374223*^-17}]}, 
                 LineBox[{{0.25, -1.7676253978748444`*^-17}, {-1.25, 
                  8.838126989374223*^-17}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 53->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24985377651195556`, 0.006044818941023976}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.249268882559778, -0.030224094705119886`}]}, 
                 LineBox[{{0.24985377651195556`, 
                  0.006044818941023976}, {-1.249268882559778, \
-0.030224094705119886`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 54->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24941502052265432`, 0.012082558445738792`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2470751026132725`, -0.060412792228693994`}]}, 
                 LineBox[{{0.24941502052265432`, 
                  0.012082558445738792`}, {-1.2470751026132725`, \
-0.060412792228693994`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 55->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24868347540789384`, 0.018106110026046472`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2434173770394696`, -0.0905305501302324}]}, 
                 LineBox[{{0.24868347540789384`, 
                  0.018106110026046472`}, {-1.2434173770394696`, \
-0.0905305501302324}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 56->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24765871330366315`, 0.024108306795343225`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2382935665183155`, -0.1205415339767161}]}, 
                 LineBox[{{0.24765871330366315`, 
                  0.024108306795343225`}, {-1.2382935665183155`, \
-0.1205415339767161}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 57->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24634013488953604`, 0.030081893526603037`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2317006744476806`, -0.15040946763301524`}]}, 
                 LineBox[{{0.24634013488953604`, 
                  0.030081893526603037`}, {-1.2317006744476806`, \
-0.15040946763301524`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 58->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24472696912420674`, 0.03601949580415445}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2236348456210342`, -0.18009747902077228`}]}, 
                 LineBox[{{0.24472696912420674`, 
                  0.03601949580415445}, {-1.2236348456210342`, \
-0.18009747902077228`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 59->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW
LJGOfc/OmLEzi+yMKFLv9/c+7zv/zPN55nvvfOfec8498zwzO4ysLt1jWbVq
1RHWVav+e0793wcFVv3f4+GbgWcphOsLvOqdLpwDapELazzhV2H/WR+qQj3l
wwkPVI6QoouNQcZtituHcJKHJ/H6Q0irKQq1J+wt/+ZWho01nMkZqbtJ+NxQ
D3G9HdjZG6cqEo5pE9fxY3cEniMHFbYT5lA1IsY/BSteTevljxS4/DJMxSzC
BTT546+0EZZ8bEDM9wxqju9jJBLOr6eKJgl5gNUTqqQd4RsfDIj5PeFgbuGG
U4RTSyqCQ257wY1vMYkshBOWeS/6sb+AeYPbHc9SKLBVW7vW6cJLqNffanmM
sGCJ7HO7+VfQ8DsjdzKZAtfpJDCL8IcwvUWls4Ql8w7cyLB5Awr8vi9nPlDA
JDHs6G7VQPhwL9o1mPCicZ1gklAQaO+feNCYRIGugCfN0cXBcOjwr1tGhEdr
aGnCr0Pg8LjkqvlECghfW3kRcjsUosftVDgJ/9RnBT/2cOAqyqtniadAMJ0r
2elCJFRKRgs5vKeA/Mknbos7ooC3O3M9LY4CZl0S1+zmoyCRXL+QF0uB7CI6
q1lEDMg//vZNIoYCARqW0hk2ceD0ZfqafTQF8NJTnnFKHDy/LBhZGkUBuYCG
RWnV95D0xl/4fCQFwvvYKhOF4kGxcufvfeEUOH50q050cQKI9Cx03AyjgPL3
hAMUyUTIrgA971AKZF4a4xF+nQgjcg8vNwZTQNzDtCH4dhLsPbVbTPINBXz+
Ncq+Yk8Gk32CJSw+xPpwSgQ9uZAKa9jkj7d7UyCscI9XYFkqLCxrhb/zosDg
0XL7jwfTYP7b9hkpTwpwd41rkDelA4eJLN+iCwWkh4bw6GAGGPbPlMfbUqAt
2/SmU2EWHPrygH+HDTE+Xnbfi9kssBJJOxVpRYFJS5s/QXuyYbqhSczFnAJb
vjD8U6Oz4eSO5X9sJhRYl230jPwsB5I/Xx/eokcB9ag+1yNnPwPjGzlc4yoF
xs2D2JU9PkNcpsM2q8sUMNTn9tYq/gwmIqPx6RcpwPz5zO6ubB60iTqb/dCg
wHZhraVA3nwQ0hb3Mj1KAQsRmsc4uQDqJoQj3fgp0FPQHRb2sBgiSjmz9/FS
4GiLsiw5thhqUqvlyRsoQNG+kL+5sxheVJ6x385JgYs7+WPj4CsUiff2O66i
AHVUv/yjQAnECvysOztBhtK1Zmxfvn2D1pPUx49KyXBa0ObhXY4yyB89k/Om
hAw2LtPebJJl0FASo5RcRIZTN1+GJZ4uA+VIBcPqz2SQ/7b1NdWuDP5u8nVv
TCEDy1QXybi/DPZtXvqyGEAGUHkZZZhbDiOZLxwr9ckQGH989KxBJbQXGz7R
v0aG+ZQiBSPHSrgfyccY1yVDWi3D5mlgJUSaf2NZrUUGI61fialVlXAgZlRi
/jQZWmR8/3Dsq4IHbWUXVnaQodFVXKLybxU4jn6WCqV2w4czZ1Ml4mqgU0Bm
IWywGzb/jo48WlQDRkd5hUJ6u+HNFQ1TrY4aUPh3RfFZRzdkLZNiHdbVAtks
VmJ7ZTec3P7nbo11LTg3O2q4xHeDZXMN9Y5SHfCwJY8l3eiGv3r6exyH64E3
+eLvtKvdcHDVounXv/WwVO56M12nG8gjty1Xb24Au/Ja0egz3aAU/7r8pW4D
cN2+dUHhYDfMP3jtEVnZAAezC6/c4OiG93UCGRkfGuH30h2LC9kkuO2b8zH6
YRNMbx06HTDdBaKL38/n/moBewWLcL8fXZBZF7yHwt4KFbopH56PdIHen6C2
VfytcNf4/MhdUhc09Um6acm2guWqiTTaty7oZ887Qb3TCq2CjjIMvy7gsbpU
u6ahFQxc6nYPSHbB1IHu3Vti2mDgl8LRs6qdcKSKy/KuYgdc2Z9pf/ZkJwyz
XrEI1O4AbW5crXKoE64vmf8pudkBNO8YNnHJTjigt1gl+KQDDinfswhg7QS3
q+E/MLsD/PV2VEuVdcDY9YPeK+KdABpuPPsVOmAyJ0FLiL0L7L3tZQ9saAcl
iyzrJzUk0DCalI5ja4eTbI3Z0EmChO0NIuuW20CbaXGMfYQEGz8+bi1ntEFi
tpPQ678k+P0v4uJIaRvIh5f3hx3uhpHRFI0mmzZw+lWi55nQDcIjUvHHmlrh
3gfBf19dyVDIX09vtG4BuSGKva58D8wWCMVLm7SA3wjd+efpHogxm05wudEC
lulJHmGaPbD3aZ4Nv3oLCGQ9ftZ5twemEkznJkVbYG1SguCZ8B54J8FBKvRu
hmst27YvLveAm2jv0S1bm+CoVvd618peGLxhLWYt3gBXLOdYi3T6gbZDOe3V
2gboN79TLGTYD9cMb0yGTtTDi/ynGTbm/aCaaWvnkF8PExfbD4u/6AcxCYF6
k7P18NH0oqfF137YQnPM+mtWB+n1tHupOwfgUWfI/Z6EGtiZt0cg+fcATH8P
3VXeWwHJqj4CDo2DYLF+5q0ZVkBW0yCxLINQddzSli2+AvS/exiZdw+CgvcT
dbb7FbDO6s+GW9RB2Fol3HxiphyOcNRrHfwzCKXn85S9/pWBhIk9NUFmCOKT
eiL0eEvB5f11kUDfIRAwMl9vtboQ+BR2th1QGgYTvo2/zbEALmWtiHxRH4Ym
qYl9Gi4F8Orih5bT54ch0uz+ubBf+dDvLOqhdm0YphPOc7+ZzAO53X1FYDEM
LpayB2ZacqHxVesH2tth2P/7Q6fsUiZcPnRt7ejUMDw0uFOrY5EJJcZ8i0fn
h8HrsvVbWaKOV+fkbvD5PQzPSYlO66vSIdVGJn072wg8jphdufsqFW7I/bp5
QmQElqR+vbLk/AALFqIOAiojID15Qj8pPgKy8mJWq4aOACR1T3IavIWAN6wX
KyJHgGm0IaRUKBzkOjX5FeNGgKL+RmuzTwiUeX4dO5A2Ahd6L9F4q17DmpcU
p4XSEYivujx1r9sOnIqf8qyaGIHDwboWKqZvsG3g3vNloEJBdbbz8apAPME0
eyquRoUt2yweM3YEo5l2hZX6OSpknxZkGPeFouLiRw2vy1Q4993JdvxmFNpF
aav2P6BCdEyUiywkYPUR6b7fb6iwIbiodjIpE92e/XhZ1E+F+DM6f1h1P+Gx
I4pa0iNUKHWSrT+8KgvN/Hn+BjGokLouPXRTZhbWrY7dYjhDhfQbl0sruXIw
KfY0o3U1DUo96vQbmj5juCDj0VZJGhhuNo/OsyvC33Psw0dNaJCt8S/WuLkI
BcKv7zv1kAaPVB6InJApxufGRVOnLGkwwDH9zGSkGEc1rIoPOdBgYu/VxE9X
SjBzzp5v0YtGnKdfXdfuKEVeoV6RhkQa5L+95MUtVoG5D5PHgwZooHREbyFQ
pwIpt30DTEdosCSxi0XOuwI5I8bvn2DQgF9BcSpnugKvSJ2JbZmiwdY3nfuH
Kyox/dqgd+kKDYx9/Ab6ravxyLSFWLYoHcL9DbUnP1Tjq6T3F45upYNPPJ+h
QF81bkdzvaIddKj4wribfrYGayTiOjOl6VCTMTvPKlmL1uvUOvSO0CG61sPy
Yl8d9m6zeJZ2kQ53hvYnjwrUozZt9mSfLh3OiKjZRpyvx9SqnRYc14j3mzAq
VP1aj9KPj27UMaDD392bG8uiGxBzOJOjTemwNcZ0UdfoO9aqv3PZ5k4H14kA
dfuo7/jXPtH6pycdUmS5/qV3fEeWgKdWVd50eGU+FXP/TBM2sc490vWjw8Jn
zz2r9zVjR53z2M5wOsx4N44NurWg1j5vr6Q0Ovhbc65PjW5BlhKl99yZdBAL
F2h2/dKCYlsuh1tl0SH3kPp+TWYLOllL/tqeR4fTG7r5re63Yq7Kxvaj3+gg
GR/YNqjThiG/YgQUmulQmHLiq5FVG8rX6eQfa6VD5LTnphm/NhRSWVVzuJ0O
Aq8zBWRr23BFcVBElESHo3oLZXLQjqTrNZVB/XTQ4RS3vyzXgafTH4ueniDW
lxSX8kqrAx+KuJh3TNLBN5bG3WTWgeayYyXG03S4aCmiZ5/SgaTvfsoWc8T1
jc/uqot3YuyNf5wyv+gQq7QmokuxE6ni1m98ftPBykWUZGPYiWXTq3v7l+hw
2PKHfl10J27Si055tEKHgrU5P5Y3deErI5PzmiwMqKJVto8c6cKZvlwFS1YG
3DC6EdV1pQvZJ35k+rIxIHxNUFpvcBfmZWVKpK5hgGP06dHpnC604HrO92kt
A2ZsXoxxt3Vhk3azVfo6BrROSOx6yEPCyZB9em84GVDp2H85RY6ENn4WHQ5c
DMhuZZGb1SYh3n38/sp6BuxttWyK9yehbrQ4zx9uBtRssvfmyiChwZ62+IoN
DLh88FaLayMJd62xfOC5kQGmQlZ/n3N149KF+5bjPAxIY2uuW5DuxnmHFF8f
XgYE7+rKtFHvxtbMo+Vb+Rgg98kj08O9G9/aVtse4WdAiO6lEuHYbnyh7tpf
QBjcxZoKvnajc81vbXkBBlxfr9jH86sbl63DpfgEGWCneay5XpCMsf133BwJ
K6bbpPofJKP0G8WqTsLvul4/uK5DxpRjLLN7hRhgvizJus+KjFmWdn+cCXNh
vh2XPxknUm4NVRFuksjLnU0lY5u2X8TaTQx4bO/2dbCWjNZF5VuVCafvM37R
TSfjYcXqh48Iu05GcZPZKDh++Lrje8JUXV2NYXEKfv594nQ1YfbFuP3zihTc
/HvvlxHCzRovcYMhBVULR4d+Ezb1YJk64EJBKfLunHXCDIh9PfbZIIqCfeIf
JXgIq8zzcAd9Icb7iu3/z6mlB6abSBQMO3iy9b/rd9su6AosUDDGq3DVEjGf
1/DPg0YCPdgmpVr43/udPfD5RaF8D1awB8xWEdbNjD+zSacHyaZnPsQRvl65
zdzVqgf3zoq02BFWGnGYnPTvwZcx2Q+AcMzDwYp76T3o0VNgyvrf+BB3Bq2+
B1+97GhEYr2ot8wvWv7oQRX2zFf2hNkfxy78XduLpbt/xO4grLprTVv4zl5c
vrObtYbYjxtHH1OOqvWiZjrPp7uEu2lf1g4b9+JCAsQsEfvbWuGkE+zRi+O+
V2p8CH+OHRDeUNqLPKHpef5EPEhWunmR+nvRokbKgo3w9RPREykrvXhLYEHd
jognsurDF8Yn+rB/6O+ZY0S8hdk++Xhevw8NWEyM3hDx6P4P40896cOfAe5e
A0S8dkc1LRwp6MPJ4F2N94h4buLXAejqw8j73cPRRLx/D3Q7fuFnH953eDna
QOTD1B8bCe+D/RjCcTiZl8iXVc7n/qZf6kdq/3ldaSKfWJYX7/XY9KNaUmLH
EQ4GnOQWyNPO6sfJB+dOnSDycf7rlE9wcz+WTGRvOkDk6yZnh/KBqX4M9vTL
2MrOAK1vT0+/lh3AGvea2UEi/4P/bj2lnDaA6Xttd63+S9QH444Ys+8D+Ocq
9W34HzpsX6d+MWZ6AKVucvJLLtNhMz/ly3rRQYz7arVqG1F/jq39FP7l1iCq
aLzojpqlw8a9+Y1TVoOoq+mRMkTULxez23O73AfxeMweEJsi6nWs3lxSwiD2
zbjHPhqjQ0fw0/nm0UHU0LuuljpMB+mO1H6JpUFc9m0wjhkk6jX1iosT1xAy
tH+u8SbqZ9sbUuHhfUM43uVepEChgy5j07lOuyHU1VKY2UzU442reNO//BtC
t+SV+4Nf6WBqOcqrxjuMxW6vfu0qosOkQVZyu/gwigzmvLxbQAfF8URYUhtG
hqZq8NdsOqiUmEqZ+w2j8Ae5S4wkOkCUYA5FZATxXPGj7cR5M+8T0hgiM4Jm
jmuvfPYh6u9xF3edUyMox1j5fNKLDmF6VUFtt0dQ0EaMtMeVDkey+o7OJY9g
3rBptZMVHVaYNV7vjlCxhLJi/eMCHTLMLkedP0PFhGDH0XXn6fDl1727f65R
cXID97SYBh12sGyZvP2Eiop2kW+kFelACx0in/xKxT4MckQ5OohLXFtWUKYh
i6SYw9R6Oli25s7/uUTDP4YSf4zX0WFx3XmuCmMaJqj7fmpipUPLlU8PLnnR
ULo+y9tziQa8EimNzrU0nJg+q/OQ6CcSnlC1FrXpaLByRWkX0kCz9PXNOkM6
+gkfHpz4QoPT/CzUKGs6uu9bezH5M9GPGB2UVw6io6Sqqt/SRxqIeMhEBXXS
cdp2uFckhAaVdxrGj95k4KrSfZIKRL90uLZk+ZzpKKrbCnDXEv0VRy84uTiN
ooyhlenrJSoUxfW0ZfqPYqPlGqo6kwpzTs713DmjeG5ycMtrKhV0OWc2FS+N
ov2ujf/sq6kQ6s7dWvnqB3aYipfHvqBCUtHUmq3pYyhTeU9V/d8IpJ9uleP6
NoYbFHquqC+MgHFDGvfP5jEEKeExhckRqDqzOfYbcwwZpJ5X0xSiP7ZpF9h1
Yhy/9KldyMobgR9pfXMn68bx0OUzY/YPRqDlwlnthaEJ5Cy6enixfBjsFX89
ZWNO4BH/KNPLhUR/fytXmpttEpP5L19LyBiGrSe8i7h3TqIMZ7W+ENG/x1Vd
i6ozncSq5n+Mi+bDIJWar755ZhLv7Q8L38Q3DJ9fXA+IWpzCdc43RscvDcHO
HyIN7Wun0XH4b6+b+hD07P7IxSY8jV57NUPYjw/BHlehs+ePTmNNndkl+vYh
iNv3wf7J42lU5b92ZmVyEI7dLrI9tDiN9Tlmpz29iO8/hg8ff3eYQSGRuKfr
Lw/APcmSlx0uM/hXf/P5t8cGwMu2YDXp+QwejzojtH7bAPyJvLj8PWgGL1yT
KUj70Q/cMt/2embOYKE6+85Gl35o4QF2VtoMzmw32h75vg86Ff28tmjP4oCW
83I+qQcC9+8IcLs8iwsH/fuvFPUAX7rDeK/+LJayGEn0R/dACpfLU+/7s7gt
/x5X2p0eMO2SZw95Novf869MKYxR4K3nWuvA7Fm8dafSWGaRDB3WIYY9G+bw
3KW9nyZXdcOPVh31WYE5zNxYekqinwQ/ywI0/onOYf7ao4WKxSSwsG9xYN01
hy+c9pEOPiKB24nxW2mn51D0sHf4CqMLCva+i7Y2n8MqC7WKI3Wd8HD1Py9W
2zks36AduJjYCTTeT+P+jnNoH7F7dfyzTkjdasXu6zGHI+r6Jz8rdMKaniqT
TW/n0H+C70FrYge4K+t98CubQ4ENLeEcTu1gJtFAC6qew4urj3TaXmmH+bX7
179pmEOVrvHkGrl2+LCLa8yycw6zNmgGHaK2wX4no7mS0TlUDErcs+18Gxyx
W5sQwc1E1nvkhCvCraCUKneCk4+J0smeKj6zLfAiUfyAjRATRfONPqTUt0CT
MKuQ+DYmsks2a+Q6t4BCyA7qhv1MdJNYJTGKzTD/7W4N90UmfpmifvdV/w4r
11ZmY3WZqHR1YbXQn0YoLD5yfvc1JvLG6b7xzm4Envd6j3fcYuLpngUU3NII
Qf24MdmMiVL25DDmdD2YB2uZsngxsVvs7ENGUC2wZ4zNsPkwkewRo92tXguL
1Rd1/r5kovEDkZLspRrYu+qdT+cbJjYuxmttM6qBLgnDs4LRTCwyedA/IVcN
Oz43snZlMVGzQ/RNQE0FvJTfMqySy8QLm4Q37HlaAf5x1y6m5DHx8Z4mr+y9
FaBGu9N4uYiJyfMLXj6B5aAbXNdxooKJ3L+tvt/SLwOlmwKVBlVMXH9qbrPp
+jIgfXsi6VDDxK3PrLKMvpVC2ZdLe142MFEih69TUrwUlkZpP063E+vVX/mI
0loC994prhboZGJMUkYD81AJXI5tshzoYuIWuwcGM+FfQS9OUfE6hYkLJp5B
oQbFcL9k78PuQSbKPgxlxDEKocHrzqDhMBON3vJ/o54tBD+v0dC+ESZmqdiH
8KQXgCkt93MxnYmKjgdSxK3zQbBF24VlgolBv9doKS3mwq3jnlGHJ5lY228S
MXcjFzYJSmoYTjHx0dpgh8DSHAh5sqIaNsPEnMLt+yJ9s0FLwDswYZaJlDGj
fexTWeB2cfO95DkmTkXJcd2+lAUdXgWRQfNMPLd88GLz4UywDX31+8lPJt4J
mdsq8zcdPj1bQ762QKz3zWoVs+o0yPmpILC4yEQSP9f+mKsfoc7imEXhLyZm
yxtoBG5NAdWPjkrWv5m4FPhMz5L+AQZ3TF2tWCLu93A92+ijRLhPmg69tczE
SnI90/tUAsC5Ms0ZwhZSms/42eNBn2Hp+PgPE3W/n+x43RgH6qyCwouEJWLc
D87vioXBvoG95itM7HfWWEjPj4bsJK48EuFw+SK1c2qRsNOJ+unYXyZe2bHB
sak9HB7aVW8JIrwxq3TghFEobIwSWx4kfIfq1xkyEwT2v+6d2/mPidG/7mX2
uL6BIX8ZTiPCGkNDz6RE/cDyBufxEMJhd/5UPD7yAt7eziR/JawmvqY975IH
xMa0j/YQji/Xyi/vewrvBdTvzxJe2GrBv0rIBqzrhy6vEI4N87zz+agBSNUE
Zf8j/HBX1IrJdxV8JHTF5RdhvXXyzHWeD7Cy5lAh47/5KrbpX+RwQNqkltF3
wkWpCjvXtrph0btGp4+Ex296lV1ofI5WcxNszoQLdLi41mX54guW5RVVwvlK
CeXJwa/xw+il+2yEk6QqxEKLA3F9yW2lIuLz7/397q6abAh2hcT5mRCedu42
HH4XhuuevTvLQbhQ7O0XU54IVHyx8DieWN81xUpbyO5ReOTj5c3yhKM2Osnv
Y8Ygk2R/oJDYn59cEboH5eNwe9vxr8nEfv41z9p7MiEec6VS5HkJ16fJOH7o
ScDVASbbbYh4EBl9WLvCn4SGzwRMBIh4YU+ldFs+T8bJqHOl14h4WpQ0U/P+
moLNY7fCAol42zTgxe89/xHfXjAoHiXi8+mWxgPH76ajpuV67jWEv7wxODAR
lYFu1RKDIkQ8N1przrq3Z6LNmXIeKSLeWV+Kc+55n4VPZjPq64j8CQyI1D22
MRfp+vST7kR+qa6/+fVbQS5qVp0Olh0n6l2mDPe+259Roq1m4e4oEb+rx51q
svJQQGU/Q5vIX56lnQdaLxZickBNTQaR3xwTeU6Bvwox69fbhNUDRP5Z7Rs8
HPcFz/1ep+/Tw8QbLZxC0tNFeJ3dR5yvg4kng/ZLvntVgtn91SdF2pjY9O/h
HjP5b+j3M9JSsIWJlqOfgoTI3/B6cqH0JFGPAva7Ulj4S3HrziOmokQ922O5
v0rYsAwjL/jPWH1iYsiyQ2IgswJvi+32qk9n4tnDRafL1Crxhbn6E9FUJkqa
qDhTwiuxwzkzJDKRWK+N0d61J6owZuD33i0RRH3MPm/p61GN36TGqnc/Y6J5
beS+y1x1mIRH6L3OTPTgv7/080Yd0vYKlXo9YeJqO6cdzul1uNGl7muhLVHf
bj45fkirHgsmLF8n3mViWfTbL+f8G1CyMNMiQp2Jm9vpWxvWNuHbXcHtU8pE
vYoJEtfUacIMDUw6AUxMq+KrzYxsQh7lqg/FCkwcWtJevV22Gb+5zFdekWZi
qbtUiY50C+LuuOHFtcR45a8LfzRa0fVc/3Q1K1Gf5NaSG8xbkTN08Lv/vzk0
lhb69PJNK3LUNAixLs6hn/u7ShKpFemPM9760eawOFbSPf1eG6adeH57B3E+
d7nO75R2bcc59o/p1l/nMG8HTflHXDvOvzM7WlgwhxnNSzFvK9ox90SVzP7M
Ofx4ViW1bF0HlvH6aFdGzmH2+lid40EdSNp1nf050S+wq93dlvW+E90287SG
bZnDXfRGXo4cEv7bOCH7XGgOe16yvRbuJKHzd8EgU545fFekXbPxFwnv/vwa
sYWN6Ce00zjzTnWjTDy5TnJ8FlviEwS7a7rxy4zfQHXBLGpejhE1I5FRfPFt
UrTmLHLc8pfdPdKDvhfDbWNVZ9G48N5TVtZeNJayiIk6NYsxxr2N5eK9uLks
4OgzuVlMO1BycuZOL7bPtRQu883i1xBhC7aBXvzmy+Fb1T2DEp4hHGwdfZjf
JEmfNZxBz/BpjpWUAVxKF1urrzeD0r+rQ7sqB3ByWF245OIMenXucAoZHMCS
oj+H7JVm8HTb77B+rkF8ZGnonCw+gxHTsXG3lQexpGNT6dXaaQw0+vmuOn0Q
H0uHFw/VTOEau1xdNschfB3GfyysYAp/cPFR5TyHUJjks0cleQq/iG5V0QoY
wnWJP794e0/h1imNBwbJQ2j5Y+FrvuoUuk8HH2jvGkI+Cb3KBpxErbRGSYGD
wximILxbN3sC1wf0eIwPDuPc1MYfRu8nMKIoNydmbBhtss4csQycwJXsBX+V
+WHc8VQhz9FmAi+ojmo+XDuClef5Jq4dmMDl2+u5JWVHMLvu1SX9rHFMEyvh
O+cwgquH1xt9TxvD5TLuaMt/I5gsbGVqFjWGFup/2yLWUvHRo4WmNa/GUOe6
91LhRioeGXUeP/xwDCW3v97Vvo2KS2E/Rh2kx3AfyUvHEaioFLmIAYk/UFq5
s9HdmYoD85eCHkeNYqsv90LhJBWt7vUz7H1HMdxZjf/3PBULOGU2WjuOYv2l
G69l/lDxnNAwj7HuKKaf+/D5PicNP1qn+J/iGkXr2d1Gp3bSUOyuUFjrUwa6
zxabG9+goZGj8/byBwzkfygh1XiHhhnJr8xyrjKw7u6aqF0PaFgxXe8cJM9A
uxsF3fn2NJzflrnp0hgdK5VuXVTwp+Hj/KoLPdfpWB+dsVBVTMNj8xSrpjN0
3Hx+/VuDMhou1obuLT9MR0P6pTuj1TRMbTbKSuOlY6HykxekVhqeqGI571NH
Q2dXWcYWBg1HGM/HbI/RcPfI5yPnNtIxudj0vZEoFcUFLD8aXaXjncOyBdkc
VMwxUadL69NRR4USz/J7BEujlpFqQMeY6ytbU0kjuLfwtvGpe8R9meRF84SO
oIZN9BY7Ozo6VMryq/CMoH2D5K+f/nTkfWjhnftvGH+ue88qEkhHPkO/Kzun
h9H473p++RA6Up5w7OJvGkbZxYFr6pF0vJn41IbTbxgHq+UO/Eqio5PF3fMO
64Zx5GIDw7uYjqJzDCGeX0P4V1dOg/sbHYeVG/LSGUMYUXZQ6GUpHW+3rvGf
qh5CV/sGwftVdCybIN0N9RpCMVb1W5+a6Lhn+niY+qMhlGnIpv9ooWOU6Y32
pbtDeK3pJB9RQ3G0J/CVueoQBox5W9wh0bHEVTH9EesQWt34O+M6QEeBNt15
YA7iDN1S22qIjrv2XnfmHhnE7dTy51dH6Jil+uBeTvkgZr1mD+dgEPc/JntW
0mMQZS4lbWCdomP+YslpDttBPKzbO506TcfaE4ZJs3cGMcJqZODsLB1PbXLr
a1QaRKberbUW83R8V30iOmP1IGZqMvefXaKj2CG13L8jA9iTzX8/YZmIE54x
iY9EnWCr5Tj28w8dD0f68vB7D2DCqeE6t390PJ+4Q+EkxwByiUvqHGBj4Akl
ZXfhsX4Mam7bdJadgSfbPvH9qe/HdZ5SGXprGHjzepQ82a8fU4WEDAzXMVCE
+5z9BE8//noY7cm1noEqEctr2Ob68Lsgw3qYsGGDvKxEex8W3fQ0zOYm4ly4
Tu9xaB+y3v99XWEjAwV3KVlnOvShm+Yj2ynC5ZPWMHGtD7WXvZNieBg4yTwv
7Sbah6u8k+ypvAwMFbfV7VjuxaLP58Wc+RjoyqN0/UBfLx5S/fabi5+B17pV
lcO+9WJaoipPCOHjy/NCrHG9KLFt930BAQaaPsobcHTvRf/GXDZ/wsttXYnz
Rr241l9meoWwz2cxtTU7ezHMcbGiVpCBvRTP/VFre1HmV1uRuBAD+y41Hj36
owepu1I3PSIc/Ylxr6++B++dKxlEwrVvcvFleg8WK2huYd3EwDcFS1qKr3tQ
/nJgy2nC3psfCf+16kE1nwZWO8LO/2p2Vur0YPTRQ19jCVuv8X4WdLAHt55m
W1VF+J6GnKypYA+K9dt2DhO+fP/AIY1FCgaX5yn/JiyVyIiWI1PQZW6V9jph
BrowIy23FVPwYL33ykbCtXweWZtiKPiL6XiNh/CWmDJTYTcKOt9mNeIgvGe7
+fsddyjoC1cllon5dh3wuHVQhYJffkW9pxFucJ9L1pKioJrk3+FawvI/I55b
r6XgqGfiZCLhrs8qy1E/yNi+/LnmCWEbtY98LQ1kzH+l63iG8FKUbev6TDL2
nYln2UDYU/7I6UtvyHj/UpnVd2K99oo9MYyzJaNbR1OlF2G2bZ9OLF4mY8ki
fa0C4aVvx8lXFcgYOCABQ8R+FN60OI0iZCyOj7F+TthD7YXN/j/dOKT6MH47
4R11BY9T+7vxYFYMJY/Yz2xtMX3Zsm7c+ensNlXCzqZVm78kdON+uotDAxEf
i+yl18YfdCNXeo59FRFP+mlfBvnOdmOqdWiLDGHn5Se/VXd3o5PQzR0vifhr
r7JfrP1BQgNbndJ9RHzO9XGMi9aTcPBul9gjIn43bN78yjGVhHZx469zNzAw
wdJm4qIZCVujL9QLE/HvvXSr+LsmCc/doyQAkR/HO0QuXdlLQh4Hi0+3uBiY
PHBt9vlkF4Zo/nvqxcHAeNpQqol1FxZSdQsciHxcqEDz4zpdKJ5eNG9I5GuX
8j9pEfku3BRgH6fEysD1BTdTFpmd2LK/4vbUKiJfPkncPfa4Ez/KS1+ZIuqB
yp2DUfeud2Lt/ZjOKKJevNzNthR9vBN5ZWr/Kf2mo/NhUVXZlQ6Uzky2fLxA
R8vPkpEdHh3YeinM8/UMHbV9O2P173Zg7U3KVhaiPp1Lzvw5rtaBvnTFd5aT
dFwbFZe4n6MDD7veNpEnzqmksz2vld+0Y+BLO9o9ov4ZMA7q+sW1oeZsVp9H
Bx2VzV8+qPNow8l/O4V82oj6tbGXh4/oCw+CX6I3UX85Eoqkq3e3YfFT1gGr
Rjr6nyro/JLbivX/GvyYFXS8pDo001rXgts+RDRVZdNR/TXvseLMFrQ3N87x
+0RHb75MzAxuQa4bs7u0M+g4K+r55rNBC4peEO4vTaFj8a35GQdqMz46u26D
SSwdI1d1L1gdb8LaxPK9n1/RcY27jKgfexM+aFnJ3ulLx4fefXNfW75jSNa9
rSHedNS/4tV88/53PHguqszQnY5Vb2zcQkMbcUF6obzIgY7WsaYVEz/rUSvV
d//z23RsZl9z50p5PUactA1OJs7Lx0N2pLbX9cjV8VCumjhP+YV/Xl4vXY/A
7bPz52U6/ohu+/KE6Ps5cvyjRc/S0f2syW6oriHa8I75F/vpaHNsZNWTtErc
1dK0esMfGl6KpZrccajEV1MXtuj9omF9TrqhkVIl3mQZ14qZp6FZSdGaTFIF
/tsQzi0ySfQjMc/5zNkrUFS4Lrarj4Y03zoxj3tlOJP6YK3VNxpSaZG7Bay/
YqXuw9gTzjTkvOPEx7b+K+aKKToyHWnYCKvTJVOK0VeNSyjZjoZa263Ji4NF
eED+SMlqMxruXdS1pV3+gjk5pUpe12l4w2i2n6SWj5ddWYPrDtOwf4yVha6Z
hbQekW7TcSpyy6tf2zf6CStru+AnnYpRdwunRo5+wtwAZXeXYSqSvAwyNXoy
8IGBaNxzMhUnIy9WL0ikofRCTp5FDRX/2SxHkiqT0Jjb1T4znoon/XSUrHzC
cMPZelnWa1RM+LnGiTc0EFR0123LLxjBN/MHXiVVBcHx12v4MnJGcM3gXb34
n8GgEPiz/n3GCIruGKjt0g0Dvf1ZEc8TRpCyyv6OHEcU/LFRW5QLGEGdTWnG
QzLxQL7xYON2kxE80Gu5p045DaoLrDkf841g96FTp9Q186EkBO8E3iP63cdg
PR+cDxXXdFTCDIexaLRH9UlvPqz3Uz4dcX0YOV7Ycq21KID1LtteRWgNo7Ba
VOQhv0Jwuyrc6Hl4GA33schSy4sg7Kv1idXsw9jS5kj7xYsgHErOyY4fQi13
pfz1MRWQWeLvY0keRMFIlw69ogrQ/WRw7Gn7IIZucnMKIVXAwRzPquffB/Hq
YepTCm8lFFzWdwgrI/qIlReD770q4eWix/30j4NYWzGmLfGwCmoXpCYSngzi
Jm27cuFdNaDG36HUKDyI16+dsOK0rQcnc4FfiSn96OQbSvX0rwf/Xlm+o1H9
eDv8etp4Sj3k7dC9VOffj5Pe3zW8B+phfoJHh27bj4UXY5+PajZA6LH4GM5T
/ajV/3L1/R2NsPvsZp5/LX24/YVWqBN+B6FOV7u0xV5UlMgXK77bAgdMPxd8
UOxB6VeXT++0boGEpm+vRYhzszvXN9HXqQWKJG6cfiXVgzl/HbWOBbXAM/kX
cmacPfgv4YLxSWyB+JNFQWIdFFzHdmd3x6ZW0DN+t1n7PgU75F5K3KpoBefC
B+/G/cjIp32T7sDWDsHPslmciO+Lx1q6Fe5xtwOtx+hFbC0JvTKqHmgJtcOB
O7FmFcUktLBTsOGSbof7qQbXOOJJqFOy6+ppzXaIus3d629JwhXud8fc37RD
agMp9OlaEnoKZtj4CnVA62+hK2NHu3D6O4O5kbcTCnl17+tHduDODS7GO0U6
4XSXa626XwfW/Homd2RHJ+z7+iRf3rUD1fObaUoHOuFQ/tRJDqMOVKxi5+TU
6YTirNmN2bs78KOs1DbDgE4QEM/+OFHYjizmFqEya4ncynuzX5TUhh9bbCdK
R7qAf71mjAtfK4bUZdBafnRBC3UvU5W9FXfv3vmiZ7oLylyL+Nb/asFD5d9q
B5e7YLX+fFZEXwuiaJdVGj8JBk5bPM5JacFKhU/Bysok4NtSkEg53YI9qa+3
e0SR4DnzfCRvVxMqT5f8+BFHgiC5irchxU04S1byOf+BBBSfFo1N75uQtSTs
HEs2CT6uZi/bbN6EO+l6HPurSSB/qk56B0sThmZpB4VOk8C+TcJn677vKB+Q
9DHwdDd8FxOqHfVqQNuhrYmnVbrh7LWm2VGzBmxMZH6nn+kGsvM4fVSnAVky
N3+W1umGFfXyw6NiDRi7ccsPW+NuqGiNdKDm1aNmxSBjx4tuUNn6YU0HrQ53
7G31n63vhjNmovuC1Wrxtv+cx5rmbuDYcofiL1OL1sWZtULt3bDhiYyxD28t
Jo13nN3dQ8z3QHy9S18NbmhOOSU03g2P/aD27qMa/MOq+42HkwxFWYvn9iVV
o8v1o+6vVcmwNL9NN52tCj98nDp/Q4MMtPiJQxajldikSsoXP08GUQ7OP7KN
lWh92cn0vS4ZOLZOn/gUXIksibfu3zIiwyrbna+zxCsxfGpnGsmVDKu1HLsy
FSvwlunmA025ZLhq6/Aq2rkMlV2mcmfyydAZfbZL/3YZvq5cZnIXkeGG1BKv
iGoZ3olT/nS0lAz981sMQrnKMHN97J4LjWTw5b56zj+yFMN/ps88GyGDFU/q
k5/WiA9+CmqvcFOgrGLdg6jRYvwxvSpXm4cCLAO0nt7cYlzcLBIRxUeBvSYv
lbe6FaMbY+P4rk0UkMm79iNOsBiHmYF5nNspcGKWLSlJuQjZhiQNfu+nwK5P
XLwZ0YWocuKPIOtBCqg1WbZN3i9E+mEXvXWHKRCm3fJy38FCPPTD3pn9GAVu
czgOfaorQMb5Rq16xf9+r+64N2chH3s38rq5XqDAjNzx+3kX85B0y4xLSYcC
cbtKs39uzkMfvw7pf5cocE7BceEw4zNuaPcWtrxKzHdZyirf5TNmBQiShAyI
z/OdU7wgNRcVtifsCTGlQG1X4KcCthz8JJT9a6MZBax7Mz8tNmfj+SyxWy/M
KbCeTSddISob2eafzTywosBSw7uoggPZGPTkyKlFewqksAdcKbiVhbuAq0zR
jQItfxejzG0ysKzXYCjiGQXSdgZJJS+n4zfpTt9Jdwp0OnqmDnml44YDTfbP
n1Mggvtc8tXINLzr2V5i7UuBv6EitooVH9EQFfe8e0kB8N/b+1TrI17dM7ij
+hUFfNJ2quSRUlAge8tn9tcUkFz3ZN2eiWR88XC1pUoQBT5a9NnzC37AZ2nP
TqkFU4BfxLleKzYJf8t1RiqFUGDZZu9Wn91JSFu1f9WeMAoEhZws/XMqEaPr
Mly+RFAgQ1BmjmYSj0caRyoCIon1vGhzYvvse7Sf3BV5O4oC+y7EeOo7vcfN
T0mLs9EUOHNsiac5IA4Lne64tsdS4NbTNBVrmxgU+/5e0zWOAoXKpbVUr2ik
cmCqxHsKSGR9OX89MgpjFfS23YqngPtKuY5yRQRG/z14mElYdYSlPZ/0Fg8Y
pPd5JFDgUPgLXZmJcPyrv50RmEiBnE2ZlwQEw7AgxFKDN4kC0UF2rT67Q1Ey
6u/JV4RbrlRdWDkVgtv4HQctPxD7dVxdk24ShIdoiQHdhFd8X9fqOwWitFps
28lkCuyMCFVrDniDIUq2Aj8Jl//hcrW28cdpdk/+sykU+Jz6z+F65CtkSWn5
EE6YuSnXSrnCF8+L2jUNEpZWkX8gM/ECzVKevZT8SIE9wS9uCwh6I+8id48R
4XPMYr2VU89RgG1faRThmumui3QTD7TfOXesmbBvZ79Gc8AzvLXhocYK4ZNR
2e7WNi64vyphXCqVAuGzgTbKFU/waUaaxFnCTVvu3REQdEBuT78ZE8LWC3I6
dBNbXNC/cMmNcB9znBhvga4JyxpBhM8v2hLXm6C8ZHhHLGH1yGnidQOkrUj9
TP7v/zLN/1kL////NFyqjqnwMObr/wBDP+3J
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24281827297428998`, 0.041913587941425946`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2140913648714498`, -0.2095679397071297}]}, 
                 LineBox[{{0.24281827297428998`, 
                  0.041913587941425946`}, {-1.2140913648714498`, \
-0.2095679397071297}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 60->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.24061293119275334`, 0.04775645931408265}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.2030646559637677`, -0.23878229657041347`}]}, 
                 LineBox[{{0.24061293119275334`, 
                  0.04775645931408265}, {-1.2030646559637677`, \
-0.23878229657041347`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 61->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.23810965622147343`, 0.053540178728249864`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.190548281107368, -0.26770089364124955`}]}, 
                 LineBox[{{0.23810965622147343`, 
                  0.053540178728249864`}, {-1.190548281107368, \
-0.26770089364124955`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 62->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.23530698831438296`, 0.05925655640609724}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.176534941571915, -0.2962827820304863}]}, 
                 LineBox[{{0.23530698831438296`, 
                  0.05925655640609724}, {-1.176534941571915, \
-0.2962827820304863}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 63->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.23220329600469256`, 0.06489710312490378}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.1610164800234632`, -0.324485515624519}]}, 
                 LineBox[{{0.23220329600469256`, 
                  0.06489710312490378}, {-1.1610164800234632`, \
-0.324485515624519}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 64->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.22879677707322846`, 0.07045298598946025}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.143983885366143, -0.3522649299473014}]}, 
                 LineBox[{{0.22879677707322846`, 
                  0.07045298598946025}, {-1.143983885366143, \
-0.3522649299473014}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 65->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.2250854602169073, 0.07591498024975485}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.125427301084537, -0.37957490124877435`}]}, 
                 LineBox[{{0.2250854602169073, 
                  0.07591498024975485}, {-1.125427301084537, \
-0.37957490124877435`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 66->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.22106720766923968`, 0.0812734164942566}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.1053360383461985`, -0.40636708247128306`}]}, 
                 LineBox[{{0.22106720766923968`, 
                  0.0812734164942566}, {-1.1053360383461985`, \
-0.40636708247128306`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 67->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.2167397190916357, 0.08651812245138925}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.0836985954581788`, -0.4325906122569464}]}, 
                 LineBox[{{0.2167397190916357, 
                  0.08651812245138925}, {-1.0836985954581788`, \
-0.4325906122569464}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 68->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.21210053713929006`, 0.09163835851503288}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.060502685696451, -0.45819179257516474`}]}, 
                 LineBox[{{0.21210053713929006`, 
                  0.09163835851503288}, {-1.060502685696451, \
-0.45819179257516474`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 69->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.20714705521389784`, 0.09662274597057885}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.035735276069489, -0.48311372985289414`}]}, 
                 LineBox[{{0.20714705521389784`, 
                  0.09662274597057885}, {-1.035735276069489, \
-0.48311372985289414`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 70->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.20187652805443304`, 0.10145918673200517`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-1.0093826402721655`, -0.507295933660026}]}, 
                 LineBox[{{0.20187652805443304`, 
                  0.10145918673200517`}, {-1.0093826402721655`, \
-0.507295933660026}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 71->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.1962860859960185, 0.1061347732026363}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.9814304299800922, -0.5306738660131813}]}, 
                 LineBox[{{0.1962860859960185, 
                  0.1061347732026363}, {-0.9814304299800922, \
-0.5306738660131813}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 72->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW
LJGOfc/OmLEzi+yMKFLv9/c+7zv/zPN55nvvfOfec8498zwzO4ysLt1jWbVq
1RHWVav+e0793wcFVv3f4+GbgWcphOsLvOqdLpwDapELazzhV2H/WR+qQj3l
wwkPVI6QoouNQcZtituHcJKHJ/H6Q0irKQq1J+wt/+ZWho01nMkZqbtJ+NxQ
D3G9HdjZG6cqEo5pE9fxY3cEniMHFbYT5lA1IsY/BSteTevljxS4/DJMxSzC
BTT546+0EZZ8bEDM9wxqju9jJBLOr6eKJgl5gNUTqqQd4RsfDIj5PeFgbuGG
U4RTSyqCQ257wY1vMYkshBOWeS/6sb+AeYPbHc9SKLBVW7vW6cJLqNffanmM
sGCJ7HO7+VfQ8DsjdzKZAtfpJDCL8IcwvUWls4Ql8w7cyLB5Awr8vi9nPlDA
JDHs6G7VQPhwL9o1mPCicZ1gklAQaO+feNCYRIGugCfN0cXBcOjwr1tGhEdr
aGnCr0Pg8LjkqvlECghfW3kRcjsUosftVDgJ/9RnBT/2cOAqyqtniadAMJ0r
2elCJFRKRgs5vKeA/Mknbos7ooC3O3M9LY4CZl0S1+zmoyCRXL+QF0uB7CI6
q1lEDMg//vZNIoYCARqW0hk2ceD0ZfqafTQF8NJTnnFKHDy/LBhZGkUBuYCG
RWnV95D0xl/4fCQFwvvYKhOF4kGxcufvfeEUOH50q050cQKI9Cx03AyjgPL3
hAMUyUTIrgA971AKZF4a4xF+nQgjcg8vNwZTQNzDtCH4dhLsPbVbTPINBXz+
Ncq+Yk8Gk32CJSw+xPpwSgQ9uZAKa9jkj7d7UyCscI9XYFkqLCxrhb/zosDg
0XL7jwfTYP7b9hkpTwpwd41rkDelA4eJLN+iCwWkh4bw6GAGGPbPlMfbUqAt
2/SmU2EWHPrygH+HDTE+Xnbfi9kssBJJOxVpRYFJS5s/QXuyYbqhSczFnAJb
vjD8U6Oz4eSO5X9sJhRYl230jPwsB5I/Xx/eokcB9ag+1yNnPwPjGzlc4yoF
xs2D2JU9PkNcpsM2q8sUMNTn9tYq/gwmIqPx6RcpwPz5zO6ubB60iTqb/dCg
wHZhraVA3nwQ0hb3Mj1KAQsRmsc4uQDqJoQj3fgp0FPQHRb2sBgiSjmz9/FS
4GiLsiw5thhqUqvlyRsoQNG+kL+5sxheVJ6x385JgYs7+WPj4CsUiff2O66i
AHVUv/yjQAnECvysOztBhtK1Zmxfvn2D1pPUx49KyXBa0ObhXY4yyB89k/Om
hAw2LtPebJJl0FASo5RcRIZTN1+GJZ4uA+VIBcPqz2SQ/7b1NdWuDP5u8nVv
TCEDy1QXybi/DPZtXvqyGEAGUHkZZZhbDiOZLxwr9ckQGH989KxBJbQXGz7R
v0aG+ZQiBSPHSrgfyccY1yVDWi3D5mlgJUSaf2NZrUUGI61fialVlXAgZlRi
/jQZWmR8/3Dsq4IHbWUXVnaQodFVXKLybxU4jn6WCqV2w4czZ1Ml4mqgU0Bm
IWywGzb/jo48WlQDRkd5hUJ6u+HNFQ1TrY4aUPh3RfFZRzdkLZNiHdbVAtks
VmJ7ZTec3P7nbo11LTg3O2q4xHeDZXMN9Y5SHfCwJY8l3eiGv3r6exyH64E3
+eLvtKvdcHDVounXv/WwVO56M12nG8gjty1Xb24Au/Ja0egz3aAU/7r8pW4D
cN2+dUHhYDfMP3jtEVnZAAezC6/c4OiG93UCGRkfGuH30h2LC9kkuO2b8zH6
YRNMbx06HTDdBaKL38/n/moBewWLcL8fXZBZF7yHwt4KFbopH56PdIHen6C2
VfytcNf4/MhdUhc09Um6acm2guWqiTTaty7oZ887Qb3TCq2CjjIMvy7gsbpU
u6ahFQxc6nYPSHbB1IHu3Vti2mDgl8LRs6qdcKSKy/KuYgdc2Z9pf/ZkJwyz
XrEI1O4AbW5crXKoE64vmf8pudkBNO8YNnHJTjigt1gl+KQDDinfswhg7QS3
q+E/MLsD/PV2VEuVdcDY9YPeK+KdABpuPPsVOmAyJ0FLiL0L7L3tZQ9saAcl
iyzrJzUk0DCalI5ja4eTbI3Z0EmChO0NIuuW20CbaXGMfYQEGz8+bi1ntEFi
tpPQ678k+P0v4uJIaRvIh5f3hx3uhpHRFI0mmzZw+lWi55nQDcIjUvHHmlrh
3gfBf19dyVDIX09vtG4BuSGKva58D8wWCMVLm7SA3wjd+efpHogxm05wudEC
lulJHmGaPbD3aZ4Nv3oLCGQ9ftZ5twemEkznJkVbYG1SguCZ8B54J8FBKvRu
hmst27YvLveAm2jv0S1bm+CoVvd618peGLxhLWYt3gBXLOdYi3T6gbZDOe3V
2gboN79TLGTYD9cMb0yGTtTDi/ynGTbm/aCaaWvnkF8PExfbD4u/6AcxCYF6
k7P18NH0oqfF137YQnPM+mtWB+n1tHupOwfgUWfI/Z6EGtiZt0cg+fcATH8P
3VXeWwHJqj4CDo2DYLF+5q0ZVkBW0yCxLINQddzSli2+AvS/exiZdw+CgvcT
dbb7FbDO6s+GW9RB2Fol3HxiphyOcNRrHfwzCKXn85S9/pWBhIk9NUFmCOKT
eiL0eEvB5f11kUDfIRAwMl9vtboQ+BR2th1QGgYTvo2/zbEALmWtiHxRH4Ym
qYl9Gi4F8Orih5bT54ch0uz+ubBf+dDvLOqhdm0YphPOc7+ZzAO53X1FYDEM
LpayB2ZacqHxVesH2tth2P/7Q6fsUiZcPnRt7ejUMDw0uFOrY5EJJcZ8i0fn
h8HrsvVbWaKOV+fkbvD5PQzPSYlO66vSIdVGJn072wg8jphdufsqFW7I/bp5
QmQElqR+vbLk/AALFqIOAiojID15Qj8pPgKy8mJWq4aOACR1T3IavIWAN6wX
KyJHgGm0IaRUKBzkOjX5FeNGgKL+RmuzTwiUeX4dO5A2Ahd6L9F4q17DmpcU
p4XSEYivujx1r9sOnIqf8qyaGIHDwboWKqZvsG3g3vNloEJBdbbz8apAPME0
eyquRoUt2yweM3YEo5l2hZX6OSpknxZkGPeFouLiRw2vy1Q4993JdvxmFNpF
aav2P6BCdEyUiywkYPUR6b7fb6iwIbiodjIpE92e/XhZ1E+F+DM6f1h1P+Gx
I4pa0iNUKHWSrT+8KgvN/Hn+BjGokLouPXRTZhbWrY7dYjhDhfQbl0sruXIw
KfY0o3U1DUo96vQbmj5juCDj0VZJGhhuNo/OsyvC33Psw0dNaJCt8S/WuLkI
BcKv7zv1kAaPVB6InJApxufGRVOnLGkwwDH9zGSkGEc1rIoPOdBgYu/VxE9X
SjBzzp5v0YtGnKdfXdfuKEVeoV6RhkQa5L+95MUtVoG5D5PHgwZooHREbyFQ
pwIpt30DTEdosCSxi0XOuwI5I8bvn2DQgF9BcSpnugKvSJ2JbZmiwdY3nfuH
Kyox/dqgd+kKDYx9/Ab6ravxyLSFWLYoHcL9DbUnP1Tjq6T3F45upYNPPJ+h
QF81bkdzvaIddKj4wribfrYGayTiOjOl6VCTMTvPKlmL1uvUOvSO0CG61sPy
Yl8d9m6zeJZ2kQ53hvYnjwrUozZt9mSfLh3OiKjZRpyvx9SqnRYc14j3mzAq
VP1aj9KPj27UMaDD392bG8uiGxBzOJOjTemwNcZ0UdfoO9aqv3PZ5k4H14kA
dfuo7/jXPtH6pycdUmS5/qV3fEeWgKdWVd50eGU+FXP/TBM2sc490vWjw8Jn
zz2r9zVjR53z2M5wOsx4N44NurWg1j5vr6Q0Ovhbc65PjW5BlhKl99yZdBAL
F2h2/dKCYlsuh1tl0SH3kPp+TWYLOllL/tqeR4fTG7r5re63Yq7Kxvaj3+gg
GR/YNqjThiG/YgQUmulQmHLiq5FVG8rX6eQfa6VD5LTnphm/NhRSWVVzuJ0O
Aq8zBWRr23BFcVBElESHo3oLZXLQjqTrNZVB/XTQ4RS3vyzXgafTH4ueniDW
lxSX8kqrAx+KuJh3TNLBN5bG3WTWgeayYyXG03S4aCmiZ5/SgaTvfsoWc8T1
jc/uqot3YuyNf5wyv+gQq7QmokuxE6ni1m98ftPBykWUZGPYiWXTq3v7l+hw
2PKHfl10J27Si055tEKHgrU5P5Y3deErI5PzmiwMqKJVto8c6cKZvlwFS1YG
3DC6EdV1pQvZJ35k+rIxIHxNUFpvcBfmZWVKpK5hgGP06dHpnC604HrO92kt
A2ZsXoxxt3Vhk3azVfo6BrROSOx6yEPCyZB9em84GVDp2H85RY6ENn4WHQ5c
DMhuZZGb1SYh3n38/sp6BuxttWyK9yehbrQ4zx9uBtRssvfmyiChwZ62+IoN
DLh88FaLayMJd62xfOC5kQGmQlZ/n3N149KF+5bjPAxIY2uuW5DuxnmHFF8f
XgYE7+rKtFHvxtbMo+Vb+Rgg98kj08O9G9/aVtse4WdAiO6lEuHYbnyh7tpf
QBjcxZoKvnajc81vbXkBBlxfr9jH86sbl63DpfgEGWCneay5XpCMsf133BwJ
K6bbpPofJKP0G8WqTsLvul4/uK5DxpRjLLN7hRhgvizJus+KjFmWdn+cCXNh
vh2XPxknUm4NVRFuksjLnU0lY5u2X8TaTQx4bO/2dbCWjNZF5VuVCafvM37R
TSfjYcXqh48Iu05GcZPZKDh++Lrje8JUXV2NYXEKfv594nQ1YfbFuP3zihTc
/HvvlxHCzRovcYMhBVULR4d+Ezb1YJk64EJBKfLunHXCDIh9PfbZIIqCfeIf
JXgIq8zzcAd9Icb7iu3/z6mlB6abSBQMO3iy9b/rd9su6AosUDDGq3DVEjGf
1/DPg0YCPdgmpVr43/udPfD5RaF8D1awB8xWEdbNjD+zSacHyaZnPsQRvl65
zdzVqgf3zoq02BFWGnGYnPTvwZcx2Q+AcMzDwYp76T3o0VNgyvrf+BB3Bq2+
B1+97GhEYr2ot8wvWv7oQRX2zFf2hNkfxy78XduLpbt/xO4grLprTVv4zl5c
vrObtYbYjxtHH1OOqvWiZjrPp7uEu2lf1g4b9+JCAsQsEfvbWuGkE+zRi+O+
V2p8CH+OHRDeUNqLPKHpef5EPEhWunmR+nvRokbKgo3w9RPREykrvXhLYEHd
jognsurDF8Yn+rB/6O+ZY0S8hdk++Xhevw8NWEyM3hDx6P4P40896cOfAe5e
A0S8dkc1LRwp6MPJ4F2N94h4buLXAejqw8j73cPRRLx/D3Q7fuFnH953eDna
QOTD1B8bCe+D/RjCcTiZl8iXVc7n/qZf6kdq/3ldaSKfWJYX7/XY9KNaUmLH
EQ4GnOQWyNPO6sfJB+dOnSDycf7rlE9wcz+WTGRvOkDk6yZnh/KBqX4M9vTL
2MrOAK1vT0+/lh3AGvea2UEi/4P/bj2lnDaA6Xttd63+S9QH444Ys+8D+Ocq
9W34HzpsX6d+MWZ6AKVucvJLLtNhMz/ly3rRQYz7arVqG1F/jq39FP7l1iCq
aLzojpqlw8a9+Y1TVoOoq+mRMkTULxez23O73AfxeMweEJsi6nWs3lxSwiD2
zbjHPhqjQ0fw0/nm0UHU0LuuljpMB+mO1H6JpUFc9m0wjhkk6jX1iosT1xAy
tH+u8SbqZ9sbUuHhfUM43uVepEChgy5j07lOuyHU1VKY2UzU442reNO//BtC
t+SV+4Nf6WBqOcqrxjuMxW6vfu0qosOkQVZyu/gwigzmvLxbQAfF8URYUhtG
hqZq8NdsOqiUmEqZ+w2j8Ae5S4wkOkCUYA5FZATxXPGj7cR5M+8T0hgiM4Jm
jmuvfPYh6u9xF3edUyMox1j5fNKLDmF6VUFtt0dQ0EaMtMeVDkey+o7OJY9g
3rBptZMVHVaYNV7vjlCxhLJi/eMCHTLMLkedP0PFhGDH0XXn6fDl1727f65R
cXID97SYBh12sGyZvP2Eiop2kW+kFelACx0in/xKxT4MckQ5OohLXFtWUKYh
i6SYw9R6Oli25s7/uUTDP4YSf4zX0WFx3XmuCmMaJqj7fmpipUPLlU8PLnnR
ULo+y9tziQa8EimNzrU0nJg+q/OQ6CcSnlC1FrXpaLByRWkX0kCz9PXNOkM6
+gkfHpz4QoPT/CzUKGs6uu9bezH5M9GPGB2UVw6io6Sqqt/SRxqIeMhEBXXS
cdp2uFckhAaVdxrGj95k4KrSfZIKRL90uLZk+ZzpKKrbCnDXEv0VRy84uTiN
ooyhlenrJSoUxfW0ZfqPYqPlGqo6kwpzTs713DmjeG5ycMtrKhV0OWc2FS+N
ov2ujf/sq6kQ6s7dWvnqB3aYipfHvqBCUtHUmq3pYyhTeU9V/d8IpJ9uleP6
NoYbFHquqC+MgHFDGvfP5jEEKeExhckRqDqzOfYbcwwZpJ5X0xSiP7ZpF9h1
Yhy/9KldyMobgR9pfXMn68bx0OUzY/YPRqDlwlnthaEJ5Cy6enixfBjsFX89
ZWNO4BH/KNPLhUR/fytXmpttEpP5L19LyBiGrSe8i7h3TqIMZ7W+ENG/x1Vd
i6ozncSq5n+Mi+bDIJWar755ZhLv7Q8L38Q3DJ9fXA+IWpzCdc43RscvDcHO
HyIN7Wun0XH4b6+b+hD07P7IxSY8jV57NUPYjw/BHlehs+ePTmNNndkl+vYh
iNv3wf7J42lU5b92ZmVyEI7dLrI9tDiN9Tlmpz29iO8/hg8ff3eYQSGRuKfr
Lw/APcmSlx0uM/hXf/P5t8cGwMu2YDXp+QwejzojtH7bAPyJvLj8PWgGL1yT
KUj70Q/cMt/2embOYKE6+85Gl35o4QF2VtoMzmw32h75vg86Ff28tmjP4oCW
83I+qQcC9+8IcLs8iwsH/fuvFPUAX7rDeK/+LJayGEn0R/dACpfLU+/7s7gt
/x5X2p0eMO2SZw95Novf869MKYxR4K3nWuvA7Fm8dafSWGaRDB3WIYY9G+bw
3KW9nyZXdcOPVh31WYE5zNxYekqinwQ/ywI0/onOYf7ao4WKxSSwsG9xYN01
hy+c9pEOPiKB24nxW2mn51D0sHf4CqMLCva+i7Y2n8MqC7WKI3Wd8HD1Py9W
2zks36AduJjYCTTeT+P+jnNoH7F7dfyzTkjdasXu6zGHI+r6Jz8rdMKaniqT
TW/n0H+C70FrYge4K+t98CubQ4ENLeEcTu1gJtFAC6qew4urj3TaXmmH+bX7
179pmEOVrvHkGrl2+LCLa8yycw6zNmgGHaK2wX4no7mS0TlUDErcs+18Gxyx
W5sQwc1E1nvkhCvCraCUKneCk4+J0smeKj6zLfAiUfyAjRATRfONPqTUt0CT
MKuQ+DYmsks2a+Q6t4BCyA7qhv1MdJNYJTGKzTD/7W4N90UmfpmifvdV/w4r
11ZmY3WZqHR1YbXQn0YoLD5yfvc1JvLG6b7xzm4Envd6j3fcYuLpngUU3NII
Qf24MdmMiVL25DDmdD2YB2uZsngxsVvs7ENGUC2wZ4zNsPkwkewRo92tXguL
1Rd1/r5kovEDkZLspRrYu+qdT+cbJjYuxmttM6qBLgnDs4LRTCwyedA/IVcN
Oz43snZlMVGzQ/RNQE0FvJTfMqySy8QLm4Q37HlaAf5x1y6m5DHx8Z4mr+y9
FaBGu9N4uYiJyfMLXj6B5aAbXNdxooKJ3L+tvt/SLwOlmwKVBlVMXH9qbrPp
+jIgfXsi6VDDxK3PrLKMvpVC2ZdLe142MFEih69TUrwUlkZpP063E+vVX/mI
0loC994prhboZGJMUkYD81AJXI5tshzoYuIWuwcGM+FfQS9OUfE6hYkLJp5B
oQbFcL9k78PuQSbKPgxlxDEKocHrzqDhMBON3vJ/o54tBD+v0dC+ESZmqdiH
8KQXgCkt93MxnYmKjgdSxK3zQbBF24VlgolBv9doKS3mwq3jnlGHJ5lY228S
MXcjFzYJSmoYTjHx0dpgh8DSHAh5sqIaNsPEnMLt+yJ9s0FLwDswYZaJlDGj
fexTWeB2cfO95DkmTkXJcd2+lAUdXgWRQfNMPLd88GLz4UywDX31+8lPJt4J
mdsq8zcdPj1bQ762QKz3zWoVs+o0yPmpILC4yEQSP9f+mKsfoc7imEXhLyZm
yxtoBG5NAdWPjkrWv5m4FPhMz5L+AQZ3TF2tWCLu93A92+ijRLhPmg69tczE
SnI90/tUAsC5Ms0ZwhZSms/42eNBn2Hp+PgPE3W/n+x43RgH6qyCwouEJWLc
D87vioXBvoG95itM7HfWWEjPj4bsJK48EuFw+SK1c2qRsNOJ+unYXyZe2bHB
sak9HB7aVW8JIrwxq3TghFEobIwSWx4kfIfq1xkyEwT2v+6d2/mPidG/7mX2
uL6BIX8ZTiPCGkNDz6RE/cDyBufxEMJhd/5UPD7yAt7eziR/JawmvqY975IH
xMa0j/YQji/Xyi/vewrvBdTvzxJe2GrBv0rIBqzrhy6vEI4N87zz+agBSNUE
Zf8j/HBX1IrJdxV8JHTF5RdhvXXyzHWeD7Cy5lAh47/5KrbpX+RwQNqkltF3
wkWpCjvXtrph0btGp4+Ex296lV1ofI5WcxNszoQLdLi41mX54guW5RVVwvlK
CeXJwa/xw+il+2yEk6QqxEKLA3F9yW2lIuLz7/397q6abAh2hcT5mRCedu42
HH4XhuuevTvLQbhQ7O0XU54IVHyx8DieWN81xUpbyO5ReOTj5c3yhKM2Osnv
Y8Ygk2R/oJDYn59cEboH5eNwe9vxr8nEfv41z9p7MiEec6VS5HkJ16fJOH7o
ScDVASbbbYh4EBl9WLvCn4SGzwRMBIh4YU+ldFs+T8bJqHOl14h4WpQ0U/P+
moLNY7fCAol42zTgxe89/xHfXjAoHiXi8+mWxgPH76ajpuV67jWEv7wxODAR
lYFu1RKDIkQ8N1przrq3Z6LNmXIeKSLeWV+Kc+55n4VPZjPq64j8CQyI1D22
MRfp+vST7kR+qa6/+fVbQS5qVp0Olh0n6l2mDPe+259Roq1m4e4oEb+rx51q
svJQQGU/Q5vIX56lnQdaLxZickBNTQaR3xwTeU6Bvwox69fbhNUDRP5Z7Rs8
HPcFz/1ep+/Tw8QbLZxC0tNFeJ3dR5yvg4kng/ZLvntVgtn91SdF2pjY9O/h
HjP5b+j3M9JSsIWJlqOfgoTI3/B6cqH0JFGPAva7Ulj4S3HrziOmokQ922O5
v0rYsAwjL/jPWH1iYsiyQ2IgswJvi+32qk9n4tnDRafL1Crxhbn6E9FUJkqa
qDhTwiuxwzkzJDKRWK+N0d61J6owZuD33i0RRH3MPm/p61GN36TGqnc/Y6J5
beS+y1x1mIRH6L3OTPTgv7/080Yd0vYKlXo9YeJqO6cdzul1uNGl7muhLVHf
bj45fkirHgsmLF8n3mViWfTbL+f8G1CyMNMiQp2Jm9vpWxvWNuHbXcHtU8pE
vYoJEtfUacIMDUw6AUxMq+KrzYxsQh7lqg/FCkwcWtJevV22Gb+5zFdekWZi
qbtUiY50C+LuuOHFtcR45a8LfzRa0fVc/3Q1K1Gf5NaSG8xbkTN08Lv/vzk0
lhb69PJNK3LUNAixLs6hn/u7ShKpFemPM9760eawOFbSPf1eG6adeH57B3E+
d7nO75R2bcc59o/p1l/nMG8HTflHXDvOvzM7WlgwhxnNSzFvK9ox90SVzP7M
Ofx4ViW1bF0HlvH6aFdGzmH2+lid40EdSNp1nf050S+wq93dlvW+E90287SG
bZnDXfRGXo4cEv7bOCH7XGgOe16yvRbuJKHzd8EgU545fFekXbPxFwnv/vwa
sYWN6Ce00zjzTnWjTDy5TnJ8FlviEwS7a7rxy4zfQHXBLGpejhE1I5FRfPFt
UrTmLHLc8pfdPdKDvhfDbWNVZ9G48N5TVtZeNJayiIk6NYsxxr2N5eK9uLks
4OgzuVlMO1BycuZOL7bPtRQu883i1xBhC7aBXvzmy+Fb1T2DEp4hHGwdfZjf
JEmfNZxBz/BpjpWUAVxKF1urrzeD0r+rQ7sqB3ByWF245OIMenXucAoZHMCS
oj+H7JVm8HTb77B+rkF8ZGnonCw+gxHTsXG3lQexpGNT6dXaaQw0+vmuOn0Q
H0uHFw/VTOEau1xdNschfB3GfyysYAp/cPFR5TyHUJjks0cleQq/iG5V0QoY
wnWJP794e0/h1imNBwbJQ2j5Y+FrvuoUuk8HH2jvGkI+Cb3KBpxErbRGSYGD
wximILxbN3sC1wf0eIwPDuPc1MYfRu8nMKIoNydmbBhtss4csQycwJXsBX+V
+WHc8VQhz9FmAi+ojmo+XDuClef5Jq4dmMDl2+u5JWVHMLvu1SX9rHFMEyvh
O+cwgquH1xt9TxvD5TLuaMt/I5gsbGVqFjWGFup/2yLWUvHRo4WmNa/GUOe6
91LhRioeGXUeP/xwDCW3v97Vvo2KS2E/Rh2kx3AfyUvHEaioFLmIAYk/UFq5
s9HdmYoD85eCHkeNYqsv90LhJBWt7vUz7H1HMdxZjf/3PBULOGU2WjuOYv2l
G69l/lDxnNAwj7HuKKaf+/D5PicNP1qn+J/iGkXr2d1Gp3bSUOyuUFjrUwa6
zxabG9+goZGj8/byBwzkfygh1XiHhhnJr8xyrjKw7u6aqF0PaFgxXe8cJM9A
uxsF3fn2NJzflrnp0hgdK5VuXVTwp+Hj/KoLPdfpWB+dsVBVTMNj8xSrpjN0
3Hx+/VuDMhou1obuLT9MR0P6pTuj1TRMbTbKSuOlY6HykxekVhqeqGI571NH
Q2dXWcYWBg1HGM/HbI/RcPfI5yPnNtIxudj0vZEoFcUFLD8aXaXjncOyBdkc
VMwxUadL69NRR4USz/J7BEujlpFqQMeY6ytbU0kjuLfwtvGpe8R9meRF84SO
oIZN9BY7Ozo6VMryq/CMoH2D5K+f/nTkfWjhnftvGH+ue88qEkhHPkO/Kzun
h9H473p++RA6Up5w7OJvGkbZxYFr6pF0vJn41IbTbxgHq+UO/Eqio5PF3fMO
64Zx5GIDw7uYjqJzDCGeX0P4V1dOg/sbHYeVG/LSGUMYUXZQ6GUpHW+3rvGf
qh5CV/sGwftVdCybIN0N9RpCMVb1W5+a6Lhn+niY+qMhlGnIpv9ooWOU6Y32
pbtDeK3pJB9RQ3G0J/CVueoQBox5W9wh0bHEVTH9EesQWt34O+M6QEeBNt15
YA7iDN1S22qIjrv2XnfmHhnE7dTy51dH6Jil+uBeTvkgZr1mD+dgEPc/JntW
0mMQZS4lbWCdomP+YslpDttBPKzbO506TcfaE4ZJs3cGMcJqZODsLB1PbXLr
a1QaRKberbUW83R8V30iOmP1IGZqMvefXaKj2CG13L8jA9iTzX8/YZmIE54x
iY9EnWCr5Tj28w8dD0f68vB7D2DCqeE6t390PJ+4Q+EkxwByiUvqHGBj4Akl
ZXfhsX4Mam7bdJadgSfbPvH9qe/HdZ5SGXprGHjzepQ82a8fU4WEDAzXMVCE
+5z9BE8//noY7cm1noEqEctr2Ob68Lsgw3qYsGGDvKxEex8W3fQ0zOYm4ly4
Tu9xaB+y3v99XWEjAwV3KVlnOvShm+Yj2ynC5ZPWMHGtD7WXvZNieBg4yTwv
7Sbah6u8k+ypvAwMFbfV7VjuxaLP58Wc+RjoyqN0/UBfLx5S/fabi5+B17pV
lcO+9WJaoipPCOHjy/NCrHG9KLFt930BAQaaPsobcHTvRf/GXDZ/wsttXYnz
Rr241l9meoWwz2cxtTU7ezHMcbGiVpCBvRTP/VFre1HmV1uRuBAD+y41Hj36
owepu1I3PSIc/Ylxr6++B++dKxlEwrVvcvFleg8WK2huYd3EwDcFS1qKr3tQ
/nJgy2nC3psfCf+16kE1nwZWO8LO/2p2Vur0YPTRQ19jCVuv8X4WdLAHt55m
W1VF+J6GnKypYA+K9dt2DhO+fP/AIY1FCgaX5yn/JiyVyIiWI1PQZW6V9jph
BrowIy23FVPwYL33ykbCtXweWZtiKPiL6XiNh/CWmDJTYTcKOt9mNeIgvGe7
+fsddyjoC1cllon5dh3wuHVQhYJffkW9pxFucJ9L1pKioJrk3+FawvI/I55b
r6XgqGfiZCLhrs8qy1E/yNi+/LnmCWEbtY98LQ1kzH+l63iG8FKUbev6TDL2
nYln2UDYU/7I6UtvyHj/UpnVd2K99oo9MYyzJaNbR1OlF2G2bZ9OLF4mY8ki
fa0C4aVvx8lXFcgYOCABQ8R+FN60OI0iZCyOj7F+TthD7YXN/j/dOKT6MH47
4R11BY9T+7vxYFYMJY/Yz2xtMX3Zsm7c+ensNlXCzqZVm78kdON+uotDAxEf
i+yl18YfdCNXeo59FRFP+mlfBvnOdmOqdWiLDGHn5Se/VXd3o5PQzR0vifhr
r7JfrP1BQgNbndJ9RHzO9XGMi9aTcPBul9gjIn43bN78yjGVhHZx469zNzAw
wdJm4qIZCVujL9QLE/HvvXSr+LsmCc/doyQAkR/HO0QuXdlLQh4Hi0+3uBiY
PHBt9vlkF4Zo/nvqxcHAeNpQqol1FxZSdQsciHxcqEDz4zpdKJ5eNG9I5GuX
8j9pEfku3BRgH6fEysD1BTdTFpmd2LK/4vbUKiJfPkncPfa4Ez/KS1+ZIuqB
yp2DUfeud2Lt/ZjOKKJevNzNthR9vBN5ZWr/Kf2mo/NhUVXZlQ6Uzky2fLxA
R8vPkpEdHh3YeinM8/UMHbV9O2P173Zg7U3KVhaiPp1Lzvw5rtaBvnTFd5aT
dFwbFZe4n6MDD7veNpEnzqmksz2vld+0Y+BLO9o9ov4ZMA7q+sW1oeZsVp9H
Bx2VzV8+qPNow8l/O4V82oj6tbGXh4/oCw+CX6I3UX85Eoqkq3e3YfFT1gGr
Rjr6nyro/JLbivX/GvyYFXS8pDo001rXgts+RDRVZdNR/TXvseLMFrQ3N87x
+0RHb75MzAxuQa4bs7u0M+g4K+r55rNBC4peEO4vTaFj8a35GQdqMz46u26D
SSwdI1d1L1gdb8LaxPK9n1/RcY27jKgfexM+aFnJ3ulLx4fefXNfW75jSNa9
rSHedNS/4tV88/53PHguqszQnY5Vb2zcQkMbcUF6obzIgY7WsaYVEz/rUSvV
d//z23RsZl9z50p5PUactA1OJs7Lx0N2pLbX9cjV8VCumjhP+YV/Xl4vXY/A
7bPz52U6/ohu+/KE6Ps5cvyjRc/S0f2syW6oriHa8I75F/vpaHNsZNWTtErc
1dK0esMfGl6KpZrccajEV1MXtuj9omF9TrqhkVIl3mQZ14qZp6FZSdGaTFIF
/tsQzi0ySfQjMc/5zNkrUFS4Lrarj4Y03zoxj3tlOJP6YK3VNxpSaZG7Bay/
YqXuw9gTzjTkvOPEx7b+K+aKKToyHWnYCKvTJVOK0VeNSyjZjoZa263Ji4NF
eED+SMlqMxruXdS1pV3+gjk5pUpe12l4w2i2n6SWj5ddWYPrDtOwf4yVha6Z
hbQekW7TcSpyy6tf2zf6CStru+AnnYpRdwunRo5+wtwAZXeXYSqSvAwyNXoy
8IGBaNxzMhUnIy9WL0ikofRCTp5FDRX/2SxHkiqT0Jjb1T4znoon/XSUrHzC
cMPZelnWa1RM+LnGiTc0EFR0123LLxjBN/MHXiVVBcHx12v4MnJGcM3gXb34
n8GgEPiz/n3GCIruGKjt0g0Dvf1ZEc8TRpCyyv6OHEcU/LFRW5QLGEGdTWnG
QzLxQL7xYON2kxE80Gu5p045DaoLrDkf841g96FTp9Q186EkBO8E3iP63cdg
PR+cDxXXdFTCDIexaLRH9UlvPqz3Uz4dcX0YOV7Ycq21KID1LtteRWgNo7Ba
VOQhv0Jwuyrc6Hl4GA33schSy4sg7Kv1idXsw9jS5kj7xYsgHErOyY4fQi13
pfz1MRWQWeLvY0keRMFIlw69ogrQ/WRw7Gn7IIZucnMKIVXAwRzPquffB/Hq
YepTCm8lFFzWdwgrI/qIlReD770q4eWix/30j4NYWzGmLfGwCmoXpCYSngzi
Jm27cuFdNaDG36HUKDyI16+dsOK0rQcnc4FfiSn96OQbSvX0rwf/Xlm+o1H9
eDv8etp4Sj3k7dC9VOffj5Pe3zW8B+phfoJHh27bj4UXY5+PajZA6LH4GM5T
/ajV/3L1/R2NsPvsZp5/LX24/YVWqBN+B6FOV7u0xV5UlMgXK77bAgdMPxd8
UOxB6VeXT++0boGEpm+vRYhzszvXN9HXqQWKJG6cfiXVgzl/HbWOBbXAM/kX
cmacPfgv4YLxSWyB+JNFQWIdFFzHdmd3x6ZW0DN+t1n7PgU75F5K3KpoBefC
B+/G/cjIp32T7sDWDsHPslmciO+Lx1q6Fe5xtwOtx+hFbC0JvTKqHmgJtcOB
O7FmFcUktLBTsOGSbof7qQbXOOJJqFOy6+ppzXaIus3d629JwhXud8fc37RD
agMp9OlaEnoKZtj4CnVA62+hK2NHu3D6O4O5kbcTCnl17+tHduDODS7GO0U6
4XSXa626XwfW/Homd2RHJ+z7+iRf3rUD1fObaUoHOuFQ/tRJDqMOVKxi5+TU
6YTirNmN2bs78KOs1DbDgE4QEM/+OFHYjizmFqEya4ncynuzX5TUhh9bbCdK
R7qAf71mjAtfK4bUZdBafnRBC3UvU5W9FXfv3vmiZ7oLylyL+Nb/asFD5d9q
B5e7YLX+fFZEXwuiaJdVGj8JBk5bPM5JacFKhU/Bysok4NtSkEg53YI9qa+3
e0SR4DnzfCRvVxMqT5f8+BFHgiC5irchxU04S1byOf+BBBSfFo1N75uQtSTs
HEs2CT6uZi/bbN6EO+l6HPurSSB/qk56B0sThmZpB4VOk8C+TcJn677vKB+Q
9DHwdDd8FxOqHfVqQNuhrYmnVbrh7LWm2VGzBmxMZH6nn+kGsvM4fVSnAVky
N3+W1umGFfXyw6NiDRi7ccsPW+NuqGiNdKDm1aNmxSBjx4tuUNn6YU0HrQ53
7G31n63vhjNmovuC1Wrxtv+cx5rmbuDYcofiL1OL1sWZtULt3bDhiYyxD28t
Jo13nN3dQ8z3QHy9S18NbmhOOSU03g2P/aD27qMa/MOq+42HkwxFWYvn9iVV
o8v1o+6vVcmwNL9NN52tCj98nDp/Q4MMtPiJQxajldikSsoXP08GUQ7OP7KN
lWh92cn0vS4ZOLZOn/gUXIksibfu3zIiwyrbna+zxCsxfGpnGsmVDKu1HLsy
FSvwlunmA025ZLhq6/Aq2rkMlV2mcmfyydAZfbZL/3YZvq5cZnIXkeGG1BKv
iGoZ3olT/nS0lAz981sMQrnKMHN97J4LjWTw5b56zj+yFMN/ps88GyGDFU/q
k5/WiA9+CmqvcFOgrGLdg6jRYvwxvSpXm4cCLAO0nt7cYlzcLBIRxUeBvSYv
lbe6FaMbY+P4rk0UkMm79iNOsBiHmYF5nNspcGKWLSlJuQjZhiQNfu+nwK5P
XLwZ0YWocuKPIOtBCqg1WbZN3i9E+mEXvXWHKRCm3fJy38FCPPTD3pn9GAVu
czgOfaorQMb5Rq16xf9+r+64N2chH3s38rq5XqDAjNzx+3kX85B0y4xLSYcC
cbtKs39uzkMfvw7pf5cocE7BceEw4zNuaPcWtrxKzHdZyirf5TNmBQiShAyI
z/OdU7wgNRcVtifsCTGlQG1X4KcCthz8JJT9a6MZBax7Mz8tNmfj+SyxWy/M
KbCeTSddISob2eafzTywosBSw7uoggPZGPTkyKlFewqksAdcKbiVhbuAq0zR
jQItfxejzG0ysKzXYCjiGQXSdgZJJS+n4zfpTt9Jdwp0OnqmDnml44YDTfbP
n1Mggvtc8tXINLzr2V5i7UuBv6EitooVH9EQFfe8e0kB8N/b+1TrI17dM7ij
+hUFfNJ2quSRUlAge8tn9tcUkFz3ZN2eiWR88XC1pUoQBT5a9NnzC37AZ2nP
TqkFU4BfxLleKzYJf8t1RiqFUGDZZu9Wn91JSFu1f9WeMAoEhZws/XMqEaPr
Mly+RFAgQ1BmjmYSj0caRyoCIon1vGhzYvvse7Sf3BV5O4oC+y7EeOo7vcfN
T0mLs9EUOHNsiac5IA4Lne64tsdS4NbTNBVrmxgU+/5e0zWOAoXKpbVUr2ik
cmCqxHsKSGR9OX89MgpjFfS23YqngPtKuY5yRQRG/z14mElYdYSlPZ/0Fg8Y
pPd5JFDgUPgLXZmJcPyrv50RmEiBnE2ZlwQEw7AgxFKDN4kC0UF2rT67Q1Ey
6u/JV4RbrlRdWDkVgtv4HQctPxD7dVxdk24ShIdoiQHdhFd8X9fqOwWitFps
28lkCuyMCFVrDniDIUq2Aj8Jl//hcrW28cdpdk/+sykU+Jz6z+F65CtkSWn5
EE6YuSnXSrnCF8+L2jUNEpZWkX8gM/ECzVKevZT8SIE9wS9uCwh6I+8id48R
4XPMYr2VU89RgG1faRThmumui3QTD7TfOXesmbBvZ79Gc8AzvLXhocYK4ZNR
2e7WNi64vyphXCqVAuGzgTbKFU/waUaaxFnCTVvu3REQdEBuT78ZE8LWC3I6
dBNbXNC/cMmNcB9znBhvga4JyxpBhM8v2hLXm6C8ZHhHLGH1yGnidQOkrUj9
TP7v/zLN/1kL////NFyqjqnwMObr/wBDP+3J
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.19037275395784775`, 0.11063568663686028`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.9518637697892387, -0.5531784331843014}]}, 
                 LineBox[{{0.19037275395784775`, 
                  0.11063568663686028`}, {-0.9518637697892387, \
-0.5531784331843014}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 73->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.1841334765207133, 0.11494708210035652`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.9206673826035666, -0.5747354105017826}]}, 
                 LineBox[{{0.1841334765207133, 
                  0.11494708210035652`}, {-0.9206673826035666, \
-0.5747354105017826}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 74->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.17756515084498187`, 0.11905295779472197`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.8878257542249095, -0.59526478897361}]}, 
                 LineBox[{{0.17756515084498187`, 
                  0.11905295779472197`}, {-0.8878257542249095, \
-0.59526478897361}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 75->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.17066466969066746`, 0.12293600612052162`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.8533233484533378, -0.6146800306026086}]}, 
                 LineBox[{{0.17066466969066746`, 
                  0.12293600612052162`}, {-0.8533233484533378, \
-0.6146800306026086}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 76->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.16342897747283985`, 0.1265774433923417}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.8171448873641995, -0.6328872169617087}]}, 
                 LineBox[{{0.16342897747283985`, 
                  0.1265774433923417}, {-0.8171448873641995, \
-0.6328872169617087}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 77->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.1558551431727848, 0.12995681458292643`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.7792757158639246, -0.6497840729146328}]}, 
                 LineBox[{{0.1558551431727848, 
                  0.12995681458292643`}, {-0.7792757158639246, \
-0.6497840729146328}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 78->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.14794045510290182`, 0.13305176885642084`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.7397022755145091, -0.6652588442821044}]}, 
                 LineBox[{{0.14794045510290182`, 
                  0.13305176885642084`}, {-0.7397022755145091, \
-0.6652588442821044}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 79->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.13968254409376732`, 0.13583780095518502`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.6984127204688367, -0.6791890047759253}]}, 
                 LineBox[{{0.13968254409376732`, 
                  0.13583780095518502`}, {-0.6984127204688367, \
-0.6791890047759253}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 80->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.13107954377593828`, 0.1382879527457514}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.6553977188796918, -0.6914397637287573}]}, 
                 LineBox[{{0.13107954377593828`, 
                  0.1382879527457514}, {-0.6553977188796918, \
-0.6914397637287573}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 81->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.12213029946062418`, 0.1403724684467069}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.6106514973031207, -0.7018623422335343}]}, 
                 LineBox[{{0.12213029946062418`, 
                  0.1403724684467069}, {-0.6106514973031207, \
-0.7018623422335343}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 82->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.11283464094892807`, 0.14205839633777678`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.5641732047446404, -0.710291981688884}]}, 
                 LineBox[{{0.11283464094892807`, 
                  0.14205839633777678`}, {-0.5641732047446404, \
-0.710291981688884}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 83->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.10319373978443233`, 0.14330912924524794`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.5159686989221618, -0.7165456462262398}]}, 
                 LineBox[{{0.10319373978443233`, 
                  0.14330912924524794`}, {-0.5159686989221618, \
-0.7165456462262398}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 84->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.09321057850653161, 0.14408387610754622`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.46605289253265814`, -0.7204193805377311}]}, 
                 LineBox[{{0.09321057850653161, 
                  0.14408387610754622`}, {-0.46605289253265814`, \
-0.7204193805377311}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 85->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.08289056903087814, 0.14433705796905616`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.41445284515439074`, -0.7216852898452809}]}, 
                 LineBox[{{0.08289056903087814, 
                  0.14433705796905616`}, {-0.41445284515439074`, \
-0.7216852898452809}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 86->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.07224237025523444, 0.14401762474375668`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.3612118512761722, -0.7200881237187834}]}, 
                 LineBox[{{0.07224237025523444, 
                  0.14401762474375668`}, {-0.3612118512761722, \
-0.7200881237187834}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 87->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.06127897246096378, 0.14306829560813533`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.30639486230481894`, -0.7153414780406768}]}, 
                 LineBox[{{0.06127897246096378, 
                  0.14306829560813533`}, {-0.30639486230481894`, \
-0.7153414780406768}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 88->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.05001913930656235, 0.14142473860889165`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.2500956965328117, -0.7071236930444582}]}, 
                 LineBox[{{0.05001913930656235, 
                  0.14142473860889165`}, {-0.2500956965328117, \
-0.7071236930444582}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 89->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.038489328339312824`, 0.13901472851969868`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.19244664169656414`, -0.6950736425984936}]}, 
                 LineBox[{{0.038489328339312824`, 
                  0.13901472851969868`}, {-0.19244664169656414`, \
-0.6950736425984936}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 90->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.02672624830477217, 0.13575736361892218`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.1336312415238609, -0.6787868180946112}]}, 
                 LineBox[{{0.02672624830477217, 
                  0.13575736361892218`}, {-0.1336312415238609, \
-0.6787868180946112}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 91->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.014780253868736914`, 0.13156249391553007`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.07390126934368454, -0.65781246957765}]}, 
                 LineBox[{{0.014780253868736914`, 
                  0.13156249391553007`}, {-0.07390126934368454, \
-0.65781246957765}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 92->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{0.0027198170602133363`, 0.12633063396855046`}]}, 
                 {PointSize[0.015], 
                  PointBox[{-0.013599085301066693`, -0.6316531698427528}]}, 
                 LineBox[{{0.0027198170602133363`, 
                  0.12633063396855046`}, {-0.013599085301066693`, \
-0.6316531698427528}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 93->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.009362673029790783, 0.11995382918681279`}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.04681336514895394, -0.5997691459340643}]}, 
                 LineBox[{{-0.009362673029790783, 0.11995382918681279`}, {
                  0.04681336514895394, -0.5997691459340643}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 94->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.02134359676576815, 0.11231824679055576`}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.10671798382884078`, -0.561591233952779}]}, 
                 LineBox[{{-0.02134359676576815, 0.11231824679055576`}, {
                  0.10671798382884078`, -0.561591233952779}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 95->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.0330593403299372, 0.10330969205001957`}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.1652967016496861, -0.516548460250098}]}, 
                 LineBox[{{-0.0330593403299372, 0.10330969205001957`}, {
                  0.1652967016496861, -0.516548460250098}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 96->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.04429676522847959, 0.09282376737215406}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.22148382614239792`, -0.46411883686077027`}]}, 
                 LineBox[{{-0.04429676522847959, 0.09282376737215406}, {
                  0.22148382614239792`, -0.46411883686077027`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 97->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.05478485662972975, 0.0807827799368698}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.2739242831486489, -0.4039138996843493}]}, 
                 LineBox[{{-0.05478485662972975, 0.0807827799368698}, {
                  0.2739242831486489, -0.4039138996843493}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 98->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.06419163035062234, 0.06716116549665432}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.3209581517531118, -0.3358058274832718}]}, 
                 LineBox[{{-0.06419163035062234, 0.06716116549665432}, {
                  0.3209581517531118, -0.3358058274832718}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 99->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.07213310163106106, 0.05201897762287946}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.36066550815530524`, -0.2600948881143973}]}, 
                 LineBox[{{-0.07213310163106106, 0.05201897762287946}, {
                  0.36066550815530524`, -0.2600948881143973}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 100->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.07820268892189204, 0.03553756419343942}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.39101344460946036`, -0.17768782096719715`}]}, 
                 LineBox[{{-0.07820268892189204, 0.03553756419343942}, {
                  0.39101344460946036`, -0.17768782096719715`}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}], 101->
               GraphicsBox[{{{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                   TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                 {PointSize[0.025], 
                  PointBox[{-0.08202595732783631, 0.018043338863953064`}]}, 
                 {PointSize[0.015], 
                  PointBox[{0.4101297866391817, -0.09021669431976534}]}, 
                 LineBox[{{-0.08202595732783631, 0.018043338863953064`}, {
                  0.4101297866391817, -0.09021669431976534}}], 
                 {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                  DiskBox[{0, 0}, 0.025]}},
                Axes->None,
                AxesLabel->{None, None},
                AxesOrigin->{0, 0},
                DisplayFunction->Identity,
                FrameLabel->{{None, None}, {None, None}},
                FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
                GridLinesStyle->Directive[
                  GrayLevel[0.5, 0.4]],
                ImagePadding->All,
                
                Method->{
                 "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "ScalingFunctions" -> None},
                PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                PlotRangeClipping->True,
                PlotRangePadding->{{
                   Scaled[0.05], 
                   Scaled[0.05]}, {
                   Scaled[0.05], 
                   Scaled[0.05]}},
                Ticks->{Automatic, Automatic}]}, Dynamic[$CellContext`i12$$],
               Alignment->Automatic,
               BaseStyle->"ListAnimateCore",
               ImageSize->All,
               TransitionDirection->Horizontal,
               TransitionDuration->0.5,
               TransitionEffect->Automatic],
              Identity,
              Editable->True,
              Selectable->True],
             ImageMargins->10],
            Deployed->False,
            StripOnInput->False,
            ScriptLevel->0,
            GraphicsBoxOptions->{PreserveImageOptions->True},
            Graphics3DBoxOptions->{PreserveImageOptions->True}],
           Identity,
           Editable->False,
           Selectable->False],
          Alignment->{Left, Center},
          Background->GrayLevel[1],
          Frame->1,
          FrameStyle->GrayLevel[0, 0.2],
          ItemSize->Automatic,
          StripOnInput->False]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
       GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {
           Offset[0.7], {
            Offset[0.5599999999999999]}, 
           Offset[0.7]}, "Rows" -> {
           Offset[0.4], {
            Offset[0.8]}, 
           Offset[0.4]}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.852194494701888*^9, 3.8521945545502043`*^9, 
  3.852194724409243*^9, 3.852195432131082*^9, 3.852195991434142*^9, 
  3.8521960836582212`*^9, 3.852196314691536*^9, 3.8521963786917057`*^9, 
  3.8521977347860937`*^9, 3.852197866449016*^9, 3.8521982223309107`*^9, 
  3.8814758986307573`*^9, 3.881477323382874*^9, 3.881477560508894*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"78114712-ce91-4607-bc18-d3794e1167dc"]
}, Open  ]],

Cell["Combine the two plots in one animation.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851855840359335*^9, 3.851855841844705*^9}, 
   3.851856265777122*^9, {3.851856310335575*^9, 3.8518563149244823`*^9}, {
   3.851856380864249*^9, 3.851856505526566*^9}, {3.851856548248098*^9, 
   3.851856558941457*^9}, {3.8518570164967203`*^9, 3.851857086171094*^9}, {
   3.8518575698851433`*^9, 3.851857681827611*^9}, {3.85185772751895*^9, 
   3.851857810152133*^9}, {3.8518579015457363`*^9, 3.85185796324026*^9}, {
   3.851857994126542*^9, 3.851858010685014*^9}, {3.8518580568281803`*^9, 
   3.8518580698580112`*^9}, {3.851858121478053*^9, 3.851858198847193*^9}, {
   3.852197421601698*^9, 3.852197476725752*^9}, {3.8814772691832542`*^9, 
   3.8814772783379097`*^9}, {3.881477525473925*^9, 3.881477525908278*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"493a04b5-3d3c-4c4c-83ea-7fa8c5170377"],

Cell[BoxData[
 RowBox[{"ListAnimate", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"GraphicsRow", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"plots1", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"plots2", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "101"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.881477367374776*^9, 3.8814774235023403`*^9}, {
  3.881477457692872*^9, 3.8814774658109694`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"1dfdc48c-a7c3-48ff-9216-d05f95977999"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i13$$ = 76, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i13$$ = 1}, 
     "\"max\"" :> {$CellContext`i13$$ = 101}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i13$$], 1, ""}, 1, 101, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True}, 
    PaneBox[
     PanelBox[GridBox[{
        {
         ItemBox[
          ItemBox[
           TagBox[
            StyleBox[GridBox[{
               {"\<\"\"\>", 
                AnimatorBox[Dynamic[$CellContext`i13$$], {1, 101, 1},
                 AnimationRate->Automatic,
                 AnimationRunTime->10.001923561096191`,
                 AnimationTimeIndex->3.7315508870795213`,
                 
                 AppearanceElements->{
                  "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
                   "DirectionButton"},
                 AutoAction->False,
                 DisplayAllSteps->True]}
              },
              AutoDelete->False,
              
              GridBoxAlignment->{
               "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
             "ListAnimateLabel",
             StripOnInput->False],
            {"ControlArea", Top}],
           Alignment->{Automatic, Inherited},
           StripOnInput->False],
          Background->None,
          StripOnInput->False]},
        {
         ItemBox[
          TagBox[
           StyleBox[
            PaneBox[
             TagBox[
              PaneSelectorBox[{1->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.492155743967018, -0.10826003318371857`}]}, 
                    LineBox[{{0, 0}, {
                    0.492155743967018, -0.10826003318371857`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.0820259573278363, -0.01804333886395309}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.0820259573278363, 0.01804333886395309}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.4101297866391817, -0.09021669431976548}]}, 
                    LineBox[{{-0.0820259573278363, 0.01804333886395309}, {
                    0.4101297866391817, -0.09021669431976548}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 2->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], PointBox[{0.5, 0.}]}, 
                    LineBox[{{0, 0}, {0.5, 0.}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.08333333333333331, 0.}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.08333333333333331, 0.}]}, 
                    {PointSize[0.015], PointBox[{0.4166666666666667, 0.}]}, 
                    LineBox[{{-0.08333333333333331, 0.}, {0.4166666666666667, 
                    0.}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 3->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.492155743967018, 0.10826003318371857`}]}, 
                    LineBox[{{0, 0}, {0.492155743967018, 
                    0.10826003318371857`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.0820259573278363, 0.01804333886395309}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.0820259573278363, -0.01804333886395309}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.4101297866391817, 0.09021669431976548}]}, 
                    LineBox[{{-0.0820259573278363, -0.01804333886395309}, {
                    0.4101297866391817, 0.09021669431976548}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 4->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.4692161335313525, 0.21322538516063588`}]}, 
                    LineBox[{{0, 0}, {0.4692161335313525, 
                    0.21322538516063588`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.07820268892189206, 0.0355375641934393}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.07820268892189206, -0.0355375641934393}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.3910134446094604, 0.1776878209671966}]}, 
                    LineBox[{{-0.07820268892189206, -0.0355375641934393}, {
                    0.3910134446094604, 0.1776878209671966}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 5->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.4327986097863661, 0.312113865737277}]}, 
                    LineBox[{{0, 0}, {0.4327986097863661, 
                    0.312113865737277}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.07213310163106101, 0.052018977622879506}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.07213310163106101, -0.052018977622879506`}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.36066550815530507`, 0.2600948881143975}]}, 
                    LineBox[{{-0.07213310163106101, -0.052018977622879506`}, {
                    0.36066550815530507`, 0.2600948881143975}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 6->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.38514978210373463`, 0.40296699297992544`}]}, 
                    LineBox[{{0, 0}, {0.38514978210373463`, 
                    0.40296699297992544`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.06419163035062243, 0.06716116549665424}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.06419163035062243, -0.06716116549665424}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.3209581517531122, 0.3358058274832712}]}, 
                    LineBox[{{-0.06419163035062243, -0.06716116549665424}, {
                    0.3209581517531122, 0.3358058274832712}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 7->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.328709139778379, 0.4846966796212186}]}, 
                    LineBox[{{0, 0}, {0.328709139778379, 
                    0.4846966796212186}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.054784856629729824, 0.08078277993686975}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.054784856629729824`, -0.08078277993686975}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.2739242831486492, 0.4039138996843489}]}, 
                    LineBox[{{-0.054784856629729824`, -0.08078277993686975}, {
                    0.2739242831486492, 0.4039138996843489}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 8->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.2657805913708785, 0.5569426042329233}]}, 
                    LineBox[{{0, 0}, {0.2657805913708785, 
                    0.5569426042329233}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.044296765228479744, 0.09282376737215386}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.044296765228479744`, -0.09282376737215386}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.22148382614239875`, 0.46411883686076943`}]}, 
                    LineBox[{{-0.044296765228479744`, -0.09282376737215386}, {
                    0.22148382614239875`, 0.46411883686076943`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 9->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.19835604197962298`, 0.619858152300118}]}, 
                    LineBox[{{0, 0}, {0.19835604197962298`, 
                    0.619858152300118}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.03305934032993715, 0.10330969205001961}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.03305934032993715, -0.10330969205001961`}]}, \

                    {PointSize[0.015], 
                    PointBox[{0.16529670164968582`, 0.5165484602500984}]}, 
                    LineBox[{{-0.03305934032993715, -0.10330969205001961`}, {
                    0.16529670164968582`, 0.5165484602500984}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 10->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.12806158059460881`, 0.6739094807433348}]}, 
                    LineBox[{{0, 0}, {0.12806158059460881`, 
                    0.6739094807433348}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.02134359676576813, 0.11231824679055576}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.02134359676576813, -0.11231824679055576`}]}, \

                    {PointSize[0.015], 
                    PointBox[{0.10671798382884068`, 0.561591233952779}]}, 
                    LineBox[{{-0.02134359676576813, -0.11231824679055576`}, {
                    0.10671798382884068`, 0.561591233952779}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 11->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.0561760381787445, 0.7197229751208771}]}, 
                    LineBox[{{0, 0}, {0.0561760381787445, 
                    0.7197229751208771}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.009362673029790745, 0.11995382918681279}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.009362673029790745, -0.11995382918681279`}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.04681336514895376, 0.5997691459340644}]}, 
                    LineBox[{{-0.009362673029790745, -0.11995382918681279`}, {
                    0.04681336514895376, 0.5997691459340644}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 12->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.016318902361279364`, 0.7579838038113029}]}, 
                    LineBox[{{0, 0}, {-0.016318902361279364`, 
                    0.7579838038113029}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.0027198170602132266, 0.12633063396855046}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{
                    0.0027198170602132266`, -0.12633063396855046`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.013599085301066138`, 0.6316531698427524}]}, 
                    LineBox[{{
                    0.0027198170602132266`, -0.12633063396855046`}, \
{-0.013599085301066138`, 0.6316531698427524}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 13->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.08868152321242107, 0.7893749634931801}]}, 
                    LineBox[{{0, 0}, {-0.08868152321242107, 
                    0.7893749634931801}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.014780253868736838, 0.13156249391552996}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.014780253868736838`, -0.13156249391552996`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.07390126934368423, 0.6578124695776502}]}, 
                    LineBox[{{
                    0.014780253868736838`, -0.13156249391552996`}, \
{-0.07390126934368423, 0.6578124695776502}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 14->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.16035748982863224`, 0.814544181713533}]}, 
                    LineBox[{{0, 0}, {-0.16035748982863224`, 
                    0.814544181713533}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.02672624830477203, 0.13575736361892213}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.02672624830477203, -0.13575736361892213`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.13363124152386022`, 0.6787868180946109}]}, 
                    LineBox[{{
                    0.02672624830477203, -0.13575736361892213`}, \
{-0.13363124152386022`, 0.6787868180946109}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 15->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.23093597003587674`, 0.8340883711181921}]}, 
                    LineBox[{{0, 0}, {-0.23093597003587674`, 
                    0.8340883711181921}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.03848932833931277, 0.1390147285196986}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.03848932833931277, -0.1390147285196986}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.19244664169656397`, 0.6950736425984936}]}, 
                    LineBox[{{
                    0.03848932833931277, -0.1390147285196986}, \
{-0.19244664169656397`, 0.6950736425984936}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 16->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.3001148358393738, 0.8485484316533497}]}, 
                    LineBox[{{0, 0}, {-0.3001148358393738, 
                    0.8485484316533497}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.05001913930656231, 0.14142473860889163}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.05001913930656231, -0.14142473860889163`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.2500956965328115, 0.7071236930444581}]}, 
                    LineBox[{{
                    0.05001913930656231, -0.14142473860889163`}, \
{-0.2500956965328115, 0.7071236930444581}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 17->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.36767383476578275`, 0.8584097736488121}]}, 
                    LineBox[{{0, 0}, {-0.36767383476578275`, 
                    0.8584097736488121}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.06127897246096378, 0.14306829560813533}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.06127897246096378, -0.14306829560813533`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.30639486230481894`, 0.7153414780406768}]}, 
                    LineBox[{{
                    0.06127897246096378, -0.14306829560813533`}, \
{-0.30639486230481894`, 0.7153414780406768}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 18->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.4334542215314058, 0.8641057484625401}]}, 
                    LineBox[{{0, 0}, {-0.4334542215314058, 
                    0.8641057484625401}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.07224237025523425, 0.1440176247437566}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.07224237025523425, -0.1440176247437566}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.3612118512761715, 0.7200881237187835}]}, 
                    LineBox[{{
                    0.07224237025523425, -0.1440176247437566}, \
{-0.3612118512761715, 0.7200881237187835}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 19->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.4973434141852686, 0.8660223478143371}]}, 
                    LineBox[{{0, 0}, {-0.4973434141852686, 
                    0.8660223478143371}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.0828905690308781, 0.14433705796905616}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.0828905690308781, -0.14433705796905616`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.4144528451543905, 0.7216852898452809}]}, 
                    LineBox[{{
                    0.0828905690308781, -0.14433705796905616`}, \
{-0.4144528451543905, 0.7216852898452809}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 20->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.5592634710391886, 0.8645032566452775}]}, 
                    LineBox[{{0, 0}, {-0.5592634710391886, 
                    0.8645032566452775}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.09321057850653142, 0.14408387610754622}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.09321057850653142, -0.14408387610754622`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.4660528925326572, 0.7204193805377312}]}, 
                    LineBox[{{
                    0.09321057850653142, -0.14408387610754622`}, \
{-0.4660528925326572, 0.7204193805377312}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 21->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.6191624387065942, 0.8598547754714878}]}, 
                    LineBox[{{0, 0}, {-0.6191624387065942, 
                    0.8598547754714878}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.10319373978443233, 0.14330912924524794}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{
                    0.10319373978443233`, -0.14330912924524794`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.5159686989221618, 0.7165456462262398}]}, 
                    LineBox[{{
                    0.10319373978443233`, -0.14330912924524794`}, \
{-0.5159686989221618, 0.7165456462262398}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 22->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.6770078456935679, 0.8523503780266608}]}, 
                    LineBox[{{0, 0}, {-0.6770078456935679, 
                    0.8523503780266608}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.11283464094892794, 0.14205839633777675}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{
                    0.11283464094892794`, -0.14205839633777675`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.56417320474464, 0.7102919816888841}]}, 
                    LineBox[{{
                    0.11283464094892794`, -0.14205839633777675`}, \
{-0.56417320474464, 0.7102919816888841}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 23->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.7327817967637447, 0.8422348106802413}]}, 
                    LineBox[{{0, 0}, {-0.7327817967637447, 
                    0.8422348106802413}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.12213029946062405, 0.14037246844670684}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{
                    0.12213029946062405`, -0.14037246844670684`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.6106514973031206, 0.7018623422335345}]}, 
                    LineBox[{{
                    0.12213029946062405`, -0.14037246844670684`}, \
{-0.6106514973031206, 0.7018623422335345}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 24->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.7864772626556263, 0.8297277164745097}]}, 
                    LineBox[{{0, 0}, {-0.7864772626556263, 
                    0.8297277164745097}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.13107954377593767, 0.13828795274575156}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{
                    0.13107954377593767`, -0.13828795274575156`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.6553977188796887, 0.6914397637287581}]}, 
                    LineBox[{{
                    0.13107954377593767`, -0.13828795274575156`}, \
{-0.6553977188796887, 0.6914397637287581}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 25->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.8380952645626045, 0.8150268057311101}]}, 
                    LineBox[{{0, 0}, {-0.8380952645626045, 
                    0.8150268057311101}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.13968254409376732, 0.13583780095518494}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{
                    0.13968254409376732`, -0.13583780095518494`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.6984127204688372, 0.6791890047759251}]}, 
                    LineBox[{{
                    0.13968254409376732`, -0.13583780095518494`}, \
{-0.6984127204688372, 0.6791890047759251}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 26->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.8876427306174102, 0.7983106131385255}]}, 
                    LineBox[{{0, 0}, {-0.8876427306174102, 
                    0.7983106131385255}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.14794045510290166, 0.13305176885642087}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{
                    0.14794045510290166`, -0.13305176885642087`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.7397022755145085, 0.6652588442821046}]}, 
                    LineBox[{{
                    0.14794045510290166`, -0.13305176885642087`}, \
{-0.7397022755145085, 0.6652588442821046}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 27->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.9351308590367096, 0.7797408874975592}]}, 
                    LineBox[{{0, 0}, {-0.9351308590367096, 
                    0.7797408874975592}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.15585514317278482, 0.12995681458292643}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{
                    0.15585514317278482`, -0.12995681458292643`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.7792757158639247, 0.6497840729146328}]}, 
                    LineBox[{{
                    0.15585514317278482`, -0.12995681458292643`}, \
{-0.7792757158639247, 0.6497840729146328}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 28->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.9805738648370391, 0.7594646603540506}]}, 
                    LineBox[{{0, 0}, {-0.9805738648370391, 
                    0.7594646603540506}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.1634289774728398, 0.1265774433923417}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.1634289774728398, -0.1265774433923417}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.8171448873641993, 0.6328872169617089}]}, 
                    LineBox[{{
                    0.1634289774728398, -0.1265774433923417}, \
{-0.8171448873641993, 0.6328872169617089}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 29->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.023988018144005, 0.7376160367231304}]}, 
                    LineBox[{{0, 0}, {-1.023988018144005, 
                    0.7376160367231304}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.1706646696906674, 0.12293600612052168}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.1706646696906674, -0.12293600612052168`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.8533233484533377, 0.6146800306026087}]}, 
                    LineBox[{{
                    0.1706646696906674, -0.12293600612052168`}, \
{-0.8533233484533377, 0.6146800306026087}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 30->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.065390905069891, 0.714317746768332}]}, 
                    LineBox[{{0, 0}, {-1.065390905069891, 
                    0.714317746768332}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.1775651508449818, 0.11905295779472197}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.1775651508449818, -0.11905295779472197`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.8878257542249093, 0.59526478897361}]}, 
                    LineBox[{{
                    0.1775651508449818, -0.11905295779472197`}, \
{-0.8878257542249093, 0.59526478897361}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 31->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.1048008591242793`, 0.6896824926021394}]}, 
                    LineBox[{{0, 0}, {-1.1048008591242793`, 
                    0.6896824926021394}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.1841334765207132, 0.11494708210035659}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.1841334765207132, -0.11494708210035659`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.9206673826035661, 0.5747354105017828}]}, 
                    LineBox[{{
                    0.1841334765207132, -0.11494708210035659`}, \
{-0.9206673826035661, 0.5747354105017828}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 32->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.1422365237470857`, 0.6638141198211621}]}, 
                    LineBox[{{0, 0}, {-1.1422365237470857`, 
                    0.6638141198211621}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.19037275395784767, 0.11063568663686038}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW
LJGOfc/OmLEzi+yMKFLv9/c+7zv/zPN55nvvfOfec8498zwzO4ysLt1jWbVq
1RHWVav+e0793wcFVv3f4+GbgWcphOsLvOqdLpwDapELazzhV2H/WR+qQj3l
wwkPVI6QoouNQcZtituHcJKHJ/H6Q0irKQq1J+wt/+ZWho01nMkZqbtJ+NxQ
D3G9HdjZG6cqEo5pE9fxY3cEniMHFbYT5lA1IsY/BSteTevljxS4/DJMxSzC
BTT546+0EZZ8bEDM9wxqju9jJBLOr6eKJgl5gNUTqqQd4RsfDIj5PeFgbuGG
U4RTSyqCQ257wY1vMYkshBOWeS/6sb+AeYPbHc9SKLBVW7vW6cJLqNffanmM
sGCJ7HO7+VfQ8DsjdzKZAtfpJDCL8IcwvUWls4Ql8w7cyLB5Awr8vi9nPlDA
JDHs6G7VQPhwL9o1mPCicZ1gklAQaO+feNCYRIGugCfN0cXBcOjwr1tGhEdr
aGnCr0Pg8LjkqvlECghfW3kRcjsUosftVDgJ/9RnBT/2cOAqyqtniadAMJ0r
2elCJFRKRgs5vKeA/Mknbos7ooC3O3M9LY4CZl0S1+zmoyCRXL+QF0uB7CI6
q1lEDMg//vZNIoYCARqW0hk2ceD0ZfqafTQF8NJTnnFKHDy/LBhZGkUBuYCG
RWnV95D0xl/4fCQFwvvYKhOF4kGxcufvfeEUOH50q050cQKI9Cx03AyjgPL3
hAMUyUTIrgA971AKZF4a4xF+nQgjcg8vNwZTQNzDtCH4dhLsPbVbTPINBXz+
Ncq+Yk8Gk32CJSw+xPpwSgQ9uZAKa9jkj7d7UyCscI9XYFkqLCxrhb/zosDg
0XL7jwfTYP7b9hkpTwpwd41rkDelA4eJLN+iCwWkh4bw6GAGGPbPlMfbUqAt
2/SmU2EWHPrygH+HDTE+Xnbfi9kssBJJOxVpRYFJS5s/QXuyYbqhSczFnAJb
vjD8U6Oz4eSO5X9sJhRYl230jPwsB5I/Xx/eokcB9ag+1yNnPwPjGzlc4yoF
xs2D2JU9PkNcpsM2q8sUMNTn9tYq/gwmIqPx6RcpwPz5zO6ubB60iTqb/dCg
wHZhraVA3nwQ0hb3Mj1KAQsRmsc4uQDqJoQj3fgp0FPQHRb2sBgiSjmz9/FS
4GiLsiw5thhqUqvlyRsoQNG+kL+5sxheVJ6x385JgYs7+WPj4CsUiff2O66i
AHVUv/yjQAnECvysOztBhtK1Zmxfvn2D1pPUx49KyXBa0ObhXY4yyB89k/Om
hAw2LtPebJJl0FASo5RcRIZTN1+GJZ4uA+VIBcPqz2SQ/7b1NdWuDP5u8nVv
TCEDy1QXybi/DPZtXvqyGEAGUHkZZZhbDiOZLxwr9ckQGH989KxBJbQXGz7R
v0aG+ZQiBSPHSrgfyccY1yVDWi3D5mlgJUSaf2NZrUUGI61fialVlXAgZlRi
/jQZWmR8/3Dsq4IHbWUXVnaQodFVXKLybxU4jn6WCqV2w4czZ1Ml4mqgU0Bm
IWywGzb/jo48WlQDRkd5hUJ6u+HNFQ1TrY4aUPh3RfFZRzdkLZNiHdbVAtks
VmJ7ZTec3P7nbo11LTg3O2q4xHeDZXMN9Y5SHfCwJY8l3eiGv3r6exyH64E3
+eLvtKvdcHDVounXv/WwVO56M12nG8gjty1Xb24Au/Ja0egz3aAU/7r8pW4D
cN2+dUHhYDfMP3jtEVnZAAezC6/c4OiG93UCGRkfGuH30h2LC9kkuO2b8zH6
YRNMbx06HTDdBaKL38/n/moBewWLcL8fXZBZF7yHwt4KFbopH56PdIHen6C2
VfytcNf4/MhdUhc09Um6acm2guWqiTTaty7oZ887Qb3TCq2CjjIMvy7gsbpU
u6ahFQxc6nYPSHbB1IHu3Vti2mDgl8LRs6qdcKSKy/KuYgdc2Z9pf/ZkJwyz
XrEI1O4AbW5crXKoE64vmf8pudkBNO8YNnHJTjigt1gl+KQDDinfswhg7QS3
q+E/MLsD/PV2VEuVdcDY9YPeK+KdABpuPPsVOmAyJ0FLiL0L7L3tZQ9saAcl
iyzrJzUk0DCalI5ja4eTbI3Z0EmChO0NIuuW20CbaXGMfYQEGz8+bi1ntEFi
tpPQ678k+P0v4uJIaRvIh5f3hx3uhpHRFI0mmzZw+lWi55nQDcIjUvHHmlrh
3gfBf19dyVDIX09vtG4BuSGKva58D8wWCMVLm7SA3wjd+efpHogxm05wudEC
lulJHmGaPbD3aZ4Nv3oLCGQ9ftZ5twemEkznJkVbYG1SguCZ8B54J8FBKvRu
hmst27YvLveAm2jv0S1bm+CoVvd618peGLxhLWYt3gBXLOdYi3T6gbZDOe3V
2gboN79TLGTYD9cMb0yGTtTDi/ynGTbm/aCaaWvnkF8PExfbD4u/6AcxCYF6
k7P18NH0oqfF137YQnPM+mtWB+n1tHupOwfgUWfI/Z6EGtiZt0cg+fcATH8P
3VXeWwHJqj4CDo2DYLF+5q0ZVkBW0yCxLINQddzSli2+AvS/exiZdw+CgvcT
dbb7FbDO6s+GW9RB2Fol3HxiphyOcNRrHfwzCKXn85S9/pWBhIk9NUFmCOKT
eiL0eEvB5f11kUDfIRAwMl9vtboQ+BR2th1QGgYTvo2/zbEALmWtiHxRH4Ym
qYl9Gi4F8Orih5bT54ch0uz+ubBf+dDvLOqhdm0YphPOc7+ZzAO53X1FYDEM
LpayB2ZacqHxVesH2tth2P/7Q6fsUiZcPnRt7ejUMDw0uFOrY5EJJcZ8i0fn
h8HrsvVbWaKOV+fkbvD5PQzPSYlO66vSIdVGJn072wg8jphdufsqFW7I/bp5
QmQElqR+vbLk/AALFqIOAiojID15Qj8pPgKy8mJWq4aOACR1T3IavIWAN6wX
KyJHgGm0IaRUKBzkOjX5FeNGgKL+RmuzTwiUeX4dO5A2Ahd6L9F4q17DmpcU
p4XSEYivujx1r9sOnIqf8qyaGIHDwboWKqZvsG3g3vNloEJBdbbz8apAPME0
eyquRoUt2yweM3YEo5l2hZX6OSpknxZkGPeFouLiRw2vy1Q4993JdvxmFNpF
aav2P6BCdEyUiywkYPUR6b7fb6iwIbiodjIpE92e/XhZ1E+F+DM6f1h1P+Gx
I4pa0iNUKHWSrT+8KgvN/Hn+BjGokLouPXRTZhbWrY7dYjhDhfQbl0sruXIw
KfY0o3U1DUo96vQbmj5juCDj0VZJGhhuNo/OsyvC33Psw0dNaJCt8S/WuLkI
BcKv7zv1kAaPVB6InJApxufGRVOnLGkwwDH9zGSkGEc1rIoPOdBgYu/VxE9X
SjBzzp5v0YtGnKdfXdfuKEVeoV6RhkQa5L+95MUtVoG5D5PHgwZooHREbyFQ
pwIpt30DTEdosCSxi0XOuwI5I8bvn2DQgF9BcSpnugKvSJ2JbZmiwdY3nfuH
Kyox/dqgd+kKDYx9/Ab6ravxyLSFWLYoHcL9DbUnP1Tjq6T3F45upYNPPJ+h
QF81bkdzvaIddKj4wribfrYGayTiOjOl6VCTMTvPKlmL1uvUOvSO0CG61sPy
Yl8d9m6zeJZ2kQ53hvYnjwrUozZt9mSfLh3OiKjZRpyvx9SqnRYc14j3mzAq
VP1aj9KPj27UMaDD392bG8uiGxBzOJOjTemwNcZ0UdfoO9aqv3PZ5k4H14kA
dfuo7/jXPtH6pycdUmS5/qV3fEeWgKdWVd50eGU+FXP/TBM2sc490vWjw8Jn
zz2r9zVjR53z2M5wOsx4N44NurWg1j5vr6Q0Ovhbc65PjW5BlhKl99yZdBAL
F2h2/dKCYlsuh1tl0SH3kPp+TWYLOllL/tqeR4fTG7r5re63Yq7Kxvaj3+gg
GR/YNqjThiG/YgQUmulQmHLiq5FVG8rX6eQfa6VD5LTnphm/NhRSWVVzuJ0O
Aq8zBWRr23BFcVBElESHo3oLZXLQjqTrNZVB/XTQ4RS3vyzXgafTH4ueniDW
lxSX8kqrAx+KuJh3TNLBN5bG3WTWgeayYyXG03S4aCmiZ5/SgaTvfsoWc8T1
jc/uqot3YuyNf5wyv+gQq7QmokuxE6ni1m98ftPBykWUZGPYiWXTq3v7l+hw
2PKHfl10J27Si055tEKHgrU5P5Y3deErI5PzmiwMqKJVto8c6cKZvlwFS1YG
3DC6EdV1pQvZJ35k+rIxIHxNUFpvcBfmZWVKpK5hgGP06dHpnC604HrO92kt
A2ZsXoxxt3Vhk3azVfo6BrROSOx6yEPCyZB9em84GVDp2H85RY6ENn4WHQ5c
DMhuZZGb1SYh3n38/sp6BuxttWyK9yehbrQ4zx9uBtRssvfmyiChwZ62+IoN
DLh88FaLayMJd62xfOC5kQGmQlZ/n3N149KF+5bjPAxIY2uuW5DuxnmHFF8f
XgYE7+rKtFHvxtbMo+Vb+Rgg98kj08O9G9/aVtse4WdAiO6lEuHYbnyh7tpf
QBjcxZoKvnajc81vbXkBBlxfr9jH86sbl63DpfgEGWCneay5XpCMsf133BwJ
K6bbpPofJKP0G8WqTsLvul4/uK5DxpRjLLN7hRhgvizJus+KjFmWdn+cCXNh
vh2XPxknUm4NVRFuksjLnU0lY5u2X8TaTQx4bO/2dbCWjNZF5VuVCafvM37R
TSfjYcXqh48Iu05GcZPZKDh++Lrje8JUXV2NYXEKfv594nQ1YfbFuP3zihTc
/HvvlxHCzRovcYMhBVULR4d+Ezb1YJk64EJBKfLunHXCDIh9PfbZIIqCfeIf
JXgIq8zzcAd9Icb7iu3/z6mlB6abSBQMO3iy9b/rd9su6AosUDDGq3DVEjGf
1/DPg0YCPdgmpVr43/udPfD5RaF8D1awB8xWEdbNjD+zSacHyaZnPsQRvl65
zdzVqgf3zoq02BFWGnGYnPTvwZcx2Q+AcMzDwYp76T3o0VNgyvrf+BB3Bq2+
B1+97GhEYr2ot8wvWv7oQRX2zFf2hNkfxy78XduLpbt/xO4grLprTVv4zl5c
vrObtYbYjxtHH1OOqvWiZjrPp7uEu2lf1g4b9+JCAsQsEfvbWuGkE+zRi+O+
V2p8CH+OHRDeUNqLPKHpef5EPEhWunmR+nvRokbKgo3w9RPREykrvXhLYEHd
jognsurDF8Yn+rB/6O+ZY0S8hdk++Xhevw8NWEyM3hDx6P4P40896cOfAe5e
A0S8dkc1LRwp6MPJ4F2N94h4buLXAejqw8j73cPRRLx/D3Q7fuFnH953eDna
QOTD1B8bCe+D/RjCcTiZl8iXVc7n/qZf6kdq/3ldaSKfWJYX7/XY9KNaUmLH
EQ4GnOQWyNPO6sfJB+dOnSDycf7rlE9wcz+WTGRvOkDk6yZnh/KBqX4M9vTL
2MrOAK1vT0+/lh3AGvea2UEi/4P/bj2lnDaA6Xttd63+S9QH444Ys+8D+Ocq
9W34HzpsX6d+MWZ6AKVucvJLLtNhMz/ly3rRQYz7arVqG1F/jq39FP7l1iCq
aLzojpqlw8a9+Y1TVoOoq+mRMkTULxez23O73AfxeMweEJsi6nWs3lxSwiD2
zbjHPhqjQ0fw0/nm0UHU0LuuljpMB+mO1H6JpUFc9m0wjhkk6jX1iosT1xAy
tH+u8SbqZ9sbUuHhfUM43uVepEChgy5j07lOuyHU1VKY2UzU442reNO//BtC
t+SV+4Nf6WBqOcqrxjuMxW6vfu0qosOkQVZyu/gwigzmvLxbQAfF8URYUhtG
hqZq8NdsOqiUmEqZ+w2j8Ae5S4wkOkCUYA5FZATxXPGj7cR5M+8T0hgiM4Jm
jmuvfPYh6u9xF3edUyMox1j5fNKLDmF6VUFtt0dQ0EaMtMeVDkey+o7OJY9g
3rBptZMVHVaYNV7vjlCxhLJi/eMCHTLMLkedP0PFhGDH0XXn6fDl1727f65R
cXID97SYBh12sGyZvP2Eiop2kW+kFelACx0in/xKxT4MckQ5OohLXFtWUKYh
i6SYw9R6Oli25s7/uUTDP4YSf4zX0WFx3XmuCmMaJqj7fmpipUPLlU8PLnnR
ULo+y9tziQa8EimNzrU0nJg+q/OQ6CcSnlC1FrXpaLByRWkX0kCz9PXNOkM6
+gkfHpz4QoPT/CzUKGs6uu9bezH5M9GPGB2UVw6io6Sqqt/SRxqIeMhEBXXS
cdp2uFckhAaVdxrGj95k4KrSfZIKRL90uLZk+ZzpKKrbCnDXEv0VRy84uTiN
ooyhlenrJSoUxfW0ZfqPYqPlGqo6kwpzTs713DmjeG5ycMtrKhV0OWc2FS+N
ov2ujf/sq6kQ6s7dWvnqB3aYipfHvqBCUtHUmq3pYyhTeU9V/d8IpJ9uleP6
NoYbFHquqC+MgHFDGvfP5jEEKeExhckRqDqzOfYbcwwZpJ5X0xSiP7ZpF9h1
Yhy/9KldyMobgR9pfXMn68bx0OUzY/YPRqDlwlnthaEJ5Cy6enixfBjsFX89
ZWNO4BH/KNPLhUR/fytXmpttEpP5L19LyBiGrSe8i7h3TqIMZ7W+ENG/x1Vd
i6ozncSq5n+Mi+bDIJWar755ZhLv7Q8L38Q3DJ9fXA+IWpzCdc43RscvDcHO
HyIN7Wun0XH4b6+b+hD07P7IxSY8jV57NUPYjw/BHlehs+ePTmNNndkl+vYh
iNv3wf7J42lU5b92ZmVyEI7dLrI9tDiN9Tlmpz29iO8/hg8ff3eYQSGRuKfr
Lw/APcmSlx0uM/hXf/P5t8cGwMu2YDXp+QwejzojtH7bAPyJvLj8PWgGL1yT
KUj70Q/cMt/2embOYKE6+85Gl35o4QF2VtoMzmw32h75vg86Ff28tmjP4oCW
83I+qQcC9+8IcLs8iwsH/fuvFPUAX7rDeK/+LJayGEn0R/dACpfLU+/7s7gt
/x5X2p0eMO2SZw95Novf869MKYxR4K3nWuvA7Fm8dafSWGaRDB3WIYY9G+bw
3KW9nyZXdcOPVh31WYE5zNxYekqinwQ/ywI0/onOYf7ao4WKxSSwsG9xYN01
hy+c9pEOPiKB24nxW2mn51D0sHf4CqMLCva+i7Y2n8MqC7WKI3Wd8HD1Py9W
2zks36AduJjYCTTeT+P+jnNoH7F7dfyzTkjdasXu6zGHI+r6Jz8rdMKaniqT
TW/n0H+C70FrYge4K+t98CubQ4ENLeEcTu1gJtFAC6qew4urj3TaXmmH+bX7
179pmEOVrvHkGrl2+LCLa8yycw6zNmgGHaK2wX4no7mS0TlUDErcs+18Gxyx
W5sQwc1E1nvkhCvCraCUKneCk4+J0smeKj6zLfAiUfyAjRATRfONPqTUt0CT
MKuQ+DYmsks2a+Q6t4BCyA7qhv1MdJNYJTGKzTD/7W4N90UmfpmifvdV/w4r
11ZmY3WZqHR1YbXQn0YoLD5yfvc1JvLG6b7xzm4Envd6j3fcYuLpngUU3NII
Qf24MdmMiVL25DDmdD2YB2uZsngxsVvs7ENGUC2wZ4zNsPkwkewRo92tXguL
1Rd1/r5kovEDkZLspRrYu+qdT+cbJjYuxmttM6qBLgnDs4LRTCwyedA/IVcN
Oz43snZlMVGzQ/RNQE0FvJTfMqySy8QLm4Q37HlaAf5x1y6m5DHx8Z4mr+y9
FaBGu9N4uYiJyfMLXj6B5aAbXNdxooKJ3L+tvt/SLwOlmwKVBlVMXH9qbrPp
+jIgfXsi6VDDxK3PrLKMvpVC2ZdLe142MFEih69TUrwUlkZpP063E+vVX/mI
0loC994prhboZGJMUkYD81AJXI5tshzoYuIWuwcGM+FfQS9OUfE6hYkLJp5B
oQbFcL9k78PuQSbKPgxlxDEKocHrzqDhMBON3vJ/o54tBD+v0dC+ESZmqdiH
8KQXgCkt93MxnYmKjgdSxK3zQbBF24VlgolBv9doKS3mwq3jnlGHJ5lY228S
MXcjFzYJSmoYTjHx0dpgh8DSHAh5sqIaNsPEnMLt+yJ9s0FLwDswYZaJlDGj
fexTWeB2cfO95DkmTkXJcd2+lAUdXgWRQfNMPLd88GLz4UywDX31+8lPJt4J
mdsq8zcdPj1bQ762QKz3zWoVs+o0yPmpILC4yEQSP9f+mKsfoc7imEXhLyZm
yxtoBG5NAdWPjkrWv5m4FPhMz5L+AQZ3TF2tWCLu93A92+ijRLhPmg69tczE
SnI90/tUAsC5Ms0ZwhZSms/42eNBn2Hp+PgPE3W/n+x43RgH6qyCwouEJWLc
D87vioXBvoG95itM7HfWWEjPj4bsJK48EuFw+SK1c2qRsNOJ+unYXyZe2bHB
sak9HB7aVW8JIrwxq3TghFEobIwSWx4kfIfq1xkyEwT2v+6d2/mPidG/7mX2
uL6BIX8ZTiPCGkNDz6RE/cDyBufxEMJhd/5UPD7yAt7eziR/JawmvqY975IH
xMa0j/YQji/Xyi/vewrvBdTvzxJe2GrBv0rIBqzrhy6vEI4N87zz+agBSNUE
Zf8j/HBX1IrJdxV8JHTF5RdhvXXyzHWeD7Cy5lAh47/5KrbpX+RwQNqkltF3
wkWpCjvXtrph0btGp4+Ex296lV1ofI5WcxNszoQLdLi41mX54guW5RVVwvlK
CeXJwa/xw+il+2yEk6QqxEKLA3F9yW2lIuLz7/397q6abAh2hcT5mRCedu42
HH4XhuuevTvLQbhQ7O0XU54IVHyx8DieWN81xUpbyO5ReOTj5c3yhKM2Osnv
Y8Ygk2R/oJDYn59cEboH5eNwe9vxr8nEfv41z9p7MiEec6VS5HkJ16fJOH7o
ScDVASbbbYh4EBl9WLvCn4SGzwRMBIh4YU+ldFs+T8bJqHOl14h4WpQ0U/P+
moLNY7fCAol42zTgxe89/xHfXjAoHiXi8+mWxgPH76ajpuV67jWEv7wxODAR
lYFu1RKDIkQ8N1przrq3Z6LNmXIeKSLeWV+Kc+55n4VPZjPq64j8CQyI1D22
MRfp+vST7kR+qa6/+fVbQS5qVp0Olh0n6l2mDPe+259Roq1m4e4oEb+rx51q
svJQQGU/Q5vIX56lnQdaLxZickBNTQaR3xwTeU6Bvwox69fbhNUDRP5Z7Rs8
HPcFz/1ep+/Tw8QbLZxC0tNFeJ3dR5yvg4kng/ZLvntVgtn91SdF2pjY9O/h
HjP5b+j3M9JSsIWJlqOfgoTI3/B6cqH0JFGPAva7Ulj4S3HrziOmokQ922O5
v0rYsAwjL/jPWH1iYsiyQ2IgswJvi+32qk9n4tnDRafL1Crxhbn6E9FUJkqa
qDhTwiuxwzkzJDKRWK+N0d61J6owZuD33i0RRH3MPm/p61GN36TGqnc/Y6J5
beS+y1x1mIRH6L3OTPTgv7/080Yd0vYKlXo9YeJqO6cdzul1uNGl7muhLVHf
bj45fkirHgsmLF8n3mViWfTbL+f8G1CyMNMiQp2Jm9vpWxvWNuHbXcHtU8pE
vYoJEtfUacIMDUw6AUxMq+KrzYxsQh7lqg/FCkwcWtJevV22Gb+5zFdekWZi
qbtUiY50C+LuuOHFtcR45a8LfzRa0fVc/3Q1K1Gf5NaSG8xbkTN08Lv/vzk0
lhb69PJNK3LUNAixLs6hn/u7ShKpFemPM9760eawOFbSPf1eG6adeH57B3E+
d7nO75R2bcc59o/p1l/nMG8HTflHXDvOvzM7WlgwhxnNSzFvK9ox90SVzP7M
Ofx4ViW1bF0HlvH6aFdGzmH2+lid40EdSNp1nf050S+wq93dlvW+E90287SG
bZnDXfRGXo4cEv7bOCH7XGgOe16yvRbuJKHzd8EgU545fFekXbPxFwnv/vwa
sYWN6Ce00zjzTnWjTDy5TnJ8FlviEwS7a7rxy4zfQHXBLGpejhE1I5FRfPFt
UrTmLHLc8pfdPdKDvhfDbWNVZ9G48N5TVtZeNJayiIk6NYsxxr2N5eK9uLks
4OgzuVlMO1BycuZOL7bPtRQu883i1xBhC7aBXvzmy+Fb1T2DEp4hHGwdfZjf
JEmfNZxBz/BpjpWUAVxKF1urrzeD0r+rQ7sqB3ByWF245OIMenXucAoZHMCS
oj+H7JVm8HTb77B+rkF8ZGnonCw+gxHTsXG3lQexpGNT6dXaaQw0+vmuOn0Q
H0uHFw/VTOEau1xdNschfB3GfyysYAp/cPFR5TyHUJjks0cleQq/iG5V0QoY
wnWJP794e0/h1imNBwbJQ2j5Y+FrvuoUuk8HH2jvGkI+Cb3KBpxErbRGSYGD
wximILxbN3sC1wf0eIwPDuPc1MYfRu8nMKIoNydmbBhtss4csQycwJXsBX+V
+WHc8VQhz9FmAi+ojmo+XDuClef5Jq4dmMDl2+u5JWVHMLvu1SX9rHFMEyvh
O+cwgquH1xt9TxvD5TLuaMt/I5gsbGVqFjWGFup/2yLWUvHRo4WmNa/GUOe6
91LhRioeGXUeP/xwDCW3v97Vvo2KS2E/Rh2kx3AfyUvHEaioFLmIAYk/UFq5
s9HdmYoD85eCHkeNYqsv90LhJBWt7vUz7H1HMdxZjf/3PBULOGU2WjuOYv2l
G69l/lDxnNAwj7HuKKaf+/D5PicNP1qn+J/iGkXr2d1Gp3bSUOyuUFjrUwa6
zxabG9+goZGj8/byBwzkfygh1XiHhhnJr8xyrjKw7u6aqF0PaFgxXe8cJM9A
uxsF3fn2NJzflrnp0hgdK5VuXVTwp+Hj/KoLPdfpWB+dsVBVTMNj8xSrpjN0
3Hx+/VuDMhou1obuLT9MR0P6pTuj1TRMbTbKSuOlY6HykxekVhqeqGI571NH
Q2dXWcYWBg1HGM/HbI/RcPfI5yPnNtIxudj0vZEoFcUFLD8aXaXjncOyBdkc
VMwxUadL69NRR4USz/J7BEujlpFqQMeY6ytbU0kjuLfwtvGpe8R9meRF84SO
oIZN9BY7Ozo6VMryq/CMoH2D5K+f/nTkfWjhnftvGH+ue88qEkhHPkO/Kzun
h9H473p++RA6Up5w7OJvGkbZxYFr6pF0vJn41IbTbxgHq+UO/Eqio5PF3fMO
64Zx5GIDw7uYjqJzDCGeX0P4V1dOg/sbHYeVG/LSGUMYUXZQ6GUpHW+3rvGf
qh5CV/sGwftVdCybIN0N9RpCMVb1W5+a6Lhn+niY+qMhlGnIpv9ooWOU6Y32
pbtDeK3pJB9RQ3G0J/CVueoQBox5W9wh0bHEVTH9EesQWt34O+M6QEeBNt15
YA7iDN1S22qIjrv2XnfmHhnE7dTy51dH6Jil+uBeTvkgZr1mD+dgEPc/JntW
0mMQZS4lbWCdomP+YslpDttBPKzbO506TcfaE4ZJs3cGMcJqZODsLB1PbXLr
a1QaRKberbUW83R8V30iOmP1IGZqMvefXaKj2CG13L8jA9iTzX8/YZmIE54x
iY9EnWCr5Tj28w8dD0f68vB7D2DCqeE6t390PJ+4Q+EkxwByiUvqHGBj4Akl
ZXfhsX4Mam7bdJadgSfbPvH9qe/HdZ5SGXprGHjzepQ82a8fU4WEDAzXMVCE
+5z9BE8//noY7cm1noEqEctr2Ob68Lsgw3qYsGGDvKxEex8W3fQ0zOYm4ly4
Tu9xaB+y3v99XWEjAwV3KVlnOvShm+Yj2ynC5ZPWMHGtD7WXvZNieBg4yTwv
7Sbah6u8k+ypvAwMFbfV7VjuxaLP58Wc+RjoyqN0/UBfLx5S/fabi5+B17pV
lcO+9WJaoipPCOHjy/NCrHG9KLFt930BAQaaPsobcHTvRf/GXDZ/wsttXYnz
Rr241l9meoWwz2cxtTU7ezHMcbGiVpCBvRTP/VFre1HmV1uRuBAD+y41Hj36
owepu1I3PSIc/Ylxr6++B++dKxlEwrVvcvFleg8WK2huYd3EwDcFS1qKr3tQ
/nJgy2nC3psfCf+16kE1nwZWO8LO/2p2Vur0YPTRQ19jCVuv8X4WdLAHt55m
W1VF+J6GnKypYA+K9dt2DhO+fP/AIY1FCgaX5yn/JiyVyIiWI1PQZW6V9jph
BrowIy23FVPwYL33ykbCtXweWZtiKPiL6XiNh/CWmDJTYTcKOt9mNeIgvGe7
+fsddyjoC1cllon5dh3wuHVQhYJffkW9pxFucJ9L1pKioJrk3+FawvI/I55b
r6XgqGfiZCLhrs8qy1E/yNi+/LnmCWEbtY98LQ1kzH+l63iG8FKUbev6TDL2
nYln2UDYU/7I6UtvyHj/UpnVd2K99oo9MYyzJaNbR1OlF2G2bZ9OLF4mY8ki
fa0C4aVvx8lXFcgYOCABQ8R+FN60OI0iZCyOj7F+TthD7YXN/j/dOKT6MH47
4R11BY9T+7vxYFYMJY/Yz2xtMX3Zsm7c+ensNlXCzqZVm78kdON+uotDAxEf
i+yl18YfdCNXeo59FRFP+mlfBvnOdmOqdWiLDGHn5Se/VXd3o5PQzR0vifhr
r7JfrP1BQgNbndJ9RHzO9XGMi9aTcPBul9gjIn43bN78yjGVhHZx469zNzAw
wdJm4qIZCVujL9QLE/HvvXSr+LsmCc/doyQAkR/HO0QuXdlLQh4Hi0+3uBiY
PHBt9vlkF4Zo/nvqxcHAeNpQqol1FxZSdQsciHxcqEDz4zpdKJ5eNG9I5GuX
8j9pEfku3BRgH6fEysD1BTdTFpmd2LK/4vbUKiJfPkncPfa4Ez/KS1+ZIuqB
yp2DUfeud2Lt/ZjOKKJevNzNthR9vBN5ZWr/Kf2mo/NhUVXZlQ6Uzky2fLxA
R8vPkpEdHh3YeinM8/UMHbV9O2P173Zg7U3KVhaiPp1Lzvw5rtaBvnTFd5aT
dFwbFZe4n6MDD7veNpEnzqmksz2vld+0Y+BLO9o9ov4ZMA7q+sW1oeZsVp9H
Bx2VzV8+qPNow8l/O4V82oj6tbGXh4/oCw+CX6I3UX85Eoqkq3e3YfFT1gGr
Rjr6nyro/JLbivX/GvyYFXS8pDo001rXgts+RDRVZdNR/TXvseLMFrQ3N87x
+0RHb75MzAxuQa4bs7u0M+g4K+r55rNBC4peEO4vTaFj8a35GQdqMz46u26D
SSwdI1d1L1gdb8LaxPK9n1/RcY27jKgfexM+aFnJ3ulLx4fefXNfW75jSNa9
rSHedNS/4tV88/53PHguqszQnY5Vb2zcQkMbcUF6obzIgY7WsaYVEz/rUSvV
d//z23RsZl9z50p5PUactA1OJs7Lx0N2pLbX9cjV8VCumjhP+YV/Xl4vXY/A
7bPz52U6/ohu+/KE6Ps5cvyjRc/S0f2syW6oriHa8I75F/vpaHNsZNWTtErc
1dK0esMfGl6KpZrccajEV1MXtuj9omF9TrqhkVIl3mQZ14qZp6FZSdGaTFIF
/tsQzi0ySfQjMc/5zNkrUFS4Lrarj4Y03zoxj3tlOJP6YK3VNxpSaZG7Bay/
YqXuw9gTzjTkvOPEx7b+K+aKKToyHWnYCKvTJVOK0VeNSyjZjoZa263Ji4NF
eED+SMlqMxruXdS1pV3+gjk5pUpe12l4w2i2n6SWj5ddWYPrDtOwf4yVha6Z
hbQekW7TcSpyy6tf2zf6CStru+AnnYpRdwunRo5+wtwAZXeXYSqSvAwyNXoy
8IGBaNxzMhUnIy9WL0ikofRCTp5FDRX/2SxHkiqT0Jjb1T4znoon/XSUrHzC
cMPZelnWa1RM+LnGiTc0EFR0123LLxjBN/MHXiVVBcHx12v4MnJGcM3gXb34
n8GgEPiz/n3GCIruGKjt0g0Dvf1ZEc8TRpCyyv6OHEcU/LFRW5QLGEGdTWnG
QzLxQL7xYON2kxE80Gu5p045DaoLrDkf841g96FTp9Q186EkBO8E3iP63cdg
PR+cDxXXdFTCDIexaLRH9UlvPqz3Uz4dcX0YOV7Ycq21KID1LtteRWgNo7Ba
VOQhv0Jwuyrc6Hl4GA33schSy4sg7Kv1idXsw9jS5kj7xYsgHErOyY4fQi13
pfz1MRWQWeLvY0keRMFIlw69ogrQ/WRw7Gn7IIZucnMKIVXAwRzPquffB/Hq
YepTCm8lFFzWdwgrI/qIlReD770q4eWix/30j4NYWzGmLfGwCmoXpCYSngzi
Jm27cuFdNaDG36HUKDyI16+dsOK0rQcnc4FfiSn96OQbSvX0rwf/Xlm+o1H9
eDv8etp4Sj3k7dC9VOffj5Pe3zW8B+phfoJHh27bj4UXY5+PajZA6LH4GM5T
/ajV/3L1/R2NsPvsZp5/LX24/YVWqBN+B6FOV7u0xV5UlMgXK77bAgdMPxd8
UOxB6VeXT++0boGEpm+vRYhzszvXN9HXqQWKJG6cfiXVgzl/HbWOBbXAM/kX
cmacPfgv4YLxSWyB+JNFQWIdFFzHdmd3x6ZW0DN+t1n7PgU75F5K3KpoBefC
B+/G/cjIp32T7sDWDsHPslmciO+Lx1q6Fe5xtwOtx+hFbC0JvTKqHmgJtcOB
O7FmFcUktLBTsOGSbof7qQbXOOJJqFOy6+ppzXaIus3d629JwhXud8fc37RD
agMp9OlaEnoKZtj4CnVA62+hK2NHu3D6O4O5kbcTCnl17+tHduDODS7GO0U6
4XSXa626XwfW/Homd2RHJ+z7+iRf3rUD1fObaUoHOuFQ/tRJDqMOVKxi5+TU
6YTirNmN2bs78KOs1DbDgE4QEM/+OFHYjizmFqEya4ncynuzX5TUhh9bbCdK
R7qAf71mjAtfK4bUZdBafnRBC3UvU5W9FXfv3vmiZ7oLylyL+Nb/asFD5d9q
B5e7YLX+fFZEXwuiaJdVGj8JBk5bPM5JacFKhU/Bysok4NtSkEg53YI9qa+3
e0SR4DnzfCRvVxMqT5f8+BFHgiC5irchxU04S1byOf+BBBSfFo1N75uQtSTs
HEs2CT6uZi/bbN6EO+l6HPurSSB/qk56B0sThmZpB4VOk8C+TcJn677vKB+Q
9DHwdDd8FxOqHfVqQNuhrYmnVbrh7LWm2VGzBmxMZH6nn+kGsvM4fVSnAVky
N3+W1umGFfXyw6NiDRi7ccsPW+NuqGiNdKDm1aNmxSBjx4tuUNn6YU0HrQ53
7G31n63vhjNmovuC1Wrxtv+cx5rmbuDYcofiL1OL1sWZtULt3bDhiYyxD28t
Jo13nN3dQ8z3QHy9S18NbmhOOSU03g2P/aD27qMa/MOq+42HkwxFWYvn9iVV
o8v1o+6vVcmwNL9NN52tCj98nDp/Q4MMtPiJQxajldikSsoXP08GUQ7OP7KN
lWh92cn0vS4ZOLZOn/gUXIksibfu3zIiwyrbna+zxCsxfGpnGsmVDKu1HLsy
FSvwlunmA025ZLhq6/Aq2rkMlV2mcmfyydAZfbZL/3YZvq5cZnIXkeGG1BKv
iGoZ3olT/nS0lAz981sMQrnKMHN97J4LjWTw5b56zj+yFMN/ps88GyGDFU/q
k5/WiA9+CmqvcFOgrGLdg6jRYvwxvSpXm4cCLAO0nt7cYlzcLBIRxUeBvSYv
lbe6FaMbY+P4rk0UkMm79iNOsBiHmYF5nNspcGKWLSlJuQjZhiQNfu+nwK5P
XLwZ0YWocuKPIOtBCqg1WbZN3i9E+mEXvXWHKRCm3fJy38FCPPTD3pn9GAVu
czgOfaorQMb5Rq16xf9+r+64N2chH3s38rq5XqDAjNzx+3kX85B0y4xLSYcC
cbtKs39uzkMfvw7pf5cocE7BceEw4zNuaPcWtrxKzHdZyirf5TNmBQiShAyI
z/OdU7wgNRcVtifsCTGlQG1X4KcCthz8JJT9a6MZBax7Mz8tNmfj+SyxWy/M
KbCeTSddISob2eafzTywosBSw7uoggPZGPTkyKlFewqksAdcKbiVhbuAq0zR
jQItfxejzG0ysKzXYCjiGQXSdgZJJS+n4zfpTt9Jdwp0OnqmDnml44YDTfbP
n1Mggvtc8tXINLzr2V5i7UuBv6EitooVH9EQFfe8e0kB8N/b+1TrI17dM7ij
+hUFfNJ2quSRUlAge8tn9tcUkFz3ZN2eiWR88XC1pUoQBT5a9NnzC37AZ2nP
TqkFU4BfxLleKzYJf8t1RiqFUGDZZu9Wn91JSFu1f9WeMAoEhZws/XMqEaPr
Mly+RFAgQ1BmjmYSj0caRyoCIon1vGhzYvvse7Sf3BV5O4oC+y7EeOo7vcfN
T0mLs9EUOHNsiac5IA4Lne64tsdS4NbTNBVrmxgU+/5e0zWOAoXKpbVUr2ik
cmCqxHsKSGR9OX89MgpjFfS23YqngPtKuY5yRQRG/z14mElYdYSlPZ/0Fg8Y
pPd5JFDgUPgLXZmJcPyrv50RmEiBnE2ZlwQEw7AgxFKDN4kC0UF2rT67Q1Ey
6u/JV4RbrlRdWDkVgtv4HQctPxD7dVxdk24ShIdoiQHdhFd8X9fqOwWitFps
28lkCuyMCFVrDniDIUq2Aj8Jl//hcrW28cdpdk/+sykU+Jz6z+F65CtkSWn5
EE6YuSnXSrnCF8+L2jUNEpZWkX8gM/ECzVKevZT8SIE9wS9uCwh6I+8id48R
4XPMYr2VU89RgG1faRThmumui3QTD7TfOXesmbBvZ79Gc8AzvLXhocYK4ZNR
2e7WNi64vyphXCqVAuGzgTbKFU/waUaaxFnCTVvu3REQdEBuT78ZE8LWC3I6
dBNbXNC/cMmNcB9znBhvga4JyxpBhM8v2hLXm6C8ZHhHLGH1yGnidQOkrUj9
TP7v/zLN/1kL////NFyqjqnwMObr/wBDP+3J
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{
                    0.19037275395784767`, -0.11063568663686038`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.951863769789238, 0.5531784331843017}]}, 
                    LineBox[{{
                    0.19037275395784767`, -0.11063568663686038`}, \
{-0.951863769789238, 0.5531784331843017}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 33->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.1777165159761105`, 0.636808639215818}]}, 
                    LineBox[{{0, 0}, {-1.1777165159761105`, 
                    0.636808639215818}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.19628608599601846, 0.10613477320263635}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW
LJGOfc/OmLEzi+yMKFLv9/c+7zv/zPN55nvvfOfec8498zwzO4ysLt1jWbVq
1RHWVav+e0793wcFVv3f4+GbgWcphOsLvOqdLpwDapELazzhV2H/WR+qQj3l
wwkPVI6QoouNQcZtituHcJKHJ/H6Q0irKQq1J+wt/+ZWho01nMkZqbtJ+NxQ
D3G9HdjZG6cqEo5pE9fxY3cEniMHFbYT5lA1IsY/BSteTevljxS4/DJMxSzC
BTT546+0EZZ8bEDM9wxqju9jJBLOr6eKJgl5gNUTqqQd4RsfDIj5PeFgbuGG
U4RTSyqCQ257wY1vMYkshBOWeS/6sb+AeYPbHc9SKLBVW7vW6cJLqNffanmM
sGCJ7HO7+VfQ8DsjdzKZAtfpJDCL8IcwvUWls4Ql8w7cyLB5Awr8vi9nPlDA
JDHs6G7VQPhwL9o1mPCicZ1gklAQaO+feNCYRIGugCfN0cXBcOjwr1tGhEdr
aGnCr0Pg8LjkqvlECghfW3kRcjsUosftVDgJ/9RnBT/2cOAqyqtniadAMJ0r
2elCJFRKRgs5vKeA/Mknbos7ooC3O3M9LY4CZl0S1+zmoyCRXL+QF0uB7CI6
q1lEDMg//vZNIoYCARqW0hk2ceD0ZfqafTQF8NJTnnFKHDy/LBhZGkUBuYCG
RWnV95D0xl/4fCQFwvvYKhOF4kGxcufvfeEUOH50q050cQKI9Cx03AyjgPL3
hAMUyUTIrgA971AKZF4a4xF+nQgjcg8vNwZTQNzDtCH4dhLsPbVbTPINBXz+
Ncq+Yk8Gk32CJSw+xPpwSgQ9uZAKa9jkj7d7UyCscI9XYFkqLCxrhb/zosDg
0XL7jwfTYP7b9hkpTwpwd41rkDelA4eJLN+iCwWkh4bw6GAGGPbPlMfbUqAt
2/SmU2EWHPrygH+HDTE+Xnbfi9kssBJJOxVpRYFJS5s/QXuyYbqhSczFnAJb
vjD8U6Oz4eSO5X9sJhRYl230jPwsB5I/Xx/eokcB9ag+1yNnPwPjGzlc4yoF
xs2D2JU9PkNcpsM2q8sUMNTn9tYq/gwmIqPx6RcpwPz5zO6ubB60iTqb/dCg
wHZhraVA3nwQ0hb3Mj1KAQsRmsc4uQDqJoQj3fgp0FPQHRb2sBgiSjmz9/FS
4GiLsiw5thhqUqvlyRsoQNG+kL+5sxheVJ6x385JgYs7+WPj4CsUiff2O66i
AHVUv/yjQAnECvysOztBhtK1Zmxfvn2D1pPUx49KyXBa0ObhXY4yyB89k/Om
hAw2LtPebJJl0FASo5RcRIZTN1+GJZ4uA+VIBcPqz2SQ/7b1NdWuDP5u8nVv
TCEDy1QXybi/DPZtXvqyGEAGUHkZZZhbDiOZLxwr9ckQGH989KxBJbQXGz7R
v0aG+ZQiBSPHSrgfyccY1yVDWi3D5mlgJUSaf2NZrUUGI61fialVlXAgZlRi
/jQZWmR8/3Dsq4IHbWUXVnaQodFVXKLybxU4jn6WCqV2w4czZ1Ml4mqgU0Bm
IWywGzb/jo48WlQDRkd5hUJ6u+HNFQ1TrY4aUPh3RfFZRzdkLZNiHdbVAtks
VmJ7ZTec3P7nbo11LTg3O2q4xHeDZXMN9Y5SHfCwJY8l3eiGv3r6exyH64E3
+eLvtKvdcHDVounXv/WwVO56M12nG8gjty1Xb24Au/Ja0egz3aAU/7r8pW4D
cN2+dUHhYDfMP3jtEVnZAAezC6/c4OiG93UCGRkfGuH30h2LC9kkuO2b8zH6
YRNMbx06HTDdBaKL38/n/moBewWLcL8fXZBZF7yHwt4KFbopH56PdIHen6C2
VfytcNf4/MhdUhc09Um6acm2guWqiTTaty7oZ887Qb3TCq2CjjIMvy7gsbpU
u6ahFQxc6nYPSHbB1IHu3Vti2mDgl8LRs6qdcKSKy/KuYgdc2Z9pf/ZkJwyz
XrEI1O4AbW5crXKoE64vmf8pudkBNO8YNnHJTjigt1gl+KQDDinfswhg7QS3
q+E/MLsD/PV2VEuVdcDY9YPeK+KdABpuPPsVOmAyJ0FLiL0L7L3tZQ9saAcl
iyzrJzUk0DCalI5ja4eTbI3Z0EmChO0NIuuW20CbaXGMfYQEGz8+bi1ntEFi
tpPQ678k+P0v4uJIaRvIh5f3hx3uhpHRFI0mmzZw+lWi55nQDcIjUvHHmlrh
3gfBf19dyVDIX09vtG4BuSGKva58D8wWCMVLm7SA3wjd+efpHogxm05wudEC
lulJHmGaPbD3aZ4Nv3oLCGQ9ftZ5twemEkznJkVbYG1SguCZ8B54J8FBKvRu
hmst27YvLveAm2jv0S1bm+CoVvd618peGLxhLWYt3gBXLOdYi3T6gbZDOe3V
2gboN79TLGTYD9cMb0yGTtTDi/ynGTbm/aCaaWvnkF8PExfbD4u/6AcxCYF6
k7P18NH0oqfF137YQnPM+mtWB+n1tHupOwfgUWfI/Z6EGtiZt0cg+fcATH8P
3VXeWwHJqj4CDo2DYLF+5q0ZVkBW0yCxLINQddzSli2+AvS/exiZdw+CgvcT
dbb7FbDO6s+GW9RB2Fol3HxiphyOcNRrHfwzCKXn85S9/pWBhIk9NUFmCOKT
eiL0eEvB5f11kUDfIRAwMl9vtboQ+BR2th1QGgYTvo2/zbEALmWtiHxRH4Ym
qYl9Gi4F8Orih5bT54ch0uz+ubBf+dDvLOqhdm0YphPOc7+ZzAO53X1FYDEM
LpayB2ZacqHxVesH2tth2P/7Q6fsUiZcPnRt7ejUMDw0uFOrY5EJJcZ8i0fn
h8HrsvVbWaKOV+fkbvD5PQzPSYlO66vSIdVGJn072wg8jphdufsqFW7I/bp5
QmQElqR+vbLk/AALFqIOAiojID15Qj8pPgKy8mJWq4aOACR1T3IavIWAN6wX
KyJHgGm0IaRUKBzkOjX5FeNGgKL+RmuzTwiUeX4dO5A2Ahd6L9F4q17DmpcU
p4XSEYivujx1r9sOnIqf8qyaGIHDwboWKqZvsG3g3vNloEJBdbbz8apAPME0
eyquRoUt2yweM3YEo5l2hZX6OSpknxZkGPeFouLiRw2vy1Q4993JdvxmFNpF
aav2P6BCdEyUiywkYPUR6b7fb6iwIbiodjIpE92e/XhZ1E+F+DM6f1h1P+Gx
I4pa0iNUKHWSrT+8KgvN/Hn+BjGokLouPXRTZhbWrY7dYjhDhfQbl0sruXIw
KfY0o3U1DUo96vQbmj5juCDj0VZJGhhuNo/OsyvC33Psw0dNaJCt8S/WuLkI
BcKv7zv1kAaPVB6InJApxufGRVOnLGkwwDH9zGSkGEc1rIoPOdBgYu/VxE9X
SjBzzp5v0YtGnKdfXdfuKEVeoV6RhkQa5L+95MUtVoG5D5PHgwZooHREbyFQ
pwIpt30DTEdosCSxi0XOuwI5I8bvn2DQgF9BcSpnugKvSJ2JbZmiwdY3nfuH
Kyox/dqgd+kKDYx9/Ab6ravxyLSFWLYoHcL9DbUnP1Tjq6T3F45upYNPPJ+h
QF81bkdzvaIddKj4wribfrYGayTiOjOl6VCTMTvPKlmL1uvUOvSO0CG61sPy
Yl8d9m6zeJZ2kQ53hvYnjwrUozZt9mSfLh3OiKjZRpyvx9SqnRYc14j3mzAq
VP1aj9KPj27UMaDD392bG8uiGxBzOJOjTemwNcZ0UdfoO9aqv3PZ5k4H14kA
dfuo7/jXPtH6pycdUmS5/qV3fEeWgKdWVd50eGU+FXP/TBM2sc490vWjw8Jn
zz2r9zVjR53z2M5wOsx4N44NurWg1j5vr6Q0Ovhbc65PjW5BlhKl99yZdBAL
F2h2/dKCYlsuh1tl0SH3kPp+TWYLOllL/tqeR4fTG7r5re63Yq7Kxvaj3+gg
GR/YNqjThiG/YgQUmulQmHLiq5FVG8rX6eQfa6VD5LTnphm/NhRSWVVzuJ0O
Aq8zBWRr23BFcVBElESHo3oLZXLQjqTrNZVB/XTQ4RS3vyzXgafTH4ueniDW
lxSX8kqrAx+KuJh3TNLBN5bG3WTWgeayYyXG03S4aCmiZ5/SgaTvfsoWc8T1
jc/uqot3YuyNf5wyv+gQq7QmokuxE6ni1m98ftPBykWUZGPYiWXTq3v7l+hw
2PKHfl10J27Si055tEKHgrU5P5Y3deErI5PzmiwMqKJVto8c6cKZvlwFS1YG
3DC6EdV1pQvZJ35k+rIxIHxNUFpvcBfmZWVKpK5hgGP06dHpnC604HrO92kt
A2ZsXoxxt3Vhk3azVfo6BrROSOx6yEPCyZB9em84GVDp2H85RY6ENn4WHQ5c
DMhuZZGb1SYh3n38/sp6BuxttWyK9yehbrQ4zx9uBtRssvfmyiChwZ62+IoN
DLh88FaLayMJd62xfOC5kQGmQlZ/n3N149KF+5bjPAxIY2uuW5DuxnmHFF8f
XgYE7+rKtFHvxtbMo+Vb+Rgg98kj08O9G9/aVtse4WdAiO6lEuHYbnyh7tpf
QBjcxZoKvnajc81vbXkBBlxfr9jH86sbl63DpfgEGWCneay5XpCMsf133BwJ
K6bbpPofJKP0G8WqTsLvul4/uK5DxpRjLLN7hRhgvizJus+KjFmWdn+cCXNh
vh2XPxknUm4NVRFuksjLnU0lY5u2X8TaTQx4bO/2dbCWjNZF5VuVCafvM37R
TSfjYcXqh48Iu05GcZPZKDh++Lrje8JUXV2NYXEKfv594nQ1YfbFuP3zihTc
/HvvlxHCzRovcYMhBVULR4d+Ezb1YJk64EJBKfLunHXCDIh9PfbZIIqCfeIf
JXgIq8zzcAd9Icb7iu3/z6mlB6abSBQMO3iy9b/rd9su6AosUDDGq3DVEjGf
1/DPg0YCPdgmpVr43/udPfD5RaF8D1awB8xWEdbNjD+zSacHyaZnPsQRvl65
zdzVqgf3zoq02BFWGnGYnPTvwZcx2Q+AcMzDwYp76T3o0VNgyvrf+BB3Bq2+
B1+97GhEYr2ot8wvWv7oQRX2zFf2hNkfxy78XduLpbt/xO4grLprTVv4zl5c
vrObtYbYjxtHH1OOqvWiZjrPp7uEu2lf1g4b9+JCAsQsEfvbWuGkE+zRi+O+
V2p8CH+OHRDeUNqLPKHpef5EPEhWunmR+nvRokbKgo3w9RPREykrvXhLYEHd
jognsurDF8Yn+rB/6O+ZY0S8hdk++Xhevw8NWEyM3hDx6P4P40896cOfAe5e
A0S8dkc1LRwp6MPJ4F2N94h4buLXAejqw8j73cPRRLx/D3Q7fuFnH953eDna
QOTD1B8bCe+D/RjCcTiZl8iXVc7n/qZf6kdq/3ldaSKfWJYX7/XY9KNaUmLH
EQ4GnOQWyNPO6sfJB+dOnSDycf7rlE9wcz+WTGRvOkDk6yZnh/KBqX4M9vTL
2MrOAK1vT0+/lh3AGvea2UEi/4P/bj2lnDaA6Xttd63+S9QH444Ys+8D+Ocq
9W34HzpsX6d+MWZ6AKVucvJLLtNhMz/ly3rRQYz7arVqG1F/jq39FP7l1iCq
aLzojpqlw8a9+Y1TVoOoq+mRMkTULxez23O73AfxeMweEJsi6nWs3lxSwiD2
zbjHPhqjQ0fw0/nm0UHU0LuuljpMB+mO1H6JpUFc9m0wjhkk6jX1iosT1xAy
tH+u8SbqZ9sbUuHhfUM43uVepEChgy5j07lOuyHU1VKY2UzU442reNO//BtC
t+SV+4Nf6WBqOcqrxjuMxW6vfu0qosOkQVZyu/gwigzmvLxbQAfF8URYUhtG
hqZq8NdsOqiUmEqZ+w2j8Ae5S4wkOkCUYA5FZATxXPGj7cR5M+8T0hgiM4Jm
jmuvfPYh6u9xF3edUyMox1j5fNKLDmF6VUFtt0dQ0EaMtMeVDkey+o7OJY9g
3rBptZMVHVaYNV7vjlCxhLJi/eMCHTLMLkedP0PFhGDH0XXn6fDl1727f65R
cXID97SYBh12sGyZvP2Eiop2kW+kFelACx0in/xKxT4MckQ5OohLXFtWUKYh
i6SYw9R6Oli25s7/uUTDP4YSf4zX0WFx3XmuCmMaJqj7fmpipUPLlU8PLnnR
ULo+y9tziQa8EimNzrU0nJg+q/OQ6CcSnlC1FrXpaLByRWkX0kCz9PXNOkM6
+gkfHpz4QoPT/CzUKGs6uu9bezH5M9GPGB2UVw6io6Sqqt/SRxqIeMhEBXXS
cdp2uFckhAaVdxrGj95k4KrSfZIKRL90uLZk+ZzpKKrbCnDXEv0VRy84uTiN
ooyhlenrJSoUxfW0ZfqPYqPlGqo6kwpzTs713DmjeG5ycMtrKhV0OWc2FS+N
ov2ujf/sq6kQ6s7dWvnqB3aYipfHvqBCUtHUmq3pYyhTeU9V/d8IpJ9uleP6
NoYbFHquqC+MgHFDGvfP5jEEKeExhckRqDqzOfYbcwwZpJ5X0xSiP7ZpF9h1
Yhy/9KldyMobgR9pfXMn68bx0OUzY/YPRqDlwlnthaEJ5Cy6enixfBjsFX89
ZWNO4BH/KNPLhUR/fytXmpttEpP5L19LyBiGrSe8i7h3TqIMZ7W+ENG/x1Vd
i6ozncSq5n+Mi+bDIJWar755ZhLv7Q8L38Q3DJ9fXA+IWpzCdc43RscvDcHO
HyIN7Wun0XH4b6+b+hD07P7IxSY8jV57NUPYjw/BHlehs+ePTmNNndkl+vYh
iNv3wf7J42lU5b92ZmVyEI7dLrI9tDiN9Tlmpz29iO8/hg8ff3eYQSGRuKfr
Lw/APcmSlx0uM/hXf/P5t8cGwMu2YDXp+QwejzojtH7bAPyJvLj8PWgGL1yT
KUj70Q/cMt/2embOYKE6+85Gl35o4QF2VtoMzmw32h75vg86Ff28tmjP4oCW
83I+qQcC9+8IcLs8iwsH/fuvFPUAX7rDeK/+LJayGEn0R/dACpfLU+/7s7gt
/x5X2p0eMO2SZw95Novf869MKYxR4K3nWuvA7Fm8dafSWGaRDB3WIYY9G+bw
3KW9nyZXdcOPVh31WYE5zNxYekqinwQ/ywI0/onOYf7ao4WKxSSwsG9xYN01
hy+c9pEOPiKB24nxW2mn51D0sHf4CqMLCva+i7Y2n8MqC7WKI3Wd8HD1Py9W
2zks36AduJjYCTTeT+P+jnNoH7F7dfyzTkjdasXu6zGHI+r6Jz8rdMKaniqT
TW/n0H+C70FrYge4K+t98CubQ4ENLeEcTu1gJtFAC6qew4urj3TaXmmH+bX7
179pmEOVrvHkGrl2+LCLa8yycw6zNmgGHaK2wX4no7mS0TlUDErcs+18Gxyx
W5sQwc1E1nvkhCvCraCUKneCk4+J0smeKj6zLfAiUfyAjRATRfONPqTUt0CT
MKuQ+DYmsks2a+Q6t4BCyA7qhv1MdJNYJTGKzTD/7W4N90UmfpmifvdV/w4r
11ZmY3WZqHR1YbXQn0YoLD5yfvc1JvLG6b7xzm4Envd6j3fcYuLpngUU3NII
Qf24MdmMiVL25DDmdD2YB2uZsngxsVvs7ENGUC2wZ4zNsPkwkewRo92tXguL
1Rd1/r5kovEDkZLspRrYu+qdT+cbJjYuxmttM6qBLgnDs4LRTCwyedA/IVcN
Oz43snZlMVGzQ/RNQE0FvJTfMqySy8QLm4Q37HlaAf5x1y6m5DHx8Z4mr+y9
FaBGu9N4uYiJyfMLXj6B5aAbXNdxooKJ3L+tvt/SLwOlmwKVBlVMXH9qbrPp
+jIgfXsi6VDDxK3PrLKMvpVC2ZdLe142MFEih69TUrwUlkZpP063E+vVX/mI
0loC994prhboZGJMUkYD81AJXI5tshzoYuIWuwcGM+FfQS9OUfE6hYkLJp5B
oQbFcL9k78PuQSbKPgxlxDEKocHrzqDhMBON3vJ/o54tBD+v0dC+ESZmqdiH
8KQXgCkt93MxnYmKjgdSxK3zQbBF24VlgolBv9doKS3mwq3jnlGHJ5lY228S
MXcjFzYJSmoYTjHx0dpgh8DSHAh5sqIaNsPEnMLt+yJ9s0FLwDswYZaJlDGj
fexTWeB2cfO95DkmTkXJcd2+lAUdXgWRQfNMPLd88GLz4UywDX31+8lPJt4J
mdsq8zcdPj1bQ762QKz3zWoVs+o0yPmpILC4yEQSP9f+mKsfoc7imEXhLyZm
yxtoBG5NAdWPjkrWv5m4FPhMz5L+AQZ3TF2tWCLu93A92+ijRLhPmg69tczE
SnI90/tUAsC5Ms0ZwhZSms/42eNBn2Hp+PgPE3W/n+x43RgH6qyCwouEJWLc
D87vioXBvoG95itM7HfWWEjPj4bsJK48EuFw+SK1c2qRsNOJ+unYXyZe2bHB
sak9HB7aVW8JIrwxq3TghFEobIwSWx4kfIfq1xkyEwT2v+6d2/mPidG/7mX2
uL6BIX8ZTiPCGkNDz6RE/cDyBufxEMJhd/5UPD7yAt7eziR/JawmvqY975IH
xMa0j/YQji/Xyi/vewrvBdTvzxJe2GrBv0rIBqzrhy6vEI4N87zz+agBSNUE
Zf8j/HBX1IrJdxV8JHTF5RdhvXXyzHWeD7Cy5lAh47/5KrbpX+RwQNqkltF3
wkWpCjvXtrph0btGp4+Ex296lV1ofI5WcxNszoQLdLi41mX54guW5RVVwvlK
CeXJwa/xw+il+2yEk6QqxEKLA3F9yW2lIuLz7/397q6abAh2hcT5mRCedu42
HH4XhuuevTvLQbhQ7O0XU54IVHyx8DieWN81xUpbyO5ReOTj5c3yhKM2Osnv
Y8Ygk2R/oJDYn59cEboH5eNwe9vxr8nEfv41z9p7MiEec6VS5HkJ16fJOH7o
ScDVASbbbYh4EBl9WLvCn4SGzwRMBIh4YU+ldFs+T8bJqHOl14h4WpQ0U/P+
moLNY7fCAol42zTgxe89/xHfXjAoHiXi8+mWxgPH76ajpuV67jWEv7wxODAR
lYFu1RKDIkQ8N1przrq3Z6LNmXIeKSLeWV+Kc+55n4VPZjPq64j8CQyI1D22
MRfp+vST7kR+qa6/+fVbQS5qVp0Olh0n6l2mDPe+259Roq1m4e4oEb+rx51q
svJQQGU/Q5vIX56lnQdaLxZickBNTQaR3xwTeU6Bvwox69fbhNUDRP5Z7Rs8
HPcFz/1ep+/Tw8QbLZxC0tNFeJ3dR5yvg4kng/ZLvntVgtn91SdF2pjY9O/h
HjP5b+j3M9JSsIWJlqOfgoTI3/B6cqH0JFGPAva7Ulj4S3HrziOmokQ922O5
v0rYsAwjL/jPWH1iYsiyQ2IgswJvi+32qk9n4tnDRafL1Crxhbn6E9FUJkqa
qDhTwiuxwzkzJDKRWK+N0d61J6owZuD33i0RRH3MPm/p61GN36TGqnc/Y6J5
beS+y1x1mIRH6L3OTPTgv7/080Yd0vYKlXo9YeJqO6cdzul1uNGl7muhLVHf
bj45fkirHgsmLF8n3mViWfTbL+f8G1CyMNMiQp2Jm9vpWxvWNuHbXcHtU8pE
vYoJEtfUacIMDUw6AUxMq+KrzYxsQh7lqg/FCkwcWtJevV22Gb+5zFdekWZi
qbtUiY50C+LuuOHFtcR45a8LfzRa0fVc/3Q1K1Gf5NaSG8xbkTN08Lv/vzk0
lhb69PJNK3LUNAixLs6hn/u7ShKpFemPM9760eawOFbSPf1eG6adeH57B3E+
d7nO75R2bcc59o/p1l/nMG8HTflHXDvOvzM7WlgwhxnNSzFvK9ox90SVzP7M
Ofx4ViW1bF0HlvH6aFdGzmH2+lid40EdSNp1nf050S+wq93dlvW+E90287SG
bZnDXfRGXo4cEv7bOCH7XGgOe16yvRbuJKHzd8EgU545fFekXbPxFwnv/vwa
sYWN6Ce00zjzTnWjTDy5TnJ8FlviEwS7a7rxy4zfQHXBLGpejhE1I5FRfPFt
UrTmLHLc8pfdPdKDvhfDbWNVZ9G48N5TVtZeNJayiIk6NYsxxr2N5eK9uLks
4OgzuVlMO1BycuZOL7bPtRQu883i1xBhC7aBXvzmy+Fb1T2DEp4hHGwdfZjf
JEmfNZxBz/BpjpWUAVxKF1urrzeD0r+rQ7sqB3ByWF245OIMenXucAoZHMCS
oj+H7JVm8HTb77B+rkF8ZGnonCw+gxHTsXG3lQexpGNT6dXaaQw0+vmuOn0Q
H0uHFw/VTOEau1xdNschfB3GfyysYAp/cPFR5TyHUJjks0cleQq/iG5V0QoY
wnWJP794e0/h1imNBwbJQ2j5Y+FrvuoUuk8HH2jvGkI+Cb3KBpxErbRGSYGD
wximILxbN3sC1wf0eIwPDuPc1MYfRu8nMKIoNydmbBhtss4csQycwJXsBX+V
+WHc8VQhz9FmAi+ojmo+XDuClef5Jq4dmMDl2+u5JWVHMLvu1SX9rHFMEyvh
O+cwgquH1xt9TxvD5TLuaMt/I5gsbGVqFjWGFup/2yLWUvHRo4WmNa/GUOe6
91LhRioeGXUeP/xwDCW3v97Vvo2KS2E/Rh2kx3AfyUvHEaioFLmIAYk/UFq5
s9HdmYoD85eCHkeNYqsv90LhJBWt7vUz7H1HMdxZjf/3PBULOGU2WjuOYv2l
G69l/lDxnNAwj7HuKKaf+/D5PicNP1qn+J/iGkXr2d1Gp3bSUOyuUFjrUwa6
zxabG9+goZGj8/byBwzkfygh1XiHhhnJr8xyrjKw7u6aqF0PaFgxXe8cJM9A
uxsF3fn2NJzflrnp0hgdK5VuXVTwp+Hj/KoLPdfpWB+dsVBVTMNj8xSrpjN0
3Hx+/VuDMhou1obuLT9MR0P6pTuj1TRMbTbKSuOlY6HykxekVhqeqGI571NH
Q2dXWcYWBg1HGM/HbI/RcPfI5yPnNtIxudj0vZEoFcUFLD8aXaXjncOyBdkc
VMwxUadL69NRR4USz/J7BEujlpFqQMeY6ytbU0kjuLfwtvGpe8R9meRF84SO
oIZN9BY7Ozo6VMryq/CMoH2D5K+f/nTkfWjhnftvGH+ue88qEkhHPkO/Kzun
h9H473p++RA6Up5w7OJvGkbZxYFr6pF0vJn41IbTbxgHq+UO/Eqio5PF3fMO
64Zx5GIDw7uYjqJzDCGeX0P4V1dOg/sbHYeVG/LSGUMYUXZQ6GUpHW+3rvGf
qh5CV/sGwftVdCybIN0N9RpCMVb1W5+a6Lhn+niY+qMhlGnIpv9ooWOU6Y32
pbtDeK3pJB9RQ3G0J/CVueoQBox5W9wh0bHEVTH9EesQWt34O+M6QEeBNt15
YA7iDN1S22qIjrv2XnfmHhnE7dTy51dH6Jil+uBeTvkgZr1mD+dgEPc/JntW
0mMQZS4lbWCdomP+YslpDttBPKzbO506TcfaE4ZJs3cGMcJqZODsLB1PbXLr
a1QaRKberbUW83R8V30iOmP1IGZqMvefXaKj2CG13L8jA9iTzX8/YZmIE54x
iY9EnWCr5Tj28w8dD0f68vB7D2DCqeE6t390PJ+4Q+EkxwByiUvqHGBj4Akl
ZXfhsX4Mam7bdJadgSfbPvH9qe/HdZ5SGXprGHjzepQ82a8fU4WEDAzXMVCE
+5z9BE8//noY7cm1noEqEctr2Ob68Lsgw3qYsGGDvKxEex8W3fQ0zOYm4ly4
Tu9xaB+y3v99XWEjAwV3KVlnOvShm+Yj2ynC5ZPWMHGtD7WXvZNieBg4yTwv
7Sbah6u8k+ypvAwMFbfV7VjuxaLP58Wc+RjoyqN0/UBfLx5S/fabi5+B17pV
lcO+9WJaoipPCOHjy/NCrHG9KLFt930BAQaaPsobcHTvRf/GXDZ/wsttXYnz
Rr241l9meoWwz2cxtTU7ezHMcbGiVpCBvRTP/VFre1HmV1uRuBAD+y41Hj36
owepu1I3PSIc/Ylxr6++B++dKxlEwrVvcvFleg8WK2huYd3EwDcFS1qKr3tQ
/nJgy2nC3psfCf+16kE1nwZWO8LO/2p2Vur0YPTRQ19jCVuv8X4WdLAHt55m
W1VF+J6GnKypYA+K9dt2DhO+fP/AIY1FCgaX5yn/JiyVyIiWI1PQZW6V9jph
BrowIy23FVPwYL33ykbCtXweWZtiKPiL6XiNh/CWmDJTYTcKOt9mNeIgvGe7
+fsddyjoC1cllon5dh3wuHVQhYJffkW9pxFucJ9L1pKioJrk3+FawvI/I55b
r6XgqGfiZCLhrs8qy1E/yNi+/LnmCWEbtY98LQ1kzH+l63iG8FKUbev6TDL2
nYln2UDYU/7I6UtvyHj/UpnVd2K99oo9MYyzJaNbR1OlF2G2bZ9OLF4mY8ki
fa0C4aVvx8lXFcgYOCABQ8R+FN60OI0iZCyOj7F+TthD7YXN/j/dOKT6MH47
4R11BY9T+7vxYFYMJY/Yz2xtMX3Zsm7c+ensNlXCzqZVm78kdON+uotDAxEf
i+yl18YfdCNXeo59FRFP+mlfBvnOdmOqdWiLDGHn5Se/VXd3o5PQzR0vifhr
r7JfrP1BQgNbndJ9RHzO9XGMi9aTcPBul9gjIn43bN78yjGVhHZx469zNzAw
wdJm4qIZCVujL9QLE/HvvXSr+LsmCc/doyQAkR/HO0QuXdlLQh4Hi0+3uBiY
PHBt9vlkF4Zo/nvqxcHAeNpQqol1FxZSdQsciHxcqEDz4zpdKJ5eNG9I5GuX
8j9pEfku3BRgH6fEysD1BTdTFpmd2LK/4vbUKiJfPkncPfa4Ez/KS1+ZIuqB
yp2DUfeud2Lt/ZjOKKJevNzNthR9vBN5ZWr/Kf2mo/NhUVXZlQ6Uzky2fLxA
R8vPkpEdHh3YeinM8/UMHbV9O2P173Zg7U3KVhaiPp1Lzvw5rtaBvnTFd5aT
dFwbFZe4n6MDD7veNpEnzqmksz2vld+0Y+BLO9o9ov4ZMA7q+sW1oeZsVp9H
Bx2VzV8+qPNow8l/O4V82oj6tbGXh4/oCw+CX6I3UX85Eoqkq3e3YfFT1gGr
Rjr6nyro/JLbivX/GvyYFXS8pDo001rXgts+RDRVZdNR/TXvseLMFrQ3N87x
+0RHb75MzAxuQa4bs7u0M+g4K+r55rNBC4peEO4vTaFj8a35GQdqMz46u26D
SSwdI1d1L1gdb8LaxPK9n1/RcY27jKgfexM+aFnJ3ulLx4fefXNfW75jSNa9
rSHedNS/4tV88/53PHguqszQnY5Vb2zcQkMbcUF6obzIgY7WsaYVEz/rUSvV
d//z23RsZl9z50p5PUactA1OJs7Lx0N2pLbX9cjV8VCumjhP+YV/Xl4vXY/A
7bPz52U6/ohu+/KE6Ps5cvyjRc/S0f2syW6oriHa8I75F/vpaHNsZNWTtErc
1dK0esMfGl6KpZrccajEV1MXtuj9omF9TrqhkVIl3mQZ14qZp6FZSdGaTFIF
/tsQzi0ySfQjMc/5zNkrUFS4Lrarj4Y03zoxj3tlOJP6YK3VNxpSaZG7Bay/
YqXuw9gTzjTkvOPEx7b+K+aKKToyHWnYCKvTJVOK0VeNSyjZjoZa263Ji4NF
eED+SMlqMxruXdS1pV3+gjk5pUpe12l4w2i2n6SWj5ddWYPrDtOwf4yVha6Z
hbQekW7TcSpyy6tf2zf6CStru+AnnYpRdwunRo5+wtwAZXeXYSqSvAwyNXoy
8IGBaNxzMhUnIy9WL0ikofRCTp5FDRX/2SxHkiqT0Jjb1T4znoon/XSUrHzC
cMPZelnWa1RM+LnGiTc0EFR0123LLxjBN/MHXiVVBcHx12v4MnJGcM3gXb34
n8GgEPiz/n3GCIruGKjt0g0Dvf1ZEc8TRpCyyv6OHEcU/LFRW5QLGEGdTWnG
QzLxQL7xYON2kxE80Gu5p045DaoLrDkf841g96FTp9Q186EkBO8E3iP63cdg
PR+cDxXXdFTCDIexaLRH9UlvPqz3Uz4dcX0YOV7Ycq21KID1LtteRWgNo7Ba
VOQhv0Jwuyrc6Hl4GA33schSy4sg7Kv1idXsw9jS5kj7xYsgHErOyY4fQi13
pfz1MRWQWeLvY0keRMFIlw69ogrQ/WRw7Gn7IIZucnMKIVXAwRzPquffB/Hq
YepTCm8lFFzWdwgrI/qIlReD770q4eWix/30j4NYWzGmLfGwCmoXpCYSngzi
Jm27cuFdNaDG36HUKDyI16+dsOK0rQcnc4FfiSn96OQbSvX0rwf/Xlm+o1H9
eDv8etp4Sj3k7dC9VOffj5Pe3zW8B+phfoJHh27bj4UXY5+PajZA6LH4GM5T
/ajV/3L1/R2NsPvsZp5/LX24/YVWqBN+B6FOV7u0xV5UlMgXK77bAgdMPxd8
UOxB6VeXT++0boGEpm+vRYhzszvXN9HXqQWKJG6cfiXVgzl/HbWOBbXAM/kX
cmacPfgv4YLxSWyB+JNFQWIdFFzHdmd3x6ZW0DN+t1n7PgU75F5K3KpoBefC
B+/G/cjIp32T7sDWDsHPslmciO+Lx1q6Fe5xtwOtx+hFbC0JvTKqHmgJtcOB
O7FmFcUktLBTsOGSbof7qQbXOOJJqFOy6+ppzXaIus3d629JwhXud8fc37RD
agMp9OlaEnoKZtj4CnVA62+hK2NHu3D6O4O5kbcTCnl17+tHduDODS7GO0U6
4XSXa626XwfW/Homd2RHJ+z7+iRf3rUD1fObaUoHOuFQ/tRJDqMOVKxi5+TU
6YTirNmN2bs78KOs1DbDgE4QEM/+OFHYjizmFqEya4ncynuzX5TUhh9bbCdK
R7qAf71mjAtfK4bUZdBafnRBC3UvU5W9FXfv3vmiZ7oLylyL+Nb/asFD5d9q
B5e7YLX+fFZEXwuiaJdVGj8JBk5bPM5JacFKhU/Bysok4NtSkEg53YI9qa+3
e0SR4DnzfCRvVxMqT5f8+BFHgiC5irchxU04S1byOf+BBBSfFo1N75uQtSTs
HEs2CT6uZi/bbN6EO+l6HPurSSB/qk56B0sThmZpB4VOk8C+TcJn677vKB+Q
9DHwdDd8FxOqHfVqQNuhrYmnVbrh7LWm2VGzBmxMZH6nn+kGsvM4fVSnAVky
N3+W1umGFfXyw6NiDRi7ccsPW+NuqGiNdKDm1aNmxSBjx4tuUNn6YU0HrQ53
7G31n63vhjNmovuC1Wrxtv+cx5rmbuDYcofiL1OL1sWZtULt3bDhiYyxD28t
Jo13nN3dQ8z3QHy9S18NbmhOOSU03g2P/aD27qMa/MOq+42HkwxFWYvn9iVV
o8v1o+6vVcmwNL9NN52tCj98nDp/Q4MMtPiJQxajldikSsoXP08GUQ7OP7KN
lWh92cn0vS4ZOLZOn/gUXIksibfu3zIiwyrbna+zxCsxfGpnGsmVDKu1HLsy
FSvwlunmA025ZLhq6/Aq2rkMlV2mcmfyydAZfbZL/3YZvq5cZnIXkeGG1BKv
iGoZ3olT/nS0lAz981sMQrnKMHN97J4LjWTw5b56zj+yFMN/ps88GyGDFU/q
k5/WiA9+CmqvcFOgrGLdg6jRYvwxvSpXm4cCLAO0nt7cYlzcLBIRxUeBvSYv
lbe6FaMbY+P4rk0UkMm79iNOsBiHmYF5nNspcGKWLSlJuQjZhiQNfu+nwK5P
XLwZ0YWocuKPIOtBCqg1WbZN3i9E+mEXvXWHKRCm3fJy38FCPPTD3pn9GAVu
czgOfaorQMb5Rq16xf9+r+64N2chH3s38rq5XqDAjNzx+3kX85B0y4xLSYcC
cbtKs39uzkMfvw7pf5cocE7BceEw4zNuaPcWtrxKzHdZyirf5TNmBQiShAyI
z/OdU7wgNRcVtifsCTGlQG1X4KcCthz8JJT9a6MZBax7Mz8tNmfj+SyxWy/M
KbCeTSddISob2eafzTywosBSw7uoggPZGPTkyKlFewqksAdcKbiVhbuAq0zR
jQItfxejzG0ysKzXYCjiGQXSdgZJJS+n4zfpTt9Jdwp0OnqmDnml44YDTfbP
n1Mggvtc8tXINLzr2V5i7UuBv6EitooVH9EQFfe8e0kB8N/b+1TrI17dM7ij
+hUFfNJ2quSRUlAge8tn9tcUkFz3ZN2eiWR88XC1pUoQBT5a9NnzC37AZ2nP
TqkFU4BfxLleKzYJf8t1RiqFUGDZZu9Wn91JSFu1f9WeMAoEhZws/XMqEaPr
Mly+RFAgQ1BmjmYSj0caRyoCIon1vGhzYvvse7Sf3BV5O4oC+y7EeOo7vcfN
T0mLs9EUOHNsiac5IA4Lne64tsdS4NbTNBVrmxgU+/5e0zWOAoXKpbVUr2ik
cmCqxHsKSGR9OX89MgpjFfS23YqngPtKuY5yRQRG/z14mElYdYSlPZ/0Fg8Y
pPd5JFDgUPgLXZmJcPyrv50RmEiBnE2ZlwQEw7AgxFKDN4kC0UF2rT67Q1Ey
6u/JV4RbrlRdWDkVgtv4HQctPxD7dVxdk24ShIdoiQHdhFd8X9fqOwWitFps
28lkCuyMCFVrDniDIUq2Aj8Jl//hcrW28cdpdk/+sykU+Jz6z+F65CtkSWn5
EE6YuSnXSrnCF8+L2jUNEpZWkX8gM/ECzVKevZT8SIE9wS9uCwh6I+8id48R
4XPMYr2VU89RgG1faRThmumui3QTD7TfOXesmbBvZ79Gc8AzvLXhocYK4ZNR
2e7WNi64vyphXCqVAuGzgTbKFU/waUaaxFnCTVvu3REQdEBuT78ZE8LWC3I6
dBNbXNC/cMmNcB9znBhvga4JyxpBhM8v2hLXm6C8ZHhHLGH1yGnidQOkrUj9
TP7v/zLN/1kL////NFyqjqnwMObr/wBDP+3J
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{
                    0.19628608599601846`, -0.10613477320263635`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.981430429980092, 0.5306738660131817}]}, 
                    LineBox[{{
                    0.19628608599601846`, -0.10613477320263635`}, \
{-0.981430429980092, 0.5306738660131817}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 34->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.211259168326599, 0.6087551203920308}]}, 
                    LineBox[{{0, 0}, {-1.211259168326599, 
                    0.6087551203920308}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.2018765280544331, 0.1014591867320051}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.2018765280544331, -0.1014591867320051}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.009382640272166, 0.5072959336600258}]}, 
                    LineBox[{{
                    0.2018765280544331, -0.1014591867320051}, \
{-1.009382640272166, 0.5072959336600258}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 35->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.242882331283387, 0.5797364758234728}]}, 
                    LineBox[{{0, 0}, {-1.242882331283387, 
                    0.5797364758234728}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.20714705521389784, 0.0966227459705788}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.20714705521389784`, -0.0966227459705788}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.0357352760694891`, 0.48311372985289397`}]}, 
                    LineBox[{{
                    0.20714705521389784`, -0.0966227459705788}, \
{-1.0357352760694891`, 0.48311372985289397`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 36->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2726032228357413`, 0.5498301510901975}]}, 
                    LineBox[{{0, 0}, {-1.2726032228357413`, 
                    0.5498301510901975}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.21210053713929025, 0.09163835851503294}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.21210053713929025`, -0.09163835851503294}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.060502685696451, 0.45819179257516457`}]}, 
                    LineBox[{{
                    0.21210053713929025`, -0.09163835851503294}, \
{-1.060502685696451, 0.45819179257516457`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 37->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.3004383145498146`, 0.5191087347083355}]}, 
                    LineBox[{{0, 0}, {-1.3004383145498146`, 
                    0.5191087347083355}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.2167397190916357, 0.08651812245138922}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.2167397190916357, -0.08651812245138922}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.0836985954581788`, 0.4325906122569463}]}, 
                    LineBox[{{
                    0.2167397190916357, -0.08651812245138922}, \
{-1.0836985954581788`, 0.4325906122569463}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 38->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.3264032460154382`, 0.48764049896553946`}]}, 
                    LineBox[{{0, 0}, {-1.3264032460154382`, 
                    0.48764049896553946`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.22106720766923968, 0.08127341649425658}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.22106720766923968`, -0.08127341649425658}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.1053360383461985`, 0.4063670824712829}]}, 
                    LineBox[{{
                    0.22106720766923968`, -0.08127341649425658}, \
{-1.1053360383461985`, 0.4063670824712829}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 39->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.3505127613014443`, 0.4554898814985294}]}, 
                    LineBox[{{0, 0}, {-1.3505127613014443`, 
                    0.4554898814985294}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.2250854602169073, 0.07591498024975489}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.2250854602169073, -0.07591498024975489}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.125427301084537, 0.3795749012487745}]}, 
                    LineBox[{{
                    0.2250854602169073, -0.07591498024975489}, \
{-1.125427301084537, 0.3795749012487745}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 40->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.3727806624393712`, 0.42271791593676183`}]}, 
                    LineBox[{{0, 0}, {-1.3727806624393712`, 
                    0.42271791593676183`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.22879677707322846, 0.07045298598946029}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.22879677707322846`, -0.07045298598946029}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.1439838853661428`, 0.3522649299473015}]}, 
                    LineBox[{{
                    0.22879677707322846`, -0.07045298598946029}, \
{-1.1439838853661428`, 0.3522649299473015}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 41->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.3932197760281557`, 0.3893826187494229}]}, 
                    LineBox[{{0, 0}, {-1.3932197760281557`, 
                    0.3893826187494229}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.23220329600469256, 0.06489710312490381}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.23220329600469256`, -0.06489710312490381}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.1610164800234632`, 0.3244855156245191}]}, 
                    LineBox[{{
                    0.23220329600469256`, -0.06489710312490381}, \
{-1.1610164800234632`, 0.3244855156245191}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 42->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.411841929886298, 0.35553933843658364`}]}, 
                    LineBox[{{0, 0}, {-1.411841929886298, 
                    0.35553933843658364`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.23530698831438296, 0.059256556406097255}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.23530698831438296`, -0.059256556406097255`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.176534941571915, 0.2962827820304864}]}, 
                    LineBox[{{
                    0.23530698831438296`, -0.059256556406097255`}, \
{-1.176534941571915, 0.2962827820304864}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 43->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4286579373288415`, 0.32124107236949995`}]}, 
                    LineBox[{{0, 0}, {-1.4286579373288415`, 
                    0.32124107236949995`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.23810965622147343, 0.05354017872824996}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.23810965622147343`, -0.05354017872824996}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.190548281107368, 0.26770089364125}]}, 
                    LineBox[{{
                    0.23810965622147343`, -0.05354017872824996}, \
{-1.190548281107368, 0.26770089364125}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 44->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4436775871565208`, 0.28653875588449673`}]}, 
                    LineBox[{{0, 0}, {-1.4436775871565208`, 
                    0.28653875588449673`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24061293119275334, 0.04775645931408276}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24061293119275334`, -0.04775645931408276}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2030646559637674`, 0.23878229657041397`}]}, 
                    LineBox[{{
                    0.24061293119275334`, -0.04775645931408276}, \
{-1.2030646559637674`, 0.23878229657041397`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 45->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4569096378457398`, 0.2514815276485562}]}, 
                    LineBox[{{0, 0}, {-1.4569096378457398`, 
                    0.2514815276485562}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24281827297428998, 0.041913587941426036}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW
LJGOfc/OmLEzi+yMKFLv9/c+7zv/zPN55nvvfOfec8498zwzO4ysLt1jWbVq
1RHWVav+e0793wcFVv3f4+GbgWcphOsLvOqdLpwDapELazzhV2H/WR+qQj3l
wwkPVI6QoouNQcZtituHcJKHJ/H6Q0irKQq1J+wt/+ZWho01nMkZqbtJ+NxQ
D3G9HdjZG6cqEo5pE9fxY3cEniMHFbYT5lA1IsY/BSteTevljxS4/DJMxSzC
BTT546+0EZZ8bEDM9wxqju9jJBLOr6eKJgl5gNUTqqQd4RsfDIj5PeFgbuGG
U4RTSyqCQ257wY1vMYkshBOWeS/6sb+AeYPbHc9SKLBVW7vW6cJLqNffanmM
sGCJ7HO7+VfQ8DsjdzKZAtfpJDCL8IcwvUWls4Ql8w7cyLB5Awr8vi9nPlDA
JDHs6G7VQPhwL9o1mPCicZ1gklAQaO+feNCYRIGugCfN0cXBcOjwr1tGhEdr
aGnCr0Pg8LjkqvlECghfW3kRcjsUosftVDgJ/9RnBT/2cOAqyqtniadAMJ0r
2elCJFRKRgs5vKeA/Mknbos7ooC3O3M9LY4CZl0S1+zmoyCRXL+QF0uB7CI6
q1lEDMg//vZNIoYCARqW0hk2ceD0ZfqafTQF8NJTnnFKHDy/LBhZGkUBuYCG
RWnV95D0xl/4fCQFwvvYKhOF4kGxcufvfeEUOH50q050cQKI9Cx03AyjgPL3
hAMUyUTIrgA971AKZF4a4xF+nQgjcg8vNwZTQNzDtCH4dhLsPbVbTPINBXz+
Ncq+Yk8Gk32CJSw+xPpwSgQ9uZAKa9jkj7d7UyCscI9XYFkqLCxrhb/zosDg
0XL7jwfTYP7b9hkpTwpwd41rkDelA4eJLN+iCwWkh4bw6GAGGPbPlMfbUqAt
2/SmU2EWHPrygH+HDTE+Xnbfi9kssBJJOxVpRYFJS5s/QXuyYbqhSczFnAJb
vjD8U6Oz4eSO5X9sJhRYl230jPwsB5I/Xx/eokcB9ag+1yNnPwPjGzlc4yoF
xs2D2JU9PkNcpsM2q8sUMNTn9tYq/gwmIqPx6RcpwPz5zO6ubB60iTqb/dCg
wHZhraVA3nwQ0hb3Mj1KAQsRmsc4uQDqJoQj3fgp0FPQHRb2sBgiSjmz9/FS
4GiLsiw5thhqUqvlyRsoQNG+kL+5sxheVJ6x385JgYs7+WPj4CsUiff2O66i
AHVUv/yjQAnECvysOztBhtK1Zmxfvn2D1pPUx49KyXBa0ObhXY4yyB89k/Om
hAw2LtPebJJl0FASo5RcRIZTN1+GJZ4uA+VIBcPqz2SQ/7b1NdWuDP5u8nVv
TCEDy1QXybi/DPZtXvqyGEAGUHkZZZhbDiOZLxwr9ckQGH989KxBJbQXGz7R
v0aG+ZQiBSPHSrgfyccY1yVDWi3D5mlgJUSaf2NZrUUGI61fialVlXAgZlRi
/jQZWmR8/3Dsq4IHbWUXVnaQodFVXKLybxU4jn6WCqV2w4czZ1Ml4mqgU0Bm
IWywGzb/jo48WlQDRkd5hUJ6u+HNFQ1TrY4aUPh3RfFZRzdkLZNiHdbVAtks
VmJ7ZTec3P7nbo11LTg3O2q4xHeDZXMN9Y5SHfCwJY8l3eiGv3r6exyH64E3
+eLvtKvdcHDVounXv/WwVO56M12nG8gjty1Xb24Au/Ja0egz3aAU/7r8pW4D
cN2+dUHhYDfMP3jtEVnZAAezC6/c4OiG93UCGRkfGuH30h2LC9kkuO2b8zH6
YRNMbx06HTDdBaKL38/n/moBewWLcL8fXZBZF7yHwt4KFbopH56PdIHen6C2
VfytcNf4/MhdUhc09Um6acm2guWqiTTaty7oZ887Qb3TCq2CjjIMvy7gsbpU
u6ahFQxc6nYPSHbB1IHu3Vti2mDgl8LRs6qdcKSKy/KuYgdc2Z9pf/ZkJwyz
XrEI1O4AbW5crXKoE64vmf8pudkBNO8YNnHJTjigt1gl+KQDDinfswhg7QS3
q+E/MLsD/PV2VEuVdcDY9YPeK+KdABpuPPsVOmAyJ0FLiL0L7L3tZQ9saAcl
iyzrJzUk0DCalI5ja4eTbI3Z0EmChO0NIuuW20CbaXGMfYQEGz8+bi1ntEFi
tpPQ678k+P0v4uJIaRvIh5f3hx3uhpHRFI0mmzZw+lWi55nQDcIjUvHHmlrh
3gfBf19dyVDIX09vtG4BuSGKva58D8wWCMVLm7SA3wjd+efpHogxm05wudEC
lulJHmGaPbD3aZ4Nv3oLCGQ9ftZ5twemEkznJkVbYG1SguCZ8B54J8FBKvRu
hmst27YvLveAm2jv0S1bm+CoVvd618peGLxhLWYt3gBXLOdYi3T6gbZDOe3V
2gboN79TLGTYD9cMb0yGTtTDi/ynGTbm/aCaaWvnkF8PExfbD4u/6AcxCYF6
k7P18NH0oqfF137YQnPM+mtWB+n1tHupOwfgUWfI/Z6EGtiZt0cg+fcATH8P
3VXeWwHJqj4CDo2DYLF+5q0ZVkBW0yCxLINQddzSli2+AvS/exiZdw+CgvcT
dbb7FbDO6s+GW9RB2Fol3HxiphyOcNRrHfwzCKXn85S9/pWBhIk9NUFmCOKT
eiL0eEvB5f11kUDfIRAwMl9vtboQ+BR2th1QGgYTvo2/zbEALmWtiHxRH4Ym
qYl9Gi4F8Orih5bT54ch0uz+ubBf+dDvLOqhdm0YphPOc7+ZzAO53X1FYDEM
LpayB2ZacqHxVesH2tth2P/7Q6fsUiZcPnRt7ejUMDw0uFOrY5EJJcZ8i0fn
h8HrsvVbWaKOV+fkbvD5PQzPSYlO66vSIdVGJn072wg8jphdufsqFW7I/bp5
QmQElqR+vbLk/AALFqIOAiojID15Qj8pPgKy8mJWq4aOACR1T3IavIWAN6wX
KyJHgGm0IaRUKBzkOjX5FeNGgKL+RmuzTwiUeX4dO5A2Ahd6L9F4q17DmpcU
p4XSEYivujx1r9sOnIqf8qyaGIHDwboWKqZvsG3g3vNloEJBdbbz8apAPME0
eyquRoUt2yweM3YEo5l2hZX6OSpknxZkGPeFouLiRw2vy1Q4993JdvxmFNpF
aav2P6BCdEyUiywkYPUR6b7fb6iwIbiodjIpE92e/XhZ1E+F+DM6f1h1P+Gx
I4pa0iNUKHWSrT+8KgvN/Hn+BjGokLouPXRTZhbWrY7dYjhDhfQbl0sruXIw
KfY0o3U1DUo96vQbmj5juCDj0VZJGhhuNo/OsyvC33Psw0dNaJCt8S/WuLkI
BcKv7zv1kAaPVB6InJApxufGRVOnLGkwwDH9zGSkGEc1rIoPOdBgYu/VxE9X
SjBzzp5v0YtGnKdfXdfuKEVeoV6RhkQa5L+95MUtVoG5D5PHgwZooHREbyFQ
pwIpt30DTEdosCSxi0XOuwI5I8bvn2DQgF9BcSpnugKvSJ2JbZmiwdY3nfuH
Kyox/dqgd+kKDYx9/Ab6ravxyLSFWLYoHcL9DbUnP1Tjq6T3F45upYNPPJ+h
QF81bkdzvaIddKj4wribfrYGayTiOjOl6VCTMTvPKlmL1uvUOvSO0CG61sPy
Yl8d9m6zeJZ2kQ53hvYnjwrUozZt9mSfLh3OiKjZRpyvx9SqnRYc14j3mzAq
VP1aj9KPj27UMaDD392bG8uiGxBzOJOjTemwNcZ0UdfoO9aqv3PZ5k4H14kA
dfuo7/jXPtH6pycdUmS5/qV3fEeWgKdWVd50eGU+FXP/TBM2sc490vWjw8Jn
zz2r9zVjR53z2M5wOsx4N44NurWg1j5vr6Q0Ovhbc65PjW5BlhKl99yZdBAL
F2h2/dKCYlsuh1tl0SH3kPp+TWYLOllL/tqeR4fTG7r5re63Yq7Kxvaj3+gg
GR/YNqjThiG/YgQUmulQmHLiq5FVG8rX6eQfa6VD5LTnphm/NhRSWVVzuJ0O
Aq8zBWRr23BFcVBElESHo3oLZXLQjqTrNZVB/XTQ4RS3vyzXgafTH4ueniDW
lxSX8kqrAx+KuJh3TNLBN5bG3WTWgeayYyXG03S4aCmiZ5/SgaTvfsoWc8T1
jc/uqot3YuyNf5wyv+gQq7QmokuxE6ni1m98ftPBykWUZGPYiWXTq3v7l+hw
2PKHfl10J27Si055tEKHgrU5P5Y3deErI5PzmiwMqKJVto8c6cKZvlwFS1YG
3DC6EdV1pQvZJ35k+rIxIHxNUFpvcBfmZWVKpK5hgGP06dHpnC604HrO92kt
A2ZsXoxxt3Vhk3azVfo6BrROSOx6yEPCyZB9em84GVDp2H85RY6ENn4WHQ5c
DMhuZZGb1SYh3n38/sp6BuxttWyK9yehbrQ4zx9uBtRssvfmyiChwZ62+IoN
DLh88FaLayMJd62xfOC5kQGmQlZ/n3N149KF+5bjPAxIY2uuW5DuxnmHFF8f
XgYE7+rKtFHvxtbMo+Vb+Rgg98kj08O9G9/aVtse4WdAiO6lEuHYbnyh7tpf
QBjcxZoKvnajc81vbXkBBlxfr9jH86sbl63DpfgEGWCneay5XpCMsf133BwJ
K6bbpPofJKP0G8WqTsLvul4/uK5DxpRjLLN7hRhgvizJus+KjFmWdn+cCXNh
vh2XPxknUm4NVRFuksjLnU0lY5u2X8TaTQx4bO/2dbCWjNZF5VuVCafvM37R
TSfjYcXqh48Iu05GcZPZKDh++Lrje8JUXV2NYXEKfv594nQ1YfbFuP3zihTc
/HvvlxHCzRovcYMhBVULR4d+Ezb1YJk64EJBKfLunHXCDIh9PfbZIIqCfeIf
JXgIq8zzcAd9Icb7iu3/z6mlB6abSBQMO3iy9b/rd9su6AosUDDGq3DVEjGf
1/DPg0YCPdgmpVr43/udPfD5RaF8D1awB8xWEdbNjD+zSacHyaZnPsQRvl65
zdzVqgf3zoq02BFWGnGYnPTvwZcx2Q+AcMzDwYp76T3o0VNgyvrf+BB3Bq2+
B1+97GhEYr2ot8wvWv7oQRX2zFf2hNkfxy78XduLpbt/xO4grLprTVv4zl5c
vrObtYbYjxtHH1OOqvWiZjrPp7uEu2lf1g4b9+JCAsQsEfvbWuGkE+zRi+O+
V2p8CH+OHRDeUNqLPKHpef5EPEhWunmR+nvRokbKgo3w9RPREykrvXhLYEHd
jognsurDF8Yn+rB/6O+ZY0S8hdk++Xhevw8NWEyM3hDx6P4P40896cOfAe5e
A0S8dkc1LRwp6MPJ4F2N94h4buLXAejqw8j73cPRRLx/D3Q7fuFnH953eDna
QOTD1B8bCe+D/RjCcTiZl8iXVc7n/qZf6kdq/3ldaSKfWJYX7/XY9KNaUmLH
EQ4GnOQWyNPO6sfJB+dOnSDycf7rlE9wcz+WTGRvOkDk6yZnh/KBqX4M9vTL
2MrOAK1vT0+/lh3AGvea2UEi/4P/bj2lnDaA6Xttd63+S9QH444Ys+8D+Ocq
9W34HzpsX6d+MWZ6AKVucvJLLtNhMz/ly3rRQYz7arVqG1F/jq39FP7l1iCq
aLzojpqlw8a9+Y1TVoOoq+mRMkTULxez23O73AfxeMweEJsi6nWs3lxSwiD2
zbjHPhqjQ0fw0/nm0UHU0LuuljpMB+mO1H6JpUFc9m0wjhkk6jX1iosT1xAy
tH+u8SbqZ9sbUuHhfUM43uVepEChgy5j07lOuyHU1VKY2UzU442reNO//BtC
t+SV+4Nf6WBqOcqrxjuMxW6vfu0qosOkQVZyu/gwigzmvLxbQAfF8URYUhtG
hqZq8NdsOqiUmEqZ+w2j8Ae5S4wkOkCUYA5FZATxXPGj7cR5M+8T0hgiM4Jm
jmuvfPYh6u9xF3edUyMox1j5fNKLDmF6VUFtt0dQ0EaMtMeVDkey+o7OJY9g
3rBptZMVHVaYNV7vjlCxhLJi/eMCHTLMLkedP0PFhGDH0XXn6fDl1727f65R
cXID97SYBh12sGyZvP2Eiop2kW+kFelACx0in/xKxT4MckQ5OohLXFtWUKYh
i6SYw9R6Oli25s7/uUTDP4YSf4zX0WFx3XmuCmMaJqj7fmpipUPLlU8PLnnR
ULo+y9tziQa8EimNzrU0nJg+q/OQ6CcSnlC1FrXpaLByRWkX0kCz9PXNOkM6
+gkfHpz4QoPT/CzUKGs6uu9bezH5M9GPGB2UVw6io6Sqqt/SRxqIeMhEBXXS
cdp2uFckhAaVdxrGj95k4KrSfZIKRL90uLZk+ZzpKKrbCnDXEv0VRy84uTiN
ooyhlenrJSoUxfW0ZfqPYqPlGqo6kwpzTs713DmjeG5ycMtrKhV0OWc2FS+N
ov2ujf/sq6kQ6s7dWvnqB3aYipfHvqBCUtHUmq3pYyhTeU9V/d8IpJ9uleP6
NoYbFHquqC+MgHFDGvfP5jEEKeExhckRqDqzOfYbcwwZpJ5X0xSiP7ZpF9h1
Yhy/9KldyMobgR9pfXMn68bx0OUzY/YPRqDlwlnthaEJ5Cy6enixfBjsFX89
ZWNO4BH/KNPLhUR/fytXmpttEpP5L19LyBiGrSe8i7h3TqIMZ7W+ENG/x1Vd
i6ozncSq5n+Mi+bDIJWar755ZhLv7Q8L38Q3DJ9fXA+IWpzCdc43RscvDcHO
HyIN7Wun0XH4b6+b+hD07P7IxSY8jV57NUPYjw/BHlehs+ePTmNNndkl+vYh
iNv3wf7J42lU5b92ZmVyEI7dLrI9tDiN9Tlmpz29iO8/hg8ff3eYQSGRuKfr
Lw/APcmSlx0uM/hXf/P5t8cGwMu2YDXp+QwejzojtH7bAPyJvLj8PWgGL1yT
KUj70Q/cMt/2embOYKE6+85Gl35o4QF2VtoMzmw32h75vg86Ff28tmjP4oCW
83I+qQcC9+8IcLs8iwsH/fuvFPUAX7rDeK/+LJayGEn0R/dACpfLU+/7s7gt
/x5X2p0eMO2SZw95Novf869MKYxR4K3nWuvA7Fm8dafSWGaRDB3WIYY9G+bw
3KW9nyZXdcOPVh31WYE5zNxYekqinwQ/ywI0/onOYf7ao4WKxSSwsG9xYN01
hy+c9pEOPiKB24nxW2mn51D0sHf4CqMLCva+i7Y2n8MqC7WKI3Wd8HD1Py9W
2zks36AduJjYCTTeT+P+jnNoH7F7dfyzTkjdasXu6zGHI+r6Jz8rdMKaniqT
TW/n0H+C70FrYge4K+t98CubQ4ENLeEcTu1gJtFAC6qew4urj3TaXmmH+bX7
179pmEOVrvHkGrl2+LCLa8yycw6zNmgGHaK2wX4no7mS0TlUDErcs+18Gxyx
W5sQwc1E1nvkhCvCraCUKneCk4+J0smeKj6zLfAiUfyAjRATRfONPqTUt0CT
MKuQ+DYmsks2a+Q6t4BCyA7qhv1MdJNYJTGKzTD/7W4N90UmfpmifvdV/w4r
11ZmY3WZqHR1YbXQn0YoLD5yfvc1JvLG6b7xzm4Envd6j3fcYuLpngUU3NII
Qf24MdmMiVL25DDmdD2YB2uZsngxsVvs7ENGUC2wZ4zNsPkwkewRo92tXguL
1Rd1/r5kovEDkZLspRrYu+qdT+cbJjYuxmttM6qBLgnDs4LRTCwyedA/IVcN
Oz43snZlMVGzQ/RNQE0FvJTfMqySy8QLm4Q37HlaAf5x1y6m5DHx8Z4mr+y9
FaBGu9N4uYiJyfMLXj6B5aAbXNdxooKJ3L+tvt/SLwOlmwKVBlVMXH9qbrPp
+jIgfXsi6VDDxK3PrLKMvpVC2ZdLe142MFEih69TUrwUlkZpP063E+vVX/mI
0loC994prhboZGJMUkYD81AJXI5tshzoYuIWuwcGM+FfQS9OUfE6hYkLJp5B
oQbFcL9k78PuQSbKPgxlxDEKocHrzqDhMBON3vJ/o54tBD+v0dC+ESZmqdiH
8KQXgCkt93MxnYmKjgdSxK3zQbBF24VlgolBv9doKS3mwq3jnlGHJ5lY228S
MXcjFzYJSmoYTjHx0dpgh8DSHAh5sqIaNsPEnMLt+yJ9s0FLwDswYZaJlDGj
fexTWeB2cfO95DkmTkXJcd2+lAUdXgWRQfNMPLd88GLz4UywDX31+8lPJt4J
mdsq8zcdPj1bQ762QKz3zWoVs+o0yPmpILC4yEQSP9f+mKsfoc7imEXhLyZm
yxtoBG5NAdWPjkrWv5m4FPhMz5L+AQZ3TF2tWCLu93A92+ijRLhPmg69tczE
SnI90/tUAsC5Ms0ZwhZSms/42eNBn2Hp+PgPE3W/n+x43RgH6qyCwouEJWLc
D87vioXBvoG95itM7HfWWEjPj4bsJK48EuFw+SK1c2qRsNOJ+unYXyZe2bHB
sak9HB7aVW8JIrwxq3TghFEobIwSWx4kfIfq1xkyEwT2v+6d2/mPidG/7mX2
uL6BIX8ZTiPCGkNDz6RE/cDyBufxEMJhd/5UPD7yAt7eziR/JawmvqY975IH
xMa0j/YQji/Xyi/vewrvBdTvzxJe2GrBv0rIBqzrhy6vEI4N87zz+agBSNUE
Zf8j/HBX1IrJdxV8JHTF5RdhvXXyzHWeD7Cy5lAh47/5KrbpX+RwQNqkltF3
wkWpCjvXtrph0btGp4+Ex296lV1ofI5WcxNszoQLdLi41mX54guW5RVVwvlK
CeXJwa/xw+il+2yEk6QqxEKLA3F9yW2lIuLz7/397q6abAh2hcT5mRCedu42
HH4XhuuevTvLQbhQ7O0XU54IVHyx8DieWN81xUpbyO5ReOTj5c3yhKM2Osnv
Y8Ygk2R/oJDYn59cEboH5eNwe9vxr8nEfv41z9p7MiEec6VS5HkJ16fJOH7o
ScDVASbbbYh4EBl9WLvCn4SGzwRMBIh4YU+ldFs+T8bJqHOl14h4WpQ0U/P+
moLNY7fCAol42zTgxe89/xHfXjAoHiXi8+mWxgPH76ajpuV67jWEv7wxODAR
lYFu1RKDIkQ8N1przrq3Z6LNmXIeKSLeWV+Kc+55n4VPZjPq64j8CQyI1D22
MRfp+vST7kR+qa6/+fVbQS5qVp0Olh0n6l2mDPe+259Roq1m4e4oEb+rx51q
svJQQGU/Q5vIX56lnQdaLxZickBNTQaR3xwTeU6Bvwox69fbhNUDRP5Z7Rs8
HPcFz/1ep+/Tw8QbLZxC0tNFeJ3dR5yvg4kng/ZLvntVgtn91SdF2pjY9O/h
HjP5b+j3M9JSsIWJlqOfgoTI3/B6cqH0JFGPAva7Ulj4S3HrziOmokQ922O5
v0rYsAwjL/jPWH1iYsiyQ2IgswJvi+32qk9n4tnDRafL1Crxhbn6E9FUJkqa
qDhTwiuxwzkzJDKRWK+N0d61J6owZuD33i0RRH3MPm/p61GN36TGqnc/Y6J5
beS+y1x1mIRH6L3OTPTgv7/080Yd0vYKlXo9YeJqO6cdzul1uNGl7muhLVHf
bj45fkirHgsmLF8n3mViWfTbL+f8G1CyMNMiQp2Jm9vpWxvWNuHbXcHtU8pE
vYoJEtfUacIMDUw6AUxMq+KrzYxsQh7lqg/FCkwcWtJevV22Gb+5zFdekWZi
qbtUiY50C+LuuOHFtcR45a8LfzRa0fVc/3Q1K1Gf5NaSG8xbkTN08Lv/vzk0
lhb69PJNK3LUNAixLs6hn/u7ShKpFemPM9760eawOFbSPf1eG6adeH57B3E+
d7nO75R2bcc59o/p1l/nMG8HTflHXDvOvzM7WlgwhxnNSzFvK9ox90SVzP7M
Ofx4ViW1bF0HlvH6aFdGzmH2+lid40EdSNp1nf050S+wq93dlvW+E90287SG
bZnDXfRGXo4cEv7bOCH7XGgOe16yvRbuJKHzd8EgU545fFekXbPxFwnv/vwa
sYWN6Ce00zjzTnWjTDy5TnJ8FlviEwS7a7rxy4zfQHXBLGpejhE1I5FRfPFt
UrTmLHLc8pfdPdKDvhfDbWNVZ9G48N5TVtZeNJayiIk6NYsxxr2N5eK9uLks
4OgzuVlMO1BycuZOL7bPtRQu883i1xBhC7aBXvzmy+Fb1T2DEp4hHGwdfZjf
JEmfNZxBz/BpjpWUAVxKF1urrzeD0r+rQ7sqB3ByWF245OIMenXucAoZHMCS
oj+H7JVm8HTb77B+rkF8ZGnonCw+gxHTsXG3lQexpGNT6dXaaQw0+vmuOn0Q
H0uHFw/VTOEau1xdNschfB3GfyysYAp/cPFR5TyHUJjks0cleQq/iG5V0QoY
wnWJP794e0/h1imNBwbJQ2j5Y+FrvuoUuk8HH2jvGkI+Cb3KBpxErbRGSYGD
wximILxbN3sC1wf0eIwPDuPc1MYfRu8nMKIoNydmbBhtss4csQycwJXsBX+V
+WHc8VQhz9FmAi+ojmo+XDuClef5Jq4dmMDl2+u5JWVHMLvu1SX9rHFMEyvh
O+cwgquH1xt9TxvD5TLuaMt/I5gsbGVqFjWGFup/2yLWUvHRo4WmNa/GUOe6
91LhRioeGXUeP/xwDCW3v97Vvo2KS2E/Rh2kx3AfyUvHEaioFLmIAYk/UFq5
s9HdmYoD85eCHkeNYqsv90LhJBWt7vUz7H1HMdxZjf/3PBULOGU2WjuOYv2l
G69l/lDxnNAwj7HuKKaf+/D5PicNP1qn+J/iGkXr2d1Gp3bSUOyuUFjrUwa6
zxabG9+goZGj8/byBwzkfygh1XiHhhnJr8xyrjKw7u6aqF0PaFgxXe8cJM9A
uxsF3fn2NJzflrnp0hgdK5VuXVTwp+Hj/KoLPdfpWB+dsVBVTMNj8xSrpjN0
3Hx+/VuDMhou1obuLT9MR0P6pTuj1TRMbTbKSuOlY6HykxekVhqeqGI571NH
Q2dXWcYWBg1HGM/HbI/RcPfI5yPnNtIxudj0vZEoFcUFLD8aXaXjncOyBdkc
VMwxUadL69NRR4USz/J7BEujlpFqQMeY6ytbU0kjuLfwtvGpe8R9meRF84SO
oIZN9BY7Ozo6VMryq/CMoH2D5K+f/nTkfWjhnftvGH+ue88qEkhHPkO/Kzun
h9H473p++RA6Up5w7OJvGkbZxYFr6pF0vJn41IbTbxgHq+UO/Eqio5PF3fMO
64Zx5GIDw7uYjqJzDCGeX0P4V1dOg/sbHYeVG/LSGUMYUXZQ6GUpHW+3rvGf
qh5CV/sGwftVdCybIN0N9RpCMVb1W5+a6Lhn+niY+qMhlGnIpv9ooWOU6Y32
pbtDeK3pJB9RQ3G0J/CVueoQBox5W9wh0bHEVTH9EesQWt34O+M6QEeBNt15
YA7iDN1S22qIjrv2XnfmHhnE7dTy51dH6Jil+uBeTvkgZr1mD+dgEPc/JntW
0mMQZS4lbWCdomP+YslpDttBPKzbO506TcfaE4ZJs3cGMcJqZODsLB1PbXLr
a1QaRKberbUW83R8V30iOmP1IGZqMvefXaKj2CG13L8jA9iTzX8/YZmIE54x
iY9EnWCr5Tj28w8dD0f68vB7D2DCqeE6t390PJ+4Q+EkxwByiUvqHGBj4Akl
ZXfhsX4Mam7bdJadgSfbPvH9qe/HdZ5SGXprGHjzepQ82a8fU4WEDAzXMVCE
+5z9BE8//noY7cm1noEqEctr2Ob68Lsgw3qYsGGDvKxEex8W3fQ0zOYm4ly4
Tu9xaB+y3v99XWEjAwV3KVlnOvShm+Yj2ynC5ZPWMHGtD7WXvZNieBg4yTwv
7Sbah6u8k+ypvAwMFbfV7VjuxaLP58Wc+RjoyqN0/UBfLx5S/fabi5+B17pV
lcO+9WJaoipPCOHjy/NCrHG9KLFt930BAQaaPsobcHTvRf/GXDZ/wsttXYnz
Rr241l9meoWwz2cxtTU7ezHMcbGiVpCBvRTP/VFre1HmV1uRuBAD+y41Hj36
owepu1I3PSIc/Ylxr6++B++dKxlEwrVvcvFleg8WK2huYd3EwDcFS1qKr3tQ
/nJgy2nC3psfCf+16kE1nwZWO8LO/2p2Vur0YPTRQ19jCVuv8X4WdLAHt55m
W1VF+J6GnKypYA+K9dt2DhO+fP/AIY1FCgaX5yn/JiyVyIiWI1PQZW6V9jph
BrowIy23FVPwYL33ykbCtXweWZtiKPiL6XiNh/CWmDJTYTcKOt9mNeIgvGe7
+fsddyjoC1cllon5dh3wuHVQhYJffkW9pxFucJ9L1pKioJrk3+FawvI/I55b
r6XgqGfiZCLhrs8qy1E/yNi+/LnmCWEbtY98LQ1kzH+l63iG8FKUbev6TDL2
nYln2UDYU/7I6UtvyHj/UpnVd2K99oo9MYyzJaNbR1OlF2G2bZ9OLF4mY8ki
fa0C4aVvx8lXFcgYOCABQ8R+FN60OI0iZCyOj7F+TthD7YXN/j/dOKT6MH47
4R11BY9T+7vxYFYMJY/Yz2xtMX3Zsm7c+ensNlXCzqZVm78kdON+uotDAxEf
i+yl18YfdCNXeo59FRFP+mlfBvnOdmOqdWiLDGHn5Se/VXd3o5PQzR0vifhr
r7JfrP1BQgNbndJ9RHzO9XGMi9aTcPBul9gjIn43bN78yjGVhHZx469zNzAw
wdJm4qIZCVujL9QLE/HvvXSr+LsmCc/doyQAkR/HO0QuXdlLQh4Hi0+3uBiY
PHBt9vlkF4Zo/nvqxcHAeNpQqol1FxZSdQsciHxcqEDz4zpdKJ5eNG9I5GuX
8j9pEfku3BRgH6fEysD1BTdTFpmd2LK/4vbUKiJfPkncPfa4Ez/KS1+ZIuqB
yp2DUfeud2Lt/ZjOKKJevNzNthR9vBN5ZWr/Kf2mo/NhUVXZlQ6Uzky2fLxA
R8vPkpEdHh3YeinM8/UMHbV9O2P173Zg7U3KVhaiPp1Lzvw5rtaBvnTFd5aT
dFwbFZe4n6MDD7veNpEnzqmksz2vld+0Y+BLO9o9ov4ZMA7q+sW1oeZsVp9H
Bx2VzV8+qPNow8l/O4V82oj6tbGXh4/oCw+CX6I3UX85Eoqkq3e3YfFT1gGr
Rjr6nyro/JLbivX/GvyYFXS8pDo001rXgts+RDRVZdNR/TXvseLMFrQ3N87x
+0RHb75MzAxuQa4bs7u0M+g4K+r55rNBC4peEO4vTaFj8a35GQdqMz46u26D
SSwdI1d1L1gdb8LaxPK9n1/RcY27jKgfexM+aFnJ3ulLx4fefXNfW75jSNa9
rSHedNS/4tV88/53PHguqszQnY5Vb2zcQkMbcUF6obzIgY7WsaYVEz/rUSvV
d//z23RsZl9z50p5PUactA1OJs7Lx0N2pLbX9cjV8VCumjhP+YV/Xl4vXY/A
7bPz52U6/ohu+/KE6Ps5cvyjRc/S0f2syW6oriHa8I75F/vpaHNsZNWTtErc
1dK0esMfGl6KpZrccajEV1MXtuj9omF9TrqhkVIl3mQZ14qZp6FZSdGaTFIF
/tsQzi0ySfQjMc/5zNkrUFS4Lrarj4Y03zoxj3tlOJP6YK3VNxpSaZG7Bay/
YqXuw9gTzjTkvOPEx7b+K+aKKToyHWnYCKvTJVOK0VeNSyjZjoZa263Ji4NF
eED+SMlqMxruXdS1pV3+gjk5pUpe12l4w2i2n6SWj5ddWYPrDtOwf4yVha6Z
hbQekW7TcSpyy6tf2zf6CStru+AnnYpRdwunRo5+wtwAZXeXYSqSvAwyNXoy
8IGBaNxzMhUnIy9WL0ikofRCTp5FDRX/2SxHkiqT0Jjb1T4znoon/XSUrHzC
cMPZelnWa1RM+LnGiTc0EFR0123LLxjBN/MHXiVVBcHx12v4MnJGcM3gXb34
n8GgEPiz/n3GCIruGKjt0g0Dvf1ZEc8TRpCyyv6OHEcU/LFRW5QLGEGdTWnG
QzLxQL7xYON2kxE80Gu5p045DaoLrDkf841g96FTp9Q186EkBO8E3iP63cdg
PR+cDxXXdFTCDIexaLRH9UlvPqz3Uz4dcX0YOV7Ycq21KID1LtteRWgNo7Ba
VOQhv0Jwuyrc6Hl4GA33schSy4sg7Kv1idXsw9jS5kj7xYsgHErOyY4fQi13
pfz1MRWQWeLvY0keRMFIlw69ogrQ/WRw7Gn7IIZucnMKIVXAwRzPquffB/Hq
YepTCm8lFFzWdwgrI/qIlReD770q4eWix/30j4NYWzGmLfGwCmoXpCYSngzi
Jm27cuFdNaDG36HUKDyI16+dsOK0rQcnc4FfiSn96OQbSvX0rwf/Xlm+o1H9
eDv8etp4Sj3k7dC9VOffj5Pe3zW8B+phfoJHh27bj4UXY5+PajZA6LH4GM5T
/ajV/3L1/R2NsPvsZp5/LX24/YVWqBN+B6FOV7u0xV5UlMgXK77bAgdMPxd8
UOxB6VeXT++0boGEpm+vRYhzszvXN9HXqQWKJG6cfiXVgzl/HbWOBbXAM/kX
cmacPfgv4YLxSWyB+JNFQWIdFFzHdmd3x6ZW0DN+t1n7PgU75F5K3KpoBefC
B+/G/cjIp32T7sDWDsHPslmciO+Lx1q6Fe5xtwOtx+hFbC0JvTKqHmgJtcOB
O7FmFcUktLBTsOGSbof7qQbXOOJJqFOy6+ppzXaIus3d629JwhXud8fc37RD
agMp9OlaEnoKZtj4CnVA62+hK2NHu3D6O4O5kbcTCnl17+tHduDODS7GO0U6
4XSXa626XwfW/Homd2RHJ+z7+iRf3rUD1fObaUoHOuFQ/tRJDqMOVKxi5+TU
6YTirNmN2bs78KOs1DbDgE4QEM/+OFHYjizmFqEya4ncynuzX5TUhh9bbCdK
R7qAf71mjAtfK4bUZdBafnRBC3UvU5W9FXfv3vmiZ7oLylyL+Nb/asFD5d9q
B5e7YLX+fFZEXwuiaJdVGj8JBk5bPM5JacFKhU/Bysok4NtSkEg53YI9qa+3
e0SR4DnzfCRvVxMqT5f8+BFHgiC5irchxU04S1byOf+BBBSfFo1N75uQtSTs
HEs2CT6uZi/bbN6EO+l6HPurSSB/qk56B0sThmZpB4VOk8C+TcJn677vKB+Q
9DHwdDd8FxOqHfVqQNuhrYmnVbrh7LWm2VGzBmxMZH6nn+kGsvM4fVSnAVky
N3+W1umGFfXyw6NiDRi7ccsPW+NuqGiNdKDm1aNmxSBjx4tuUNn6YU0HrQ53
7G31n63vhjNmovuC1Wrxtv+cx5rmbuDYcofiL1OL1sWZtULt3bDhiYyxD28t
Jo13nN3dQ8z3QHy9S18NbmhOOSU03g2P/aD27qMa/MOq+42HkwxFWYvn9iVV
o8v1o+6vVcmwNL9NN52tCj98nDp/Q4MMtPiJQxajldikSsoXP08GUQ7OP7KN
lWh92cn0vS4ZOLZOn/gUXIksibfu3zIiwyrbna+zxCsxfGpnGsmVDKu1HLsy
FSvwlunmA025ZLhq6/Aq2rkMlV2mcmfyydAZfbZL/3YZvq5cZnIXkeGG1BKv
iGoZ3olT/nS0lAz981sMQrnKMHN97J4LjWTw5b56zj+yFMN/ps88GyGDFU/q
k5/WiA9+CmqvcFOgrGLdg6jRYvwxvSpXm4cCLAO0nt7cYlzcLBIRxUeBvSYv
lbe6FaMbY+P4rk0UkMm79iNOsBiHmYF5nNspcGKWLSlJuQjZhiQNfu+nwK5P
XLwZ0YWocuKPIOtBCqg1WbZN3i9E+mEXvXWHKRCm3fJy38FCPPTD3pn9GAVu
czgOfaorQMb5Rq16xf9+r+64N2chH3s38rq5XqDAjNzx+3kX85B0y4xLSYcC
cbtKs39uzkMfvw7pf5cocE7BceEw4zNuaPcWtrxKzHdZyirf5TNmBQiShAyI
z/OdU7wgNRcVtifsCTGlQG1X4KcCthz8JJT9a6MZBax7Mz8tNmfj+SyxWy/M
KbCeTSddISob2eafzTywosBSw7uoggPZGPTkyKlFewqksAdcKbiVhbuAq0zR
jQItfxejzG0ysKzXYCjiGQXSdgZJJS+n4zfpTt9Jdwp0OnqmDnml44YDTfbP
n1Mggvtc8tXINLzr2V5i7UuBv6EitooVH9EQFfe8e0kB8N/b+1TrI17dM7ij
+hUFfNJ2quSRUlAge8tn9tcUkFz3ZN2eiWR88XC1pUoQBT5a9NnzC37AZ2nP
TqkFU4BfxLleKzYJf8t1RiqFUGDZZu9Wn91JSFu1f9WeMAoEhZws/XMqEaPr
Mly+RFAgQ1BmjmYSj0caRyoCIon1vGhzYvvse7Sf3BV5O4oC+y7EeOo7vcfN
T0mLs9EUOHNsiac5IA4Lne64tsdS4NbTNBVrmxgU+/5e0zWOAoXKpbVUr2ik
cmCqxHsKSGR9OX89MgpjFfS23YqngPtKuY5yRQRG/z14mElYdYSlPZ/0Fg8Y
pPd5JFDgUPgLXZmJcPyrv50RmEiBnE2ZlwQEw7AgxFKDN4kC0UF2rT67Q1Ey
6u/JV4RbrlRdWDkVgtv4HQctPxD7dVxdk24ShIdoiQHdhFd8X9fqOwWitFps
28lkCuyMCFVrDniDIUq2Aj8Jl//hcrW28cdpdk/+sykU+Jz6z+F65CtkSWn5
EE6YuSnXSrnCF8+L2jUNEpZWkX8gM/ECzVKevZT8SIE9wS9uCwh6I+8id48R
4XPMYr2VU89RgG1faRThmumui3QTD7TfOXesmbBvZ79Gc8AzvLXhocYK4ZNR
2e7WNi64vyphXCqVAuGzgTbKFU/waUaaxFnCTVvu3REQdEBuT78ZE8LWC3I6
dBNbXNC/cMmNcB9znBhvga4JyxpBhM8v2hLXm6C8ZHhHLGH1yGnidQOkrUj9
TP7v/zLN/1kL////NFyqjqnwMObr/wBDP+3J
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24281827297428998`, -0.041913587941426036`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2140913648714498`, 0.20956793970713017`}]}, 
                    LineBox[{{
                    0.24281827297428998`, -0.041913587941426036`}, \
{-1.2140913648714498`, 0.20956793970713017`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 46->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4683618147452409`, 0.21611697482492656`}]}, 
                    LineBox[{{0, 0}, {-1.4683618147452409`, 
                    0.21611697482492656`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24472696912420674, 0.03601949580415442}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24472696912420674`, -0.03601949580415442}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2236348456210342`, 0.18009747902077214`}]}, 
                    LineBox[{{
                    0.24472696912420674`, -0.03601949580415442}, \
{-1.2236348456210342`, 0.18009747902077214`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 47->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4780408093372164`, 0.18049136115961847`}]}, 
                    LineBox[{{0, 0}, {-1.4780408093372164`, 
                    0.18049136115961847`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24634013488953602, 0.030081893526603072}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24634013488953602`, -0.030081893526603072`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2317006744476804`, 0.1504094676330154}]}, 
                    LineBox[{{
                    0.24634013488953602`, -0.030081893526603072`}, \
{-1.2317006744476804`, 0.1504094676330154}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 48->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4859522798219786`, 0.14464984077205914`}]}, 
                    LineBox[{{0, 0}, {-1.4859522798219786`, 
                    0.14464984077205914`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24765871330366315, 0.024108306795343194}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24765871330366315`, -0.024108306795343194`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2382935665183155`, 0.12054153397671595`}]}, 
                    LineBox[{{
                    0.24765871330366315`, -0.024108306795343194`}, \
{-1.2382935665183155`, 0.12054153397671595`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 49->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4921008524473636`, 0.10863666015627868`}]}, 
                    LineBox[{{0, 0}, {-1.4921008524473636`, 
                    0.10863666015627868`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24868347540789384, 0.01810611002604644}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24868347540789384`, -0.01810611002604644}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2434173770394696`, 0.09053055013023224}]}, 
                    LineBox[{{
                    0.24868347540789384`, -0.01810611002604644}, \
{-1.2434173770394696`, 0.09053055013023224}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 50->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4964901231359269`, 0.072495350674433}]}, 
                    LineBox[{{0, 0}, {-1.4964901231359269`, 
                    0.072495350674433}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24941502052265432, 0.012082558445738826}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24941502052265432`, -0.012082558445738826`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2470751026132725`, 0.06041279222869417}]}, 
                    LineBox[{{
                    0.24941502052265432`, -0.012082558445738826`}, \
{-1.2470751026132725`, 0.06041279222869417}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 51->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4991226590717335`, 0.03626891364614408}]}, 
                    LineBox[{{0, 0}, {-1.4991226590717335`, 
                    0.03626891364614408}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24985377651195556, 0.0060448189410240135}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{
                    0.24985377651195556`, -0.0060448189410240135`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.249268882559778, 0.03022409470512007}]}, 
                    LineBox[{{
                    0.24985377651195556`, -0.0060448189410240135`}, \
{-1.249268882559778, 0.03022409470512007}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 52->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.5, 1.0605752387249068`*^-16}]}, 
                    LineBox[{{0, 0}, {-1.5, 1.0605752387249068`*^-16}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.25, 1.7676253978748444*^-17}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.25, -1.7676253978748444`*^-17}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.25, 8.838126989374223*^-17}]}, 
                    LineBox[{{0.25, -1.7676253978748444`*^-17}, {-1.25, 
                    8.838126989374223*^-17}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 53->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4991226590717335`, -0.03626891364614386}]}, 
                    LineBox[{{0, 
                    0}, {-1.4991226590717335`, -0.03626891364614386}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24985377651195556, -0.006044818941023976}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24985377651195556`, 0.006044818941023976}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.249268882559778, -0.030224094705119886`}]}, 
                    LineBox[{{0.24985377651195556`, 
                    0.006044818941023976}, {-1.249268882559778, \
-0.030224094705119886`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 54->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4964901231359269`, -0.07249535067443279}]}, 
                    LineBox[{{0, 
                    0}, {-1.4964901231359269`, -0.07249535067443279}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24941502052265432, -0.012082558445738792}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24941502052265432`, 
                    0.012082558445738792`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2470751026132725`, -0.060412792228693994`}]},
                     LineBox[{{0.24941502052265432`, 
                    0.012082558445738792`}, {-1.2470751026132725`, \
-0.060412792228693994`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 55->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4921008524473636`, -0.10863666015627887`}]}, 
                    LineBox[{{0, 
                    0}, {-1.4921008524473636`, -0.10863666015627887`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24868347540789384, -0.018106110026046472}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24868347540789384`, 
                    0.018106110026046472`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2434173770394696`, -0.0905305501302324}]}, 
                    LineBox[{{0.24868347540789384`, 
                    0.018106110026046472`}, {-1.2434173770394696`, \
-0.0905305501302324}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 56->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4859522798219786`, -0.14464984077205933`}]}, 
                    LineBox[{{0, 
                    0}, {-1.4859522798219786`, -0.14464984077205933`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24765871330366315, -0.024108306795343225}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24765871330366315`, 
                    0.024108306795343225`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2382935665183155`, -0.1205415339767161}]}, 
                    LineBox[{{0.24765871330366315`, 
                    0.024108306795343225`}, {-1.2382935665183155`, \
-0.1205415339767161}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 57->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4780408093372166`, -0.18049136115961828`}]}, 
                    LineBox[{{0, 
                    0}, {-1.4780408093372166`, -0.18049136115961828`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24634013488953604, -0.030081893526603037}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24634013488953604`, 
                    0.030081893526603037`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2317006744476806`, -0.15040946763301524`}]}, 
                    LineBox[{{0.24634013488953604`, 
                    0.030081893526603037`}, {-1.2317006744476806`, \
-0.15040946763301524`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 58->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4683618147452409`, -0.21611697482492673`}]}, 
                    LineBox[{{0, 
                    0}, {-1.4683618147452409`, -0.21611697482492673`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24472696912420674, -0.03601949580415445}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW
LJGOfc/OmLEzi+yMKFLv9/c+7zv/zPN55nvvfOfec8498zwzO4ysLt1jWbVq
1RHWVav+e0793wcFVv3f4+GbgWcphOsLvOqdLpwDapELazzhV2H/WR+qQj3l
wwkPVI6QoouNQcZtituHcJKHJ/H6Q0irKQq1J+wt/+ZWho01nMkZqbtJ+NxQ
D3G9HdjZG6cqEo5pE9fxY3cEniMHFbYT5lA1IsY/BSteTevljxS4/DJMxSzC
BTT546+0EZZ8bEDM9wxqju9jJBLOr6eKJgl5gNUTqqQd4RsfDIj5PeFgbuGG
U4RTSyqCQ257wY1vMYkshBOWeS/6sb+AeYPbHc9SKLBVW7vW6cJLqNffanmM
sGCJ7HO7+VfQ8DsjdzKZAtfpJDCL8IcwvUWls4Ql8w7cyLB5Awr8vi9nPlDA
JDHs6G7VQPhwL9o1mPCicZ1gklAQaO+feNCYRIGugCfN0cXBcOjwr1tGhEdr
aGnCr0Pg8LjkqvlECghfW3kRcjsUosftVDgJ/9RnBT/2cOAqyqtniadAMJ0r
2elCJFRKRgs5vKeA/Mknbos7ooC3O3M9LY4CZl0S1+zmoyCRXL+QF0uB7CI6
q1lEDMg//vZNIoYCARqW0hk2ceD0ZfqafTQF8NJTnnFKHDy/LBhZGkUBuYCG
RWnV95D0xl/4fCQFwvvYKhOF4kGxcufvfeEUOH50q050cQKI9Cx03AyjgPL3
hAMUyUTIrgA971AKZF4a4xF+nQgjcg8vNwZTQNzDtCH4dhLsPbVbTPINBXz+
Ncq+Yk8Gk32CJSw+xPpwSgQ9uZAKa9jkj7d7UyCscI9XYFkqLCxrhb/zosDg
0XL7jwfTYP7b9hkpTwpwd41rkDelA4eJLN+iCwWkh4bw6GAGGPbPlMfbUqAt
2/SmU2EWHPrygH+HDTE+Xnbfi9kssBJJOxVpRYFJS5s/QXuyYbqhSczFnAJb
vjD8U6Oz4eSO5X9sJhRYl230jPwsB5I/Xx/eokcB9ag+1yNnPwPjGzlc4yoF
xs2D2JU9PkNcpsM2q8sUMNTn9tYq/gwmIqPx6RcpwPz5zO6ubB60iTqb/dCg
wHZhraVA3nwQ0hb3Mj1KAQsRmsc4uQDqJoQj3fgp0FPQHRb2sBgiSjmz9/FS
4GiLsiw5thhqUqvlyRsoQNG+kL+5sxheVJ6x385JgYs7+WPj4CsUiff2O66i
AHVUv/yjQAnECvysOztBhtK1Zmxfvn2D1pPUx49KyXBa0ObhXY4yyB89k/Om
hAw2LtPebJJl0FASo5RcRIZTN1+GJZ4uA+VIBcPqz2SQ/7b1NdWuDP5u8nVv
TCEDy1QXybi/DPZtXvqyGEAGUHkZZZhbDiOZLxwr9ckQGH989KxBJbQXGz7R
v0aG+ZQiBSPHSrgfyccY1yVDWi3D5mlgJUSaf2NZrUUGI61fialVlXAgZlRi
/jQZWmR8/3Dsq4IHbWUXVnaQodFVXKLybxU4jn6WCqV2w4czZ1Ml4mqgU0Bm
IWywGzb/jo48WlQDRkd5hUJ6u+HNFQ1TrY4aUPh3RfFZRzdkLZNiHdbVAtks
VmJ7ZTec3P7nbo11LTg3O2q4xHeDZXMN9Y5SHfCwJY8l3eiGv3r6exyH64E3
+eLvtKvdcHDVounXv/WwVO56M12nG8gjty1Xb24Au/Ja0egz3aAU/7r8pW4D
cN2+dUHhYDfMP3jtEVnZAAezC6/c4OiG93UCGRkfGuH30h2LC9kkuO2b8zH6
YRNMbx06HTDdBaKL38/n/moBewWLcL8fXZBZF7yHwt4KFbopH56PdIHen6C2
VfytcNf4/MhdUhc09Um6acm2guWqiTTaty7oZ887Qb3TCq2CjjIMvy7gsbpU
u6ahFQxc6nYPSHbB1IHu3Vti2mDgl8LRs6qdcKSKy/KuYgdc2Z9pf/ZkJwyz
XrEI1O4AbW5crXKoE64vmf8pudkBNO8YNnHJTjigt1gl+KQDDinfswhg7QS3
q+E/MLsD/PV2VEuVdcDY9YPeK+KdABpuPPsVOmAyJ0FLiL0L7L3tZQ9saAcl
iyzrJzUk0DCalI5ja4eTbI3Z0EmChO0NIuuW20CbaXGMfYQEGz8+bi1ntEFi
tpPQ678k+P0v4uJIaRvIh5f3hx3uhpHRFI0mmzZw+lWi55nQDcIjUvHHmlrh
3gfBf19dyVDIX09vtG4BuSGKva58D8wWCMVLm7SA3wjd+efpHogxm05wudEC
lulJHmGaPbD3aZ4Nv3oLCGQ9ftZ5twemEkznJkVbYG1SguCZ8B54J8FBKvRu
hmst27YvLveAm2jv0S1bm+CoVvd618peGLxhLWYt3gBXLOdYi3T6gbZDOe3V
2gboN79TLGTYD9cMb0yGTtTDi/ynGTbm/aCaaWvnkF8PExfbD4u/6AcxCYF6
k7P18NH0oqfF137YQnPM+mtWB+n1tHupOwfgUWfI/Z6EGtiZt0cg+fcATH8P
3VXeWwHJqj4CDo2DYLF+5q0ZVkBW0yCxLINQddzSli2+AvS/exiZdw+CgvcT
dbb7FbDO6s+GW9RB2Fol3HxiphyOcNRrHfwzCKXn85S9/pWBhIk9NUFmCOKT
eiL0eEvB5f11kUDfIRAwMl9vtboQ+BR2th1QGgYTvo2/zbEALmWtiHxRH4Ym
qYl9Gi4F8Orih5bT54ch0uz+ubBf+dDvLOqhdm0YphPOc7+ZzAO53X1FYDEM
LpayB2ZacqHxVesH2tth2P/7Q6fsUiZcPnRt7ejUMDw0uFOrY5EJJcZ8i0fn
h8HrsvVbWaKOV+fkbvD5PQzPSYlO66vSIdVGJn072wg8jphdufsqFW7I/bp5
QmQElqR+vbLk/AALFqIOAiojID15Qj8pPgKy8mJWq4aOACR1T3IavIWAN6wX
KyJHgGm0IaRUKBzkOjX5FeNGgKL+RmuzTwiUeX4dO5A2Ahd6L9F4q17DmpcU
p4XSEYivujx1r9sOnIqf8qyaGIHDwboWKqZvsG3g3vNloEJBdbbz8apAPME0
eyquRoUt2yweM3YEo5l2hZX6OSpknxZkGPeFouLiRw2vy1Q4993JdvxmFNpF
aav2P6BCdEyUiywkYPUR6b7fb6iwIbiodjIpE92e/XhZ1E+F+DM6f1h1P+Gx
I4pa0iNUKHWSrT+8KgvN/Hn+BjGokLouPXRTZhbWrY7dYjhDhfQbl0sruXIw
KfY0o3U1DUo96vQbmj5juCDj0VZJGhhuNo/OsyvC33Psw0dNaJCt8S/WuLkI
BcKv7zv1kAaPVB6InJApxufGRVOnLGkwwDH9zGSkGEc1rIoPOdBgYu/VxE9X
SjBzzp5v0YtGnKdfXdfuKEVeoV6RhkQa5L+95MUtVoG5D5PHgwZooHREbyFQ
pwIpt30DTEdosCSxi0XOuwI5I8bvn2DQgF9BcSpnugKvSJ2JbZmiwdY3nfuH
Kyox/dqgd+kKDYx9/Ab6ravxyLSFWLYoHcL9DbUnP1Tjq6T3F45upYNPPJ+h
QF81bkdzvaIddKj4wribfrYGayTiOjOl6VCTMTvPKlmL1uvUOvSO0CG61sPy
Yl8d9m6zeJZ2kQ53hvYnjwrUozZt9mSfLh3OiKjZRpyvx9SqnRYc14j3mzAq
VP1aj9KPj27UMaDD392bG8uiGxBzOJOjTemwNcZ0UdfoO9aqv3PZ5k4H14kA
dfuo7/jXPtH6pycdUmS5/qV3fEeWgKdWVd50eGU+FXP/TBM2sc490vWjw8Jn
zz2r9zVjR53z2M5wOsx4N44NurWg1j5vr6Q0Ovhbc65PjW5BlhKl99yZdBAL
F2h2/dKCYlsuh1tl0SH3kPp+TWYLOllL/tqeR4fTG7r5re63Yq7Kxvaj3+gg
GR/YNqjThiG/YgQUmulQmHLiq5FVG8rX6eQfa6VD5LTnphm/NhRSWVVzuJ0O
Aq8zBWRr23BFcVBElESHo3oLZXLQjqTrNZVB/XTQ4RS3vyzXgafTH4ueniDW
lxSX8kqrAx+KuJh3TNLBN5bG3WTWgeayYyXG03S4aCmiZ5/SgaTvfsoWc8T1
jc/uqot3YuyNf5wyv+gQq7QmokuxE6ni1m98ftPBykWUZGPYiWXTq3v7l+hw
2PKHfl10J27Si055tEKHgrU5P5Y3deErI5PzmiwMqKJVto8c6cKZvlwFS1YG
3DC6EdV1pQvZJ35k+rIxIHxNUFpvcBfmZWVKpK5hgGP06dHpnC604HrO92kt
A2ZsXoxxt3Vhk3azVfo6BrROSOx6yEPCyZB9em84GVDp2H85RY6ENn4WHQ5c
DMhuZZGb1SYh3n38/sp6BuxttWyK9yehbrQ4zx9uBtRssvfmyiChwZ62+IoN
DLh88FaLayMJd62xfOC5kQGmQlZ/n3N149KF+5bjPAxIY2uuW5DuxnmHFF8f
XgYE7+rKtFHvxtbMo+Vb+Rgg98kj08O9G9/aVtse4WdAiO6lEuHYbnyh7tpf
QBjcxZoKvnajc81vbXkBBlxfr9jH86sbl63DpfgEGWCneay5XpCMsf133BwJ
K6bbpPofJKP0G8WqTsLvul4/uK5DxpRjLLN7hRhgvizJus+KjFmWdn+cCXNh
vh2XPxknUm4NVRFuksjLnU0lY5u2X8TaTQx4bO/2dbCWjNZF5VuVCafvM37R
TSfjYcXqh48Iu05GcZPZKDh++Lrje8JUXV2NYXEKfv594nQ1YfbFuP3zihTc
/HvvlxHCzRovcYMhBVULR4d+Ezb1YJk64EJBKfLunHXCDIh9PfbZIIqCfeIf
JXgIq8zzcAd9Icb7iu3/z6mlB6abSBQMO3iy9b/rd9su6AosUDDGq3DVEjGf
1/DPg0YCPdgmpVr43/udPfD5RaF8D1awB8xWEdbNjD+zSacHyaZnPsQRvl65
zdzVqgf3zoq02BFWGnGYnPTvwZcx2Q+AcMzDwYp76T3o0VNgyvrf+BB3Bq2+
B1+97GhEYr2ot8wvWv7oQRX2zFf2hNkfxy78XduLpbt/xO4grLprTVv4zl5c
vrObtYbYjxtHH1OOqvWiZjrPp7uEu2lf1g4b9+JCAsQsEfvbWuGkE+zRi+O+
V2p8CH+OHRDeUNqLPKHpef5EPEhWunmR+nvRokbKgo3w9RPREykrvXhLYEHd
jognsurDF8Yn+rB/6O+ZY0S8hdk++Xhevw8NWEyM3hDx6P4P40896cOfAe5e
A0S8dkc1LRwp6MPJ4F2N94h4buLXAejqw8j73cPRRLx/D3Q7fuFnH953eDna
QOTD1B8bCe+D/RjCcTiZl8iXVc7n/qZf6kdq/3ldaSKfWJYX7/XY9KNaUmLH
EQ4GnOQWyNPO6sfJB+dOnSDycf7rlE9wcz+WTGRvOkDk6yZnh/KBqX4M9vTL
2MrOAK1vT0+/lh3AGvea2UEi/4P/bj2lnDaA6Xttd63+S9QH444Ys+8D+Ocq
9W34HzpsX6d+MWZ6AKVucvJLLtNhMz/ly3rRQYz7arVqG1F/jq39FP7l1iCq
aLzojpqlw8a9+Y1TVoOoq+mRMkTULxez23O73AfxeMweEJsi6nWs3lxSwiD2
zbjHPhqjQ0fw0/nm0UHU0LuuljpMB+mO1H6JpUFc9m0wjhkk6jX1iosT1xAy
tH+u8SbqZ9sbUuHhfUM43uVepEChgy5j07lOuyHU1VKY2UzU442reNO//BtC
t+SV+4Nf6WBqOcqrxjuMxW6vfu0qosOkQVZyu/gwigzmvLxbQAfF8URYUhtG
hqZq8NdsOqiUmEqZ+w2j8Ae5S4wkOkCUYA5FZATxXPGj7cR5M+8T0hgiM4Jm
jmuvfPYh6u9xF3edUyMox1j5fNKLDmF6VUFtt0dQ0EaMtMeVDkey+o7OJY9g
3rBptZMVHVaYNV7vjlCxhLJi/eMCHTLMLkedP0PFhGDH0XXn6fDl1727f65R
cXID97SYBh12sGyZvP2Eiop2kW+kFelACx0in/xKxT4MckQ5OohLXFtWUKYh
i6SYw9R6Oli25s7/uUTDP4YSf4zX0WFx3XmuCmMaJqj7fmpipUPLlU8PLnnR
ULo+y9tziQa8EimNzrU0nJg+q/OQ6CcSnlC1FrXpaLByRWkX0kCz9PXNOkM6
+gkfHpz4QoPT/CzUKGs6uu9bezH5M9GPGB2UVw6io6Sqqt/SRxqIeMhEBXXS
cdp2uFckhAaVdxrGj95k4KrSfZIKRL90uLZk+ZzpKKrbCnDXEv0VRy84uTiN
ooyhlenrJSoUxfW0ZfqPYqPlGqo6kwpzTs713DmjeG5ycMtrKhV0OWc2FS+N
ov2ujf/sq6kQ6s7dWvnqB3aYipfHvqBCUtHUmq3pYyhTeU9V/d8IpJ9uleP6
NoYbFHquqC+MgHFDGvfP5jEEKeExhckRqDqzOfYbcwwZpJ5X0xSiP7ZpF9h1
Yhy/9KldyMobgR9pfXMn68bx0OUzY/YPRqDlwlnthaEJ5Cy6enixfBjsFX89
ZWNO4BH/KNPLhUR/fytXmpttEpP5L19LyBiGrSe8i7h3TqIMZ7W+ENG/x1Vd
i6ozncSq5n+Mi+bDIJWar755ZhLv7Q8L38Q3DJ9fXA+IWpzCdc43RscvDcHO
HyIN7Wun0XH4b6+b+hD07P7IxSY8jV57NUPYjw/BHlehs+ePTmNNndkl+vYh
iNv3wf7J42lU5b92ZmVyEI7dLrI9tDiN9Tlmpz29iO8/hg8ff3eYQSGRuKfr
Lw/APcmSlx0uM/hXf/P5t8cGwMu2YDXp+QwejzojtH7bAPyJvLj8PWgGL1yT
KUj70Q/cMt/2embOYKE6+85Gl35o4QF2VtoMzmw32h75vg86Ff28tmjP4oCW
83I+qQcC9+8IcLs8iwsH/fuvFPUAX7rDeK/+LJayGEn0R/dACpfLU+/7s7gt
/x5X2p0eMO2SZw95Novf869MKYxR4K3nWuvA7Fm8dafSWGaRDB3WIYY9G+bw
3KW9nyZXdcOPVh31WYE5zNxYekqinwQ/ywI0/onOYf7ao4WKxSSwsG9xYN01
hy+c9pEOPiKB24nxW2mn51D0sHf4CqMLCva+i7Y2n8MqC7WKI3Wd8HD1Py9W
2zks36AduJjYCTTeT+P+jnNoH7F7dfyzTkjdasXu6zGHI+r6Jz8rdMKaniqT
TW/n0H+C70FrYge4K+t98CubQ4ENLeEcTu1gJtFAC6qew4urj3TaXmmH+bX7
179pmEOVrvHkGrl2+LCLa8yycw6zNmgGHaK2wX4no7mS0TlUDErcs+18Gxyx
W5sQwc1E1nvkhCvCraCUKneCk4+J0smeKj6zLfAiUfyAjRATRfONPqTUt0CT
MKuQ+DYmsks2a+Q6t4BCyA7qhv1MdJNYJTGKzTD/7W4N90UmfpmifvdV/w4r
11ZmY3WZqHR1YbXQn0YoLD5yfvc1JvLG6b7xzm4Envd6j3fcYuLpngUU3NII
Qf24MdmMiVL25DDmdD2YB2uZsngxsVvs7ENGUC2wZ4zNsPkwkewRo92tXguL
1Rd1/r5kovEDkZLspRrYu+qdT+cbJjYuxmttM6qBLgnDs4LRTCwyedA/IVcN
Oz43snZlMVGzQ/RNQE0FvJTfMqySy8QLm4Q37HlaAf5x1y6m5DHx8Z4mr+y9
FaBGu9N4uYiJyfMLXj6B5aAbXNdxooKJ3L+tvt/SLwOlmwKVBlVMXH9qbrPp
+jIgfXsi6VDDxK3PrLKMvpVC2ZdLe142MFEih69TUrwUlkZpP063E+vVX/mI
0loC994prhboZGJMUkYD81AJXI5tshzoYuIWuwcGM+FfQS9OUfE6hYkLJp5B
oQbFcL9k78PuQSbKPgxlxDEKocHrzqDhMBON3vJ/o54tBD+v0dC+ESZmqdiH
8KQXgCkt93MxnYmKjgdSxK3zQbBF24VlgolBv9doKS3mwq3jnlGHJ5lY228S
MXcjFzYJSmoYTjHx0dpgh8DSHAh5sqIaNsPEnMLt+yJ9s0FLwDswYZaJlDGj
fexTWeB2cfO95DkmTkXJcd2+lAUdXgWRQfNMPLd88GLz4UywDX31+8lPJt4J
mdsq8zcdPj1bQ762QKz3zWoVs+o0yPmpILC4yEQSP9f+mKsfoc7imEXhLyZm
yxtoBG5NAdWPjkrWv5m4FPhMz5L+AQZ3TF2tWCLu93A92+ijRLhPmg69tczE
SnI90/tUAsC5Ms0ZwhZSms/42eNBn2Hp+PgPE3W/n+x43RgH6qyCwouEJWLc
D87vioXBvoG95itM7HfWWEjPj4bsJK48EuFw+SK1c2qRsNOJ+unYXyZe2bHB
sak9HB7aVW8JIrwxq3TghFEobIwSWx4kfIfq1xkyEwT2v+6d2/mPidG/7mX2
uL6BIX8ZTiPCGkNDz6RE/cDyBufxEMJhd/5UPD7yAt7eziR/JawmvqY975IH
xMa0j/YQji/Xyi/vewrvBdTvzxJe2GrBv0rIBqzrhy6vEI4N87zz+agBSNUE
Zf8j/HBX1IrJdxV8JHTF5RdhvXXyzHWeD7Cy5lAh47/5KrbpX+RwQNqkltF3
wkWpCjvXtrph0btGp4+Ex296lV1ofI5WcxNszoQLdLi41mX54guW5RVVwvlK
CeXJwa/xw+il+2yEk6QqxEKLA3F9yW2lIuLz7/397q6abAh2hcT5mRCedu42
HH4XhuuevTvLQbhQ7O0XU54IVHyx8DieWN81xUpbyO5ReOTj5c3yhKM2Osnv
Y8Ygk2R/oJDYn59cEboH5eNwe9vxr8nEfv41z9p7MiEec6VS5HkJ16fJOH7o
ScDVASbbbYh4EBl9WLvCn4SGzwRMBIh4YU+ldFs+T8bJqHOl14h4WpQ0U/P+
moLNY7fCAol42zTgxe89/xHfXjAoHiXi8+mWxgPH76ajpuV67jWEv7wxODAR
lYFu1RKDIkQ8N1przrq3Z6LNmXIeKSLeWV+Kc+55n4VPZjPq64j8CQyI1D22
MRfp+vST7kR+qa6/+fVbQS5qVp0Olh0n6l2mDPe+259Roq1m4e4oEb+rx51q
svJQQGU/Q5vIX56lnQdaLxZickBNTQaR3xwTeU6Bvwox69fbhNUDRP5Z7Rs8
HPcFz/1ep+/Tw8QbLZxC0tNFeJ3dR5yvg4kng/ZLvntVgtn91SdF2pjY9O/h
HjP5b+j3M9JSsIWJlqOfgoTI3/B6cqH0JFGPAva7Ulj4S3HrziOmokQ922O5
v0rYsAwjL/jPWH1iYsiyQ2IgswJvi+32qk9n4tnDRafL1Crxhbn6E9FUJkqa
qDhTwiuxwzkzJDKRWK+N0d61J6owZuD33i0RRH3MPm/p61GN36TGqnc/Y6J5
beS+y1x1mIRH6L3OTPTgv7/080Yd0vYKlXo9YeJqO6cdzul1uNGl7muhLVHf
bj45fkirHgsmLF8n3mViWfTbL+f8G1CyMNMiQp2Jm9vpWxvWNuHbXcHtU8pE
vYoJEtfUacIMDUw6AUxMq+KrzYxsQh7lqg/FCkwcWtJevV22Gb+5zFdekWZi
qbtUiY50C+LuuOHFtcR45a8LfzRa0fVc/3Q1K1Gf5NaSG8xbkTN08Lv/vzk0
lhb69PJNK3LUNAixLs6hn/u7ShKpFemPM9760eawOFbSPf1eG6adeH57B3E+
d7nO75R2bcc59o/p1l/nMG8HTflHXDvOvzM7WlgwhxnNSzFvK9ox90SVzP7M
Ofx4ViW1bF0HlvH6aFdGzmH2+lid40EdSNp1nf050S+wq93dlvW+E90287SG
bZnDXfRGXo4cEv7bOCH7XGgOe16yvRbuJKHzd8EgU545fFekXbPxFwnv/vwa
sYWN6Ce00zjzTnWjTDy5TnJ8FlviEwS7a7rxy4zfQHXBLGpejhE1I5FRfPFt
UrTmLHLc8pfdPdKDvhfDbWNVZ9G48N5TVtZeNJayiIk6NYsxxr2N5eK9uLks
4OgzuVlMO1BycuZOL7bPtRQu883i1xBhC7aBXvzmy+Fb1T2DEp4hHGwdfZjf
JEmfNZxBz/BpjpWUAVxKF1urrzeD0r+rQ7sqB3ByWF245OIMenXucAoZHMCS
oj+H7JVm8HTb77B+rkF8ZGnonCw+gxHTsXG3lQexpGNT6dXaaQw0+vmuOn0Q
H0uHFw/VTOEau1xdNschfB3GfyysYAp/cPFR5TyHUJjks0cleQq/iG5V0QoY
wnWJP794e0/h1imNBwbJQ2j5Y+FrvuoUuk8HH2jvGkI+Cb3KBpxErbRGSYGD
wximILxbN3sC1wf0eIwPDuPc1MYfRu8nMKIoNydmbBhtss4csQycwJXsBX+V
+WHc8VQhz9FmAi+ojmo+XDuClef5Jq4dmMDl2+u5JWVHMLvu1SX9rHFMEyvh
O+cwgquH1xt9TxvD5TLuaMt/I5gsbGVqFjWGFup/2yLWUvHRo4WmNa/GUOe6
91LhRioeGXUeP/xwDCW3v97Vvo2KS2E/Rh2kx3AfyUvHEaioFLmIAYk/UFq5
s9HdmYoD85eCHkeNYqsv90LhJBWt7vUz7H1HMdxZjf/3PBULOGU2WjuOYv2l
G69l/lDxnNAwj7HuKKaf+/D5PicNP1qn+J/iGkXr2d1Gp3bSUOyuUFjrUwa6
zxabG9+goZGj8/byBwzkfygh1XiHhhnJr8xyrjKw7u6aqF0PaFgxXe8cJM9A
uxsF3fn2NJzflrnp0hgdK5VuXVTwp+Hj/KoLPdfpWB+dsVBVTMNj8xSrpjN0
3Hx+/VuDMhou1obuLT9MR0P6pTuj1TRMbTbKSuOlY6HykxekVhqeqGI571NH
Q2dXWcYWBg1HGM/HbI/RcPfI5yPnNtIxudj0vZEoFcUFLD8aXaXjncOyBdkc
VMwxUadL69NRR4USz/J7BEujlpFqQMeY6ytbU0kjuLfwtvGpe8R9meRF84SO
oIZN9BY7Ozo6VMryq/CMoH2D5K+f/nTkfWjhnftvGH+ue88qEkhHPkO/Kzun
h9H473p++RA6Up5w7OJvGkbZxYFr6pF0vJn41IbTbxgHq+UO/Eqio5PF3fMO
64Zx5GIDw7uYjqJzDCGeX0P4V1dOg/sbHYeVG/LSGUMYUXZQ6GUpHW+3rvGf
qh5CV/sGwftVdCybIN0N9RpCMVb1W5+a6Lhn+niY+qMhlGnIpv9ooWOU6Y32
pbtDeK3pJB9RQ3G0J/CVueoQBox5W9wh0bHEVTH9EesQWt34O+M6QEeBNt15
YA7iDN1S22qIjrv2XnfmHhnE7dTy51dH6Jil+uBeTvkgZr1mD+dgEPc/JntW
0mMQZS4lbWCdomP+YslpDttBPKzbO506TcfaE4ZJs3cGMcJqZODsLB1PbXLr
a1QaRKberbUW83R8V30iOmP1IGZqMvefXaKj2CG13L8jA9iTzX8/YZmIE54x
iY9EnWCr5Tj28w8dD0f68vB7D2DCqeE6t390PJ+4Q+EkxwByiUvqHGBj4Akl
ZXfhsX4Mam7bdJadgSfbPvH9qe/HdZ5SGXprGHjzepQ82a8fU4WEDAzXMVCE
+5z9BE8//noY7cm1noEqEctr2Ob68Lsgw3qYsGGDvKxEex8W3fQ0zOYm4ly4
Tu9xaB+y3v99XWEjAwV3KVlnOvShm+Yj2ynC5ZPWMHGtD7WXvZNieBg4yTwv
7Sbah6u8k+ypvAwMFbfV7VjuxaLP58Wc+RjoyqN0/UBfLx5S/fabi5+B17pV
lcO+9WJaoipPCOHjy/NCrHG9KLFt930BAQaaPsobcHTvRf/GXDZ/wsttXYnz
Rr241l9meoWwz2cxtTU7ezHMcbGiVpCBvRTP/VFre1HmV1uRuBAD+y41Hj36
owepu1I3PSIc/Ylxr6++B++dKxlEwrVvcvFleg8WK2huYd3EwDcFS1qKr3tQ
/nJgy2nC3psfCf+16kE1nwZWO8LO/2p2Vur0YPTRQ19jCVuv8X4WdLAHt55m
W1VF+J6GnKypYA+K9dt2DhO+fP/AIY1FCgaX5yn/JiyVyIiWI1PQZW6V9jph
BrowIy23FVPwYL33ykbCtXweWZtiKPiL6XiNh/CWmDJTYTcKOt9mNeIgvGe7
+fsddyjoC1cllon5dh3wuHVQhYJffkW9pxFucJ9L1pKioJrk3+FawvI/I55b
r6XgqGfiZCLhrs8qy1E/yNi+/LnmCWEbtY98LQ1kzH+l63iG8FKUbev6TDL2
nYln2UDYU/7I6UtvyHj/UpnVd2K99oo9MYyzJaNbR1OlF2G2bZ9OLF4mY8ki
fa0C4aVvx8lXFcgYOCABQ8R+FN60OI0iZCyOj7F+TthD7YXN/j/dOKT6MH47
4R11BY9T+7vxYFYMJY/Yz2xtMX3Zsm7c+ensNlXCzqZVm78kdON+uotDAxEf
i+yl18YfdCNXeo59FRFP+mlfBvnOdmOqdWiLDGHn5Se/VXd3o5PQzR0vifhr
r7JfrP1BQgNbndJ9RHzO9XGMi9aTcPBul9gjIn43bN78yjGVhHZx469zNzAw
wdJm4qIZCVujL9QLE/HvvXSr+LsmCc/doyQAkR/HO0QuXdlLQh4Hi0+3uBiY
PHBt9vlkF4Zo/nvqxcHAeNpQqol1FxZSdQsciHxcqEDz4zpdKJ5eNG9I5GuX
8j9pEfku3BRgH6fEysD1BTdTFpmd2LK/4vbUKiJfPkncPfa4Ez/KS1+ZIuqB
yp2DUfeud2Lt/ZjOKKJevNzNthR9vBN5ZWr/Kf2mo/NhUVXZlQ6Uzky2fLxA
R8vPkpEdHh3YeinM8/UMHbV9O2P173Zg7U3KVhaiPp1Lzvw5rtaBvnTFd5aT
dFwbFZe4n6MDD7veNpEnzqmksz2vld+0Y+BLO9o9ov4ZMA7q+sW1oeZsVp9H
Bx2VzV8+qPNow8l/O4V82oj6tbGXh4/oCw+CX6I3UX85Eoqkq3e3YfFT1gGr
Rjr6nyro/JLbivX/GvyYFXS8pDo001rXgts+RDRVZdNR/TXvseLMFrQ3N87x
+0RHb75MzAxuQa4bs7u0M+g4K+r55rNBC4peEO4vTaFj8a35GQdqMz46u26D
SSwdI1d1L1gdb8LaxPK9n1/RcY27jKgfexM+aFnJ3ulLx4fefXNfW75jSNa9
rSHedNS/4tV88/53PHguqszQnY5Vb2zcQkMbcUF6obzIgY7WsaYVEz/rUSvV
d//z23RsZl9z50p5PUactA1OJs7Lx0N2pLbX9cjV8VCumjhP+YV/Xl4vXY/A
7bPz52U6/ohu+/KE6Ps5cvyjRc/S0f2syW6oriHa8I75F/vpaHNsZNWTtErc
1dK0esMfGl6KpZrccajEV1MXtuj9omF9TrqhkVIl3mQZ14qZp6FZSdGaTFIF
/tsQzi0ySfQjMc/5zNkrUFS4Lrarj4Y03zoxj3tlOJP6YK3VNxpSaZG7Bay/
YqXuw9gTzjTkvOPEx7b+K+aKKToyHWnYCKvTJVOK0VeNSyjZjoZa263Ji4NF
eED+SMlqMxruXdS1pV3+gjk5pUpe12l4w2i2n6SWj5ddWYPrDtOwf4yVha6Z
hbQekW7TcSpyy6tf2zf6CStru+AnnYpRdwunRo5+wtwAZXeXYSqSvAwyNXoy
8IGBaNxzMhUnIy9WL0ikofRCTp5FDRX/2SxHkiqT0Jjb1T4znoon/XSUrHzC
cMPZelnWa1RM+LnGiTc0EFR0123LLxjBN/MHXiVVBcHx12v4MnJGcM3gXb34
n8GgEPiz/n3GCIruGKjt0g0Dvf1ZEc8TRpCyyv6OHEcU/LFRW5QLGEGdTWnG
QzLxQL7xYON2kxE80Gu5p045DaoLrDkf841g96FTp9Q186EkBO8E3iP63cdg
PR+cDxXXdFTCDIexaLRH9UlvPqz3Uz4dcX0YOV7Ycq21KID1LtteRWgNo7Ba
VOQhv0Jwuyrc6Hl4GA33schSy4sg7Kv1idXsw9jS5kj7xYsgHErOyY4fQi13
pfz1MRWQWeLvY0keRMFIlw69ogrQ/WRw7Gn7IIZucnMKIVXAwRzPquffB/Hq
YepTCm8lFFzWdwgrI/qIlReD770q4eWix/30j4NYWzGmLfGwCmoXpCYSngzi
Jm27cuFdNaDG36HUKDyI16+dsOK0rQcnc4FfiSn96OQbSvX0rwf/Xlm+o1H9
eDv8etp4Sj3k7dC9VOffj5Pe3zW8B+phfoJHh27bj4UXY5+PajZA6LH4GM5T
/ajV/3L1/R2NsPvsZp5/LX24/YVWqBN+B6FOV7u0xV5UlMgXK77bAgdMPxd8
UOxB6VeXT++0boGEpm+vRYhzszvXN9HXqQWKJG6cfiXVgzl/HbWOBbXAM/kX
cmacPfgv4YLxSWyB+JNFQWIdFFzHdmd3x6ZW0DN+t1n7PgU75F5K3KpoBefC
B+/G/cjIp32T7sDWDsHPslmciO+Lx1q6Fe5xtwOtx+hFbC0JvTKqHmgJtcOB
O7FmFcUktLBTsOGSbof7qQbXOOJJqFOy6+ppzXaIus3d629JwhXud8fc37RD
agMp9OlaEnoKZtj4CnVA62+hK2NHu3D6O4O5kbcTCnl17+tHduDODS7GO0U6
4XSXa626XwfW/Homd2RHJ+z7+iRf3rUD1fObaUoHOuFQ/tRJDqMOVKxi5+TU
6YTirNmN2bs78KOs1DbDgE4QEM/+OFHYjizmFqEya4ncynuzX5TUhh9bbCdK
R7qAf71mjAtfK4bUZdBafnRBC3UvU5W9FXfv3vmiZ7oLylyL+Nb/asFD5d9q
B5e7YLX+fFZEXwuiaJdVGj8JBk5bPM5JacFKhU/Bysok4NtSkEg53YI9qa+3
e0SR4DnzfCRvVxMqT5f8+BFHgiC5irchxU04S1byOf+BBBSfFo1N75uQtSTs
HEs2CT6uZi/bbN6EO+l6HPurSSB/qk56B0sThmZpB4VOk8C+TcJn677vKB+Q
9DHwdDd8FxOqHfVqQNuhrYmnVbrh7LWm2VGzBmxMZH6nn+kGsvM4fVSnAVky
N3+W1umGFfXyw6NiDRi7ccsPW+NuqGiNdKDm1aNmxSBjx4tuUNn6YU0HrQ53
7G31n63vhjNmovuC1Wrxtv+cx5rmbuDYcofiL1OL1sWZtULt3bDhiYyxD28t
Jo13nN3dQ8z3QHy9S18NbmhOOSU03g2P/aD27qMa/MOq+42HkwxFWYvn9iVV
o8v1o+6vVcmwNL9NN52tCj98nDp/Q4MMtPiJQxajldikSsoXP08GUQ7OP7KN
lWh92cn0vS4ZOLZOn/gUXIksibfu3zIiwyrbna+zxCsxfGpnGsmVDKu1HLsy
FSvwlunmA025ZLhq6/Aq2rkMlV2mcmfyydAZfbZL/3YZvq5cZnIXkeGG1BKv
iGoZ3olT/nS0lAz981sMQrnKMHN97J4LjWTw5b56zj+yFMN/ps88GyGDFU/q
k5/WiA9+CmqvcFOgrGLdg6jRYvwxvSpXm4cCLAO0nt7cYlzcLBIRxUeBvSYv
lbe6FaMbY+P4rk0UkMm79iNOsBiHmYF5nNspcGKWLSlJuQjZhiQNfu+nwK5P
XLwZ0YWocuKPIOtBCqg1WbZN3i9E+mEXvXWHKRCm3fJy38FCPPTD3pn9GAVu
czgOfaorQMb5Rq16xf9+r+64N2chH3s38rq5XqDAjNzx+3kX85B0y4xLSYcC
cbtKs39uzkMfvw7pf5cocE7BceEw4zNuaPcWtrxKzHdZyirf5TNmBQiShAyI
z/OdU7wgNRcVtifsCTGlQG1X4KcCthz8JJT9a6MZBax7Mz8tNmfj+SyxWy/M
KbCeTSddISob2eafzTywosBSw7uoggPZGPTkyKlFewqksAdcKbiVhbuAq0zR
jQItfxejzG0ysKzXYCjiGQXSdgZJJS+n4zfpTt9Jdwp0OnqmDnml44YDTfbP
n1Mggvtc8tXINLzr2V5i7UuBv6EitooVH9EQFfe8e0kB8N/b+1TrI17dM7ij
+hUFfNJ2quSRUlAge8tn9tcUkFz3ZN2eiWR88XC1pUoQBT5a9NnzC37AZ2nP
TqkFU4BfxLleKzYJf8t1RiqFUGDZZu9Wn91JSFu1f9WeMAoEhZws/XMqEaPr
Mly+RFAgQ1BmjmYSj0caRyoCIon1vGhzYvvse7Sf3BV5O4oC+y7EeOo7vcfN
T0mLs9EUOHNsiac5IA4Lne64tsdS4NbTNBVrmxgU+/5e0zWOAoXKpbVUr2ik
cmCqxHsKSGR9OX89MgpjFfS23YqngPtKuY5yRQRG/z14mElYdYSlPZ/0Fg8Y
pPd5JFDgUPgLXZmJcPyrv50RmEiBnE2ZlwQEw7AgxFKDN4kC0UF2rT67Q1Ey
6u/JV4RbrlRdWDkVgtv4HQctPxD7dVxdk24ShIdoiQHdhFd8X9fqOwWitFps
28lkCuyMCFVrDniDIUq2Aj8Jl//hcrW28cdpdk/+sykU+Jz6z+F65CtkSWn5
EE6YuSnXSrnCF8+L2jUNEpZWkX8gM/ECzVKevZT8SIE9wS9uCwh6I+8id48R
4XPMYr2VU89RgG1faRThmumui3QTD7TfOXesmbBvZ79Gc8AzvLXhocYK4ZNR
2e7WNi64vyphXCqVAuGzgTbKFU/waUaaxFnCTVvu3REQdEBuT78ZE8LWC3I6
dBNbXNC/cMmNcB9znBhvga4JyxpBhM8v2hLXm6C8ZHhHLGH1yGnidQOkrUj9
TP7v/zLN/1kL////NFyqjqnwMObr/wBDP+3J
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24472696912420674`, 0.03601949580415445}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2236348456210342`, -0.18009747902077228`}]}, 
                    LineBox[{{0.24472696912420674`, 
                    0.03601949580415445}, {-1.2236348456210342`, \
-0.18009747902077228`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 59->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4569096378457398`, -0.25148152764855564`}]}, 
                    LineBox[{{0, 
                    0}, {-1.4569096378457398`, -0.25148152764855564`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24281827297428998, -0.041913587941425946}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24281827297428998`, 
                    0.041913587941425946`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2140913648714498`, -0.2095679397071297}]}, 
                    LineBox[{{0.24281827297428998`, 
                    0.041913587941425946`}, {-1.2140913648714498`, \
-0.2095679397071297}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 60->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.443677587156521, -0.2865387558844961}]}, 
                    LineBox[{{0, 
                    0}, {-1.443677587156521, -0.2865387558844961}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.24061293119275334, -0.04775645931408265}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.24061293119275334`, 0.04775645931408265}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2030646559637677`, -0.23878229657041347`}]}, 
                    LineBox[{{0.24061293119275334`, 
                    0.04775645931408265}, {-1.2030646559637677`, \
-0.23878229657041347`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 61->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.4286579373288415`, -0.3212410723694994}]}, 
                    LineBox[{{0, 
                    0}, {-1.4286579373288415`, -0.3212410723694994}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.23810965622147343, -0.053540178728249864}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.23810965622147343`, 
                    0.053540178728249864`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.190548281107368, -0.26770089364124955`}]}, 
                    LineBox[{{0.23810965622147343`, 
                    0.053540178728249864`}, {-1.190548281107368, \
-0.26770089364124955`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 62->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.411841929886298, -0.35553933843658353`}]}, 
                    LineBox[{{0, 
                    0}, {-1.411841929886298, -0.35553933843658353`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.23530698831438296, -0.05925655640609724}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.23530698831438296`, 0.05925655640609724}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.176534941571915, -0.2962827820304863}]}, 
                    LineBox[{{0.23530698831438296`, 
                    0.05925655640609724}, {-1.176534941571915, \
-0.2962827820304863}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 63->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.3932197760281557`, -0.38938261874942276`}]}, 
                    LineBox[{{0, 
                    0}, {-1.3932197760281557`, -0.38938261874942276`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.23220329600469256, -0.06489710312490378}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.23220329600469256`, 0.06489710312490378}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.1610164800234632`, -0.324485515624519}]}, 
                    LineBox[{{0.23220329600469256`, 
                    0.06489710312490378}, {-1.1610164800234632`, \
-0.324485515624519}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 64->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.3727806624393715`, -0.42271791593676167`}]}, 
                    LineBox[{{0, 
                    0}, {-1.3727806624393715`, -0.42271791593676167`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.22879677707322846, -0.07045298598946025}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.22879677707322846`, 0.07045298598946025}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.143983885366143, -0.3522649299473014}]}, 
                    LineBox[{{0.22879677707322846`, 
                    0.07045298598946025}, {-1.143983885366143, \
-0.3522649299473014}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 65->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.3505127613014443`, -0.4554898814985292}]}, 
                    LineBox[{{0, 
                    0}, {-1.3505127613014443`, -0.4554898814985292}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.2250854602169073, -0.07591498024975485}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.2250854602169073, 0.07591498024975485}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.125427301084537, -0.37957490124877435`}]}, 
                    LineBox[{{0.2250854602169073, 
                    0.07591498024975485}, {-1.125427301084537, \
-0.37957490124877435`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 66->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.3264032460154382`, -0.4876404989655397}]}, 
                    LineBox[{{0, 
                    0}, {-1.3264032460154382`, -0.4876404989655397}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.22106720766923968, -0.0812734164942566}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.22106720766923968`, 0.0812734164942566}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.1053360383461985`, -0.40636708247128306`}]}, 
                    LineBox[{{0.22106720766923968`, 
                    0.0812734164942566}, {-1.1053360383461985`, \
-0.40636708247128306`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 67->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.3004383145498144`, -0.5191087347083356}]}, 
                    LineBox[{{0, 
                    0}, {-1.3004383145498144`, -0.5191087347083356}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.2167397190916357, -0.08651812245138925}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.2167397190916357, 0.08651812245138925}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.0836985954581788`, -0.4325906122569464}]}, 
                    LineBox[{{0.2167397190916357, 
                    0.08651812245138925}, {-1.0836985954581788`, \
-0.4325906122569464}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 68->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys
e68hmW5KhUolJVIKDUr1O9/ned/7j+fznGOfc/Zea+29/9hiV53OW7OtWLFi
/6oVK/77a2z0348GK/7vF+WqlWFA2HnJbu21dVJw/qriDR3Cz8b/swocGGdj
ahC2yc+NuZcIINHfXnSQsL7KDeK6BpgcvLpBjvCoXkCvt+5ZcLg4vWYLYT62
JOJ+XbgUrxuxgvC79bqlT+3Og5vF3cT3hjR4kqVD/L8RXHArkH5A+M4hjRtz
1SbAWR54soxwgfQeoj0zePxbcjaYcHvFml1rv16CC/eChS8Rlud6EH0v0RLu
MpNG9hI2Utzvzid0BUh/zwqzEdZ74Fby1O4qyJ0LUM8woIEWdzHHtXXW4Czw
TvIK4eo/UftlzW3A+Ur7XUnCb/Q1beaqr8Op6sSV+edpsNZoe5e3rh0slTms
NSN8RE1y8XjeTRAT8U3jJSzz+Ln42q/2UCL9xcBZnwbS73f630t0AvMf8v7b
CDfb6xtXuzjDrlY95Q49GvBX9drzCbnAFuPvKmsJ//RmpT21uwVHf8sV2OrQ
4GQo5+zVdbdhKHjzxp/aNJDbe+9fF/U2lHtKcYUQ/roheKOsuTvovzmUmKBF
g2+7z++fq74D8d1//wadpYF26VtXb10vSL2PVd/P0CCjoSNg/IcXsFdUvLEh
LPTOI+Z4njeEHHN5ffg0DeZ71uSt+eoDK7IbFVCDBp3Sf6hJif4g4NPFt4Uw
m8u0mbdwAMRl9XvePEmDhfVGY1UuATCDYi851WlQv/LzE16hQGj7s2Ny+zEa
qKUfaX9iFwQGpnd6Mw/S4HIB7fiVdaFgv//i77IDNHjV3ZJdej0Ukh4UbSSr
0mD7/ZU/PjFDIcFae6FBhQZHK1vzvDzDwFHkq1uiIg3EqdT+pPfhQPWLVQna
SYPQ7eWXu+hRIHdvR7m2DBGPQwK+3NujgeEl/pdfmgZ+dR+S9O9Ew4Wn3OdS
JWiwe+do7UuFGPgbcNXGToQGZYGqGd8yYmGHXI3O2U00sK/d8i9BLR4MlGqq
Hm+gQduX40P7bOOBGv3znSkf0V8CLjnPkuPhY3XTB2MeGnz/oSwr/DUeeGsf
iIutocG2186/S0sToMplG/vnJSpEn2qwbeVPAqe21/w2L6hwrnvTq/HPyTBh
84QePUaFntHMKC/BFMiPOMCsHqGCb/GtXZtPpsDBbPuO98NUGNPn1dJOT4Gr
tDNk+QEqzBhMrGxRT4VAvs7hNW1UYHscsepeWhqc6J1O+pFOhT9iH9TVTmRC
twHHt5JUKjT0bOUets+EZ6mTGeeTqbBXoaLNITUTHr5JJOfEUyHsmtXbvNlM
SPdUW8kVTgUOkqQ0R2oW0AV67sm7UiHjJp98/8ds+BhtL599mgovdJLD8s/m
Qfky+dcbDSrEf9rdHWiZB2ICJ0Ql1Klg4tC0eMUtD94ap9lmHKHCdpckYfGc
PNg5GTZ9SYkKPBLDKflf86B5feY6xW1UcLH+8CErLR8u7/gxwzdDgR0c+Z+D
3heARoXRrlfvKXD2Psn78u8CmFk6Vln+lgJldx5/OsJXCElKlTbKLykQu/zK
/+fBQhCQEKwXfEgBa8oDPfvYQkiDbg5FGgWkR3P1dPYVwfqHjS0hPhRIq675
/DOwGMpDj92L9KCA3Ar5lpS0YljOTHsb6UYBgWBt0321xSCnojbhY0+BVTRu
NqcXxXCE4gfylyiwK5ybbWJ/Ccgtdt+pVaOAXj6fZPvHEujpoUbBIhm25V8U
O2tUBjHvAqzhAhk6v9aeCpWpBAt5SU9nQzJsLRc9GX+4Elap7zifrUuGxe6Q
mQz9SgjRddad0SDDlpRhxVrvSqDbGBvrK5Eh7XBL4mNWJdzeIB95nosMQX7C
Y1weVUDuVfu8taEOJnXpvAo91RCgkNTtsKoOurMPRwcrk2D8QnT8mj8koGW9
bBs7SgIosl6Z9Z0E/MltKYpnSRC62u8hdZoElzYtqY5fJkHCoPDXYhYJBsY1
xJTjSFC8KTAnJIMExjXMod4PJMjgSHeVlieBKVPXpTK7DuYKP3lv860BFclY
+q/VFDiRfXr9gEMNWK9yZvzjo8CBfR6XXC1q4Nbdrwrs2ylAOb64LQdqQI+x
R4NbiQLx6bLUmytr4NKrwXMbLSjwqNSt9G1QNfR2W1Wz1VOAMeS0Sta3CkRD
T/67Zk2FxVD3In6dCrgw5W3+gkGD4AuSD3mOVIDLdtHUH300SNnof3B5VwXE
SIiwbXxKgwnZOVojZwVoLHTbnJyhwWTuiZnaznJwmAk6mbuxHt4Hqb1KOlAO
/DwUQflr9WBz+m3S5q1lsLtIkyttVQPQfBZ8pWnF8OorI+vK8UYQ3WY7V5Bb
DFMSgXs2ajWCl39t1IaoYhi2SDZhGDeCXfRO2S6LYpAsPWGxzb4RAoLcHUPX
FMNccwlbe0ojbA1ZumBtXASmTxpCWj42QtKdl+d9pgtArLOlPPReEwi+FV+X
fT8Xjg2XfGp93Qxnvd7LVKXlwra663W6M83g0rm5Ie9GLlgI5GS/XmiGb5yX
uNS4c4F36/3JZY4WUFob5yevnQMxz19MiCi0AFtNi93a/izIe2qgxuHZAkNP
uu6a0dJhL+tbnA5vK2hsa3tqui8JREydg7ertEHY85HLUf8SoZFy9fvikTYY
bYiUyutNhNcBzlO9mm1Amgs95HE5Efrvx+93Mm2DRd0jRaNRCSB0+7dcuncb
WJ+dCKRQ78JmTV0XJ0YbxP36WCHZEwFzYdEj6861g8mkdp6bSQRY2Qubxhm0
w4GXF15HEXW8qOH85LpL7ZDzKniZkz0cxmkem1Y6tMOvapk+vcPEvLA19kpX
XDuk6CdxzucHwtfaeOPmoXaIiHrwRjjIDYQj92QdNELYF/LapMDXFd4FPNJa
bYFgHsTNl+FxC7Qiqj722yBM3HQtmrB3Bjv7Xy91PRCOkcpmSrNtoajcfEki
E4Gd8/PmQroudP80F1rxGiHyY6P36hN2WK4lkr1HmQ4MrvpfHY72uPeScY+O
Kh2Wrbxji7Mcse1oVszNQ3S4m1YROu3rgvvkWx5nq9OBy+VB3Nzb2/hD4Naq
dwZ0uLZHftm7zw85LA22/Halw/oXu9XaQyJwZUb4k91kOugddLu2nzcSexJs
njXR6JBpOVE+lx6JbVxjViea6KDhptkqRYpCzsx3m7XodDgr36yc/yoGZ8l9
occHiftth72diuPx1IbZH3XTdKBMtG62kE3GK0z2D0kiDPjOkS5YfysZNV55
RfeKMcAyK+zUntZkvLk92fSvJAO0HeeVQ3VTMNwBr5rvYoCUSWU93klFaWb8
85+qDKDsvGx1azAd13ts9i7QY8B87IzjxL0c/P45tLXMnwH726Sjpj/k4ARF
bbQ5iAG7Hrus2nokFwuq50QfhDJgVnJg88d3uejRsFpwLJoB79eNL1Cz8tDU
k3JgIJUBenmF/u8W8rFbKnrLYg0Dap6Rj0qKFuCzGaGS7joGDOvcJrufLcBA
pahNyVQGDN0XbTDOL8BhXcodqWYGOH41k1ulV4hMDvaXm7oYcM5BRYqnrgj9
BCUHxMcYUC8kMxv2sgjX6cf9Ib1gQL6X3UV+rmKUzGlsU3vFAK8v2xTsrhVj
89LSyLFJBii3CDiv3FKCK++und38meifLZ+7XgSWYv6BrX/frWBCuoTrgfja
UuyPD6bLrWJCi4mTksnLUtwPyWi3mglcUdF1ogfL8Nj+ixYvOJmQZH4jIuNr
GVYOX4sI3ciED89eV+yzqUBuqQNDM+JM8BW6o6l+rwJVUvdRn0kyYa9puJ8V
swLJZ9SriEGA8PBCyrhIJe6NDe4OkGOCNelCU91IJZrfAN77ikw49JAmPKhb
jRVJdeqWwAQzN8vL7P7VyHQ4/vPXMSYkku3ntWqqsVplhX3CCSZEbJ78xM9T
g2kDgt41Gkz4dqEty7+vBt+css8uO8eE9U+osi+lSJhurCCQZsyE4VcUA86j
JIw8lSrx0oQJBf4hLkeNSdge9Tl1+wUmPP9a7dkRRsI3zwozoy4yQY3rut6B
DySk1io5iV9mwvuMnOrKFXWoHyTNo3aFCResTr+SEazDQdz39txVJixJitWq
na3DU5t8d1hYMeF+LiP8QVUdHqGJHDlsy4THDQ95g7vqMK7u0pLkDSac/SBw
RmO8DnMjxXCNHRP4H7m1vuUlY9dCu27LTaK/3/6dxZ1klOJ8uD7GngkX43Jb
io6TcZR7FI0dmFD2RVc0wpWM8+pSr0cdmbA66VxFWAwZmU+j1BOdmHDXTQVj
i8l4XVgh8KQzE+aPzbvQnpHxzlsd1xQXJuRXya5++oWMgkbPt+2/xYSNslt5
/nFS0PBmexiLcESllLXdYQqmjIZGz7kyQdLuVv5PAwr+3PVJzcGNCRWiHlJx
NylYbqpg+44wQ4ptfjCDggLMnJ1dt5lwsny9oheZgsM5f+vk3Zlw/fpkkXwv
BdNy7xXHET7jbLOldImC18yqGo7fYcKPJwrrnDZQkXJOpz+R8GDkothRWSq2
jNqojhMO8Cg24D9O+P7KRQkP4nuShbO+mlLxopTsn2uEufp3fX/iTMWvBu+0
cwi7TsdfYkRQ8SX3kTePCF+N//eAkkfFxSsq5JWeTDCV2n6wupGKS/1DLXKE
V7T7FFU/pKLkLv4lbcIzvOUctA9U7Ly/bHWT8EFLIbOOFTScvBz1K4iwm8Oh
9JGtNGRXaKbeI2xka9u+uJeGH1+Hx+URDhz53LHlDA0DaJ+CSgirxvMUHb9C
Q5LDZMx/lshYNL3lSUPPS9dK/7tffGfXi/IEGr63uzzwX3scQQmyH8ppqC7y
cOm/5x1avHRQgUnD/TnFMv+9T0X7Ng7PMRoKtDzS/+99vVdRIvvmaSixeMpV
lvBD2s82Se565PJbDPtHfH9ABCUrRKIe95/pDmcR3vAyQ/TjoXp0WVvhnE5Y
n2x8zNSwHu1Uow+bEz6Q5P+zz74ebcUM3wsRfhSac1wztB7/TH2yfUSMx+SS
vMD97Hp8GnkMgwlPNNyz16mvx6RppcndhJ+z9hx/MViPbcMVjx4T452oJXiK
e0UDrj/Z9oOL8ExWv13V1gaUOigimU3Ey+llny8Gig34rjxhtSxh7+zPq+uv
NqCWjtJjBSK+qi7eC3f2bsBztiK0EiIeM//901G814AJoxmqgoQF3h5N7Ooi
2lNv4vxIxPcor9u/tPEG3By2SfcsYe7nSsm3fjSgaJfjjkIiH+h7L24/INuI
HsPx548T+cJazv8rcaIRP57jKg8j8mmoR/6jwMVGfCQ8495F5FsaF18nd2wj
SoUfstpD5GPin/Y83pJG7Je46GlG5Gv1AwtbQWxEvv1HvvoR+TyqeDXt6NdG
XJOZu0gh8v/F33Opg0ZN2Caxs2mAqA9XpssnxV2aME1Dz6vqGhOE8oZGfWOa
UITkeCKYqCfd+h13T3U0YeBe6YGtRP2RLa6b36nYjKsccje9NWOC4OvIU3Va
zXjHKdMgkKhfe18pz4BtM/4htVhvMWWCiY3MjFNuM/rHrnwvZ0TEV5hcuOD6
FnTc9Cb7sw4TTuwY//NItgWtHA/Xn9VmQjKHxNVEjRY0vPXjZg5RPxunTBni
vi34pXJfsvxpJhgUx7hHzLagelGi9FuiHlPTAzUv9bfiijCrMMpeJrj78gQ7
fmjFa+lOl8N2E/GxR2g0lL0NBQK+OerJE/07via943AbGj69wdsrQ9Sf37ef
eFa3obeIdNl5ESL/EsX1Ou+2476CqwkUYr4xXG94SqyqHaMs7Su+czCh37zH
NqinHS+I9sXvZWdCtNmTGb2ViJWxW6oi/jJgQfCBjLArYuKH8JsP5hlg9T2X
nbyLjooTqbHho8R8L/5SgOsgHet5u8McnjLgd3dI8DVNOs5zF0mde8wAncwz
JkJX6Hj9rvexT/0M+HiHyp+aQkf/9DLLfmTA9u1VV7tXMpBNb8vPr4VEezwd
HXt5GZgqOL2sm8eA7jxOzqztDJzJUbtQnMWA0pMxO26rMtDgkNnq/ckMKKM1
Fe51YGD0BcfSz8R6YubX9LOuEQb6p25Y2WTNABflWyS19wwc0fyhFXWFAekn
MqdrFxioImVfct6cAXt0L13MXM/Emaz9zj2GDDidOXf69kkmLl788PaUOgPs
Ap0iFUhMzEw3DU4k1kuJHH17nMI70P4iX9FBYn3luFl5+U9yB0aS5z+59BDr
v/cTz6OLOvDI/ND2XCYdvu/5k1/E6EAnE6EtI/V0uHNo4VXP7w7sPA//OnKI
9dvKo6UPnTrx5OfAQX97Oszunr/pZ9yF1RxPHz/9ixCdNoZPrLrQv90i0vkL
gt5hYxc51y5cUSDNt/AG4eZBH3Lf3S4cRUtPcidCskw532xPF+564LRVKBLB
2LhuZ6paN0p8OvoynAdhDIZddm27j3e+t7W0s7dDgvLlqw933sdo78QTzQtt
MHbu0ifn/ffRTXTHfM5EG2jtOZBcpH8fNficOyXobUBT1fQZDr+PRf7967Z5
EfuDzxarzyzcRxftL6Y43QpduafWbe7uwfKlXWOvGlpA1LDmCe/jHpRR/Xv/
X2ELkAzDD6963YNr+TU+rY1vAZO+8bynSz1Yyqs58/R6CwSZfvyuoPAAD4W2
c1/d3AK/tXouxic+wDshr64dcGoGUhqfTK1JL2qeovzm5GuCw2o9FZ+u9qJS
7cTh178awWkmmiXp2IsPBDg0Ct81Qk+ndpdPSC8+12jtmmtuhImTe98MkXpR
4VG2fqFVIwRSFZ+wr+3DWO1t2t7UBjBe6VWgQOrDQJdry7s062E7dbDOurkP
L3933lq5ux70N32tvNfZhxm2Otu3bqmHE1VX5J6N9KHOLhHO1ikavJAQeTK7
oh+Lf1a0y0fQ4GJusaCubj++136o29pFhTmhcKXEyX58evyL6VdlCrzQnX6q
87kf52/ZKG7fSoHWLP+xvz/60fJgUrfyMhneGgi1H+AeQIflrx6ynWRQtvRQ
3Kg4gGd+sGsqGpCB7nXtvrbXAA6ZsN/ocqiDDSyrpweCB5DFPcLTrVcHTtOT
GptjBnDXm+YBqnIdVPbWrS3LHsDg1QJ/Li2RoCThsIsUfQChraxpLJgEN+zo
hV5sgxixOSDmxK5a2Jg7XhDCNYhCbF/EROZqoGVdwKaAjYO4Oqpq3Si5BrhH
N/CdEx/EKd/x+k8HayBwl+rMnuODmBGsdjJNsxpMG0fYZX0G8eAhZq64WSWo
vnyXoB48iLzFjw7wbK8ENzV2mk7UIFpKDBWOvayALXE5kfvTBtGZ492YyJUK
MNuRxXGOQrSnq6xrYFMOYn1qt3zeD+Lu+WCX/Jul0BvTs115dhD3e+zK3LC3
FO5aSlY//zqIL7TKS24ulsA2Wxkztj+DmD6xS3ncpwTCev+9K9rIwtlL/K+Y
McXgHTqxXvUQC19vGRZrKiuEgjcvp9YcY2GN7eTR1zcLIcaFuq33JAvrw06l
Lu4uhDMr9rqJ67CQO4n27B21ANpy/64Xv8zCZZFPdV8wHx42edkbB7JQ85Nc
ALk4FzQaum8cDGXhh/YLb1/I5sK7FRe0eSJZeKli89MP1TnwzPFGdXg8C48b
th8upWWDQegJse4cFpIYWhO9HZmQlbQjb08BC712CyetP5UJMn+/PY4sZmGa
DTlAtTcDsu42qPNVsfCgXshntYfpIPfcqdyqkYXK71btEnieCgV796kYtLDQ
L0Ty6V3zVBBTmjyr1M7CyZ2ffBdepcB3m+srmB0slBe9UXZnMhlck0/xyQyy
cN7wZFPAbBJUObFdT3/Iwu3VvGl6jkngXcAjsfyIhTL749V5viQCn1NTc+Iz
Fl63XJzVWUiAL1p1v1e9ZmHDt2f8bPN3wcb8gOXcGxaWpRbtDFmKAxTLK+l7
y8I57sa2DyviIILZM2w8xUIRRsZmc94YIBkU0lZPszDhZA7JcXM0XBdKdCye
YSFZXsvDRjgKmp3mzRs+sfBpsuyxdbsi4GOLxl3ZORbq8DG3tiqGw9SAc1zM
Fxa6vR1iGR0Ig49G0p8kF4j+K38Sc1YjBF5MXDxttshC5sUtDqXngkHtNtoG
fGPhnuc2r7/qB8HKVb5fc36wcM2utaoGFgEwGq1lnPqThcPMO7PPevwgQ13F
M2CJhW8PeayYHfYBuVt1pma/WPix5n7Y5Gsv4H5kuCD5m4XTpOuXOmY9QCWl
/9RrwlPX8iyifrpDkNMrw5hlFlZd/G13iP02jCY4CMr+YeHGwKOWI7yuUNno
fK+e8LEFG8Fr21xAa9dy576/LGQ9PjXXrO0ILfTDFYWEr8gUkhKt7IDtrYf6
qn8sdJyaUtb3toFziXzxBoQ1A6/t/5VwFS5e9717j3DBqiMfxfXNoT/5/PFu
wvWZRRYqfkbw8NPh4g+E2628Q22Mz0HQS7aW34Snxtl04i+rwjOXkKB/hD2L
LfZw14qipEnL7wXC3o8Xd67JUsdDo83So4S373/Pz5Ovj5xva1fVEk6NkG9c
7XYBf/55nXibcKSv6krXwstI06sZlie8ez3n4ccxVlianfBgmPieyyunB0Xd
bZH7uMgtB8LOTjeXDS3t0Xv3StZ3oj++XCYHq0o6o/TnFW+cCcf+8RSkbb2F
Zel/yp4T/bnbT/OKGI8b2o58kVEl7HB1pa/XSneMev7JIpjo/7OjPXHt3+5g
+AUxXToxXl9fLTZ+nPbEVcIWl9cR4/n3lNCbpSFfNDx8LGQbMd4eVRulnnX5
4w0/ruvbiHh4M9vC0fciAK8P7HD+RMTPwRbvatOHQei7xJeBRHwpNBixr+4N
RtodxaigeSLeyOzuOR0h+G3r1a4xIj7/nClcvFcfhl6k1/zOn1l4lcdP5ktt
OA442yt/nyXqiQwnY195BApD9tQwEf+55dnu7plRGE/zufNigoXBZHNRpl8c
jvx4en+QyK8nmkmXrWLuotfav/q140R+fRUv+qoVj4+mb0keGmNh3r65PQfN
EjAih3LUj8jf9T2NsWOuSXhMC0YnBoh4iExY5vmVhPVmcY9U+ljYge2CuwLu
4Qam2/eSLhaeOVawYUdMMv5wLMmub2LhPzf69GRBKganFt2Pq2dhSX9Ei9HO
NNzc2ulrRGHhQlNMWWV1GsaPxJbWEPVIa+pBPHtjOtoUGpfFE/Vs/IzQE7O+
TFzaOhEg6E/k/08Tte2zubj/6vP8l17E+8j19A2o5uGxU1zMeHeifuhnpXh7
5qHE7i1inQ4sTF5Hupm3nIcpSt9PXb7IwuJY5+g1bAVoc5iP212ZhaZ5p6X4
OItwxFryyO7dLHx4QjQ54UwRcnpLrHi6k4VZ35KnliOLkHrlxJVFYaK++dzf
Hc9VjOhVR3JYw8JM0qbdBVwlmC9dN3Hx2SC+LWvcepijDL+P6Iv6DQ1i99nb
H9YeL0Pf0r6CxL5B/GJ3mwO9y3DbQ8eiRBxE3au3rr//UoZpe8Lz50oG0Tbr
yZXtY+W4r9xGVdp1EE3sLkv+Lq3EPr5efxf7QXzvx71T800larYM1NZaD6La
WKTfHaEqVOfW/MpuOogTtr0OMTFVWLLoLcN/mJjv0tVsvZyqsTrx8QrWykGU
+mtw9NjeWvzotP6N9q8BlLhxKOf59VoU69Mwo88P4GZBixSz3FoMt1yrGfB2
AI3y2YxWriFhlq7rWYfOAbx4xN/ttxsJY9d9c+QIGcCbdsH+0jp1mN4l+CHq
Vz9+CjmyfniRjNffV/k8/tKPk4eyXV7zUfDKhLge71Q/kn8ftR+Vp+Ah8d/f
Lj/ux/oRoyfxVhTcmM3kdazsx9IPQSc3PaZgl5C30tEL/eiiPlljVEXFm9GM
JwpVfbh2q4ukoW49npxqF/6X14fCCiLJLNt6VCuo6elK7kOyLslZJage7w2S
Y5X9+/CrWepeOrUeDfR1GIn6fWj9UtPkIbHPtXlRdtxpsRdD2CrWPHzRgNFb
HAu3K/eiqmdM/h+DJuzmf+DyXboXWxVyT2rYNaHP0DPpHqFeXD0+1eMe0ITX
On+FG7AR60fh7yapVU1oclbpF/fQA4wn9w8MrGrGPnVN5Y0OD3A7+1wqV00z
/m7SeDCV24Pw8WNo3tcWLK3kvTee2IOVVdP2gqtbsUZDzYgV2oNyCSk53ltb
MX9a7nfOzR7sO7N+7PfRVlz4tCv15/4eZNcKC/oY1YoVNM9Vhf330c/jVH6Y
SBu+TtQMP7HYjd5+iexV+9pRFtcZBk11o1zn+ZA9J9vx7sKjhPaxbrSqjzqT
a9COwbuX4uUZ3Uh5XFKlfqsdhwrXf3kV240Kma/582qI+4edymqku/HU8r2G
cgnEGzpcH44Q+4vdqzZf3vIP8ZMmNouf6cLom31l/Bx0tOi0uLX6cBeOVef8
TlpHx6XZa62dYl0oEnC06bYgHZcrwz/t+tSJ8x5DY11KdLzhLa9cEtyJn/ed
5Mq8RscA8xNlSbUdeNyxKEGhnY7S+lsN5PI70Gvv0O1fHXT85Si+jp7YgQVl
Ey6tD+h42ENn7MPtDmw71Ngh+oSO4mY7jioe7sCLi+E6Vh/pOLldo7K0h4kr
4x5ITAswcPvSg/f7mpnIF6HbwLmN2PfNFswxKpmYr3egVnQHA4dwberzOCYm
1Ca+3iXHwARBU8/1Rky8ufLdaNcRBt63GAKfNwwsIJl0sV9jYI9sbQz3YwbW
cR7Z5HedgVfUxo0zOxmo01gm9OkmA41Gt8W2ljJQge2KfZUbA1PsVAo5HBn4
R/FrIymU2JeKqhoxf9GxhRb/c7iYgTtSDKnbBOgozGdqSBtn4LS5iSVjDR07
Pg7pNxPPrb8Zzz60iJjhs/yvfpLY5zJ/p7ojYnQ3JSh1hoGbjopfmTJEdJTx
JX37xsD5xxP6NwPa0eLwjPwubiY2lJ/mmrVux5+PA7KqeZgomvY6wvlcO+qn
HeHdycfEpEsnuEM3t2NMouCm1QJM7HlsHvSyqg2nbl6QuSzCRPnavNfGY62o
O/ZENHcPEzunoV2Q3oo27niwSJHop6Fx8TfFrfgm41JlvjIT2XRdanxdWnGF
HGdlqCoTVd/gmrm1rbg1a6hu/igTx+s6jZ99bsHIgkWRlmNMtOS1DO0cbkFP
7tT1PieYuD5pe1V1XgseN3oUNaXBxJTUAc3WAy0ofSYt1lqLiRH1os39Ii0Y
GypVPK/NxHXVcZcn2FtQO1jFzkOXiVQ1HifhoWaMG7Hb6HieiQp3zpQ9vtGM
xs+Fb7GZMtE05kHver1mTDxBijG6QDyv+6+j7v5mFJCe9s83Y+Lvr1ZX37A1
4/dN71ZLmjOx98jS0umsJjTllJUZvsJEiiy7rFJwE9YtnhCdvkp8P0/E9A6i
TrDnDV/+cY2JS/yOx3gPNKHwX+rwP2smjkwLye8dbsTCwHoexg0mpmYMDmi2
NKL66PNXeXZE+8elT1wraERHNhFJr5tM3PpGgFnt3Ihfxk9uEXRgokBR/vdI
nkb83bJ5P6cz0Z/8KasfLjZg8UlRGRphasFOye1EHbvmyyKbuTDxZZVDdXdF
A+4XvVKTeIuJlaEZ0lKJDbjiqflOKVcmPjQx64/0bECeBwf06whHyz5rsj7d
gNdzGjrq3Zi4MSiO9+WeBkyJd96y9zYT+0sGqs22NKDcQ8XdhYSrNO0yx//W
45f6VTx87sT4XJV7Zfu+nlhvfGp0Jzxn3um/NFCPcOT7/meEFXlfBcfTiDr9
TDxG8Q4TneInHw6F1KOX/BLrMeGzEyxpH/t6jOwu69nmwURB3iO/5A3riTyJ
qDInvEU6TH/yUD02OqYGpBN25PmuVCBRj4rdT86wCI8l9hTZcNfjTr7jPP8I
2/vIVSsu0DCH4ylrpycTldIPnl/1nIbnFOJTtAh/G2LPeM6koXbfDRs7wh8P
xkQ1V9Dw3eTFk0GEPUQZsnmJNFRXsVC599/17WG+MV40tNp5/Wjef+3J1kb7
X6Xhj+GbViWEC8pWmnmepeGV75ZV/5nsu++zpxIN+9+rbMsn3Cr4RTtQiIaH
0sdpyYSbYwf97rLR8EHSmcAQwlyZF8OKZqjEOswqyIGwXCe/Hf0RFY32C7fr
EfY0v7HnbTMVT6aYH9z93/tnNz9fV0jFpQLepdWEl2svuh2JpmKd/Ta2EeL7
2ZkJf91cqbjj9vULRYRNt9zzp1yk4sqKkVU3CT/aGrP8U52K/ZbnOeQJp1gn
e2nIU/G2Vr31FDEe99+2/U3jp6Ji0KR0NuH9Q6vjFpYpqGPXoqNNeNuwpYLR
OwrK0bdM/CDGl8ld96ZtgIKiMcPvsggriQ3VKtRT8K5In8Vhwldy0qvEwyl4
RILZYUfEz5nW+5QyBwp+kd4wNkfEW9qe3wqqhhS08tgc6Ej4zlBHooMYBd8x
xtJNifiMrxuOEFhLwW0N41s6iXhe5zOxtvszGTvei4Ms4fpombZjrWQ8cXY0
/zWRD3m/zy1zFZLxSIj3tBLh5Rennr+MJCPPz7Z5Pycmir1/FZttQsaNT62v
sjsyMTgk0Ch0oQ7v6blbdhH52JXVL5E8Vod6ElfN3xP5uoll3VzNqEP+dXLa
KwkftfQ1WLpbh6V0FSGp60x8NR9U/0u+Do2/zfJJEflvN/XttD5/HebP+p7c
TNQHZ8NVPaTfJFSfs09fSdQPq843WVG9JDSMnm3vtmDiguwMf4UtCU+c8Mji
JuqP65px/9N6JFyzRcB/kKhXh2bbf8ypkvBQ6EBdtAkTh09rC5sR67JdaRSR
b4ZMfHL751lV7VpcX3C3IYSof1bFs/rVA9X4LDZ2MlOdiY81K3h4c6pRSlnU
g4Oor78n5XWCHavxR9rT+ptE/S0fMncr5K3GlB42LekjTCQlR88xz1chp3Kh
86X9RPxzsG0LflGBUyH8t4ZkmHjMNyhuV10F/ozU3cklzcSnem+tJ0Mr8Eit
WdhRSSaGJORoh++pQFKx5rmMHUR8bTU3Swwux061PBcRQWL8B6p+4u4yXNOQ
+eUSJxMdMub4ndnL0OjYX5nza5j4Zegsc+9YKWrEhpxTX81Enzuqo29DSzHe
sfa64Eom5h5jKG0YL8GkT522yT8ZuFPws0pUQjFCxLD0w/cM5LmZo33Sthgn
UuJ4w4j5skeoYyMvFCMX35zUgQkGjleZVzydLcIMrryP8S8ZKLHlxO7dxLr/
ySLXWYFhBtoO6xv+Yy/Ez1ovO+zpDJS9opuhEJmHzaPcmS4pDLztr3eeapGH
XPNA8kxiIOfdL2SdfXm4VWXumW88MR/vSXjmg7mYUazh4hXFwLTdw3qbnHJw
8+s8LQ0/BjqX317OepKJMnNhuVLWxHqg4bQYHz0FVd1byHv2MrBIe/n4KucU
TJjs72LKMxBsrhsL70hBJ3ZOj/OyDCx5H3OqOyAZOxgJvdfFGYhdLxgz6vfw
e9yKTDt+Bk4Gyvh7DiXgRuus28M/6Gi94XEW56YobPR5U2XYSseRRXbP6LBI
VFXbqNzZSMdzwgrzur8isANU9inS6FjN7hedNxGOLWdPU1bV0BFP86y2rA/F
CAvmj6hcOg4uJgto2gWisMtfWakgOio6u11Hjlu4bjhfMkuDjgdbixJoYvaw
5jxPmnEM4jbD+vG1nI7w48yz7adDEEf618jYzTmB2YeIDft9EAWo7x5XvnCB
nULal9bYI/oOXKLO592GK/Vr5/3PIc60bzjItskXZLtd3/VzIi76SBmtYYWC
c8yU+kJwO3qZp/YOPUmAvWL9bLpObcjoVqJ/500EDumgA23Wbbi32Sf715lE
mKjKvrbzUhseyr14OLeN8D3rym+n2/CUqs9p88IkuB5F97QXb0MhKduoettk
aFcI7BocbsXnzy1DFJ6nwc4IZkOQaiu+HbT9Un0lF/z2nCn1/daMUd97dsTF
58Invz3M7x+b8atp308DzIWW+kdrHSeasUpO7+rp9XlAb+6QMGE14wXFx++n
7PJgQ8zQyKbyZnzCahmhieVDuclTz4OXmtHr6CXb6tACcG5sYmkymnBCY9l0
7c5i6DXmuzwT1oh/HU4KrzpaDCVvTZ7L+zSiTtWp1jmDYkik3n7u4NKICzeL
8nL8i8Eiisft48VGvHdMK9vgaTFs3P3h7JO9jQhbnfaJBpZApJpPifVYA+rm
Pnt5tb8U+E8qyUbKN+BgjvFyp1oF7DSMlz8/QMMXGwz/cGpXgH5x2ogXMW8u
nn+Rd8KyAq5On04raKBhSOqFibjgCtj37cCFuXwa2nAIPkrqq4D6a7/X+7nT
0JXD9rbBhUrgn66rdRGl4RzZ/dGDm1WgqNDs1+pMxYYzClzRDjWgPmCmsmcD
MW9QZKSfeNfAx9oPq99zUJDLx8lNIKoG4oQEjbOWyegTKkXzKKmB8JYtnms+
kDGk55ZE73gNTL4/8vZZOxmTz1y7m6ldC61Onhuu2pNRdYNk3JqNJOD9XflS
7H4dXjgaJus6RgKF9S9Cvb1J2OTSG/TxNQmUPKzzDjiT0EHheozFFAnwwX2L
b1YkzLUYbdi3SILOBNNeBx0SXlfNyc/nqYNUuoyrmRgJxdqFtfyhDsL3f7h9
Kq4WbxhLbjDOrYP2ViHqd8kabHH9FjmgS4YwzcrfPXqVeDJfUqTUkAw6+fyh
+Ycq0ShcxN7nAhke9sY3eEpX4s99SmpC18jAHr9jm+xyBfZ7j6O4OxmU/r5Z
CC6twAPdUu62mWRoXJLMl/tbjmfFbwUMTpAh9+6R08cry5Al1RcuNkWGclTx
4kspQ1nvlQ7OH8lAynN1eBVQhqusNJ6sXCRDy3W7DB/jMpwNqVZbYKcA80/e
DurKMqLujhzfIE2BXben7bealuLdWyGGx60pwH2u8mAzewl+1yZP/7WlwOGq
o3Gf5orx6AyzqNGeAhPXWht3PC/Gh5Kb43e4UaD/gG1CWF0xTt3abMgMooDd
8QkLPYtifKYiZKCTS4FsP5FHLxqK8EMrD3fcEwo4zL2RfGFXiNpFF9kejVDg
iY+QALdxITKvSqltfEEBnntzHw4eL8SmOXXH8AkKDBl8OJy6pRBLinf8PTlH
gftPlfL0Ogvw2n5ea561VEihWxa0Cxdg2qnL10f2U+FBvOCLyId5eF5svnDi
IBVCaBI/vjTlYclDjcQPh6mweXh42aQwD2VeJodPnaDC2q0xD6Tc8/BG/bnZ
Oh0qqFxsdKFvy8M37Y1GntZUUPU2jZocyEEhsTMyI3epcEHYZOO9X5lomxot
a5ZIhblfZRIWA5lYsura92f3qPDLsWP7zrxMDKJkznenUyHVcHdPi0YmXjji
H3GrkAonayP5JuIzkN8iir6ingpmx1ruy8mko1jChpE/z6hw44ZDWK1BCoot
KN8dGaVC1rsGH1/ZFPxVW11d+5wKko2Otuf+JWO6qKu4wSsqGP/YKDZVkYx6
30t/OL6nQl9strAIWzJma8+Qfi1QYdaU0y2KlIQPk1M2ZH2jwsGR6OcmYUm4
Y5fV64M/qOA1MnpI6lIS/tzx44HdLypMOSRO4Zok/FT49Fn+Cho01Vt+WbRI
xLp1bkrW62hAj9k9a86TgK/PtRYM8NBApyl9Ue5tPDo484Ur8dLAydLy54/G
eBwtO1D9dQMNAtVD5hOs4jFu3biHxhYa5LypuBF95y7+0tI1UhejEfVweuuF
4RiM8TBTcBWnAeVyHXnePwaLpP38ciVo4M3xQTNmVwzafVeO/SRFg3hPK0sM
ikb3e7usLOVoUFZQZySlGIUG/9buy1CiwW3rbp8vseGYSZrUrlGmgcT55zON
e8JRufnlmvZ9NPBcUjEKHArDMbqL+cP9NDjj4ii6USAMhW+8SKWr0cB63CtO
OSsEA/7ZtNQdooHNM+O3v4+E4CuxgMCcwzQ4FNmo0vkqGD3MfL/bHaVBCMe9
x4YSwXjQaF806zgNPkdt+XG7IhDZjAd6s0/Q4I5XyqGjWoG4Z4Gv9ro6DXoX
I/04Pgdg6ECMzeeTNHjhvndFqmIATqq1p94/RYPNkePTTi6+aFm4fZXraRpU
UrZZrqD54M+2WX6hMzTwP5f8KP6nN5KuVMlfPEuD0bgOap2/FyqkTCmWaxHX
fxvdWIi9g35c254qatNgN9vA4+AhdzzvqCReT7jhwpUj/ALuqL1URa7ToUFm
qsp6lSw3JPdd+rFTlwarpzNvd71yRdnJyMlMwj897F8YSbiicu37Rjc9Gshq
Rpe5V7jgL3fTvDG9/85jfOdZ89kZ9Wr79h7Wp0HpSXbXVEVn1OaV154nbG7h
7OHs4oAWDXqjmudp8Id38ljCz5v46eG79amEnS/OrSX72+GGQYa7nAENVqVy
pi3EXkezHJVyB8I/PitZ8gvYYFaTa2jVf361U1olywqPnr7LPUU4gu3brJHE
NTTZkXFI2JAGc2W5FPeKK1jeVSSg+9/5kG97vFIVL2PFjfZ0H8I8700CnV3M
MeHj4v1iwuVGiuvJ/maoNWKY10tYyWcxYyHWBGPtpsU/EvZcLJVRyTLE3qhW
3TX/nU95q0d1r9DHY6yn0qKEt5u8J9rTxl/eUKZE2F9WInMh9hT2By0/Pk6Y
a+kicf9xvBi8sUKL8GoBaeK6Kor0hcj9d17mKfxnGfz/8zRcD7s+K0Xcaf0f
WiLySg==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2726032228357411`, -0.5498301510901976}]}, 
                    LineBox[{{0, 
                    0}, {-1.2726032228357411`, -0.5498301510901976}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.21210053713929006, -0.09163835851503288}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.21210053713929006`, 0.09163835851503288}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.060502685696451, -0.45819179257516474`}]}, 
                    LineBox[{{0.21210053713929006`, 
                    0.09163835851503288}, {-1.060502685696451, \
-0.45819179257516474`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 69->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2428823312833868`, -0.579736475823473}]}, 
                    LineBox[{{0, 
                    0}, {-1.2428823312833868`, -0.579736475823473}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.20714705521389784, -0.09662274597057885}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.20714705521389784`, 0.09662274597057885}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.035735276069489, -0.48311372985289414`}]}, 
                    LineBox[{{0.20714705521389784`, 
                    0.09662274597057885}, {-1.035735276069489, \
-0.48311372985289414`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 70->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.2112591683265985`, -0.6087551203920312}]}, 
                    LineBox[{{0, 
                    0}, {-1.2112591683265985`, -0.6087551203920312}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.20187652805443304, -0.10145918673200517}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.20187652805443304`, 0.10145918673200517`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.0093826402721655`, -0.507295933660026}]}, 
                    LineBox[{{0.20187652805443304`, 
                    0.10145918673200517`}, {-1.0093826402721655`, \
-0.507295933660026}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 71->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.1777165159761107`, -0.6368086392158177}]}, 
                    LineBox[{{0, 
                    0}, {-1.1777165159761107`, -0.6368086392158177}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.1962860859960185, -0.1061347732026363}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.1962860859960185, 0.1061347732026363}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.9814304299800922, -0.5306738660131813}]}, 
                    LineBox[{{0.1962860859960185, 
                    0.1061347732026363}, {-0.9814304299800922, \
-0.5306738660131813}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 72->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.1422365237470864`, -0.6638141198211617}]}, 
                    LineBox[{{0, 
                    0}, {-1.1422365237470864`, -0.6638141198211617}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.19037275395784775, -0.11063568663686028}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.19037275395784775`, 0.11063568663686028`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.9518637697892387, -0.5531784331843014}]}, 
                    LineBox[{{0.19037275395784775`, 
                    0.11063568663686028`}, {-0.9518637697892387, \
-0.5531784331843014}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 73->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.10480085912428, -0.6896824926021391}]}, 
                    LineBox[{{0, 
                    0}, {-1.10480085912428, -0.6896824926021391}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.1841334765207133, -0.11494708210035652}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.1841334765207133, 0.11494708210035652`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.9206673826035666, -0.5747354105017826}]}, 
                    LineBox[{{0.1841334765207133, 
                    0.11494708210035652`}, {-0.9206673826035666, \
-0.5747354105017826}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 74->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.0653909050698913`, -0.7143177467683319}]}, 
                    LineBox[{{0, 
                    0}, {-1.0653909050698913`, -0.7143177467683319}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.17756515084498187, -0.11905295779472197}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.17756515084498187`, 0.11905295779472197`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.8878257542249095, -0.59526478897361}]}, 
                    LineBox[{{0.17756515084498187`, 
                    0.11905295779472197`}, {-0.8878257542249095, \
-0.59526478897361}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 75->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-1.0239880181440053`, -0.7376160367231301}]}, 
                    LineBox[{{0, 
                    0}, {-1.0239880181440053`, -0.7376160367231301}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.17066466969066746, -0.12293600612052162}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW
LJGOfc/OmLEzi+yMKFLv9/c+7zv/zPN55nvvfOfec8498zwzO4ysLt1jWbVq
1RHWVav+e0793wcFVv3f4+GbgWcphOsLvOqdLpwDapELazzhV2H/WR+qQj3l
wwkPVI6QoouNQcZtituHcJKHJ/H6Q0irKQq1J+wt/+ZWho01nMkZqbtJ+NxQ
D3G9HdjZG6cqEo5pE9fxY3cEniMHFbYT5lA1IsY/BSteTevljxS4/DJMxSzC
BTT546+0EZZ8bEDM9wxqju9jJBLOr6eKJgl5gNUTqqQd4RsfDIj5PeFgbuGG
U4RTSyqCQ257wY1vMYkshBOWeS/6sb+AeYPbHc9SKLBVW7vW6cJLqNffanmM
sGCJ7HO7+VfQ8DsjdzKZAtfpJDCL8IcwvUWls4Ql8w7cyLB5Awr8vi9nPlDA
JDHs6G7VQPhwL9o1mPCicZ1gklAQaO+feNCYRIGugCfN0cXBcOjwr1tGhEdr
aGnCr0Pg8LjkqvlECghfW3kRcjsUosftVDgJ/9RnBT/2cOAqyqtniadAMJ0r
2elCJFRKRgs5vKeA/Mknbos7ooC3O3M9LY4CZl0S1+zmoyCRXL+QF0uB7CI6
q1lEDMg//vZNIoYCARqW0hk2ceD0ZfqafTQF8NJTnnFKHDy/LBhZGkUBuYCG
RWnV95D0xl/4fCQFwvvYKhOF4kGxcufvfeEUOH50q050cQKI9Cx03AyjgPL3
hAMUyUTIrgA971AKZF4a4xF+nQgjcg8vNwZTQNzDtCH4dhLsPbVbTPINBXz+
Ncq+Yk8Gk32CJSw+xPpwSgQ9uZAKa9jkj7d7UyCscI9XYFkqLCxrhb/zosDg
0XL7jwfTYP7b9hkpTwpwd41rkDelA4eJLN+iCwWkh4bw6GAGGPbPlMfbUqAt
2/SmU2EWHPrygH+HDTE+Xnbfi9kssBJJOxVpRYFJS5s/QXuyYbqhSczFnAJb
vjD8U6Oz4eSO5X9sJhRYl230jPwsB5I/Xx/eokcB9ag+1yNnPwPjGzlc4yoF
xs2D2JU9PkNcpsM2q8sUMNTn9tYq/gwmIqPx6RcpwPz5zO6ubB60iTqb/dCg
wHZhraVA3nwQ0hb3Mj1KAQsRmsc4uQDqJoQj3fgp0FPQHRb2sBgiSjmz9/FS
4GiLsiw5thhqUqvlyRsoQNG+kL+5sxheVJ6x385JgYs7+WPj4CsUiff2O66i
AHVUv/yjQAnECvysOztBhtK1Zmxfvn2D1pPUx49KyXBa0ObhXY4yyB89k/Om
hAw2LtPebJJl0FASo5RcRIZTN1+GJZ4uA+VIBcPqz2SQ/7b1NdWuDP5u8nVv
TCEDy1QXybi/DPZtXvqyGEAGUHkZZZhbDiOZLxwr9ckQGH989KxBJbQXGz7R
v0aG+ZQiBSPHSrgfyccY1yVDWi3D5mlgJUSaf2NZrUUGI61fialVlXAgZlRi
/jQZWmR8/3Dsq4IHbWUXVnaQodFVXKLybxU4jn6WCqV2w4czZ1Ml4mqgU0Bm
IWywGzb/jo48WlQDRkd5hUJ6u+HNFQ1TrY4aUPh3RfFZRzdkLZNiHdbVAtks
VmJ7ZTec3P7nbo11LTg3O2q4xHeDZXMN9Y5SHfCwJY8l3eiGv3r6exyH64E3
+eLvtKvdcHDVounXv/WwVO56M12nG8gjty1Xb24Au/Ja0egz3aAU/7r8pW4D
cN2+dUHhYDfMP3jtEVnZAAezC6/c4OiG93UCGRkfGuH30h2LC9kkuO2b8zH6
YRNMbx06HTDdBaKL38/n/moBewWLcL8fXZBZF7yHwt4KFbopH56PdIHen6C2
VfytcNf4/MhdUhc09Um6acm2guWqiTTaty7oZ887Qb3TCq2CjjIMvy7gsbpU
u6ahFQxc6nYPSHbB1IHu3Vti2mDgl8LRs6qdcKSKy/KuYgdc2Z9pf/ZkJwyz
XrEI1O4AbW5crXKoE64vmf8pudkBNO8YNnHJTjigt1gl+KQDDinfswhg7QS3
q+E/MLsD/PV2VEuVdcDY9YPeK+KdABpuPPsVOmAyJ0FLiL0L7L3tZQ9saAcl
iyzrJzUk0DCalI5ja4eTbI3Z0EmChO0NIuuW20CbaXGMfYQEGz8+bi1ntEFi
tpPQ678k+P0v4uJIaRvIh5f3hx3uhpHRFI0mmzZw+lWi55nQDcIjUvHHmlrh
3gfBf19dyVDIX09vtG4BuSGKva58D8wWCMVLm7SA3wjd+efpHogxm05wudEC
lulJHmGaPbD3aZ4Nv3oLCGQ9ftZ5twemEkznJkVbYG1SguCZ8B54J8FBKvRu
hmst27YvLveAm2jv0S1bm+CoVvd618peGLxhLWYt3gBXLOdYi3T6gbZDOe3V
2gboN79TLGTYD9cMb0yGTtTDi/ynGTbm/aCaaWvnkF8PExfbD4u/6AcxCYF6
k7P18NH0oqfF137YQnPM+mtWB+n1tHupOwfgUWfI/Z6EGtiZt0cg+fcATH8P
3VXeWwHJqj4CDo2DYLF+5q0ZVkBW0yCxLINQddzSli2+AvS/exiZdw+CgvcT
dbb7FbDO6s+GW9RB2Fol3HxiphyOcNRrHfwzCKXn85S9/pWBhIk9NUFmCOKT
eiL0eEvB5f11kUDfIRAwMl9vtboQ+BR2th1QGgYTvo2/zbEALmWtiHxRH4Ym
qYl9Gi4F8Orih5bT54ch0uz+ubBf+dDvLOqhdm0YphPOc7+ZzAO53X1FYDEM
LpayB2ZacqHxVesH2tth2P/7Q6fsUiZcPnRt7ejUMDw0uFOrY5EJJcZ8i0fn
h8HrsvVbWaKOV+fkbvD5PQzPSYlO66vSIdVGJn072wg8jphdufsqFW7I/bp5
QmQElqR+vbLk/AALFqIOAiojID15Qj8pPgKy8mJWq4aOACR1T3IavIWAN6wX
KyJHgGm0IaRUKBzkOjX5FeNGgKL+RmuzTwiUeX4dO5A2Ahd6L9F4q17DmpcU
p4XSEYivujx1r9sOnIqf8qyaGIHDwboWKqZvsG3g3vNloEJBdbbz8apAPME0
eyquRoUt2yweM3YEo5l2hZX6OSpknxZkGPeFouLiRw2vy1Q4993JdvxmFNpF
aav2P6BCdEyUiywkYPUR6b7fb6iwIbiodjIpE92e/XhZ1E+F+DM6f1h1P+Gx
I4pa0iNUKHWSrT+8KgvN/Hn+BjGokLouPXRTZhbWrY7dYjhDhfQbl0sruXIw
KfY0o3U1DUo96vQbmj5juCDj0VZJGhhuNo/OsyvC33Psw0dNaJCt8S/WuLkI
BcKv7zv1kAaPVB6InJApxufGRVOnLGkwwDH9zGSkGEc1rIoPOdBgYu/VxE9X
SjBzzp5v0YtGnKdfXdfuKEVeoV6RhkQa5L+95MUtVoG5D5PHgwZooHREbyFQ
pwIpt30DTEdosCSxi0XOuwI5I8bvn2DQgF9BcSpnugKvSJ2JbZmiwdY3nfuH
Kyox/dqgd+kKDYx9/Ab6ravxyLSFWLYoHcL9DbUnP1Tjq6T3F45upYNPPJ+h
QF81bkdzvaIddKj4wribfrYGayTiOjOl6VCTMTvPKlmL1uvUOvSO0CG61sPy
Yl8d9m6zeJZ2kQ53hvYnjwrUozZt9mSfLh3OiKjZRpyvx9SqnRYc14j3mzAq
VP1aj9KPj27UMaDD392bG8uiGxBzOJOjTemwNcZ0UdfoO9aqv3PZ5k4H14kA
dfuo7/jXPtH6pycdUmS5/qV3fEeWgKdWVd50eGU+FXP/TBM2sc490vWjw8Jn
zz2r9zVjR53z2M5wOsx4N44NurWg1j5vr6Q0Ovhbc65PjW5BlhKl99yZdBAL
F2h2/dKCYlsuh1tl0SH3kPp+TWYLOllL/tqeR4fTG7r5re63Yq7Kxvaj3+gg
GR/YNqjThiG/YgQUmulQmHLiq5FVG8rX6eQfa6VD5LTnphm/NhRSWVVzuJ0O
Aq8zBWRr23BFcVBElESHo3oLZXLQjqTrNZVB/XTQ4RS3vyzXgafTH4ueniDW
lxSX8kqrAx+KuJh3TNLBN5bG3WTWgeayYyXG03S4aCmiZ5/SgaTvfsoWc8T1
jc/uqot3YuyNf5wyv+gQq7QmokuxE6ni1m98ftPBykWUZGPYiWXTq3v7l+hw
2PKHfl10J27Si055tEKHgrU5P5Y3deErI5PzmiwMqKJVto8c6cKZvlwFS1YG
3DC6EdV1pQvZJ35k+rIxIHxNUFpvcBfmZWVKpK5hgGP06dHpnC604HrO92kt
A2ZsXoxxt3Vhk3azVfo6BrROSOx6yEPCyZB9em84GVDp2H85RY6ENn4WHQ5c
DMhuZZGb1SYh3n38/sp6BuxttWyK9yehbrQ4zx9uBtRssvfmyiChwZ62+IoN
DLh88FaLayMJd62xfOC5kQGmQlZ/n3N149KF+5bjPAxIY2uuW5DuxnmHFF8f
XgYE7+rKtFHvxtbMo+Vb+Rgg98kj08O9G9/aVtse4WdAiO6lEuHYbnyh7tpf
QBjcxZoKvnajc81vbXkBBlxfr9jH86sbl63DpfgEGWCneay5XpCMsf133BwJ
K6bbpPofJKP0G8WqTsLvul4/uK5DxpRjLLN7hRhgvizJus+KjFmWdn+cCXNh
vh2XPxknUm4NVRFuksjLnU0lY5u2X8TaTQx4bO/2dbCWjNZF5VuVCafvM37R
TSfjYcXqh48Iu05GcZPZKDh++Lrje8JUXV2NYXEKfv594nQ1YfbFuP3zihTc
/HvvlxHCzRovcYMhBVULR4d+Ezb1YJk64EJBKfLunHXCDIh9PfbZIIqCfeIf
JXgIq8zzcAd9Icb7iu3/z6mlB6abSBQMO3iy9b/rd9su6AosUDDGq3DVEjGf
1/DPg0YCPdgmpVr43/udPfD5RaF8D1awB8xWEdbNjD+zSacHyaZnPsQRvl65
zdzVqgf3zoq02BFWGnGYnPTvwZcx2Q+AcMzDwYp76T3o0VNgyvrf+BB3Bq2+
B1+97GhEYr2ot8wvWv7oQRX2zFf2hNkfxy78XduLpbt/xO4grLprTVv4zl5c
vrObtYbYjxtHH1OOqvWiZjrPp7uEu2lf1g4b9+JCAsQsEfvbWuGkE+zRi+O+
V2p8CH+OHRDeUNqLPKHpef5EPEhWunmR+nvRokbKgo3w9RPREykrvXhLYEHd
jognsurDF8Yn+rB/6O+ZY0S8hdk++Xhevw8NWEyM3hDx6P4P40896cOfAe5e
A0S8dkc1LRwp6MPJ4F2N94h4buLXAejqw8j73cPRRLx/D3Q7fuFnH953eDna
QOTD1B8bCe+D/RjCcTiZl8iXVc7n/qZf6kdq/3ldaSKfWJYX7/XY9KNaUmLH
EQ4GnOQWyNPO6sfJB+dOnSDycf7rlE9wcz+WTGRvOkDk6yZnh/KBqX4M9vTL
2MrOAK1vT0+/lh3AGvea2UEi/4P/bj2lnDaA6Xttd63+S9QH444Ys+8D+Ocq
9W34HzpsX6d+MWZ6AKVucvJLLtNhMz/ly3rRQYz7arVqG1F/jq39FP7l1iCq
aLzojpqlw8a9+Y1TVoOoq+mRMkTULxez23O73AfxeMweEJsi6nWs3lxSwiD2
zbjHPhqjQ0fw0/nm0UHU0LuuljpMB+mO1H6JpUFc9m0wjhkk6jX1iosT1xAy
tH+u8SbqZ9sbUuHhfUM43uVepEChgy5j07lOuyHU1VKY2UzU442reNO//BtC
t+SV+4Nf6WBqOcqrxjuMxW6vfu0qosOkQVZyu/gwigzmvLxbQAfF8URYUhtG
hqZq8NdsOqiUmEqZ+w2j8Ae5S4wkOkCUYA5FZATxXPGj7cR5M+8T0hgiM4Jm
jmuvfPYh6u9xF3edUyMox1j5fNKLDmF6VUFtt0dQ0EaMtMeVDkey+o7OJY9g
3rBptZMVHVaYNV7vjlCxhLJi/eMCHTLMLkedP0PFhGDH0XXn6fDl1727f65R
cXID97SYBh12sGyZvP2Eiop2kW+kFelACx0in/xKxT4MckQ5OohLXFtWUKYh
i6SYw9R6Oli25s7/uUTDP4YSf4zX0WFx3XmuCmMaJqj7fmpipUPLlU8PLnnR
ULo+y9tziQa8EimNzrU0nJg+q/OQ6CcSnlC1FrXpaLByRWkX0kCz9PXNOkM6
+gkfHpz4QoPT/CzUKGs6uu9bezH5M9GPGB2UVw6io6Sqqt/SRxqIeMhEBXXS
cdp2uFckhAaVdxrGj95k4KrSfZIKRL90uLZk+ZzpKKrbCnDXEv0VRy84uTiN
ooyhlenrJSoUxfW0ZfqPYqPlGqo6kwpzTs713DmjeG5ycMtrKhV0OWc2FS+N
ov2ujf/sq6kQ6s7dWvnqB3aYipfHvqBCUtHUmq3pYyhTeU9V/d8IpJ9uleP6
NoYbFHquqC+MgHFDGvfP5jEEKeExhckRqDqzOfYbcwwZpJ5X0xSiP7ZpF9h1
Yhy/9KldyMobgR9pfXMn68bx0OUzY/YPRqDlwlnthaEJ5Cy6enixfBjsFX89
ZWNO4BH/KNPLhUR/fytXmpttEpP5L19LyBiGrSe8i7h3TqIMZ7W+ENG/x1Vd
i6ozncSq5n+Mi+bDIJWar755ZhLv7Q8L38Q3DJ9fXA+IWpzCdc43RscvDcHO
HyIN7Wun0XH4b6+b+hD07P7IxSY8jV57NUPYjw/BHlehs+ePTmNNndkl+vYh
iNv3wf7J42lU5b92ZmVyEI7dLrI9tDiN9Tlmpz29iO8/hg8ff3eYQSGRuKfr
Lw/APcmSlx0uM/hXf/P5t8cGwMu2YDXp+QwejzojtH7bAPyJvLj8PWgGL1yT
KUj70Q/cMt/2embOYKE6+85Gl35o4QF2VtoMzmw32h75vg86Ff28tmjP4oCW
83I+qQcC9+8IcLs8iwsH/fuvFPUAX7rDeK/+LJayGEn0R/dACpfLU+/7s7gt
/x5X2p0eMO2SZw95Novf869MKYxR4K3nWuvA7Fm8dafSWGaRDB3WIYY9G+bw
3KW9nyZXdcOPVh31WYE5zNxYekqinwQ/ywI0/onOYf7ao4WKxSSwsG9xYN01
hy+c9pEOPiKB24nxW2mn51D0sHf4CqMLCva+i7Y2n8MqC7WKI3Wd8HD1Py9W
2zks36AduJjYCTTeT+P+jnNoH7F7dfyzTkjdasXu6zGHI+r6Jz8rdMKaniqT
TW/n0H+C70FrYge4K+t98CubQ4ENLeEcTu1gJtFAC6qew4urj3TaXmmH+bX7
179pmEOVrvHkGrl2+LCLa8yycw6zNmgGHaK2wX4no7mS0TlUDErcs+18Gxyx
W5sQwc1E1nvkhCvCraCUKneCk4+J0smeKj6zLfAiUfyAjRATRfONPqTUt0CT
MKuQ+DYmsks2a+Q6t4BCyA7qhv1MdJNYJTGKzTD/7W4N90UmfpmifvdV/w4r
11ZmY3WZqHR1YbXQn0YoLD5yfvc1JvLG6b7xzm4Envd6j3fcYuLpngUU3NII
Qf24MdmMiVL25DDmdD2YB2uZsngxsVvs7ENGUC2wZ4zNsPkwkewRo92tXguL
1Rd1/r5kovEDkZLspRrYu+qdT+cbJjYuxmttM6qBLgnDs4LRTCwyedA/IVcN
Oz43snZlMVGzQ/RNQE0FvJTfMqySy8QLm4Q37HlaAf5x1y6m5DHx8Z4mr+y9
FaBGu9N4uYiJyfMLXj6B5aAbXNdxooKJ3L+tvt/SLwOlmwKVBlVMXH9qbrPp
+jIgfXsi6VDDxK3PrLKMvpVC2ZdLe142MFEih69TUrwUlkZpP063E+vVX/mI
0loC994prhboZGJMUkYD81AJXI5tshzoYuIWuwcGM+FfQS9OUfE6hYkLJp5B
oQbFcL9k78PuQSbKPgxlxDEKocHrzqDhMBON3vJ/o54tBD+v0dC+ESZmqdiH
8KQXgCkt93MxnYmKjgdSxK3zQbBF24VlgolBv9doKS3mwq3jnlGHJ5lY228S
MXcjFzYJSmoYTjHx0dpgh8DSHAh5sqIaNsPEnMLt+yJ9s0FLwDswYZaJlDGj
fexTWeB2cfO95DkmTkXJcd2+lAUdXgWRQfNMPLd88GLz4UywDX31+8lPJt4J
mdsq8zcdPj1bQ762QKz3zWoVs+o0yPmpILC4yEQSP9f+mKsfoc7imEXhLyZm
yxtoBG5NAdWPjkrWv5m4FPhMz5L+AQZ3TF2tWCLu93A92+ijRLhPmg69tczE
SnI90/tUAsC5Ms0ZwhZSms/42eNBn2Hp+PgPE3W/n+x43RgH6qyCwouEJWLc
D87vioXBvoG95itM7HfWWEjPj4bsJK48EuFw+SK1c2qRsNOJ+unYXyZe2bHB
sak9HB7aVW8JIrwxq3TghFEobIwSWx4kfIfq1xkyEwT2v+6d2/mPidG/7mX2
uL6BIX8ZTiPCGkNDz6RE/cDyBufxEMJhd/5UPD7yAt7eziR/JawmvqY975IH
xMa0j/YQji/Xyi/vewrvBdTvzxJe2GrBv0rIBqzrhy6vEI4N87zz+agBSNUE
Zf8j/HBX1IrJdxV8JHTF5RdhvXXyzHWeD7Cy5lAh47/5KrbpX+RwQNqkltF3
wkWpCjvXtrph0btGp4+Ex296lV1ofI5WcxNszoQLdLi41mX54guW5RVVwvlK
CeXJwa/xw+il+2yEk6QqxEKLA3F9yW2lIuLz7/397q6abAh2hcT5mRCedu42
HH4XhuuevTvLQbhQ7O0XU54IVHyx8DieWN81xUpbyO5ReOTj5c3yhKM2Osnv
Y8Ygk2R/oJDYn59cEboH5eNwe9vxr8nEfv41z9p7MiEec6VS5HkJ16fJOH7o
ScDVASbbbYh4EBl9WLvCn4SGzwRMBIh4YU+ldFs+T8bJqHOl14h4WpQ0U/P+
moLNY7fCAol42zTgxe89/xHfXjAoHiXi8+mWxgPH76ajpuV67jWEv7wxODAR
lYFu1RKDIkQ8N1przrq3Z6LNmXIeKSLeWV+Kc+55n4VPZjPq64j8CQyI1D22
MRfp+vST7kR+qa6/+fVbQS5qVp0Olh0n6l2mDPe+259Roq1m4e4oEb+rx51q
svJQQGU/Q5vIX56lnQdaLxZickBNTQaR3xwTeU6Bvwox69fbhNUDRP5Z7Rs8
HPcFz/1ep+/Tw8QbLZxC0tNFeJ3dR5yvg4kng/ZLvntVgtn91SdF2pjY9O/h
HjP5b+j3M9JSsIWJlqOfgoTI3/B6cqH0JFGPAva7Ulj4S3HrziOmokQ922O5
v0rYsAwjL/jPWH1iYsiyQ2IgswJvi+32qk9n4tnDRafL1Crxhbn6E9FUJkqa
qDhTwiuxwzkzJDKRWK+N0d61J6owZuD33i0RRH3MPm/p61GN36TGqnc/Y6J5
beS+y1x1mIRH6L3OTPTgv7/080Yd0vYKlXo9YeJqO6cdzul1uNGl7muhLVHf
bj45fkirHgsmLF8n3mViWfTbL+f8G1CyMNMiQp2Jm9vpWxvWNuHbXcHtU8pE
vYoJEtfUacIMDUw6AUxMq+KrzYxsQh7lqg/FCkwcWtJevV22Gb+5zFdekWZi
qbtUiY50C+LuuOHFtcR45a8LfzRa0fVc/3Q1K1Gf5NaSG8xbkTN08Lv/vzk0
lhb69PJNK3LUNAixLs6hn/u7ShKpFemPM9760eawOFbSPf1eG6adeH57B3E+
d7nO75R2bcc59o/p1l/nMG8HTflHXDvOvzM7WlgwhxnNSzFvK9ox90SVzP7M
Ofx4ViW1bF0HlvH6aFdGzmH2+lid40EdSNp1nf050S+wq93dlvW+E90287SG
bZnDXfRGXo4cEv7bOCH7XGgOe16yvRbuJKHzd8EgU545fFekXbPxFwnv/vwa
sYWN6Ce00zjzTnWjTDy5TnJ8FlviEwS7a7rxy4zfQHXBLGpejhE1I5FRfPFt
UrTmLHLc8pfdPdKDvhfDbWNVZ9G48N5TVtZeNJayiIk6NYsxxr2N5eK9uLks
4OgzuVlMO1BycuZOL7bPtRQu883i1xBhC7aBXvzmy+Fb1T2DEp4hHGwdfZjf
JEmfNZxBz/BpjpWUAVxKF1urrzeD0r+rQ7sqB3ByWF245OIMenXucAoZHMCS
oj+H7JVm8HTb77B+rkF8ZGnonCw+gxHTsXG3lQexpGNT6dXaaQw0+vmuOn0Q
H0uHFw/VTOEau1xdNschfB3GfyysYAp/cPFR5TyHUJjks0cleQq/iG5V0QoY
wnWJP794e0/h1imNBwbJQ2j5Y+FrvuoUuk8HH2jvGkI+Cb3KBpxErbRGSYGD
wximILxbN3sC1wf0eIwPDuPc1MYfRu8nMKIoNydmbBhtss4csQycwJXsBX+V
+WHc8VQhz9FmAi+ojmo+XDuClef5Jq4dmMDl2+u5JWVHMLvu1SX9rHFMEyvh
O+cwgquH1xt9TxvD5TLuaMt/I5gsbGVqFjWGFup/2yLWUvHRo4WmNa/GUOe6
91LhRioeGXUeP/xwDCW3v97Vvo2KS2E/Rh2kx3AfyUvHEaioFLmIAYk/UFq5
s9HdmYoD85eCHkeNYqsv90LhJBWt7vUz7H1HMdxZjf/3PBULOGU2WjuOYv2l
G69l/lDxnNAwj7HuKKaf+/D5PicNP1qn+J/iGkXr2d1Gp3bSUOyuUFjrUwa6
zxabG9+goZGj8/byBwzkfygh1XiHhhnJr8xyrjKw7u6aqF0PaFgxXe8cJM9A
uxsF3fn2NJzflrnp0hgdK5VuXVTwp+Hj/KoLPdfpWB+dsVBVTMNj8xSrpjN0
3Hx+/VuDMhou1obuLT9MR0P6pTuj1TRMbTbKSuOlY6HykxekVhqeqGI571NH
Q2dXWcYWBg1HGM/HbI/RcPfI5yPnNtIxudj0vZEoFcUFLD8aXaXjncOyBdkc
VMwxUadL69NRR4USz/J7BEujlpFqQMeY6ytbU0kjuLfwtvGpe8R9meRF84SO
oIZN9BY7Ozo6VMryq/CMoH2D5K+f/nTkfWjhnftvGH+ue88qEkhHPkO/Kzun
h9H473p++RA6Up5w7OJvGkbZxYFr6pF0vJn41IbTbxgHq+UO/Eqio5PF3fMO
64Zx5GIDw7uYjqJzDCGeX0P4V1dOg/sbHYeVG/LSGUMYUXZQ6GUpHW+3rvGf
qh5CV/sGwftVdCybIN0N9RpCMVb1W5+a6Lhn+niY+qMhlGnIpv9ooWOU6Y32
pbtDeK3pJB9RQ3G0J/CVueoQBox5W9wh0bHEVTH9EesQWt34O+M6QEeBNt15
YA7iDN1S22qIjrv2XnfmHhnE7dTy51dH6Jil+uBeTvkgZr1mD+dgEPc/JntW
0mMQZS4lbWCdomP+YslpDttBPKzbO506TcfaE4ZJs3cGMcJqZODsLB1PbXLr
a1QaRKberbUW83R8V30iOmP1IGZqMvefXaKj2CG13L8jA9iTzX8/YZmIE54x
iY9EnWCr5Tj28w8dD0f68vB7D2DCqeE6t390PJ+4Q+EkxwByiUvqHGBj4Akl
ZXfhsX4Mam7bdJadgSfbPvH9qe/HdZ5SGXprGHjzepQ82a8fU4WEDAzXMVCE
+5z9BE8//noY7cm1noEqEctr2Ob68Lsgw3qYsGGDvKxEex8W3fQ0zOYm4ly4
Tu9xaB+y3v99XWEjAwV3KVlnOvShm+Yj2ynC5ZPWMHGtD7WXvZNieBg4yTwv
7Sbah6u8k+ypvAwMFbfV7VjuxaLP58Wc+RjoyqN0/UBfLx5S/fabi5+B17pV
lcO+9WJaoipPCOHjy/NCrHG9KLFt930BAQaaPsobcHTvRf/GXDZ/wsttXYnz
Rr241l9meoWwz2cxtTU7ezHMcbGiVpCBvRTP/VFre1HmV1uRuBAD+y41Hj36
owepu1I3PSIc/Ylxr6++B++dKxlEwrVvcvFleg8WK2huYd3EwDcFS1qKr3tQ
/nJgy2nC3psfCf+16kE1nwZWO8LO/2p2Vur0YPTRQ19jCVuv8X4WdLAHt55m
W1VF+J6GnKypYA+K9dt2DhO+fP/AIY1FCgaX5yn/JiyVyIiWI1PQZW6V9jph
BrowIy23FVPwYL33ykbCtXweWZtiKPiL6XiNh/CWmDJTYTcKOt9mNeIgvGe7
+fsddyjoC1cllon5dh3wuHVQhYJffkW9pxFucJ9L1pKioJrk3+FawvI/I55b
r6XgqGfiZCLhrs8qy1E/yNi+/LnmCWEbtY98LQ1kzH+l63iG8FKUbev6TDL2
nYln2UDYU/7I6UtvyHj/UpnVd2K99oo9MYyzJaNbR1OlF2G2bZ9OLF4mY8ki
fa0C4aVvx8lXFcgYOCABQ8R+FN60OI0iZCyOj7F+TthD7YXN/j/dOKT6MH47
4R11BY9T+7vxYFYMJY/Yz2xtMX3Zsm7c+ensNlXCzqZVm78kdON+uotDAxEf
i+yl18YfdCNXeo59FRFP+mlfBvnOdmOqdWiLDGHn5Se/VXd3o5PQzR0vifhr
r7JfrP1BQgNbndJ9RHzO9XGMi9aTcPBul9gjIn43bN78yjGVhHZx469zNzAw
wdJm4qIZCVujL9QLE/HvvXSr+LsmCc/doyQAkR/HO0QuXdlLQh4Hi0+3uBiY
PHBt9vlkF4Zo/nvqxcHAeNpQqol1FxZSdQsciHxcqEDz4zpdKJ5eNG9I5GuX
8j9pEfku3BRgH6fEysD1BTdTFpmd2LK/4vbUKiJfPkncPfa4Ez/KS1+ZIuqB
yp2DUfeud2Lt/ZjOKKJevNzNthR9vBN5ZWr/Kf2mo/NhUVXZlQ6Uzky2fLxA
R8vPkpEdHh3YeinM8/UMHbV9O2P173Zg7U3KVhaiPp1Lzvw5rtaBvnTFd5aT
dFwbFZe4n6MDD7veNpEnzqmksz2vld+0Y+BLO9o9ov4ZMA7q+sW1oeZsVp9H
Bx2VzV8+qPNow8l/O4V82oj6tbGXh4/oCw+CX6I3UX85Eoqkq3e3YfFT1gGr
Rjr6nyro/JLbivX/GvyYFXS8pDo001rXgts+RDRVZdNR/TXvseLMFrQ3N87x
+0RHb75MzAxuQa4bs7u0M+g4K+r55rNBC4peEO4vTaFj8a35GQdqMz46u26D
SSwdI1d1L1gdb8LaxPK9n1/RcY27jKgfexM+aFnJ3ulLx4fefXNfW75jSNa9
rSHedNS/4tV88/53PHguqszQnY5Vb2zcQkMbcUF6obzIgY7WsaYVEz/rUSvV
d//z23RsZl9z50p5PUactA1OJs7Lx0N2pLbX9cjV8VCumjhP+YV/Xl4vXY/A
7bPz52U6/ohu+/KE6Ps5cvyjRc/S0f2syW6oriHa8I75F/vpaHNsZNWTtErc
1dK0esMfGl6KpZrccajEV1MXtuj9omF9TrqhkVIl3mQZ14qZp6FZSdGaTFIF
/tsQzi0ySfQjMc/5zNkrUFS4Lrarj4Y03zoxj3tlOJP6YK3VNxpSaZG7Bay/
YqXuw9gTzjTkvOPEx7b+K+aKKToyHWnYCKvTJVOK0VeNSyjZjoZa263Ji4NF
eED+SMlqMxruXdS1pV3+gjk5pUpe12l4w2i2n6SWj5ddWYPrDtOwf4yVha6Z
hbQekW7TcSpyy6tf2zf6CStru+AnnYpRdwunRo5+wtwAZXeXYSqSvAwyNXoy
8IGBaNxzMhUnIy9WL0ikofRCTp5FDRX/2SxHkiqT0Jjb1T4znoon/XSUrHzC
cMPZelnWa1RM+LnGiTc0EFR0123LLxjBN/MHXiVVBcHx12v4MnJGcM3gXb34
n8GgEPiz/n3GCIruGKjt0g0Dvf1ZEc8TRpCyyv6OHEcU/LFRW5QLGEGdTWnG
QzLxQL7xYON2kxE80Gu5p045DaoLrDkf841g96FTp9Q186EkBO8E3iP63cdg
PR+cDxXXdFTCDIexaLRH9UlvPqz3Uz4dcX0YOV7Ycq21KID1LtteRWgNo7Ba
VOQhv0Jwuyrc6Hl4GA33schSy4sg7Kv1idXsw9jS5kj7xYsgHErOyY4fQi13
pfz1MRWQWeLvY0keRMFIlw69ogrQ/WRw7Gn7IIZucnMKIVXAwRzPquffB/Hq
YepTCm8lFFzWdwgrI/qIlReD770q4eWix/30j4NYWzGmLfGwCmoXpCYSngzi
Jm27cuFdNaDG36HUKDyI16+dsOK0rQcnc4FfiSn96OQbSvX0rwf/Xlm+o1H9
eDv8etp4Sj3k7dC9VOffj5Pe3zW8B+phfoJHh27bj4UXY5+PajZA6LH4GM5T
/ajV/3L1/R2NsPvsZp5/LX24/YVWqBN+B6FOV7u0xV5UlMgXK77bAgdMPxd8
UOxB6VeXT++0boGEpm+vRYhzszvXN9HXqQWKJG6cfiXVgzl/HbWOBbXAM/kX
cmacPfgv4YLxSWyB+JNFQWIdFFzHdmd3x6ZW0DN+t1n7PgU75F5K3KpoBefC
B+/G/cjIp32T7sDWDsHPslmciO+Lx1q6Fe5xtwOtx+hFbC0JvTKqHmgJtcOB
O7FmFcUktLBTsOGSbof7qQbXOOJJqFOy6+ppzXaIus3d629JwhXud8fc37RD
agMp9OlaEnoKZtj4CnVA62+hK2NHu3D6O4O5kbcTCnl17+tHduDODS7GO0U6
4XSXa626XwfW/Homd2RHJ+z7+iRf3rUD1fObaUoHOuFQ/tRJDqMOVKxi5+TU
6YTirNmN2bs78KOs1DbDgE4QEM/+OFHYjizmFqEya4ncynuzX5TUhh9bbCdK
R7qAf71mjAtfK4bUZdBafnRBC3UvU5W9FXfv3vmiZ7oLylyL+Nb/asFD5d9q
B5e7YLX+fFZEXwuiaJdVGj8JBk5bPM5JacFKhU/Bysok4NtSkEg53YI9qa+3
e0SR4DnzfCRvVxMqT5f8+BFHgiC5irchxU04S1byOf+BBBSfFo1N75uQtSTs
HEs2CT6uZi/bbN6EO+l6HPurSSB/qk56B0sThmZpB4VOk8C+TcJn677vKB+Q
9DHwdDd8FxOqHfVqQNuhrYmnVbrh7LWm2VGzBmxMZH6nn+kGsvM4fVSnAVky
N3+W1umGFfXyw6NiDRi7ccsPW+NuqGiNdKDm1aNmxSBjx4tuUNn6YU0HrQ53
7G31n63vhjNmovuC1Wrxtv+cx5rmbuDYcofiL1OL1sWZtULt3bDhiYyxD28t
Jo13nN3dQ8z3QHy9S18NbmhOOSU03g2P/aD27qMa/MOq+42HkwxFWYvn9iVV
o8v1o+6vVcmwNL9NN52tCj98nDp/Q4MMtPiJQxajldikSsoXP08GUQ7OP7KN
lWh92cn0vS4ZOLZOn/gUXIksibfu3zIiwyrbna+zxCsxfGpnGsmVDKu1HLsy
FSvwlunmA025ZLhq6/Aq2rkMlV2mcmfyydAZfbZL/3YZvq5cZnIXkeGG1BKv
iGoZ3olT/nS0lAz981sMQrnKMHN97J4LjWTw5b56zj+yFMN/ps88GyGDFU/q
k5/WiA9+CmqvcFOgrGLdg6jRYvwxvSpXm4cCLAO0nt7cYlzcLBIRxUeBvSYv
lbe6FaMbY+P4rk0UkMm79iNOsBiHmYF5nNspcGKWLSlJuQjZhiQNfu+nwK5P
XLwZ0YWocuKPIOtBCqg1WbZN3i9E+mEXvXWHKRCm3fJy38FCPPTD3pn9GAVu
czgOfaorQMb5Rq16xf9+r+64N2chH3s38rq5XqDAjNzx+3kX85B0y4xLSYcC
cbtKs39uzkMfvw7pf5cocE7BceEw4zNuaPcWtrxKzHdZyirf5TNmBQiShAyI
z/OdU7wgNRcVtifsCTGlQG1X4KcCthz8JJT9a6MZBax7Mz8tNmfj+SyxWy/M
KbCeTSddISob2eafzTywosBSw7uoggPZGPTkyKlFewqksAdcKbiVhbuAq0zR
jQItfxejzG0ysKzXYCjiGQXSdgZJJS+n4zfpTt9Jdwp0OnqmDnml44YDTfbP
n1Mggvtc8tXINLzr2V5i7UuBv6EitooVH9EQFfe8e0kB8N/b+1TrI17dM7ij
+hUFfNJ2quSRUlAge8tn9tcUkFz3ZN2eiWR88XC1pUoQBT5a9NnzC37AZ2nP
TqkFU4BfxLleKzYJf8t1RiqFUGDZZu9Wn91JSFu1f9WeMAoEhZws/XMqEaPr
Mly+RFAgQ1BmjmYSj0caRyoCIon1vGhzYvvse7Sf3BV5O4oC+y7EeOo7vcfN
T0mLs9EUOHNsiac5IA4Lne64tsdS4NbTNBVrmxgU+/5e0zWOAoXKpbVUr2ik
cmCqxHsKSGR9OX89MgpjFfS23YqngPtKuY5yRQRG/z14mElYdYSlPZ/0Fg8Y
pPd5JFDgUPgLXZmJcPyrv50RmEiBnE2ZlwQEw7AgxFKDN4kC0UF2rT67Q1Ey
6u/JV4RbrlRdWDkVgtv4HQctPxD7dVxdk24ShIdoiQHdhFd8X9fqOwWitFps
28lkCuyMCFVrDniDIUq2Aj8Jl//hcrW28cdpdk/+sykU+Jz6z+F65CtkSWn5
EE6YuSnXSrnCF8+L2jUNEpZWkX8gM/ECzVKevZT8SIE9wS9uCwh6I+8id48R
4XPMYr2VU89RgG1faRThmumui3QTD7TfOXesmbBvZ79Gc8AzvLXhocYK4ZNR
2e7WNi64vyphXCqVAuGzgTbKFU/waUaaxFnCTVvu3REQdEBuT78ZE8LWC3I6
dBNbXNC/cMmNcB9znBhvga4JyxpBhM8v2hLXm6C8ZHhHLGH1yGnidQOkrUj9
TP7v/zLN/1kL////NFyqjqnwMObr/wBDP+3J
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.17066466969066746`, 0.12293600612052162`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.8533233484533378, -0.6146800306026086}]}, 
                    LineBox[{{0.17066466969066746`, 
                    0.12293600612052162`}, {-0.8533233484533378, \
-0.6146800306026086}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 76->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.9805738648370395, -0.7594646603540504}]}, 
                    LineBox[{{0, 
                    0}, {-0.9805738648370395, -0.7594646603540504}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.16342897747283985, -0.1265774433923417}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.16342897747283985`, 0.1265774433923417}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.8171448873641995, -0.6328872169617087}]}, 
                    LineBox[{{0.16342897747283985`, 
                    0.1265774433923417}, {-0.8171448873641995, \
-0.6328872169617087}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 77->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.9351308590367094, -0.7797408874975592}]}, 
                    LineBox[{{0, 
                    0}, {-0.9351308590367094, -0.7797408874975592}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.1558551431727848, -0.12995681458292643}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW
LJGOfc/OmLEzi+yMKFLv9/c+7zv/zPN55nvvfOfec8498zwzO4ysLt1jWbVq
1RHWVav+e0793wcFVv3f4+GbgWcphOsLvOqdLpwDapELazzhV2H/WR+qQj3l
wwkPVI6QoouNQcZtituHcJKHJ/H6Q0irKQq1J+wt/+ZWho01nMkZqbtJ+NxQ
D3G9HdjZG6cqEo5pE9fxY3cEniMHFbYT5lA1IsY/BSteTevljxS4/DJMxSzC
BTT546+0EZZ8bEDM9wxqju9jJBLOr6eKJgl5gNUTqqQd4RsfDIj5PeFgbuGG
U4RTSyqCQ257wY1vMYkshBOWeS/6sb+AeYPbHc9SKLBVW7vW6cJLqNffanmM
sGCJ7HO7+VfQ8DsjdzKZAtfpJDCL8IcwvUWls4Ql8w7cyLB5Awr8vi9nPlDA
JDHs6G7VQPhwL9o1mPCicZ1gklAQaO+feNCYRIGugCfN0cXBcOjwr1tGhEdr
aGnCr0Pg8LjkqvlECghfW3kRcjsUosftVDgJ/9RnBT/2cOAqyqtniadAMJ0r
2elCJFRKRgs5vKeA/Mknbos7ooC3O3M9LY4CZl0S1+zmoyCRXL+QF0uB7CI6
q1lEDMg//vZNIoYCARqW0hk2ceD0ZfqafTQF8NJTnnFKHDy/LBhZGkUBuYCG
RWnV95D0xl/4fCQFwvvYKhOF4kGxcufvfeEUOH50q050cQKI9Cx03AyjgPL3
hAMUyUTIrgA971AKZF4a4xF+nQgjcg8vNwZTQNzDtCH4dhLsPbVbTPINBXz+
Ncq+Yk8Gk32CJSw+xPpwSgQ9uZAKa9jkj7d7UyCscI9XYFkqLCxrhb/zosDg
0XL7jwfTYP7b9hkpTwpwd41rkDelA4eJLN+iCwWkh4bw6GAGGPbPlMfbUqAt
2/SmU2EWHPrygH+HDTE+Xnbfi9kssBJJOxVpRYFJS5s/QXuyYbqhSczFnAJb
vjD8U6Oz4eSO5X9sJhRYl230jPwsB5I/Xx/eokcB9ag+1yNnPwPjGzlc4yoF
xs2D2JU9PkNcpsM2q8sUMNTn9tYq/gwmIqPx6RcpwPz5zO6ubB60iTqb/dCg
wHZhraVA3nwQ0hb3Mj1KAQsRmsc4uQDqJoQj3fgp0FPQHRb2sBgiSjmz9/FS
4GiLsiw5thhqUqvlyRsoQNG+kL+5sxheVJ6x385JgYs7+WPj4CsUiff2O66i
AHVUv/yjQAnECvysOztBhtK1Zmxfvn2D1pPUx49KyXBa0ObhXY4yyB89k/Om
hAw2LtPebJJl0FASo5RcRIZTN1+GJZ4uA+VIBcPqz2SQ/7b1NdWuDP5u8nVv
TCEDy1QXybi/DPZtXvqyGEAGUHkZZZhbDiOZLxwr9ckQGH989KxBJbQXGz7R
v0aG+ZQiBSPHSrgfyccY1yVDWi3D5mlgJUSaf2NZrUUGI61fialVlXAgZlRi
/jQZWmR8/3Dsq4IHbWUXVnaQodFVXKLybxU4jn6WCqV2w4czZ1Ml4mqgU0Bm
IWywGzb/jo48WlQDRkd5hUJ6u+HNFQ1TrY4aUPh3RfFZRzdkLZNiHdbVAtks
VmJ7ZTec3P7nbo11LTg3O2q4xHeDZXMN9Y5SHfCwJY8l3eiGv3r6exyH64E3
+eLvtKvdcHDVounXv/WwVO56M12nG8gjty1Xb24Au/Ja0egz3aAU/7r8pW4D
cN2+dUHhYDfMP3jtEVnZAAezC6/c4OiG93UCGRkfGuH30h2LC9kkuO2b8zH6
YRNMbx06HTDdBaKL38/n/moBewWLcL8fXZBZF7yHwt4KFbopH56PdIHen6C2
VfytcNf4/MhdUhc09Um6acm2guWqiTTaty7oZ887Qb3TCq2CjjIMvy7gsbpU
u6ahFQxc6nYPSHbB1IHu3Vti2mDgl8LRs6qdcKSKy/KuYgdc2Z9pf/ZkJwyz
XrEI1O4AbW5crXKoE64vmf8pudkBNO8YNnHJTjigt1gl+KQDDinfswhg7QS3
q+E/MLsD/PV2VEuVdcDY9YPeK+KdABpuPPsVOmAyJ0FLiL0L7L3tZQ9saAcl
iyzrJzUk0DCalI5ja4eTbI3Z0EmChO0NIuuW20CbaXGMfYQEGz8+bi1ntEFi
tpPQ678k+P0v4uJIaRvIh5f3hx3uhpHRFI0mmzZw+lWi55nQDcIjUvHHmlrh
3gfBf19dyVDIX09vtG4BuSGKva58D8wWCMVLm7SA3wjd+efpHogxm05wudEC
lulJHmGaPbD3aZ4Nv3oLCGQ9ftZ5twemEkznJkVbYG1SguCZ8B54J8FBKvRu
hmst27YvLveAm2jv0S1bm+CoVvd618peGLxhLWYt3gBXLOdYi3T6gbZDOe3V
2gboN79TLGTYD9cMb0yGTtTDi/ynGTbm/aCaaWvnkF8PExfbD4u/6AcxCYF6
k7P18NH0oqfF137YQnPM+mtWB+n1tHupOwfgUWfI/Z6EGtiZt0cg+fcATH8P
3VXeWwHJqj4CDo2DYLF+5q0ZVkBW0yCxLINQddzSli2+AvS/exiZdw+CgvcT
dbb7FbDO6s+GW9RB2Fol3HxiphyOcNRrHfwzCKXn85S9/pWBhIk9NUFmCOKT
eiL0eEvB5f11kUDfIRAwMl9vtboQ+BR2th1QGgYTvo2/zbEALmWtiHxRH4Ym
qYl9Gi4F8Orih5bT54ch0uz+ubBf+dDvLOqhdm0YphPOc7+ZzAO53X1FYDEM
LpayB2ZacqHxVesH2tth2P/7Q6fsUiZcPnRt7ejUMDw0uFOrY5EJJcZ8i0fn
h8HrsvVbWaKOV+fkbvD5PQzPSYlO66vSIdVGJn072wg8jphdufsqFW7I/bp5
QmQElqR+vbLk/AALFqIOAiojID15Qj8pPgKy8mJWq4aOACR1T3IavIWAN6wX
KyJHgGm0IaRUKBzkOjX5FeNGgKL+RmuzTwiUeX4dO5A2Ahd6L9F4q17DmpcU
p4XSEYivujx1r9sOnIqf8qyaGIHDwboWKqZvsG3g3vNloEJBdbbz8apAPME0
eyquRoUt2yweM3YEo5l2hZX6OSpknxZkGPeFouLiRw2vy1Q4993JdvxmFNpF
aav2P6BCdEyUiywkYPUR6b7fb6iwIbiodjIpE92e/XhZ1E+F+DM6f1h1P+Gx
I4pa0iNUKHWSrT+8KgvN/Hn+BjGokLouPXRTZhbWrY7dYjhDhfQbl0sruXIw
KfY0o3U1DUo96vQbmj5juCDj0VZJGhhuNo/OsyvC33Psw0dNaJCt8S/WuLkI
BcKv7zv1kAaPVB6InJApxufGRVOnLGkwwDH9zGSkGEc1rIoPOdBgYu/VxE9X
SjBzzp5v0YtGnKdfXdfuKEVeoV6RhkQa5L+95MUtVoG5D5PHgwZooHREbyFQ
pwIpt30DTEdosCSxi0XOuwI5I8bvn2DQgF9BcSpnugKvSJ2JbZmiwdY3nfuH
Kyox/dqgd+kKDYx9/Ab6ravxyLSFWLYoHcL9DbUnP1Tjq6T3F45upYNPPJ+h
QF81bkdzvaIddKj4wribfrYGayTiOjOl6VCTMTvPKlmL1uvUOvSO0CG61sPy
Yl8d9m6zeJZ2kQ53hvYnjwrUozZt9mSfLh3OiKjZRpyvx9SqnRYc14j3mzAq
VP1aj9KPj27UMaDD392bG8uiGxBzOJOjTemwNcZ0UdfoO9aqv3PZ5k4H14kA
dfuo7/jXPtH6pycdUmS5/qV3fEeWgKdWVd50eGU+FXP/TBM2sc490vWjw8Jn
zz2r9zVjR53z2M5wOsx4N44NurWg1j5vr6Q0Ovhbc65PjW5BlhKl99yZdBAL
F2h2/dKCYlsuh1tl0SH3kPp+TWYLOllL/tqeR4fTG7r5re63Yq7Kxvaj3+gg
GR/YNqjThiG/YgQUmulQmHLiq5FVG8rX6eQfa6VD5LTnphm/NhRSWVVzuJ0O
Aq8zBWRr23BFcVBElESHo3oLZXLQjqTrNZVB/XTQ4RS3vyzXgafTH4ueniDW
lxSX8kqrAx+KuJh3TNLBN5bG3WTWgeayYyXG03S4aCmiZ5/SgaTvfsoWc8T1
jc/uqot3YuyNf5wyv+gQq7QmokuxE6ni1m98ftPBykWUZGPYiWXTq3v7l+hw
2PKHfl10J27Si055tEKHgrU5P5Y3deErI5PzmiwMqKJVto8c6cKZvlwFS1YG
3DC6EdV1pQvZJ35k+rIxIHxNUFpvcBfmZWVKpK5hgGP06dHpnC604HrO92kt
A2ZsXoxxt3Vhk3azVfo6BrROSOx6yEPCyZB9em84GVDp2H85RY6ENn4WHQ5c
DMhuZZGb1SYh3n38/sp6BuxttWyK9yehbrQ4zx9uBtRssvfmyiChwZ62+IoN
DLh88FaLayMJd62xfOC5kQGmQlZ/n3N149KF+5bjPAxIY2uuW5DuxnmHFF8f
XgYE7+rKtFHvxtbMo+Vb+Rgg98kj08O9G9/aVtse4WdAiO6lEuHYbnyh7tpf
QBjcxZoKvnajc81vbXkBBlxfr9jH86sbl63DpfgEGWCneay5XpCMsf133BwJ
K6bbpPofJKP0G8WqTsLvul4/uK5DxpRjLLN7hRhgvizJus+KjFmWdn+cCXNh
vh2XPxknUm4NVRFuksjLnU0lY5u2X8TaTQx4bO/2dbCWjNZF5VuVCafvM37R
TSfjYcXqh48Iu05GcZPZKDh++Lrje8JUXV2NYXEKfv594nQ1YfbFuP3zihTc
/HvvlxHCzRovcYMhBVULR4d+Ezb1YJk64EJBKfLunHXCDIh9PfbZIIqCfeIf
JXgIq8zzcAd9Icb7iu3/z6mlB6abSBQMO3iy9b/rd9su6AosUDDGq3DVEjGf
1/DPg0YCPdgmpVr43/udPfD5RaF8D1awB8xWEdbNjD+zSacHyaZnPsQRvl65
zdzVqgf3zoq02BFWGnGYnPTvwZcx2Q+AcMzDwYp76T3o0VNgyvrf+BB3Bq2+
B1+97GhEYr2ot8wvWv7oQRX2zFf2hNkfxy78XduLpbt/xO4grLprTVv4zl5c
vrObtYbYjxtHH1OOqvWiZjrPp7uEu2lf1g4b9+JCAsQsEfvbWuGkE+zRi+O+
V2p8CH+OHRDeUNqLPKHpef5EPEhWunmR+nvRokbKgo3w9RPREykrvXhLYEHd
jognsurDF8Yn+rB/6O+ZY0S8hdk++Xhevw8NWEyM3hDx6P4P40896cOfAe5e
A0S8dkc1LRwp6MPJ4F2N94h4buLXAejqw8j73cPRRLx/D3Q7fuFnH953eDna
QOTD1B8bCe+D/RjCcTiZl8iXVc7n/qZf6kdq/3ldaSKfWJYX7/XY9KNaUmLH
EQ4GnOQWyNPO6sfJB+dOnSDycf7rlE9wcz+WTGRvOkDk6yZnh/KBqX4M9vTL
2MrOAK1vT0+/lh3AGvea2UEi/4P/bj2lnDaA6Xttd63+S9QH444Ys+8D+Ocq
9W34HzpsX6d+MWZ6AKVucvJLLtNhMz/ly3rRQYz7arVqG1F/jq39FP7l1iCq
aLzojpqlw8a9+Y1TVoOoq+mRMkTULxez23O73AfxeMweEJsi6nWs3lxSwiD2
zbjHPhqjQ0fw0/nm0UHU0LuuljpMB+mO1H6JpUFc9m0wjhkk6jX1iosT1xAy
tH+u8SbqZ9sbUuHhfUM43uVepEChgy5j07lOuyHU1VKY2UzU442reNO//BtC
t+SV+4Nf6WBqOcqrxjuMxW6vfu0qosOkQVZyu/gwigzmvLxbQAfF8URYUhtG
hqZq8NdsOqiUmEqZ+w2j8Ae5S4wkOkCUYA5FZATxXPGj7cR5M+8T0hgiM4Jm
jmuvfPYh6u9xF3edUyMox1j5fNKLDmF6VUFtt0dQ0EaMtMeVDkey+o7OJY9g
3rBptZMVHVaYNV7vjlCxhLJi/eMCHTLMLkedP0PFhGDH0XXn6fDl1727f65R
cXID97SYBh12sGyZvP2Eiop2kW+kFelACx0in/xKxT4MckQ5OohLXFtWUKYh
i6SYw9R6Oli25s7/uUTDP4YSf4zX0WFx3XmuCmMaJqj7fmpipUPLlU8PLnnR
ULo+y9tziQa8EimNzrU0nJg+q/OQ6CcSnlC1FrXpaLByRWkX0kCz9PXNOkM6
+gkfHpz4QoPT/CzUKGs6uu9bezH5M9GPGB2UVw6io6Sqqt/SRxqIeMhEBXXS
cdp2uFckhAaVdxrGj95k4KrSfZIKRL90uLZk+ZzpKKrbCnDXEv0VRy84uTiN
ooyhlenrJSoUxfW0ZfqPYqPlGqo6kwpzTs713DmjeG5ycMtrKhV0OWc2FS+N
ov2ujf/sq6kQ6s7dWvnqB3aYipfHvqBCUtHUmq3pYyhTeU9V/d8IpJ9uleP6
NoYbFHquqC+MgHFDGvfP5jEEKeExhckRqDqzOfYbcwwZpJ5X0xSiP7ZpF9h1
Yhy/9KldyMobgR9pfXMn68bx0OUzY/YPRqDlwlnthaEJ5Cy6enixfBjsFX89
ZWNO4BH/KNPLhUR/fytXmpttEpP5L19LyBiGrSe8i7h3TqIMZ7W+ENG/x1Vd
i6ozncSq5n+Mi+bDIJWar755ZhLv7Q8L38Q3DJ9fXA+IWpzCdc43RscvDcHO
HyIN7Wun0XH4b6+b+hD07P7IxSY8jV57NUPYjw/BHlehs+ePTmNNndkl+vYh
iNv3wf7J42lU5b92ZmVyEI7dLrI9tDiN9Tlmpz29iO8/hg8ff3eYQSGRuKfr
Lw/APcmSlx0uM/hXf/P5t8cGwMu2YDXp+QwejzojtH7bAPyJvLj8PWgGL1yT
KUj70Q/cMt/2embOYKE6+85Gl35o4QF2VtoMzmw32h75vg86Ff28tmjP4oCW
83I+qQcC9+8IcLs8iwsH/fuvFPUAX7rDeK/+LJayGEn0R/dACpfLU+/7s7gt
/x5X2p0eMO2SZw95Novf869MKYxR4K3nWuvA7Fm8dafSWGaRDB3WIYY9G+bw
3KW9nyZXdcOPVh31WYE5zNxYekqinwQ/ywI0/onOYf7ao4WKxSSwsG9xYN01
hy+c9pEOPiKB24nxW2mn51D0sHf4CqMLCva+i7Y2n8MqC7WKI3Wd8HD1Py9W
2zks36AduJjYCTTeT+P+jnNoH7F7dfyzTkjdasXu6zGHI+r6Jz8rdMKaniqT
TW/n0H+C70FrYge4K+t98CubQ4ENLeEcTu1gJtFAC6qew4urj3TaXmmH+bX7
179pmEOVrvHkGrl2+LCLa8yycw6zNmgGHaK2wX4no7mS0TlUDErcs+18Gxyx
W5sQwc1E1nvkhCvCraCUKneCk4+J0smeKj6zLfAiUfyAjRATRfONPqTUt0CT
MKuQ+DYmsks2a+Q6t4BCyA7qhv1MdJNYJTGKzTD/7W4N90UmfpmifvdV/w4r
11ZmY3WZqHR1YbXQn0YoLD5yfvc1JvLG6b7xzm4Envd6j3fcYuLpngUU3NII
Qf24MdmMiVL25DDmdD2YB2uZsngxsVvs7ENGUC2wZ4zNsPkwkewRo92tXguL
1Rd1/r5kovEDkZLspRrYu+qdT+cbJjYuxmttM6qBLgnDs4LRTCwyedA/IVcN
Oz43snZlMVGzQ/RNQE0FvJTfMqySy8QLm4Q37HlaAf5x1y6m5DHx8Z4mr+y9
FaBGu9N4uYiJyfMLXj6B5aAbXNdxooKJ3L+tvt/SLwOlmwKVBlVMXH9qbrPp
+jIgfXsi6VDDxK3PrLKMvpVC2ZdLe142MFEih69TUrwUlkZpP063E+vVX/mI
0loC994prhboZGJMUkYD81AJXI5tshzoYuIWuwcGM+FfQS9OUfE6hYkLJp5B
oQbFcL9k78PuQSbKPgxlxDEKocHrzqDhMBON3vJ/o54tBD+v0dC+ESZmqdiH
8KQXgCkt93MxnYmKjgdSxK3zQbBF24VlgolBv9doKS3mwq3jnlGHJ5lY228S
MXcjFzYJSmoYTjHx0dpgh8DSHAh5sqIaNsPEnMLt+yJ9s0FLwDswYZaJlDGj
fexTWeB2cfO95DkmTkXJcd2+lAUdXgWRQfNMPLd88GLz4UywDX31+8lPJt4J
mdsq8zcdPj1bQ762QKz3zWoVs+o0yPmpILC4yEQSP9f+mKsfoc7imEXhLyZm
yxtoBG5NAdWPjkrWv5m4FPhMz5L+AQZ3TF2tWCLu93A92+ijRLhPmg69tczE
SnI90/tUAsC5Ms0ZwhZSms/42eNBn2Hp+PgPE3W/n+x43RgH6qyCwouEJWLc
D87vioXBvoG95itM7HfWWEjPj4bsJK48EuFw+SK1c2qRsNOJ+unYXyZe2bHB
sak9HB7aVW8JIrwxq3TghFEobIwSWx4kfIfq1xkyEwT2v+6d2/mPidG/7mX2
uL6BIX8ZTiPCGkNDz6RE/cDyBufxEMJhd/5UPD7yAt7eziR/JawmvqY975IH
xMa0j/YQji/Xyi/vewrvBdTvzxJe2GrBv0rIBqzrhy6vEI4N87zz+agBSNUE
Zf8j/HBX1IrJdxV8JHTF5RdhvXXyzHWeD7Cy5lAh47/5KrbpX+RwQNqkltF3
wkWpCjvXtrph0btGp4+Ex296lV1ofI5WcxNszoQLdLi41mX54guW5RVVwvlK
CeXJwa/xw+il+2yEk6QqxEKLA3F9yW2lIuLz7/397q6abAh2hcT5mRCedu42
HH4XhuuevTvLQbhQ7O0XU54IVHyx8DieWN81xUpbyO5ReOTj5c3yhKM2Osnv
Y8Ygk2R/oJDYn59cEboH5eNwe9vxr8nEfv41z9p7MiEec6VS5HkJ16fJOH7o
ScDVASbbbYh4EBl9WLvCn4SGzwRMBIh4YU+ldFs+T8bJqHOl14h4WpQ0U/P+
moLNY7fCAol42zTgxe89/xHfXjAoHiXi8+mWxgPH76ajpuV67jWEv7wxODAR
lYFu1RKDIkQ8N1przrq3Z6LNmXIeKSLeWV+Kc+55n4VPZjPq64j8CQyI1D22
MRfp+vST7kR+qa6/+fVbQS5qVp0Olh0n6l2mDPe+259Roq1m4e4oEb+rx51q
svJQQGU/Q5vIX56lnQdaLxZickBNTQaR3xwTeU6Bvwox69fbhNUDRP5Z7Rs8
HPcFz/1ep+/Tw8QbLZxC0tNFeJ3dR5yvg4kng/ZLvntVgtn91SdF2pjY9O/h
HjP5b+j3M9JSsIWJlqOfgoTI3/B6cqH0JFGPAva7Ulj4S3HrziOmokQ922O5
v0rYsAwjL/jPWH1iYsiyQ2IgswJvi+32qk9n4tnDRafL1Crxhbn6E9FUJkqa
qDhTwiuxwzkzJDKRWK+N0d61J6owZuD33i0RRH3MPm/p61GN36TGqnc/Y6J5
beS+y1x1mIRH6L3OTPTgv7/080Yd0vYKlXo9YeJqO6cdzul1uNGl7muhLVHf
bj45fkirHgsmLF8n3mViWfTbL+f8G1CyMNMiQp2Jm9vpWxvWNuHbXcHtU8pE
vYoJEtfUacIMDUw6AUxMq+KrzYxsQh7lqg/FCkwcWtJevV22Gb+5zFdekWZi
qbtUiY50C+LuuOHFtcR45a8LfzRa0fVc/3Q1K1Gf5NaSG8xbkTN08Lv/vzk0
lhb69PJNK3LUNAixLs6hn/u7ShKpFemPM9760eawOFbSPf1eG6adeH57B3E+
d7nO75R2bcc59o/p1l/nMG8HTflHXDvOvzM7WlgwhxnNSzFvK9ox90SVzP7M
Ofx4ViW1bF0HlvH6aFdGzmH2+lid40EdSNp1nf050S+wq93dlvW+E90287SG
bZnDXfRGXo4cEv7bOCH7XGgOe16yvRbuJKHzd8EgU545fFekXbPxFwnv/vwa
sYWN6Ce00zjzTnWjTDy5TnJ8FlviEwS7a7rxy4zfQHXBLGpejhE1I5FRfPFt
UrTmLHLc8pfdPdKDvhfDbWNVZ9G48N5TVtZeNJayiIk6NYsxxr2N5eK9uLks
4OgzuVlMO1BycuZOL7bPtRQu883i1xBhC7aBXvzmy+Fb1T2DEp4hHGwdfZjf
JEmfNZxBz/BpjpWUAVxKF1urrzeD0r+rQ7sqB3ByWF245OIMenXucAoZHMCS
oj+H7JVm8HTb77B+rkF8ZGnonCw+gxHTsXG3lQexpGNT6dXaaQw0+vmuOn0Q
H0uHFw/VTOEau1xdNschfB3GfyysYAp/cPFR5TyHUJjks0cleQq/iG5V0QoY
wnWJP794e0/h1imNBwbJQ2j5Y+FrvuoUuk8HH2jvGkI+Cb3KBpxErbRGSYGD
wximILxbN3sC1wf0eIwPDuPc1MYfRu8nMKIoNydmbBhtss4csQycwJXsBX+V
+WHc8VQhz9FmAi+ojmo+XDuClef5Jq4dmMDl2+u5JWVHMLvu1SX9rHFMEyvh
O+cwgquH1xt9TxvD5TLuaMt/I5gsbGVqFjWGFup/2yLWUvHRo4WmNa/GUOe6
91LhRioeGXUeP/xwDCW3v97Vvo2KS2E/Rh2kx3AfyUvHEaioFLmIAYk/UFq5
s9HdmYoD85eCHkeNYqsv90LhJBWt7vUz7H1HMdxZjf/3PBULOGU2WjuOYv2l
G69l/lDxnNAwj7HuKKaf+/D5PicNP1qn+J/iGkXr2d1Gp3bSUOyuUFjrUwa6
zxabG9+goZGj8/byBwzkfygh1XiHhhnJr8xyrjKw7u6aqF0PaFgxXe8cJM9A
uxsF3fn2NJzflrnp0hgdK5VuXVTwp+Hj/KoLPdfpWB+dsVBVTMNj8xSrpjN0
3Hx+/VuDMhou1obuLT9MR0P6pTuj1TRMbTbKSuOlY6HykxekVhqeqGI571NH
Q2dXWcYWBg1HGM/HbI/RcPfI5yPnNtIxudj0vZEoFcUFLD8aXaXjncOyBdkc
VMwxUadL69NRR4USz/J7BEujlpFqQMeY6ytbU0kjuLfwtvGpe8R9meRF84SO
oIZN9BY7Ozo6VMryq/CMoH2D5K+f/nTkfWjhnftvGH+ue88qEkhHPkO/Kzun
h9H473p++RA6Up5w7OJvGkbZxYFr6pF0vJn41IbTbxgHq+UO/Eqio5PF3fMO
64Zx5GIDw7uYjqJzDCGeX0P4V1dOg/sbHYeVG/LSGUMYUXZQ6GUpHW+3rvGf
qh5CV/sGwftVdCybIN0N9RpCMVb1W5+a6Lhn+niY+qMhlGnIpv9ooWOU6Y32
pbtDeK3pJB9RQ3G0J/CVueoQBox5W9wh0bHEVTH9EesQWt34O+M6QEeBNt15
YA7iDN1S22qIjrv2XnfmHhnE7dTy51dH6Jil+uBeTvkgZr1mD+dgEPc/JntW
0mMQZS4lbWCdomP+YslpDttBPKzbO506TcfaE4ZJs3cGMcJqZODsLB1PbXLr
a1QaRKberbUW83R8V30iOmP1IGZqMvefXaKj2CG13L8jA9iTzX8/YZmIE54x
iY9EnWCr5Tj28w8dD0f68vB7D2DCqeE6t390PJ+4Q+EkxwByiUvqHGBj4Akl
ZXfhsX4Mam7bdJadgSfbPvH9qe/HdZ5SGXprGHjzepQ82a8fU4WEDAzXMVCE
+5z9BE8//noY7cm1noEqEctr2Ob68Lsgw3qYsGGDvKxEex8W3fQ0zOYm4ly4
Tu9xaB+y3v99XWEjAwV3KVlnOvShm+Yj2ynC5ZPWMHGtD7WXvZNieBg4yTwv
7Sbah6u8k+ypvAwMFbfV7VjuxaLP58Wc+RjoyqN0/UBfLx5S/fabi5+B17pV
lcO+9WJaoipPCOHjy/NCrHG9KLFt930BAQaaPsobcHTvRf/GXDZ/wsttXYnz
Rr241l9meoWwz2cxtTU7ezHMcbGiVpCBvRTP/VFre1HmV1uRuBAD+y41Hj36
owepu1I3PSIc/Ylxr6++B++dKxlEwrVvcvFleg8WK2huYd3EwDcFS1qKr3tQ
/nJgy2nC3psfCf+16kE1nwZWO8LO/2p2Vur0YPTRQ19jCVuv8X4WdLAHt55m
W1VF+J6GnKypYA+K9dt2DhO+fP/AIY1FCgaX5yn/JiyVyIiWI1PQZW6V9jph
BrowIy23FVPwYL33ykbCtXweWZtiKPiL6XiNh/CWmDJTYTcKOt9mNeIgvGe7
+fsddyjoC1cllon5dh3wuHVQhYJffkW9pxFucJ9L1pKioJrk3+FawvI/I55b
r6XgqGfiZCLhrs8qy1E/yNi+/LnmCWEbtY98LQ1kzH+l63iG8FKUbev6TDL2
nYln2UDYU/7I6UtvyHj/UpnVd2K99oo9MYyzJaNbR1OlF2G2bZ9OLF4mY8ki
fa0C4aVvx8lXFcgYOCABQ8R+FN60OI0iZCyOj7F+TthD7YXN/j/dOKT6MH47
4R11BY9T+7vxYFYMJY/Yz2xtMX3Zsm7c+ensNlXCzqZVm78kdON+uotDAxEf
i+yl18YfdCNXeo59FRFP+mlfBvnOdmOqdWiLDGHn5Se/VXd3o5PQzR0vifhr
r7JfrP1BQgNbndJ9RHzO9XGMi9aTcPBul9gjIn43bN78yjGVhHZx469zNzAw
wdJm4qIZCVujL9QLE/HvvXSr+LsmCc/doyQAkR/HO0QuXdlLQh4Hi0+3uBiY
PHBt9vlkF4Zo/nvqxcHAeNpQqol1FxZSdQsciHxcqEDz4zpdKJ5eNG9I5GuX
8j9pEfku3BRgH6fEysD1BTdTFpmd2LK/4vbUKiJfPkncPfa4Ez/KS1+ZIuqB
yp2DUfeud2Lt/ZjOKKJevNzNthR9vBN5ZWr/Kf2mo/NhUVXZlQ6Uzky2fLxA
R8vPkpEdHh3YeinM8/UMHbV9O2P173Zg7U3KVhaiPp1Lzvw5rtaBvnTFd5aT
dFwbFZe4n6MDD7veNpEnzqmksz2vld+0Y+BLO9o9ov4ZMA7q+sW1oeZsVp9H
Bx2VzV8+qPNow8l/O4V82oj6tbGXh4/oCw+CX6I3UX85Eoqkq3e3YfFT1gGr
Rjr6nyro/JLbivX/GvyYFXS8pDo001rXgts+RDRVZdNR/TXvseLMFrQ3N87x
+0RHb75MzAxuQa4bs7u0M+g4K+r55rNBC4peEO4vTaFj8a35GQdqMz46u26D
SSwdI1d1L1gdb8LaxPK9n1/RcY27jKgfexM+aFnJ3ulLx4fefXNfW75jSNa9
rSHedNS/4tV88/53PHguqszQnY5Vb2zcQkMbcUF6obzIgY7WsaYVEz/rUSvV
d//z23RsZl9z50p5PUactA1OJs7Lx0N2pLbX9cjV8VCumjhP+YV/Xl4vXY/A
7bPz52U6/ohu+/KE6Ps5cvyjRc/S0f2syW6oriHa8I75F/vpaHNsZNWTtErc
1dK0esMfGl6KpZrccajEV1MXtuj9omF9TrqhkVIl3mQZ14qZp6FZSdGaTFIF
/tsQzi0ySfQjMc/5zNkrUFS4Lrarj4Y03zoxj3tlOJP6YK3VNxpSaZG7Bay/
YqXuw9gTzjTkvOPEx7b+K+aKKToyHWnYCKvTJVOK0VeNSyjZjoZa263Ji4NF
eED+SMlqMxruXdS1pV3+gjk5pUpe12l4w2i2n6SWj5ddWYPrDtOwf4yVha6Z
hbQekW7TcSpyy6tf2zf6CStru+AnnYpRdwunRo5+wtwAZXeXYSqSvAwyNXoy
8IGBaNxzMhUnIy9WL0ikofRCTp5FDRX/2SxHkiqT0Jjb1T4znoon/XSUrHzC
cMPZelnWa1RM+LnGiTc0EFR0123LLxjBN/MHXiVVBcHx12v4MnJGcM3gXb34
n8GgEPiz/n3GCIruGKjt0g0Dvf1ZEc8TRpCyyv6OHEcU/LFRW5QLGEGdTWnG
QzLxQL7xYON2kxE80Gu5p045DaoLrDkf841g96FTp9Q186EkBO8E3iP63cdg
PR+cDxXXdFTCDIexaLRH9UlvPqz3Uz4dcX0YOV7Ycq21KID1LtteRWgNo7Ba
VOQhv0Jwuyrc6Hl4GA33schSy4sg7Kv1idXsw9jS5kj7xYsgHErOyY4fQi13
pfz1MRWQWeLvY0keRMFIlw69ogrQ/WRw7Gn7IIZucnMKIVXAwRzPquffB/Hq
YepTCm8lFFzWdwgrI/qIlReD770q4eWix/30j4NYWzGmLfGwCmoXpCYSngzi
Jm27cuFdNaDG36HUKDyI16+dsOK0rQcnc4FfiSn96OQbSvX0rwf/Xlm+o1H9
eDv8etp4Sj3k7dC9VOffj5Pe3zW8B+phfoJHh27bj4UXY5+PajZA6LH4GM5T
/ajV/3L1/R2NsPvsZp5/LX24/YVWqBN+B6FOV7u0xV5UlMgXK77bAgdMPxd8
UOxB6VeXT++0boGEpm+vRYhzszvXN9HXqQWKJG6cfiXVgzl/HbWOBbXAM/kX
cmacPfgv4YLxSWyB+JNFQWIdFFzHdmd3x6ZW0DN+t1n7PgU75F5K3KpoBefC
B+/G/cjIp32T7sDWDsHPslmciO+Lx1q6Fe5xtwOtx+hFbC0JvTKqHmgJtcOB
O7FmFcUktLBTsOGSbof7qQbXOOJJqFOy6+ppzXaIus3d629JwhXud8fc37RD
agMp9OlaEnoKZtj4CnVA62+hK2NHu3D6O4O5kbcTCnl17+tHduDODS7GO0U6
4XSXa626XwfW/Homd2RHJ+z7+iRf3rUD1fObaUoHOuFQ/tRJDqMOVKxi5+TU
6YTirNmN2bs78KOs1DbDgE4QEM/+OFHYjizmFqEya4ncynuzX5TUhh9bbCdK
R7qAf71mjAtfK4bUZdBafnRBC3UvU5W9FXfv3vmiZ7oLylyL+Nb/asFD5d9q
B5e7YLX+fFZEXwuiaJdVGj8JBk5bPM5JacFKhU/Bysok4NtSkEg53YI9qa+3
e0SR4DnzfCRvVxMqT5f8+BFHgiC5irchxU04S1byOf+BBBSfFo1N75uQtSTs
HEs2CT6uZi/bbN6EO+l6HPurSSB/qk56B0sThmZpB4VOk8C+TcJn677vKB+Q
9DHwdDd8FxOqHfVqQNuhrYmnVbrh7LWm2VGzBmxMZH6nn+kGsvM4fVSnAVky
N3+W1umGFfXyw6NiDRi7ccsPW+NuqGiNdKDm1aNmxSBjx4tuUNn6YU0HrQ53
7G31n63vhjNmovuC1Wrxtv+cx5rmbuDYcofiL1OL1sWZtULt3bDhiYyxD28t
Jo13nN3dQ8z3QHy9S18NbmhOOSU03g2P/aD27qMa/MOq+42HkwxFWYvn9iVV
o8v1o+6vVcmwNL9NN52tCj98nDp/Q4MMtPiJQxajldikSsoXP08GUQ7OP7KN
lWh92cn0vS4ZOLZOn/gUXIksibfu3zIiwyrbna+zxCsxfGpnGsmVDKu1HLsy
FSvwlunmA025ZLhq6/Aq2rkMlV2mcmfyydAZfbZL/3YZvq5cZnIXkeGG1BKv
iGoZ3olT/nS0lAz981sMQrnKMHN97J4LjWTw5b56zj+yFMN/ps88GyGDFU/q
k5/WiA9+CmqvcFOgrGLdg6jRYvwxvSpXm4cCLAO0nt7cYlzcLBIRxUeBvSYv
lbe6FaMbY+P4rk0UkMm79iNOsBiHmYF5nNspcGKWLSlJuQjZhiQNfu+nwK5P
XLwZ0YWocuKPIOtBCqg1WbZN3i9E+mEXvXWHKRCm3fJy38FCPPTD3pn9GAVu
czgOfaorQMb5Rq16xf9+r+64N2chH3s38rq5XqDAjNzx+3kX85B0y4xLSYcC
cbtKs39uzkMfvw7pf5cocE7BceEw4zNuaPcWtrxKzHdZyirf5TNmBQiShAyI
z/OdU7wgNRcVtifsCTGlQG1X4KcCthz8JJT9a6MZBax7Mz8tNmfj+SyxWy/M
KbCeTSddISob2eafzTywosBSw7uoggPZGPTkyKlFewqksAdcKbiVhbuAq0zR
jQItfxejzG0ysKzXYCjiGQXSdgZJJS+n4zfpTt9Jdwp0OnqmDnml44YDTfbP
n1Mggvtc8tXINLzr2V5i7UuBv6EitooVH9EQFfe8e0kB8N/b+1TrI17dM7ij
+hUFfNJ2quSRUlAge8tn9tcUkFz3ZN2eiWR88XC1pUoQBT5a9NnzC37AZ2nP
TqkFU4BfxLleKzYJf8t1RiqFUGDZZu9Wn91JSFu1f9WeMAoEhZws/XMqEaPr
Mly+RFAgQ1BmjmYSj0caRyoCIon1vGhzYvvse7Sf3BV5O4oC+y7EeOo7vcfN
T0mLs9EUOHNsiac5IA4Lne64tsdS4NbTNBVrmxgU+/5e0zWOAoXKpbVUr2ik
cmCqxHsKSGR9OX89MgpjFfS23YqngPtKuY5yRQRG/z14mElYdYSlPZ/0Fg8Y
pPd5JFDgUPgLXZmJcPyrv50RmEiBnE2ZlwQEw7AgxFKDN4kC0UF2rT67Q1Ey
6u/JV4RbrlRdWDkVgtv4HQctPxD7dVxdk24ShIdoiQHdhFd8X9fqOwWitFps
28lkCuyMCFVrDniDIUq2Aj8Jl//hcrW28cdpdk/+sykU+Jz6z+F65CtkSWn5
EE6YuSnXSrnCF8+L2jUNEpZWkX8gM/ECzVKevZT8SIE9wS9uCwh6I+8id48R
4XPMYr2VU89RgG1faRThmumui3QTD7TfOXesmbBvZ79Gc8AzvLXhocYK4ZNR
2e7WNi64vyphXCqVAuGzgTbKFU/waUaaxFnCTVvu3REQdEBuT78ZE8LWC3I6
dBNbXNC/cMmNcB9znBhvga4JyxpBhM8v2hLXm6C8ZHhHLGH1yGnidQOkrUj9
TP7v/zLN/1kL////NFyqjqnwMObr/wBDP+3J
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.1558551431727848, 0.12995681458292643`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.7792757158639246, -0.6497840729146328}]}, 
                    LineBox[{{0.1558551431727848, 
                    0.12995681458292643`}, {-0.7792757158639246, \
-0.6497840729146328}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 78->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.887642730617411, -0.7983106131385251}]}, 
                    LineBox[{{0, 
                    0}, {-0.887642730617411, -0.7983106131385251}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.14794045510290182, -0.13305176885642084}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.14794045510290182`, 0.13305176885642084`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.7397022755145091, -0.6652588442821044}]}, 
                    LineBox[{{0.14794045510290182`, 
                    0.13305176885642084`}, {-0.7397022755145091, \
-0.6652588442821044}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 79->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.8380952645626041, -0.8150268057311103}]}, 
                    LineBox[{{0, 
                    0}, {-0.8380952645626041, -0.8150268057311103}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.13968254409376732, -0.13583780095518502}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.13968254409376732`, 0.13583780095518502`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.6984127204688367, -0.6791890047759253}]}, 
                    LineBox[{{0.13968254409376732`, 
                    0.13583780095518502`}, {-0.6984127204688367, \
-0.6791890047759253}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 80->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.78647726265563, -0.8297277164745087}]}, 
                    LineBox[{{0, 
                    0}, {-0.78647726265563, -0.8297277164745087}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.13107954377593828, -0.1382879527457514}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.13107954377593828`, 0.1382879527457514}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.6553977188796918, -0.6914397637287573}]}, 
                    LineBox[{{0.13107954377593828`, 
                    0.1382879527457514}, {-0.6553977188796918, \
-0.6914397637287573}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 81->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.7327817967637449, -0.8422348106802412}]}, 
                    LineBox[{{0, 
                    0}, {-0.7327817967637449, -0.8422348106802412}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.12213029946062418, -0.1403724684467069}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.12213029946062418`, 0.1403724684467069}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.6106514973031207, -0.7018623422335343}]}, 
                    LineBox[{{0.12213029946062418`, 
                    0.1403724684467069}, {-0.6106514973031207, \
-0.7018623422335343}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 82->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.6770078456935684, -0.8523503780266607}]}, 
                    LineBox[{{0, 
                    0}, {-0.6770078456935684, -0.8523503780266607}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.11283464094892807, -0.14205839633777678}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.11283464094892807`, 0.14205839633777678`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.5641732047446404, -0.710291981688884}]}, 
                    LineBox[{{0.11283464094892807`, 
                    0.14205839633777678`}, {-0.5641732047446404, \
-0.710291981688884}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 83->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.6191624387065942, -0.8598547754714878}]}, 
                    LineBox[{{0, 
                    0}, {-0.6191624387065942, -0.8598547754714878}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.10319373978443233, -0.14330912924524794}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.10319373978443233`, 0.14330912924524794`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.5159686989221618, -0.7165456462262398}]}, 
                    LineBox[{{0.10319373978443233`, 
                    0.14330912924524794`}, {-0.5159686989221618, \
-0.7165456462262398}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 84->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.5592634710391897, -0.8645032566452774}]}, 
                    LineBox[{{0, 
                    0}, {-0.5592634710391897, -0.8645032566452774}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.09321057850653161, -0.14408387610754622}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.09321057850653161, 0.14408387610754622`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.46605289253265814`, -0.7204193805377311}]}, 
                    LineBox[{{0.09321057850653161, 
                    0.14408387610754622`}, {-0.46605289253265814`, \
-0.7204193805377311}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 85->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.4973434141852689, -0.8660223478143371}]}, 
                    LineBox[{{0, 
                    0}, {-0.4973434141852689, -0.8660223478143371}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.08289056903087814, -0.14433705796905616}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.08289056903087814, 0.14433705796905616`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.41445284515439074`, -0.7216852898452809}]}, 
                    LineBox[{{0.08289056903087814, 
                    0.14433705796905616`}, {-0.41445284515439074`, \
-0.7216852898452809}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 86->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.43345422153140667`, -0.8641057484625401}]}, 
                    LineBox[{{0, 
                    0}, {-0.43345422153140667`, -0.8641057484625401}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.07224237025523444, -0.14401762474375668}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.07224237025523444, 0.14401762474375668`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.3612118512761722, -0.7200881237187834}]}, 
                    LineBox[{{0.07224237025523444, 
                    0.14401762474375668`}, {-0.3612118512761722, \
-0.7200881237187834}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 87->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.36767383476578275`, -0.8584097736488121}]}, 
                    LineBox[{{0, 
                    0}, {-0.36767383476578275`, -0.8584097736488121}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.06127897246096378, -0.14306829560813533}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.06127897246096378, 0.14306829560813533`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.30639486230481894`, -0.7153414780406768}]}, 
                    LineBox[{{0.06127897246096378, 
                    0.14306829560813533`}, {-0.30639486230481894`, \
-0.7153414780406768}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 88->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.30011483583937404`, -0.8485484316533498}]}, 
                    LineBox[{{0, 
                    0}, {-0.30011483583937404`, -0.8485484316533498}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.05001913930656235, -0.14142473860889165}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.05001913930656235, 0.14142473860889165`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.2500956965328117, -0.7071236930444582}]}, 
                    LineBox[{{0.05001913930656235, 
                    0.14142473860889165`}, {-0.2500956965328117, \
-0.7071236930444582}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 89->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.23093597003587696`, -0.8340883711181922}]}, 
                    LineBox[{{0, 
                    0}, {-0.23093597003587696`, -0.8340883711181922}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.038489328339312824, -0.13901472851969868}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.038489328339312824`, 
                    0.13901472851969868`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.19244664169656414`, -0.6950736425984936}]}, 
                    LineBox[{{0.038489328339312824`, 
                    0.13901472851969868`}, {-0.19244664169656414`, \
-0.6950736425984936}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 90->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.16035748982863307`, -0.8145441817135334}]}, 
                    LineBox[{{0, 
                    0}, {-0.16035748982863307`, -0.8145441817135334}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.02672624830477217, -0.13575736361892218}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.02672624830477217, 0.13575736361892218`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.1336312415238609, -0.6787868180946112}]}, 
                    LineBox[{{0.02672624830477217, 
                    0.13575736361892218`}, {-0.1336312415238609, \
-0.6787868180946112}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 91->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.08868152321242145, -0.7893749634931801}]}, 
                    LineBox[{{0, 
                    0}, {-0.08868152321242145, -0.7893749634931801}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.014780253868736914, -0.13156249391553007}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.014780253868736914`, 
                    0.13156249391553007`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.07390126934368454, -0.65781246957765}]}, 
                    LineBox[{{0.014780253868736914`, 
                    0.13156249391553007`}, {-0.07390126934368454, \
-0.65781246957765}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 92->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.01631890236128003, -0.7579838038113033}]}, 
                    LineBox[{{0, 
                    0}, {-0.01631890236128003, -0.7579838038113033}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{-0.0027198170602133363, -0.12633063396855046}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{0.0027198170602133363`, 0.12633063396855046`}]}, 
                    {PointSize[0.015], 
                    PointBox[{-0.013599085301066693`, -0.6316531698427528}]}, 
                    LineBox[{{0.0027198170602133363`, 
                    0.12633063396855046`}, {-0.013599085301066693`, \
-0.6316531698427528}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 93->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.056176038178744725`, -0.719722975120877}]}, 
                    LineBox[{{0, 0}, {
                    0.056176038178744725`, -0.719722975120877}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.009362673029790783, -0.11995382918681279}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.009362673029790783, 
                    0.11995382918681279`}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.04681336514895394, -0.5997691459340643}]}, 
                    LineBox[{{-0.009362673029790783, 0.11995382918681279`}, {
                    0.04681336514895394, -0.5997691459340643}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 94->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.12806158059460893`, -0.6739094807433348}]}, 
                    LineBox[{{0, 0}, {
                    0.12806158059460893`, -0.6739094807433348}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.02134359676576815, -0.11231824679055576}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.02134359676576815, 0.11231824679055576`}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.10671798382884078`, -0.561591233952779}]}, 
                    LineBox[{{-0.02134359676576815, 0.11231824679055576`}, {
                    0.10671798382884078`, -0.561591233952779}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 95->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI
juzNPWz3fch2K8nvfH+/x88/PB/n3Oc+5/1+Xdf7ff6ww+TRVXN2NjY2hZVs
bP/7/f9+6PD//7qc9OT20jINdlmHe/h6q8EL3h8hc6SVrvzPhqB1eVXUKGnu
vOd3JpJuw8H9ws/bSf9pCCGPP4IV13kFkXTkCXpHcIEViK+lvo8k7aH4kDz/
ObzTfl73mvQN//k/iuF2kMTT0aND+hTxjPy8A7gkz+TJkf48NvPR6rsjfLD/
fuvvPxr81osir+cEhS8O91eQXl9yTrQy0wVcDc7JviMdUdVuMZH0FjqiKGcv
kF6+oJEmEOMOHK8mZVaSXpBL+a0Y/h7w8Wnz20s0mPrEcvf19oRd4Tdy/iOt
eGp0lFrxCXZ5h3Rk/6XBnaJMD6vvXjC6Uu/N1CINKqCtJbjAB6ztv3K/JZ0s
I/R8X64v7E0qMNtCWo8qIViZ6Qeso6P2Un9o8CXRwHAiKQC4rMpOxf2mwWZx
2xXO8YEAgr/rJEhvZ5ePEoj5DGKOU+rcCzSYPXp4SDH8C/TYnJ4JnqPBkPJ6
E1/vMMir2CE0O0sDEYkUB1/lcHipcGTDedJPL/f/pFaEw+8mHd3uaRocjiqy
sPoeAe3Sr16VT9DgRRHTP7ggCkwSRFZO/6JBRo03ffjoV1iz7HBVkHRLwk3p
fblfoZIep647RoOs9tW5FZnR8JrwLQ8dpcEmSlHVr6QYED4m9TlyhAZO0gac
R2VjoY2ZrhAxTIN7/g7KTvGxQA1Lr/04SINP7EMlW2Li4MvLfddl6DToMNcL
OR2eAHarMlLutNPA0+pTv5d3CkQ2cb5YaiXz1XYpu4gnFXT3sITet9BA65ri
i/1XU0FHYHbMp5EGD19/WBDqSYXopDspuj9osPXt265fY2nAc0pLvayQBqZt
rzh9N2YCUFPtZ/PJPOo3hnBeywTR3AP2Ink0EHb5tcf+cya4lHpNmmTRQIza
f+aWWBa8LPX5HJZEg5MRcQeOHMyGvbDaeiKYBjveRv3rvpELLy+udioKooEg
o/+oWnAufGia1XYJpMG3sLgHZfRc6HPerM/uS4PJmZ9FCXfywN91T2baO/J5
1KV/29nlw5vd0muGrGmgTmwKEQwrBMltGiKfVWmQ03pl1y6rErgqeDqiSZkG
1wZmR4R8SmCyTitq1TkyD3/9wjdmlEAbISZ5E8jns+f6/Xu6BHg/PeQqO0CD
ieI7inVPSqFEYCe+FyLzGvqN/dGT72CSQtWfGabCq62/0hMsyyHW3v2R7QAV
3PyvcoZ5lUPpwPXRRRoVBiLgindaOeRc7eX61UmFr6rv422mysE8u2OF5w8q
rHT+EnzWsgLCRGVp3xOpkK7OvaPrcSVQmyK/E/epcGGedmH6UTUs2XIvNFtQ
QdvsfJySZzWkigwkZ5pRgV1i84R3cjVovhkMvq1HhThpfdkD49Vw/LqqwfuL
VPA5eMrkyd0a2OI/6l0jRQXpQD19wuwHeKY+MdpKo8Be9ynzcp06uO3AVnql
mwK/drvnbXxRBxTrvtev2ihgd6BoUC+wDnpr2QR/1lKg5U8DzrbXQWimpNfO
XAps/rDnhZjWTzA1lH5X40mB3IoJm2dX6oHviN/WqmMU2M++MsN2RyO8rDYy
qD9IARE2Y27L/Y3wm2HWVr+HAmpix5Run2mEYrUbmgViFCitclPUNG+Ebu5T
hkrrKGAU7eYoHdcIpx7GH+Do7IVFG+4v9fJNICO3Qd3wYS+05q76zIJmuKqt
KEBz6QHNubK5KP1W8FDKzop91QNNxVsO3H/QCs5m8ov3nvfAYb+BvQftW+Hc
c6nnNIse8HpsaF4W3AoiQY4rbC/2gOUD7mRqTyvsFfz+025DD/QJ+4tz3myD
dfLa5tHe3UAcb6zdcb0doLw3TsKlC2LHutXPXe6En2uatN/bdcHGe3XbVAw6
wcBagJ1p2QWhhttMVB91wnnOoiOeBl2wNmRO87JXJ3RmJTJsDnfBgfrRtEtt
nfA8pHS8cqQTXq/+ekxevwuG3c2Tjip1glMUS9rxfjfMHJsObqW0w5XsFtEF
t16Yepb9Q6e5HTavlop0+NwLu3fddGmvbAeZG8yza+J74fw+lm92SjssRFSN
bKztBZkDIlUbHdthrVq2pRAPBSj2AUW7xdphz+4tq1Z5UUCd4vOdqt8GSVXD
//gDqfB8UNvOM78FnMa3nTfXoIPYGSG9H0ktZL+4kfZbmw6Tl0VklsJbIC7I
3/GDER0sDK3cVN+2gJUC/+WMR3RgstImnDRboGmviRXrAx1k+++NPGQ2Q/2F
87zGP+hwyZr5a+OmZhBbzORIV+qDtyHW1F7lRrj9zOvQ2n39cIPv44H8w40w
3h0exXO0H76ErZT6sKsRRDhSV/yn2A+eFlQqL0cj6C6lufJp9ENxWZqkyvsG
OMC95Ljesh/Ez8+vCXSshxV096i61H7QPXDp5TGDOhBouQRmewfg6m7Bmqy2
KtgrcjL9g9Qg5PSMbXdMr4LWcp6Kgr2DoMWr4X7EswrWfFKwHlUYhOccFW/v
qVQB11W/hJPnBkHSlWnQl1cJsV8ld3cYD8Lr79zqaz5XAItenFAeNAj6Rq3E
SpUyMNM9QthyDcFQrJCSS30hbFbyNWkbGQLlC+e81BwKoWbNj9znv4agwufK
kcm9hRBj5CsnMDcEriMqOpmfCqDTb8xCk30Yxli61ufV86E54AQ9fdsw/Mi5
E+FalQOeTxd9eTWGgbko/1rIPx32R1tEXsgdhtP3jtkEKKaD6n+bv8cXk8fN
z0iNkn08f+2phLUVw5A9YmLPcSYNbrkF1Zc0DQPLuUD+RXcKPGiWXstHDIPR
H731xJN4mHUaK7m4fQRq1ZKbZctCoe2b+CHCYQQuVzY6WZ0IgQR6yG8n1xF4
f+Y/gZHML3D0Vmnq1g8j0LIjaV4zKhDUmuyGjweNgLzzv4mT1t5wHNYs3swc
ge+u+zVsG5+Dr20lL9voCHxL/bHNOc0H/z5Juld1aRQ2unH+3aTphyrvHGXn
r45Cwfttu1/O+aOgAfPqDp1RaBt0UKGeCMLL3wOL7puPQhXfloSZu+E4JSrj
0mE/Cu7iO5aCBWLQbf1S5ELSKKyVjEr4aJqObLcvnj7PxYDF3QE/LGrTMaF7
a5n/RgZkVN1BqwMZKLRROWCAnwH7Ow5e3rYqE99baIs9EWWAQkTtcG5MFhp5
pKmYHGLASHDx0V0LucjY2j/zzoAB3FpCYjzFiF7iHL2UJAYcqdjvw7m5BIev
HGlKSWeA8tzXZ+KXSzAsnuZsn8OAvOa54aiCElSVEOHjLmWAriNbTcPnUjwi
rnNhroUBrsIqtW03y5A/MyJ3ZoEBz5h7W+ImKtFyuFrQHpgwyhOyK2VPFbbw
dJ4TOMsEIwM/9uYHVWjlPJKSpMKE1J6tGo/HqvCgj5tklQYTtHl/PthAVONK
BZ62DFMmPH/8DDrHf2Bsrrr4Q1cmOJ3hNsjeU4uKRlK/494x4eR8Clf6o1os
uagWQvvIhJyElE3s07VYyPI4cCSACeJ33XDVQh3uWOdaGxLDhAnxxhyftQ14
Ymf2gYNVTNgQe8xE9VIDer249nJtLRMmc0TchT0b8OC477bOeibozrZGeK5r
xIB563PG7Uy4dWkjn6JXI75u5zYRG2LCC68nvuYRTTipJbGkvYKA9JvXdyeW
NeE+nQrRklUE1Dm2mK8YbsJGqqGIKCcBb2OkKjp2N6NBk9uHH+sJkFujNnwg
qxnZ0O9StRAB4xFSr2PqWvDT4dajRgcJoGh2Pd0/0YIN/Vc+njlMgPibIYPa
/1rR/ZfZG5FjBERH56/ZdaMVqzUrpEuBgItnV1506W9FLmGaf7wqAbJ6Kv7d
i23ooP9uaL0hAWcClFXOiLRjpITJUxtjAsZcmrLylNrRUZ1NrNuUgKGN99Ib
3NvRNPNbrosFAc9XfswKE+jAxntiYy8tCfADz+LaI504tKJcZNCRgKKGD0s8
+p14mTDJqnUi4Amej9d37MRtjUMD8S4EVDGdFSR/dGJj2TOGmjsB1z2DbLT0
uvADR923A58I0Bl94LzCsQtflOXxdngR4OI/Vl8Q3YVZIg2tlj4EPM1JW6M9
0YWM4AL5D/4ExD2KvLjHqRu7NyTr3gwmoIA3L+BsbDdqreOyzgkh4GFv+Pjt
n9344Ep6KFcYAduPpwS1benBmAehrMAIAvSuvRoQOdmDOTxHNjdHkvNx7dHW
5yY9WO5VIcL+lYDFUdaeS0k9yBw63Hj+GwGuepbLNc09KKakbq4bQ0DbnsZQ
rYUeFEwsK70VS8AdY2L3pzO9uO/afKJxPAGTb4o5FO/04tflammNBAI+n/zq
8+9jLy6Fb1c9nEjOj2NuQFh3LxpVqmiMJBFwMExmenapF2dKTTujkgl4tffg
kWs7KPh31dlt2ikEhB1ZeU/BgoLC4r8KY1LJ+Vnyu5DznoInfy2tO5NGwNYv
11lKKRQ0mTBYaCN9L3ZrlO08BX3fvvHpTydgquSs905BKnpYPtuvl0FAZv2v
/ZSTVAw4L6j5kzQetLEPNSadwP7rUCYBDCPZu3ddqMiRW7ToR5onXXHqdBwV
R5c6no6TljXoWif2k4o/vHo0TmQR4KW9nMwzRcXxTerv35BmPxLftpKfhk8z
8reWkF7eVmC96igNM0+Hzs2SpgUsuW/Qp2G0jN2WHdkEtH7cxSHpSEMtr4bn
Z0nLSnQNnY2mocuZLRsMSTsEB29/VENDo6batsekS84OR0eN0/DUJ7PyF6Sl
Zdcdn+Kk49uv11v+5yCrnO/8QnTMXMe/+L/zt1J9zEGOjtrhGw/+73rOO+RE
HgIdTeVyrf/v9+WsJiI06KjxwKZAlPRyvW95tykdQwUK/8yQ9xusdD5GwJqO
h34RssWkdd1sP+q60ZGn6KGqA2nDb67PooLo2Pgg7uJh0nWSmTcmE+kYy70s
NUyOV+FqRXklpKNwS2P3e9J3kw3/BDbRUWj/Kx0p0vqDCmmzA3Rc7DELKSDn
425Bn9q1eTqW1tNDz5FmuD9qyufsQ12DS9cryfkc7BmQlxTqQ0FgKzxJ+v7v
q884T/ch3/AXq43k/Kc826rueLUPc67JZd8j86JQpD/7z6wPO1/ddCsi87Rt
/okz57s+fPKstvBs8v/GM8XcN7gPHwcnbbAl85i5DIsSKX2oc96iJZrMq9ru
FDmt1j7MHvT7SCfz3c8VgNPDfSh6IcR6Io4AFYnhCb/ffZiy61vqLFkPnmZn
+ZnC/Zhxqmuxj6yfIPvf/4L29SPN0nOpJpocT3/jx+pn+zFf1nB/LFlvUxzc
LdV3+jFHVWezMlmPcqc8c9+/7Me0LM5sDrJelbYor9f07EeBpp47xWQ9m0Rf
mP6V2Y/vLCZ+8ZD1LrlsM3WTbQCDDxX6HQwggPORg0w33wCaWtjkvPEjgPeI
vqmB9ADKcn4bKCf7iZZ9c8KzqwNYqpJ3QJLsP7Tjq7OpXwfQWfxRiJYbAZss
Yuac8wZw/647S4quBJiOfJvYWz+Atu6fBcSdCSj1CJnwYQ3gSS12nRIHAgIH
DSV9VAdRIqRpzNyagH2Bt04ZGA6ib/TN/yatCJg4G1Qj93QQX8rMRDwg+2dN
Evt/3SGDOLqigaZ0n4B/dgztW1ODaDbfk6dF9uPzB/oOnvs8hGw1/hd4LhAg
IKzafzV5CPluxXyqOUcAM6rFxKxsCEVOP/5mo0SA4EhFuvf4EL4sFd6ScpyA
3JcCRkJKw5grd/SvnRxZP+NbT7QQw3h5hvfmB3K9wXUOcwIrRvCKZ+Sy5ToC
tM/71xtvHsHVKfJdKmsIGF0pmvr39Ag6aImz/1xiwrOWdso1/xHs7r24Y88Y
E/ynJta8VxxF1RZTrYuVTLibWSvqeW0UP22RVv1aygSb3crn/O6MIvM/69zJ
QibMWfx6E+M1ioI38uimGUygZ6wP6+8bxZPDLz3Tw5ggvZvdN+4NA1cuiM0y
nzGB8P0qWePPQJNv+ovPHzNByvIjDzOegQa/OlYv3GXCn1vNqXtbGLikzcHZ
ZMgEu0/+c9XiTFRzlVwcIvcTBgvUMqkKJp40DXL0EyA/fzmBU7uLiUrMJ1Zq
m5gwNGBBfTvOxIbDkb8XuZhQab1uLYOfQANCI1Z2mQGExe3xlFsEjrv3thGD
DBBR2nXlLOcY3h5eVdFD7pd63FOrdl4cRzF3Aevr5P4qOuLSn79G4/iTa2ww
XpYBL2621jRZj6MecSzhlzgDJqsWp60jx3GnU4zY2U3kfq1rTC3pN+m/1H+S
v0ZhZAXlT27ML7w19D0LI0dBPmqukco2iStc6MI7lkfAYnpALZxrEmnrOW5r
zY7AiSS2NsPNk+jwe9sla8YIbJShVHTKTGJ/A0ePS8sIpFBecaddJ89v1/Ru
+TYCyOZiMJUwiV37JoYkVUdgYK+hn5HWFHbZ1HN7Og1D4s7qC8EGUxjTO55W
az0MA0dWp7daTKH/lsBDrDvDYCPOfHTcfgoPcmu1CKoPQ1XcQX1a9BTmG36+
4Cs0DIP7Ocqt56eQ71jmG7WUIWjJOeT+yXcaTy2GD4zUDMIWVKJfDJ1Gvbh/
bcv5g+DsYP6APXYa1zTMpK1JHARHgZgFo4JpLHyfubfvwyAYv5F/0d83jWMD
9W416oNQeLT97JjcDOpEjajebRkApyeX9MtKZ9DqWeVLjrp+SJLZfHr/jxk0
XxkvJ1XYD80TsV++NM/g9U/lVscS+8FP84+P/sAMmh283HrAox/iDgxahKya
xQh9BXvbi/1gpDwUtvL8LErbtr7Qq+oDNseeo2Llsyjqp7oUnkkHfg7dc3W1
s1iVq3WVLYoOL+tnXz9qmUWr+mP8V73osE+xxjCifxZtw9vX/HxAh8Gg9rA0
tjm0O8bmuWMnHZwOn9C0Oz6HnU9znwdJ0WC/1lD0g4Q5RBOL1cyfvTC0uGdH
Qfoc3kvcqrr7ay94ZNHEl/PmcH17b9xl215gFvt8vFs9h1F/7h46tbMXbikL
Rv8cnMPxJxyMmpc9sCH43bV8oXnMc3LdHivRDZe+1IbfFZvHrP/K+aR/d8Gm
lHuZG6XnETUCD3r+7AI2bZc1pxTm8axbmB2XdRccfzDOt019HqlC9purKzqh
Xq3xT4/jPA5tNGJYGnXAZdZO24G38+iz4unn6wc6wGNt+Hr6h3l0uu1YI7am
A6pNeC7lfp7HB9SdF54ktEO4UdzEQOo8ZvTLHJiebQPFd5FlwpR5vJvYxPrs
1Aqj5veTnvTPY+1iCHPttVZolynjKBiZR9fu3j+mO1vBi6kwIjU9j63lMhId
1S1wRmDurM0aFmbY3bIr5m4BbYHEaxRZFkbOifHnfWqCgDv+13buY6FUkNFB
HrMmiFfuKTU7xMKvv/8Vqh9uAr6PIWWlJ1k4zTD69o3SCIMdDomLl1mYdk5t
l7d0I2wblL545z4LG8WL0/ntf8LRO8Pjqx+zcFXIdYPGHT9B6lqVb4AVCzeq
Ev0PK+tAgU2i47MtCz31PpVpb6iDn6xT77e6sfBF8sA6RtgP0OXSa2KLYOHs
PlH6ucIqsFp7bQMRxUI5Nad4c8MqiC9h/1PzjYXly5/CH7JXgSjvhu/miSyU
x48PTqpUwr+BqUC+HBae8cqT7mwuh6yHArlReSzs6b/2S/VZOQS/WjDYVcjC
qTqX8Lgt5PGEmv3cpSzcfWJgv6xeGRgO8jpc/MHCYUKJrjZYCi8kRm6/qmOh
gekXuoxrKQRKyuRG17MwnmoZOr+rFA5/uPy6qZmFxh1XinXulcDm1EOXQrpZ
eM9hmL+0vwhKWhR5rHrJ8522DNpIFkHvUVXBk1QWHtPQHuK1KISLvFzcyX0s
3Or50HR+LB8yfpf/ZR9l4YWFCE/HuRzgOn/3rRWDhUWWdsLix3PgytaFwk4m
C2c4VT8mv86GIS9/EcdxFrZvnG104cqCslfHVMp/sfB+hvWqFvVMqPMZ3/R3
goXOO452c/tnQG3LM9cL0yw0kheRvyCaDhOXnsoYzpD34+G16bJ5GtwPar17
Z5aFAXcpuqfjU+FxSW+a7jwLFV6dbpm4nQwSzLPZZ1hkftZGidtNJQIR4HlF
dIGFlSpBjUzbBDj9ffuhnN8sfHfao/nlh1jot8h7bfmHhcLNOlMRm2MgY3rk
pugiCxmyN9nSwqIhjN/lexlp+TJ+8wSpr+AW4pCt+5eFKeWXXbzTIiHmcdeh
UdJjqguVt49FQIRPDNxZYuGbtS9EdVzDwERuUwuVdFAp5WN5QDC8fqc1ofKP
hfT7gt/44j7DC9EinxjSPdRnBy7l+4PHpyT8Q9pN33bVw1ofUIwPeqK0zELv
8fHhl72fIPcBd+Ir0qOKfhqs7vfgxBN6L4V03vcH8t1/XUB7cim1lXT108U1
scKvQTd93O4X6Y/vtw3WvX4KO3Yq1f0lLbfrzbH7bsZgdG0gYpm04F9XU5Uy
ZdR1rPs7T/rIyUdF6+4+wDExbko/aWkNnTAfS1s8zyxTKiP9+NYO1VVbnPBF
sdSeQNKXT7Q4ys65oWvhmzBj0mf8eLpPtHzEEwpyASKkOUr39ARoe2N1qj9/
M/l8vj7qRQ7KfmTuTwu9IG3h9f6cpkIgfkkvieUjrflX4dsGyS948kBx8Vdy
/M4WMf5L5w3Fy5Gz+tKkm9aWUoQcwzHGbP/bSHL8WZGbiSsLESixUuf4RtKz
MTk/Hj+Kwu9+51VqyPn9l9ViYaf/DUFOPoqPtM6Kel3j1hispyp/0CLzoDGw
9Z38xTjkCRLgSyfz0xp4dJXLkUTcXuCR0UDmq8z7tStHShJWbo0e6ZtjYTYX
R9oDyRTM8V7LN0jm0/65bc4EZxrqOsduaCXzu/Zd6PbZsjT8rOX1LXeKhSqU
yk8jr9Lx2kRWkiGZ98Mw3xk4m4EybiE6kmS99J1zDfiPlo19R/v4v5D1JfLs
ocrFuBzUdX1lv3KEhXZ3D1rftcpF/b3XdRMHWDhZP1x1jSMfh7LXpBiQ9csn
69daJVeEe19MiN0l69vySvcfPlYRcpQz9S06yX4pEvrtdEkxenh1HDnZStZL
6lEeAekSPNJyYl6lloXFN9RTZPJLMdKygJ+oZuHLz98unRb+jhs+aAq/rmSh
9fs7xafffMd7JvFLb8h+ZPMg4P5K1TJ8/+f0q7FsFt7KaRFx7izHfO84Uc0w
Fqb/KZXhn6rCGHezozuDyX4AiWmZmtX4KOut11ggmWdbpvHR7GoMMmkS0PRm
IW2TW8SkbQ1ORi8ccnNm4fNWKQ2ulbV4Ue6SW+Atsp4mxw4H8tSj8aWepEgT
cvwGkw1vPqzH88GCr8MNyPxMGuku1pOumVJ5fp3sb8dlznd6NuCGbS5nvc+x
8Gn5x8jfbxtxoXcV03kH2e9evduUtKoZc03sA4S3k+O3cCO5Ur4ZQ4oE/iQJ
sPDgxs6zDXrNyLtNczFpAwsLavx+JmY2Y5qpZN6BpXm8fMjogp9pC47884jT
a5/HUjUV3b9FrRjo0SFyrWkeZcM4Q2dHW/Hppe6yM3XzmGA6EtrF24ZP3GYz
V36fx7j6G1fv3GlDO1bw9g1J89g/LVP/hbcdVySHntYl1+cv/4r3yJt14GTL
D4t8u3ns/piYPfihA7W1M89stJ7HRu/KSaecDvyq7How/O48Lk85LTuu68Qs
u3aWhuY8cvYW73mR0ol3ag63rBKfx3CRc3h0rgv3a/HuGS2YQxNlPf5Tj3qx
LtExJDRzDtu67sWrf+7FamnBlxeT5vD9CwOx82W9mKjzMtctdA7/q2A73bWZ
gj/nmt57v57D33rlw8GFFOTV6o3+pTSHUubXXV+z0/CTlIaRWOksrmnWEnIo
oOMTObXrmDuL7RHtKV/q6Zjw+811rdRZrDjuzBfbR8cJwfPxt8Jm8aCzpcQn
jj78V/hn4x77WeTa+UwxmHzPvRh9ylLz8Cz2O+Lq4KE+jPXytr32bQYZN6WP
/vvXjz4N19uOhMzgJZPnMxkbBnA7Zcf2zb4z6DyctFlHdABVef9GFzvO4JDf
gqOl4gCW5EQvVuvNIOGic7P7zQB2pj/99vO/GeQ/MzP1ln0Q7S7Oto8/n8aH
k4/NjswNYmEJ18TOh9PooJjyX8vKIVTKJBx0zaaRNjaZrbdpCI/sNTqRoz6N
N3LeDZzYO4TW00aWx6SnkT1vMELeYghB5YuSbdcU6gfNLQy2D+GuX0+H9h2e
Ivv9g5WOMcNo4LkWI+SmUIT3VJR4xjDGKxiMr5eYwh+cUs9zioexrz//ft/G
KawUti9NbxvG3j/rZm8zJ9H4aeyGBfYRvEvT/MceMokHi1Iu4M0RrM/neJhM
vl+YvNnoprE8giZMYYHM8QlU37FvSXjtKH7Y+VGGs3sCq1Y9/E3ZNIrPBvwE
Y9InULaE4ie/cxR/O14cLDWdwHuHjlVLXRrFbXnfL72o+IVmarc8LfxGETxM
X+q/HUfjaOubZ7czMO/F15doOY7Z1XmpLEkGWn87sElUbxxn/rbEB+1h4M3M
Z8oU+XH8ouMbnQIMPPBWnnKhewzf/qp9ttmYgdcTRl4vyo7himvJWZRwBsbP
7bmptmUMt1xieX+MZWCjydORyBVjOGXT6ro3lYG5Ih9MLrQTqM3R26iIDNTZ
uSrbz4FA0TcdlbG9DNy9Pt/wWDMTZ9xWSr3lY2JC8RpNr0Imun3s2XZSiImf
blxmZ3xjohXfUszADiYuV8S1BNkx8YyTVyT7XibSRRpn10oycfHHHX53FSZS
U5odxG0YGLix6ynaMFG+79XHOJFR3C3g/G9DPRN7uVduiOQaxai+fNsA8nur
1e+XBbNGcCT/j8OmDiZONv2dCmwYwcY4nrMDNCZ+SO5yS3IYQYmCArfJSSbO
Ct+1V6cPo8dNw7KSjQSqOGRzWNYN4+zJ0rvOfARueRJ7yzd3GG3MejefECDw
QYVl9cCnYWzS/Rb8VoTAdoPKHd8Uh7F7x5rjn+QINHaykSqNGsLnVSUpD5UJ
1JxIucL7aQgD94Vdt1YlcOP2Xd0WL4dQY3Sd45PLBCoutioJXxvC5eIPr1U0
CRwdbTiXsWYIxe/mr7tvQOAtF17HHTOD+HPmYbKAMYFvL3KY+dAG8ZBXP3++
KYGqD/kV3+QOIt3huHqPBYGp+wQPfbg7iHkPzLQCnxA4VB3wfuuNQdRUyWUR
TwmsWXGvOu7MIM6eVQ87+JxAjrELvO3bBrH1bLhQtB15/1sPFxs0DOCKGtmE
lc7k/UlvEeAqHMBuU05NNlcC3/GBT0HsAIrkUWD6LYEvs2rXSpN1PBXSwZn9
nsAbv2wLFA4N4KqPRceKvQk8J1IWai42gJyPBpP1fcnnX7czJZDsE6snT/03
40dgvufVx1zMfpSx34DLgeT37+XbIRHWj0+/e/lGhBI4NXNT8JlHPw5U1KhN
hZG5Swu2/PGiH7+ulFM4HEFgk8UnjTda/XjrykhkdBR5/eO/bXat68eFrWJN
PLEESnnKrwpm9eH8cHL+hjgC19gKC/GTfYzvxGFuzngCoxU3sfOX9GFTstfq
3gQCTw/O9H5J6sPlEo/CnEQCe0rP6Oz60ofecm2/3ZPI6xkaX7xk3YdBD3wk
N6UQ+KEvvnbItA/pnVLi1aS3nrzJ7qzRh5CrWvE0lcAVWZ6zO6EPb3u78Aqk
EThZYxhTL9uH5e/N+NNJW51vEbET7EOqrmWzUjqBZhdHTGQ5+7Bd6eDVH6Sv
3k/QCxmgY9b3uZyiDAJzGULb9ZvoWC+9lCidSR6vTSrYgXSk7a1740HaK1ji
JJFIR76dA6eHSW96d+RbXhAdVeJKfilkESj+0H/Rw42OJwL7fF6R1qDQFM2t
6Ti+tvRwEemh/Qn2SmbkunCms2+a9PMQpwyJq3ScTg39LJJN4GMZxgjXaTre
6HC/dYb05w51kQU5Og6q8agbkE71kzBgCNHRvzBI/zHpIYOyWNpach3CCP8X
pKdesnNkT9DQa8qT3Zb0u8IrQ9m1NJTvboy1/N/1do7OlsbQsGvo5ycj0v6t
h051ONEwUf9X6XnSHy3ca+YNaZhvEHBGgvTJnSJhoido+KpJZvtv8n4PcgtX
aQnQ0NyY+3oF6YmxgAs+s1R89jRgzo3077fue3obqbhOXHrlWdKro7rt9yZR
MXWvkOs8OV7s4gbwwZ2KbMvlLuGkj0o2286Zk8c97daSaw8aCdAPWyhRMeWJ
l0APOR/xbdteDQlTUaXsev490o15nNceLFLwmcjW+Rly/qSKN5Qvd1DwVLh4
ixXpSC/35uBMCu5pLtYmyPmvSct7e9aLgm1J8h9vkv70YJg9U5WCPQejJEXJ
/DwISuCxl6DgrfytVbfJfJlWLZRf/deLfpkRpdHJBO7Pl9STSO/FdrHq4VVk
Pm+sg8uiHr0Yu6lefCeZ3//yNXmkb/Wi+M1M6kky314aBULGgr1oMlExrU7W
w6PflrafZnvw5vmjBpfIenlRS1TX1fcg7+y2+6diCJTvatC679SDgqWBPmui
CSw7r8SmMt6NVJt9G6TCCdxFpGfRqrqRdZDXo4us1+DswADnyG7cvglnHEMI
7F1/YmnuRjf+CVePyQki8PL98v9syrpw+ZHp5xyyHwj3PB5/EdqFk/2Ft3b4
EBjzb5Ws+4su7L8lfuuNF4F+364SDXu7cKnRRHj3RwKJU4Yiy8GdaGKaefc/
sv/Icv3E+zad+C4yrPiQC4E6JqEzI5qd2Kmc+U7DiczH+IwMB1cnnjbjSX5E
rlNG2sdsGC86kN/qBq8y2f/WvbRcUrzZjt+1WtvvmBO4PQtU3yu0Y3bdnsy1
ZH8tTIiw7d/UjpZDit4RRgSe0j8fkF/bhn2yq57k6RJ4JjX2wKZTbehRNxv7
ToMcLxdFLRPJVtSpEpbJP07mj9IXT1/VitNXnp/YcJTA8Jd3L90bbMGeNW41
+goEio0r2EZHtaDrAuPxiDxZX80VZUliLbhT+3F8kiSB858d/2wQb8Z33gwL
rvVkv8vI2KC1shlfGS0dX1xH9o/tuV5fB5pwuOX81CAHgSGfGf13vzZhh+Rb
oW8ryPqd3DjssbMJdc12bafPMpHi/SR2l1wj6tedOnakm4kXGhWOHVjfiFf7
r22paWfi7liJYH9qA/IEDh/RamHiRSePZUXTBhze8NhYp46J6WKm5yoe1CM8
2jghUszEL8W2/169rUPzmVrJqHAmFv73/Hb5z2r0q/SyiDdm4l60sVv/sRrX
E4ZuCvrk+ttuwW19pRojG4bLCrWZeHkgMSKkoQpv2YzG5agxcUos7OWVlkoU
VZ+avn2SibygXXSITr7X3FJ9lLuFXM/d5wW4N5bi1X1bPZSrGXjsmL0le2sJ
dl7PkJIoY2Cyx0+2zYEl+M2VJ3OxiIGLiXFZvqIlGBnZnfIlg4HBUrVidPNi
fNz+ejQslIGtSgWnFPLz8XPA3dRiKwZyXQ49pPwxA/mOX13pIMjAyJyyoFGJ
DLx648ulnfwMZLVFzBUUpONXmlp9zQYGOjqFWiww0lDg8ZjH6tUM/Dhfc6ZK
JRV/fIiyUp8YxQMTRqJ3ROIxIW6p+HDZKF6I3SMksu4LbiqeVrhrQe5jPhyX
U9nqB85La6dPx40gH3LGVLr6w4vnEfwKUSMY2XUuxHMmAM4k7/wgFTKCIh87
i1bUBkFIy1GX1V4juD3oHEf2kXCodnOdC7MZwT1qP+MV66MhtHVzoo7yCOZs
73U4p5sKWnHjT+b7h1GBeyAlvyQfBgS2KtnxDuOO3ZdEp7cUgHOwMfMy9zCe
33J8jPWwAOIUs1WFVw9j50P37ofbCiFur8fp3PkhZF7NH+N6VgR1t9V1m7qG
sEWofsRtfQlc6Rfl+xI2hIODyuImX7/D9uGmtZHSQyj95cpTJfcqCB2wPil8
ZBBHcv0D7yZWwb6wqP9+yw9ixpvAP68aqoBrbahrs/Qgrjht43Ofvxo21DXf
dBQaxNU/TnTrhlcDj3RIf/2/ASzO2VrxKb0GikqNhGQqBjBb/9025+pa0FSt
FZpTHyD3A7Yu3IUNsEWRu3qveT/+/TqcsIrSAIVMx6879Ml9xZt7QSNLDfBA
OdBs07V+nFO3W8gWaYTKXesCJs/24yP531nFRo3wQWzPQphEP+69qnm7g94I
wzKUE3UDfWibY7xTtasJ1mcMUW8Z96Eg63QRb2ILCMP9iCUdOprxLNtX5bXA
X7snYr0adDx8KnrBsqoF1qYoTOddoGPUvjLphP4WGMlhvrE6Sse6cm9KskAr
VL878Z4qQMf2VesD/71phRDKu7e7U2i4f02Xfod6G1Sf2VIsGEfFC6wIZanm
dhg8wNlYSb4vJlSG9NJ624HOQeHUedeLHCGaWz6NtENbjKQj07YXt0v0vu3+
2w6qn6MOcemRfX+zf9CWXR1wrbu39YxwL8o/f5dw0LYDgnYpCPpE9mDTVoVr
XEKdQL6u1aXHd6Or/oXiROUuOMv/Q+VoXif6xe89a6zRBRcPBk5qxXaiWHlQ
M49uF4Qmy6x/HNCJv3gqedUedkF0t3PK12edKKj54MkT3y7oCy9I5NjfiftD
ZKdP0bpgSOphYFZ8B4Y4Zm9d8agbPvDwceR9acdAuckrmc97YPBpSaH/y1Yc
mlJI+vOqB/7YNIjn3W/Ffz/kIo+59oBQYOKFHr1WtFK7eCPGtwfY72u3Cp9s
xfS8nyIH03og+hVjPnKpBTXjjqRtY/TAhYKehbBXLfjwQELJIa1eyJbZM//4
dTNm56ZeTL/ZC8Vqsboej5ux8MibKCnjXnDK3ewdY9SMqzaPIvvDXqj72WBF
Od2MxsqrOu+/7QWNYhsB5RXNZN8t79+a1wv0LSkam940YXtC5b++LRRQsTmd
8N6pESefvjd4tZ0CsitSdk9bNaKeoQSLT5wCDNUP77TNGvHw4R2d8nsoELh7
/bjEuUbUSdzxSvwsBTakSSsXrmnE7+oxL+ceUoBZJHe8lrcBdb/4brxWQgHx
kauHVUV/opW1+8rjFRSAgpiwjSt+4g6+IzeEflBgk8FtSntfHfqOmEvWtlAg
116vxySqDm0W5O1HhimwW+nSpM3OOvRr8t/Cx00FerjnTIhsLZrd2/jl7FUq
yOrs/FF/pAb/7CPmWq5T4fynrCeMzTW4kGvRo6dLBdFTsLhyrhrza40u6ppR
gUviavKRtGoM8bLsX2dNhXo33/hw6WpUF/ZjUwikgoXe99v3BKswOm38WHkH
Fdivl/JMLJbjNlONU297qHCgsDhoTXc52rj4Tp2hUeG4jze/cG45Kn1g3Isf
poIlirVfelqOq3qL62TmqPDkzG2PuLEy3P6hQXTFfzQ487iO34jyHdN0BMv/
nqHB+g3NX8uKSzBt7Gd7+XkaHBxz3y4cVoLzb52d316ggdA6zY82DiVonpKY
8fcKDV4frdeWO12Cz6fsrL7p0CBZ676snBPivaeGaxce0MBk9frkBrcizKUb
C959TAOtco0apwtFmHzav7H9CQ2yyyu7Dq8rQqu06T3hz2nQ/VW3J+x9IQ7M
lZZNv6YBv7enxaOPBbiWN7k2wJsGoi3n+rl987DBUvBppi8NZv2GH5Zo5WFU
bOCPWn8a7NzgOWvFn4fnllqdmEE0UDSvJLr9c7F10+VDo5E0UJA+7Rn7OQet
Z+aXB9NoULQipVkpLAubMznKEzNo4Mq5es28YRbOHS06+SiLBj2r9hyKE83C
sKmfmoO5NJDVff92Q2QmphkobvZEGiwdPcfW+zUD/77iuTJSS4Mtdb76T+PT
cJSz46nLTxoE2Uuk/jBNw4sBdVzbG2ggaDe6LLo9Dc9F7PY40kyD+VbvgJ+e
qZgQ8mNAtJMGAZdzr11mJiM4CH5+10WDrWfY237rJWP9/tPfx7tp0PHTV/1b
QxJmcBRahlNoULnW4ORyZiK2OdSr5/TTwEw9ajrVIR7ZVxxMHRugQVqOsY7+
dBxW3P/sKjREgz0T9UVrzePw/MGWz+YjNFBNV3ltohqL17VDTBMIGjQO35rg
5f+GPHPxzoljNCip1FIueRuNM9tMRWLGaRC6MBFy/89XdPNmL3OboIFYgrdy
BS0Kzxj3/FiapkHYSzZP6/gILPKUKv0xQ4PI0i6q2PYIfBF98YDXLA0urFy7
p8EzHKefrfRYN08DC1N1PzVmKLrv47IqIu1KuSMf2xCCJ9rr2++waGCVFfmD
LSsY69bc5E9ZoMEJRuPfNIcgtE53nlT+TYPrm6d815l/xgXXfRe6Sf+55Spr
qhqIM5u/WxF/yPE5r3WTj98fuXl/n7u7SM4XV8Lk/T++aJqn7d9P2tc5w7WC
5oNbs8TS8S+Zl30c6dbxXuj6oNFeYokGRw/cUm7w/IR3/OWq3/zv/y/UTuap
MT+i3th1r27StU6PBtiyPPCN/O0umX80uGX/iCfd4R2+lHoebk0aJ5UPm6q6
oUNoyHA+afexFcZ8/K6oYzyRsED6FFv0uwqaE1qedZjcu0wDSf3Dmdbxjtgq
YpBpRDr7l12BGvMVyjUGsd6Rrrj2Yn26gy1SFZTyk0lrld4nr2dN5tXwby1p
EcOb5OctcV/5n6J+0p5z7uT5d3FthdDyNOlyTz3yuDEmylfhX9L0lP9ZA///
/9Nw6PEd2PktovD/AJvTgao=
                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.1983560419796233, -0.6198581523001176}]}, 
                    LineBox[{{0, 0}, {
                    0.1983560419796233, -0.6198581523001176}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.0330593403299372, -0.10330969205001957}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.0330593403299372, 0.10330969205001957`}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.1652967016496861, -0.516548460250098}]}, 
                    LineBox[{{-0.0330593403299372, 0.10330969205001957`}, {
                    0.1652967016496861, -0.516548460250098}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 96->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.2657805913708775, -0.5569426042329243}]}, 
                    LineBox[{{0, 0}, {
                    0.2657805913708775, -0.5569426042329243}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.04429676522847959, -0.09282376737215406}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.04429676522847959, 0.09282376737215406}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.22148382614239792`, -0.46411883686077027`}]}, 
                    LineBox[{{-0.04429676522847959, 0.09282376737215406}, {
                    0.22148382614239792`, -0.46411883686077027`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 97->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.3287091397783787, -0.4846966796212191}]}, 
                    LineBox[{{0, 0}, {
                    0.3287091397783787, -0.4846966796212191}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.05478485662972975, -0.0807827799368698}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.05478485662972975, 0.0807827799368698}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.2739242831486489, -0.4039138996843493}]}, 
                    LineBox[{{-0.05478485662972975, 0.0807827799368698}, {
                    0.2739242831486489, -0.4039138996843493}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 98->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.3851497821037342, -0.40296699297992616`}]}, 
                    LineBox[{{0, 0}, {
                    0.3851497821037342, -0.40296699297992616`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.06419163035062234, -0.06716116549665432}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.06419163035062234, 0.06716116549665432}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.3209581517531118, -0.3358058274832718}]}, 
                    LineBox[{{-0.06419163035062234, 0.06716116549665432}, {
                    0.3209581517531118, -0.3358058274832718}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 99->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.4327986097863663, -0.31211386573727673`}]}, 
                    LineBox[{{0, 0}, {
                    0.4327986097863663, -0.31211386573727673`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.07213310163106106, -0.05201897762287946}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.07213310163106106, 0.05201897762287946}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.36066550815530524`, -0.2600948881143973}]}, 
                    LineBox[{{-0.07213310163106106, 0.05201897762287946}, {
                    0.36066550815530524`, -0.2600948881143973}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 100->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.4692161335313524, -0.21322538516063658`}]}, 
                    LineBox[{{0, 0}, {
                    0.4692161335313524, -0.21322538516063658`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.07820268892189204, -0.03553756419343942}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH
5nXOsecRhTIqO9LQoIjf/Xn8Hl//8Hzct/s+1/Ua13X9cYRu2ulZsDAxMUms
Y2L63+///9MD//fXNS0j2aU1BkhcPnPvaRRAlYPj2w+EDcNOcflEaUMZOH2q
Ipxrs76/s/AyvNiUbOlHWMOyOk4t6gbcztPWVSbsYS3IOF9jDmyP1nKnVxnQ
KlrBb1FoBdlO4PCI8MoPmqllyl3YPF6TzUFYdTiNdj7SDhZKFS8G/2NAfhjz
8RCaAxQrpVr8WmEA69wP2rVqJ3hsOPlFl/CKw1s+PpILuGoIzSUvM0BHfvfV
5nw3aKvzvzr8lwHnrhlEGWW6w49hY9XNhOuv2g/2JT2AKkcuJ7klBkDr0VmX
cG+4uMZKl11kAFew//dOug8k6GaHif1mwMS5F+nd9b5whiGRNPCDAa4Ws7ov
yv1g8er6yfgFBnSJiFlbl/lDpKlx6bnvDDgVLWQuUPQY5KMejHh/IZ5HrlW4
8DIQOm6tV1s3z4BJE1EJemoQeE4Fy7jNMSD1ywclgaRgKI/ja5WcYUAspWwg
PCoUKm6dYZ37wADRG2Oxwl5P4dy/buEfowygmRZ+vq4UAbZzouNzwwzg2Hji
dVJVBLTYcpoWDzJAaYNp7DQpEiLqjpZ6MRjQs6vyVX72M1D91HGFvYsBepkH
ntqKRsPyL4eGkHYGRP76PcCfFg1rq28WjJoYYLH9n5TK8xjQOnRTVq2aAc36
hwUDQ+NA4cJfB8MKBvA7xmunscbDvVv8MVfJDKAzjVzL9IuHxB7eLPkiBrzj
KDtp/iABnJQn/E+mEe/vOmtbcTsRvPv1tnv5M4CTiTGgr5oCQnNHc7V9GLDn
iswu7uYUoHsyf+Z6yICh3zcHDfalQi1bc9I1JwYUX9w6XJmbCrunLj/fb8aA
ucKHnUmlafBKZHA6VIHIr10me1PqMoBpINf3/DEG6DfeTcPVDLDxt7y2cpSI
7+eqpTbIhJvf7/87KMqAH0u9OxNpmbBZTZ67noMBQX3PG/Y3vgRupSv/9Y10
Q7DfTfPSxmzIb35XEjbQDSN7VaV1/ssBr2XTi7KvuqGyzof2Wj0HDm+UDDNq
7IbPHjliT+g5gEn3LT/mdsNblSX1mvpc+LTX15/ZsRvUv9x60VaaDyOT+8ve
/+6CN58aOAR8i2H5GrlU8WsXHOh7O8BWVQxmrBqiodNd8K1NwGvoWzEEDV+N
+m+wC6Rdk69ulSyBjw86J25WdkFF4LuDWckl8FtIRnjQlXjeHw+nn/dL4eFG
Of9/s50Ayv1HkoVI0J2qy/7hYyeYxGqYJymSYPmnSXLFYCfoqmwqCjYggW35
/I7TzcT1QRc1qWASxIdLdX5M7QTtKlp22VcSWN15oiCo3wl6ndvm7KvI4Jjx
Kn03qQPypKMj3aAcHp9e2f85pwMidzimNhqWQ+Lkp05KcgdkNB6krt0rh+z5
2/lHQzpgoV6aVSWpHO50ikhVmnZAbfrAk+nFcpAQ6+KRZe+AtwXLvW35FeBT
7+qmaNIOt1+cnUxaXwWnr6T/YNNrB4qh34cE3ir49itS+c3pdnj12WrQT6IK
9tSH2OtJtsPuN9TMvUZVYDYn07HE0g6PeFf/s8uvgiQ+kS3M2W1gZvB62eV8
NfQ1SCqazLZCcIyEyop3DUxNNnKajLQC7arZRqHoGmiTHTY17GmFkht7O47m
1EBWqkbD8fJWwF/Wx9b31IBOyVW9XN9WeBtacP7F3lqInD7H7rirFW6J3uy+
X1ELGy8xBpZPtoCTs+nugYE6qHPilNOSagE3DZorz6c6qLH5yBsr0gKi6zRq
1f7WQUNfSNHejS3QdkaDVY+vHhpk/SpWeprB/AT97dUb9UDWFq78Y9YMSt9X
m/Z+rIfWqdjzpr5N8OhItciDPoSgR2uiEs5NcJXziMfsB4RdmVTSsmUTcPL7
7j39BWGDDrPwk/NNIMb1UcrsPypInD7mnbCrCbQm/pCt9lLBd+jiRv3CRnB7
dPpPig4Vtm/8EJo50ABGERuLXhVSwatO8Am0N8A504GQSyQqXFy+nPq2tgF+
df753FFJhRIaKz9begNohF7WTm2gQgFP+NNbNg1grsPyfWCQCmuafr/+MDXA
0F6PycfMNGBxD7jy/SAdspTUfy1q0cDM5jWn2R467N9iXFmkQ4Nq/oOcr9jp
MKUQ+sXYgAb5DM7tZV9psF/Ar/3ZdRoExbjYulNo0Kt4dTTQngb+22IrxFRp
UKlR7+4VRYN3ek83p0rT4JMI7n4aSwOv1J06vKI0eLTzcHDMcxpox3EObWWl
wclq9S9+6TTgvLG0gbOLCn/U/D2mS2kg/zxMVt2ICrYGZ393d9Ng4FDt2Z5z
VDh7b8YKemnwsdD503UlKlzVMWDLekPc3z+54CNAhY99o0yGwzQ4VuOiV9aB
ELE54orqJxqcmTRNbJish3X+hYZazHSYPfY3cVdbPZDUv4wL/UcHw88iHXYF
9XArc3LT1w10EPZ3+n3YqR6Yth49cY+Yh6YHaerDTPVQHa0+8WcnHQ7vdbzH
x18HN2O0DhgfokPKOl45YK4D8Wm/kajDdCh4c3PRcrIWRsRCZ+hH6bDZoyuq
qbAWpjQsd2+SoYNU5MYS6slagKdn4o8q0mHM0zGPXaQWbpwaLxRWpgM1vGHD
ddZa0Fc5fp4T6LApoJdnK5H31RbBSp1qdLCS28pabVYDaaXsKeNn6WAn1u8i
fboGzjPZFEZr0aFV62p+yaEayC4ud1O+QDz/skxi/Y9qkJmrNHLVoUMa+g8L
BVQDR50ya4AhHb5mWfS03akG20DM+XWZDuKRSZ/ctKvhPH+EgokRHW63+1dN
8VSDQm6/2vZrdOiKPrlxS0EV5BdsyRE2o0NYmIfpbEQVhLPtva93k/BciGyH
SxWI+X2542FOh2Pz6QGpUAWmw5G9ZRZ0ONRYsCNGtAqiySr6DZZ0iEx4ej5i
UxU8v3+Hu9OKDuHd4++e91XCzO8xk+bbdPjM/uJ0XmUlNJRsXqq4Q4cEWXxE
fVEJSUo3ZtLuEvFUfPWM2boSPCdOTF6/R4dpA7mDAysVUCNwfp2XPR1iDSYO
7B2rgJ0191hkHOjwpaFPw6alAq43Mod+IFzhp7zCH1UB/Ezb9fY5/W++x7J9
3SrgqYjRi1rC54MFYj5fq4DnPsmh553p8CK0+fLg/gp4+T7/jqELHejvC04a
cVSA8Hcp6x7CE1yiIR8XyqFP45iwuisdDoST1RwGy+FHK2dKEWF7t1f2G+vL
4ex2vkluNzpMUgb5sjOI+y0of+0IR3Nt074QXA5xMdJTTYQX1Mlcy7blEMI2
W7j9PjE/IkOWJfrlEEmRvHKN8NE+ziVJpXJw27yjK56wkf20ZKVIOWz52LSH
QfjLjY5dp9nKIWW/+dk1whMuW0nvFihQHcl29aA7HZo3MG9yfUeB55HDBhcI
C/95JcBDp4Cn7sLJu4Q3DRT8o+ZSQKjQao8f4eD3eTn2kRQ4JW74LZrwHp5+
sf3uFFBYfENPJXz4+kGvCVMKPHn3Ly6LcMr9CHKOJgVeyY47/88aB2cYTpIU
0FxLuP6/+41Prr7R4KHAaNkx4/89b1tmZOdeJgpwGDbaPCK83lWvanWaDJ02
VxLvEC7fMpY2ySBDyc/V2fOEhUT6QvsqyLDhRqPp/8ZzlJr7sDWFDMyhJGam
/43Hfsi9MZAMi/imt4cY/yE1RlCLHRmqs6XfJhIeHBkpenWZDD81e3abEY6J
1v0+BmRIYSYlCBKe1Tv3gXcLGWobde4+IeJBneOLU10iQSAne4sS4Z8TX73s
PpCgdpzddZKI75+CuF8fSkggfq/z4z7CJTvOPRFNIMHEKc+cOiI/zI5X3rXz
JcHbicv92oSvm8yx7tEjwY404wfmRH4tHBPseXCCBCrClisTRP698v/2dVyY
BF3iN5dMCZ+oKNJs/1EGWdkjzpqOxPy1pYZoDpeBxj6pNRKRz+5vZGW7G8ug
Wp6fh5ewR33T0NeYMlBw0N3Ub0eHd5eMRkO9yiCBbDInTjjUtfmqhFUZVNBC
7B7a0kH3wuuBMPky4J2vdOAg6qlm5tHp9KFSSL3APvmVqEdvW5Yoj8ZSqFzo
u7GHMBPrjfvGhaWwOGudoWpNBx/5BlEp71KoOXYg3ouobwWe7eYnREohtKGu
rproDwrKJx6jTQn0KE8LqBgT+WXD+v6gfgmE10yZMhP9prpn4M4LxRKo6DV9
W0v0oxGHr/tTN5eAmrlHkLABEZ+n+1UP6hWDpbOXf642Hd58tFZ2ZxRCirwH
d746HWRnPzx1SykEqViLUG6iXxpd2EkOsisE+XU7E5xV6JD/bX/wOFchGFsn
Bx8g+u1Z5551D3UL4PI2u+s6snTgGy3sURrMg5fSCo2Z++kQdXK18U5uHuwM
1peo3EcHrk02w/keefBN5XtQswiRD7+uP7biz4Mdg0n8rwWI+LaYSDSZ58LT
KBsL0i46XBJi3cr/Mxv8p1gPBBLrSzL9Q/olkZfwZdrKPecDDeZ6qza8/5MJ
dI7tzNqjNCBZd1o86MkEfUmFku9DNFivzMU77ZkJh3jlYsQHaOD2tc815G0G
bKFcnnPoooHrNp5i5uh0OPN619nzVTR4pmScTt6RCvrlxscvPaGBc4zlBtpw
Cgj+5LocEEoDx9Z4xoknKRCy+pqvPIgGKq+bnKK/J0N8ilEGmx8NWD9uHHlf
9QJam4+te+pGA8kOTcobnUR410ZR/HuDBgfcAzYciY+FWrcNZg+O0uChioSC
vHYsfMtk22YsToMoV4U+8w2xIFcz+fv4AWK/UMUmwecSA58WskwnhWiQM3eI
f6t+NLyOK9gmsoMGTy2yjTbyREHB+uBcvmUqhA8cKeK1DwXda8nx/E1UyCpX
SD4xFQIL/DrWOTQqVD9XV3x+LQTMt59uk6ynQt+3Uh2ec8FwRR7OnaigwptQ
3jLOA4HQnZIUK5lLBZbmHZrvvj4CzWUHekEYFdJex2VJmLjA46CzEr91qcA6
bfmUR90ZKjuMZ6YuUEF4B6nx2UEnUFP+eeDNWWK/ZmgerLJkDxnNIRfyVKnQ
+lpe9b38bZgS5vOUk6LCLvk5PW4mHdgR2i71gYsK6YMih38n3MYd9Cu6THEI
gRu4FwRNA/C/Hr5iGfd6qClXcT7RF4ClOz+FZtrXwwfplmie04H4Y+tuA27r
euh5I7goLB6E02P+tROG9VBZ43rUcSEYNWNbL1gcq4eDCTMzm1zDUfaM1ejg
lzp4/+ngRNeBKHyvZsKaaVYH/x0dSxUsjsfkdtHjEVAL2/dtFKdPxmNTvllt
1PFacJnb4KnOl4AG6/YWRonXQgyfZ/ZkUAI+uvvwXciuWuAufHU91/Q5Vrkn
M659rQFlEu25/OYkVMjpuhOSXAMuwypnWzVS0HD8LGnfcjWsSU9pJ5Wk49d4
6ieeoiq46y1wLqslHWmfHxbQM6qAL89NJH00HfvYX9TdSaiCBpWlIDv2DDyo
VfSG4l8Ff7V2UMysMpB943sx+atVoHyZoZjDm4lcP0civrJWwfKbeJZx15cY
sDb244RpJQDFt0+KNQcL6x4ZNrFXQLyl22Tw7hyMwSCObpYKKJZ26+wXz8Gu
KM32N0vl4CgTcFBbJweX3x65OjZRDl6MvU+r43PQ60Le+m+1xLos3fDQe38u
Xl6eZYzalAMHf9DREaU8PMl2+c72Tgrc5vPLrT1TgGPLUobiQWQIf0ZWqblS
gCYz6ZdEPckwkmT+qvB2ASadOfCUz5EMhncufbcNLUCL32LNm6+RIaEuPtes
uwBFd3teHZUgg9aa9AS7XiHSnm4xMh8gwa598UoJOkXokV80Nr+PBJ5ZxQY1
O0pw/Gg5x1laKdi2LzzR4ytBh4MdSu/KS2FD/wWmSeESvNTlvv5uQSlUKEZH
LkuUYJNkt2VoXCncltv3/OvZElRblvNuuUecRyN3JP98WIJf+m+UHeEtBZtI
l62e70vwnt1HlQrHEkj7feTi29hSNC1vGG7VKAIm6ePe9UmlaBuz6wKzRBHs
WV3nk5xeis5qmyQVeIrg6PfcxYtFpeibLXEpe7YQFEiZ8w5Npch1fFzG82kh
eLMfvUVbKEXI7vfd8rYATmfplUaeLUM/V6H5kbv5QPnIvtZ3sQz7bLJFWA3y
4YeJi/ZW/TIUV3v5Q+JkPlQp6K4+vF6GG0u1b/lsyYdA05k6HqcytPEdeclH
yYNi3TIO88Qy9GTmfaq+mguHWHq/nZ8pw+3tmrW6ETngWWjXNPy5DA/JcJW/
c8+B5aQnv62+l2H1sct3zM1zoInJyMn+bxnODD5d7yybA0ZFO/+eZSehtLM6
X9RwNlTzvNIWlCChiY6TI/1ANuhPFbrddCDh9GJ90RL1JQzq7jxu6kJCTDQ3
9ch7CQr3Jp2N3ElYlEEeW372El7dE/I56UtCRz28umr5EoIni8d7I0i4OjUm
wczxEhoT9vTsKybhfrOr71evZEJrPz5+MEPCAPvvnKPf0qHKYXdZyRwJWeI0
Y0eG0kFTK5Z77AsJn/aOs4w0pwP+t9VJ4RcJd7IbhA8lpcNqjEdLNTMZ8/cs
2Q9opoNUQrrlRl4yvuM8hO2pacCxayjq9RkyNrqP5afppII/H7U08hwZg/yz
PJMVU6E4tnWP1gUybsiOOZkolgpuKdN9ZXpkdGz7x3/wTwr8+/5yysCEjBoj
0mPsuikgUuSyb86BjJsvbx3rZkomzmMa+obxZFS7IzIOpokwdlqQjfGcjEWb
lpkKpBMhMfW+p/oLMj5RYbDyrE8E70e2cQLpZMy4DL1fc59DpF89KTOfjJS3
6ZbJPxJgUt5RdLyOjDUHwucWA+Lh6bWwiV1UMlo+iei8aRQPT7xb7mjSyXiS
U+xFl3g8eOoJdCY1k/GmijtnRk8cNFcG/uBmkBHbnipe4I0DSZn3xsffk1FT
NXBTSmEMhBiaNYl9JOP4iDT7Jp8YEHRyWts2TsZ/C4nrnPRioNLWfeLjFBn7
zBpfnV6MhgcPxHy1vpBRJXt5YV4lGmRufnY3XCHjtZQY3xOvo6Brlqn34g4K
xt/cTU769RT+7Krnz9hJQeXdBooPUp+CFNcs48cuwnRGtZHWU9COGLYO4aWg
cLd7xs60J8Aiye8aJkBBTre9whHnw+FLXI7axAEK3vxp99+jjBDQyk7nXTtI
QVUHlkOmF0OAJWvYZKc4BbkyhbRO/gkGbZ99+08coWDrjRKfvxeDoUHaptNQ
ioJrih51jn8DYSz6S8KEPAWvzJBf3NR9DIOVgaeaFSi4iWU4XGXFH6IHL1zP
PEHBuz9pD/Zm+0OQnPIHAyUK+nUe13234gdhaw9EngAF+bI8J3VzHsGGRsML
l1Qo2Mt/s1ni0iNIYaxNb1eloNCL5pccq76wJ+yhfbgaBXfJmJm2XfIFsfIj
fZc0KHiffzjcd9UbJlmeBK0QNuDqU1TW9wY7mX0laacpeCB/dnop1wsuYKLh
xzMUXNJcOGFv4AlWnt/+kz1HQbtDxozrBR7weLuBDp1wXpuhAy+LB8Q+E+TS
0qJgup4qd/9ld3j2yGla9zwF//JJ6V5Ydx8+qYZsOH6Rgtbi7k2Kxi4Qtb+z
OZ3wr88uV7RJznByfeVeDm0K5s/Mz95kd4beqIWYAcKHbbw5Q+odwbLIgSKn
Q8FXq0UpL3Y5wqWEZZtowr/mH0uW2jtARH1gprouBY9IXNQdFLYH9Q8k0VjC
46yp9IFFWxBJPak8SZjn6bGx1dx7wPe6Ws5dj4Ij46cEL3DehT/5jN31hLVV
Bk86U2/Dk0/B0WuE7UrFTRIdrWHr7cP69y8R8WmSTfjUbwHZoVIJxYRbdq+W
bwm+Befe7HAbJ1y1lvlaTtEcXAsn57fpUzBLRWrh+rwZXMgv+KdC2G42mysg
xRTSY1yy7hCurOA1Ns64Dizm52YiCDelt0fnsF6DlwrHGkiES8YtGL/vGoGv
naJcH+FuyvdNGj2GoBZideor4SgTx1PPjumDLuAsqwEFC1TmvD7G60Kfk+Yh
fsI2K3WON/5egCKljeskCOttT5lepmuC7yiLizLhS2EPr8WHqgOpS9FHkzCL
TUn67RwlsC6iiOoQPqVpGZauIA2P9B1v6hM+MGY7eE9cAIobHBUMCLeKujGb
CKxHQ4mKXD3C5/4s2FjsO4Q5f0+SzhPOm2nodPeVw6jKjYbqhMsxwEFwSQXb
xbmjZAmLGuWt+EmcRurpK1ZihNMudQROW2phkfjAG27CvWSn4H3aOuh3OGRk
mRhv1ct/Fwdm9XCh/a7XR8K7j/luDw4wQIdKl8oGwh+vL789IXwFD/WnhqYT
FtC3TvlcZ4zrjk8uehJONGi4lWxkgik7TvwzILyasuGQzq8bqDMTk3iIcE5O
zKKPphl2bZPPaCPi+S7uQa30hDmiohV7NGFpjqZkNmkL3PzTlvMq4c63sz4T
3pZ4hdozPErkC2d+0anYPbeRLsiRm0iYeaeSmN3tO2iUN8VhQDg91J9Vs+Iu
Jo8cTqsj8rHuJW/bHz1bDNVxYdgQvpOindubaod7vLljeQgL8gY2GrjZY37B
nzkLIt93/3LOONrkgLtXtlUOEPXDdYTL5IOpMy4mM1+6SVjzwMOq3ztcsE7+
+NzMBSL+S+o7ODpc8JPPBPcsUY8yh5LbFY674Su3G4q1RP26ROscerbJA590
+tSKEf73yM47t94DVfZUKISfJfJLU7kPnR7gmxLy/ouaFGz84uL6eeQhzlEW
OlOI/tG5tJytUeaNWrX0g7OnKBjNeLFYKOODLHeP+koSpqVs5VV44oNbn28Q
KCX60fcpkava6r5o3VCz5RHRz97YB3Y8KHyEPyrC428S/XE5punia9/HKHlK
wN9GjsjPN/v1bww/Rp3bPpaOskR8+rMNZ2UDcLUxltPxGJFfo/f0mD4T+3j2
3RMqkhRkCmkRPGwYhJFVY6Z8+ylouV5q4dGhUBw2+x4zuY/I16xnFI7Hobiv
6UNtnigRD3Zpp/j3oRgqsjp6QJiC+/9TGC6MDkNB/hN3fvJR8NrF6uuDq+E4
U3bkbOtWCgbf0f8VczsCf590Kri9heiPk6Sp188i8MeK5SNWLgrGbino21Yf
gel/Vvzl2SkY9344JZI7Ek2TjgzZbaDgnqOG/8JqInHkHO8Dmb9kPJ/0O+8R
xzOM8MgbTVwiY0iYxima3DNsvbqtmGmRjItuZf1rZs9wq9JQNP4gI0ft4amH
5c9wffqG29zzZLwfdTPP9UY0Vlz7b4CNWF+3qHIkWpfGICdjsf/ECPE8o4ai
rKEY/HOaU9lyiIzS4tqVE+tjkZN7UKFsgIybRn7nmxrHIvUYz6e9PWQc2lbN
eWVdHPYbHaGcI9Z7eYdHQacM4nF3pXzYDLF/4L/4UIv7z3Psb3bzcUwk493G
Ax2DYom47eInsSVi/yHoVCeTop+IfreCAn8/I6OyLdaJlyRiKzr4YTAZVYdy
stWtkvBKeCX6OpMx3CbBzPbNCzSpYhmgnSZjaqYP/c2VVKy/MBhHVSfj4T0S
7BV2qSijm/W9WoWMtquCqvEBqajhV2KTfoLYn4xb3zUmp+I95rdWSkfJqPjD
r2KEKw3jNkjmJm4nY2ih2rv3zWnI2MTSwTRKQue2BkfGsQyUX3V75vuOhO6f
P/uraWWg1MHHTKv9JNTS13KlmGXgiVfejZ8YJGQvbv/5/EkGeonbDobRSPgr
zv/SrZkMLMF/2kyZJLS/53HwW2Im7o0VU46xIGFl/5NHMyxZ+I2tNjnIjIT/
2tZ7Gu7OwpJMRz83ExL6X7XSaJTIQj+VhldnDEjIf8RaOeVaFr6sOXKz7BQJ
F0d9K/XKs9D61Zp2kTAJaT9unim+nY08Uh0cCkNlGHyrd0ihJwehcLPabH8Z
bpPhdd07mYOd8gH34nrLkNHyuYflbw5qc7BlTbaV4a3PwU3tIrloVbfJR7ey
DNmM6HGX3XLxY1rprEV0GW5JGjl1a28e8kRGrrkT5wNld7m0Uzb56H6o9zBX
dim60+wrfmwoQqbUsRDVtFIMTmSR8ucvwrEDln22iaWYdOiz4PZjRSjZqcpf
/bQUF608r0ubFeGi/Q3LbfdLUTFlm7h1TRE+k7ljzDhTilI+C28q7IqxTTNl
wnS8BG8f3JP95W4JHgv3nwnYXILXLEVcf/SW4rMeHXy/rgR3d698sRgpRS+W
pUCrv8XIOrZrdWC6FH3Ob017/r4Yjzp0DFWvlGI/dToqLLcYB3rnPR+IlaF9
yu8XSYrF2G8lnTLtXoaFckWHDa8U4eegIWELQRKa8QtctnMqQFqRsijeJfaZ
kUf0580LsFlhw+SQCxnF3kormOkXYOVo/rolbzJ+zxQvPHS8AH+tEzE8Gk1G
XiHKO/Xf+dhS9VDyWS0ZL0kfOx7mmo+RU/QaJQ5iXQt07r1ql4cFARvGNhRR
0PlGl8YB1RwM+tpRKTFfjulh58fcjuTgq54ZhYXFciykkf2rifPzAevaBBJL
BapPy7fwLGSjtyR5XpqnAue3m5fLp2cjy9uAYhH1Crz4rruHmSkbja919nfE
V6D1n3X7Ykpf4q28QOYD6pVolKB9OXEuHTm73AIjnlVh+seR/Vv601H6gTn7
mRdVKN7hEHSfmo7cchXbV7KqcC1iZlokJh2fSWOWWXUVnvUKzphQTse7ewYi
eT9WIX//OrHN4WkYLRMQqHq0GhOrYbZJKBVPvE14cKmlGu+tZbKv13yO4Ru5
bf7+qEGjVk1Pde7nmPX5w/z61RpcDHVjvTmcgAXmaV85N9ZiXW6BAtgnoGXh
lPluvlqU8/rWdT82Hm1KOV5ynarFTWuSHqPDscji0Svm9awW2U7KCQnrPkPn
zf47zkjWIUvx61cseYHYcXw4I860HnNrJj5skQ3E2bGKf6du1+O9mX+aY7QA
/F7cffyrQz0KJVYNdQ8+xhQdeckTfvUYU8u5tWudPwZN9LzNfVmPckpy/128
6IPPs5R1Pn+qx7cipm6dtx3Q41/19fd2iNqPEwbcHe3xeH2LtOB9xL42gY2X
ftniJ7GeKyY+iJNn3Vz2bruLJWw7gjojEMdTNs18UDNHCs+hr56liJZ6v3xe
xSqioY1r4YEFRC5S7rV98zbQkv87X1meiocay3nNvtuCi5EZO5sSFfc9jdmh
9cAe9nKGXe0HKqrOYuRvX0fg/CdQa3mGikNfKlUPxbjCZucSsDWkIkuRsBZf
nxcIFv3ettOZii11X0O/9QfCLpkbYeWFVGz/4t84fiMIVNdW6pRKqbia1TK3
81MQKLakBVPJVPSzI8sorwSD+WHaOLWGiouHZT+G7AuD24Uc+pltVCTL5nHy
qkVAsuKu9B8TVORZ4B5lroqGSbZi/ZTdNByqsefLY42B1fUTjjz8NHyg8anw
vmEM3JUpvfhEkIZ2QvUjQT9jIKZmk4T9fho23ev/6SIdByEiCULsx2mIokuM
AEoChO1mV0jTpuHgV1ObpMFkCB/1oAk/omE+jbNk5+EUcFxwCRB/TENGkmNZ
hXcKeMz7+EoG0XBmjbxSvi0VqgPfsEo8oeEpqe63BrWp0D+waeBfAg1ffu/T
kN2aDtLfXL1HS2go39Yi69uWCfVrmw+HDtGQm9dpvmIhE3bKqNVNjdBQ01HA
c23PS8itsvc6+YGGnnotwjTblzD7OcxnbIKGXzO4zDl3ZIHfU07ulXni8/Sx
3mTcyobazex9Dms0tLzhvMz9NBtyzITdnzDTcfT9wiWrqmxY/0WNI3sdHak7
7RTUOHPgv5+0Lx2sdIyQz42hVubAps7vAhNcdHwcsFF/ZEseHDR5/OCcAB1b
TE5QxJXyQDp9mVlUiI4748ryQqzyYJVSKPVHmI4zX89oeNTngXjQ0QexYnTc
opY0KHAvH34tT51IOkJHZr6dx327CmBYWyGg5wQdFbNv7B/4UwD9IUyhN5Xo
uPTayl5ZrBAy5Ky+f1Wm48+iqJ8nvAvhjkxnz4oKHcNGe1X/SBXBy1E7o9HT
dPT+OBHu9bwYLk+cflyrS8dwWmhqRkcxxIs3B/BfouO2D4u+QyvFkMzK0Xhf
n46PpB+30SRKwLpr8C3/ZTre1z29+V1UCcxQ/7QKXaNj12bDmxX5JSDgdWPt
kgkdXS5xsyQ3loDTDLOqz3U6tv/zZg38XQLw2rWr2ZSONz9sK24xLoW48brr
bBZ0PLzjfdsXp1KY869T47CkY8ARn40C4aUQbhXPtMmKjrxt20afYylwtn//
Nm9Nx31+anenBkshVu/7zoHbdKQb4UbFhVJwVOj+V3WHGK+LkemaaBlM/137
aWNDx+Ud+7bYnSyDjN11S0r36Bivn1gzfbkMjMUPZG6wpeOAD/+3HyFlwBFQ
MRhgR8fW8PDjbt/LgC/q44YTjnS8bqZ68CgbCZa+n43tJ/xMZG5uXpQExiJO
z22c6Chcb9YceIUEI4ZXp/2difmwFug1cyRB7gFlEVYXOnbbk6NPhZFgi8e+
6keED4U47BOlkkAyXeq9hSsdz8l8nRJ8R4J3MzdNuwifl/mqIfaTBKnJFOGj
bnS8sDyreIyTDKZseQJBhD9xaNLPHSDDwYU6nSHCPeOXe2+rkUE9waZ4/306
VvVctoi8Rga/3qPH7xFWmrF3prmSoXDdg6F8wjFjFUt/IsgwdrQpcZywFfOR
uRP5ZNi/7GW33Z0Y38+aU/5NZBCv26VzkjAbKq6+eU+GDT4rsmaEDRJtt0j+
JYMQZzy/J2HyB2bnqO0U0Pir9y+ScOR0uNC/oxRIzHnGSCGs+yVmq/1ZCnBf
qQ/PInxoNVBpzpwCUeLHpf7nt4za57ZeFIiUuUJKJmxR4ib6N54CyW6POSII
11lMvQonUeDXGo+CB+GUbUKJB7spcO+9jYQJYVPBQ/e7ZihwU/ntJ3nCibu/
mLqvK4eiG2Qzjv99/gT1C0f2lsMrsl7EO2K8Rw/OHfskXw4wusEulfCK4d89
kpfKYXnFXsGUsPGd8Eyve+UgF9Iyy0N4IiOu+XVgOfDsJD9sJ+Z73GzRXTq9
HIzyR2ecCWuwupbH1ZYD19v5AzyEP4+1OP03UA49tQGyZCKem33Pa/9kq4BE
ofHUfiL+sSme19zEKiCCefbbNcJqD7xamVUrYM8d5l9DRP7cyVlLOOxaAVGp
79YaiPwyH3k13xlRAb9H3/w5TDjVYpenc34FvEzSf/KEyMfjgcUH336oAJHr
6vcUHeho9zDzWOxyBXSenMgLsKfjf+d1DY13VsJv2zu324n8jrkkXLmoVQlK
5720FYn8nzeQneyxrIT0/ON3rIn6OBb3kaXUtxIK+/d9DifqJ8pyYuZxRSX4
tS+z0Yn6kjzk+sKjl3he1PoXPUT9zVht2+M6XwnkkxEPBoj6XE6c1vQVqQKS
+B3WbqKe9yeIXJx+WgXfdky9NLlJR4+60UNb86vgR3nJlyNmhIOOeao2V8Gj
SFfd3zeIfNgrd5myUgX7mg5r2RH9ZHvY5vyZ29WwTbbHmPkKHeUOkNZOPSY2
MZ9YMNKQjk/Uo+yzU6thc1vGJl4DOtZXOt33GqgGPZV78tx6RD/UGXrjpFED
qi/Hz6Rq0bEj+S9tzbQGEt3PiX89S0cZx447kQ9rYJSRRTuuScfyd+PUJlIN
HNgdMZ97io6Ckdx7HYRrwU8r6MkRor++NLFWbWGqA+2PTVeTDhP1wMVu3sZb
BzbvJGeDDxH1GE7uZByrg01a76bsDtDxX2fMuU/WdRAqcmnnPlE6FjnXF154
VQdzD3jqZfbQMdtCpvJVej1oBAhWjhDriZWs9RB3XT0I3ZNt1F5P5EOnY+Dl
gXqYKv/5uYqFjjs+2ZyZY0O4fU7Tx/UfDdPG9zApuiBkHBsWilig4UOp85/l
RKlQ7X3xlwqxPip/LqxwkKKC5eyss/QgDdW8H44UnKSC+v1W2p43NLQKteHb
b0SFe/8xit9007DnWXTaoSdUEKE4G0zRaGjm6+xitUSF2WNRMa5ZNDza7XjX
r4sGHuKywtK3aag4G7/l7xANDt+WGa2+RUNV2tfDDrM02Hsi9IyCKQ2dBMNT
TVnpYNy5h33XZRrav67VUFelQ0jqlgaDUzTkO+0wzUEhrldRZYb4aBgU/OVD
QAMdenMeKdbuomFRlmjq2is6SCZdT4zipuHj+tOq377QwXn9cW2BjcT7aoeb
Og80wAntDSsVC1TsHL9w0zqpAWK7ZY6ONVGx1lVWbDCvAQqvHbm3k0rFwM37
vp6uagAz3+YKqKbi5s4BE6H+Bnh9Y9d1hyIqWurkarVyNUK69UUXnVgq8h9b
L9T3qBHEkoJE/ppT8aS6o7O3VRNYC30+TptHvCxIG210bgKhVClXvQ/EfrLk
xRLroybYSNvWzehF9Ju5yB6Y1AR9t7+VPqlAPJbkdcfqVRNUKZM6+Ij95292
j/isE80QEL6Y7MqB6GESYNe2uQUKzvBf37i7HmMDZJwKd7VA2cWYYzs21SO5
yCQ5XLQF8p8NV3H8qUPxsGY5tZMtsPTodjttsA51vO9yPHBogWdCLsPH4+pw
mq1zRGCgBV7L/Js+v6UO68s9rrxNbgV/Yb+C48R+n/H85NfZvFbIWH8xefvH
GgwwuqC4WN4KzHFz7B+6a1A8Lx7XulvBsTnGWimvBl9xfONgrLZC0f2Fy2ym
NahZ0md81aQNpocybP5rJc4TWu+Lune0g43blMfD4CqUXHj/jF+oHfbtdxH7
7lyFLXPMwRaH26FxNrdNz5Q4v+zWtP2g1g7M+l2cI7JV+PHGWJGPXTuIitJU
OccrcV5X1OBGSzt4/hTc/0muEtvMhyPkHDognbb3bXlfOfJYbdxk97ADyiRC
rk5Vl+M2BZXrSYEdoNx8MpMpvRzlP/+5OviiA0zJG+t+2ZXjmqBfe19bB9ze
HxQwvrkcBYKLy9oEOiG/2vHLWyUKrut22Xr5UCdoBImb1wpT8DVti8rbY53w
82Z6QMhGCsoYa7bXnO2EI+uKeGf7yDjWv0xfdOwEmo+BZuVtMuZSro0pNXSC
1p+MyZRIEn4PD/Dn6iL+/wH9jIYrCVUtrn97098Jw9cLHQeMSXjh18iE8mwn
ZFGl7OkiJJzI+e17f0sX6CmiFIVchlOht6tDjLuAsVOnSKCvFH1v3dGumOiC
58K9XmksJRig62Bt9Jm4XhtturG7GA1HWmW//uiCst4PAqWxxLk7TqDpF0s3
FNh8u1y4vxhLE1ys7gl2wxtSr6KBZhGeymubXbnSDXcnNYSD/Auws4lp85sb
3XCfi8oXp1WAB5OZD6dadkNM81bRMO4CXMoYvsDl3A1TNHfOg6n5+EVpeUz7
STd4d0sYyFTn4RTLa2NdajdU62pGln3KwYcmx7v1mwnTgnnli3MwdYg7/Vxn
N1Qc1EzPcs7BTcNCGhyD3eCWuNER1rJx5DXDYf5LN5if2+RrsS0bo2XnbLfy
MkB+23BYsdxLjLXmfS4rwAA4YfJ4eDkTWyu5Yy+IMuCb8b3cX5iJ/yJl3usc
ZcDDi8un589kYpduRm++KgOWDEyyFg0zUEVso3WBBQPCIqc4cxzS8F6Nsp71
HQYEsO1Mjz+ShlLy539ttWPAjcXVOudPqVhy4TEcvc+A810Czd9MUzF4t8T7
4GAG9LB5qDEnJ6O35r/gsnAGTP0ZWlewPRl/MNtktkYS789Or5UOfYG7alQ3
1CUwwO83RvS7JWHgr6D4phwG7DcYUA/Wfo7nOXa+u1LAgL2Nz5T3NSXgFlTQ
elvMgKs8Z2TSTySg8CJbSlo5AyLstr9Q3RePi8JFmtoNDGgfkTp34E8MWp2s
UtVqZkDBtxim0XsxuHL4lcyxNgYcO7Sz130sGn/cbZzt7GYAG8/SNcuOZ5g/
k8y8+y0xfzsq1fYlRWLNuimBh0MMSJRbWOPfEolMT103d44wYMvBRg4W/wg8
fWGDlPQYA/LkFNz4B57guW0kc80JBuhQNxs51IejfOp/OlpTDOj9GSqQ9jIM
zzIVnto1ywDvLQUZCU4h6Jn489SHOQZ0BqxssDAOxvkK+peYeQYIFhg+36oa
hCwBzyRbvjGgpk8zbRtnAHIOdNLUFhhwhTZfd/enPxaw/f2S94MBlsyF1/Le
+aHNetOtqr8Z0PEx0PVDli9qeOxitltkgOqz+y/ehfngn4tU3+AlBriOayr5
TnphywBTZMQfBsz8vp68v/QhUkpzDvv/JcaztMqZ/9ADebpL9G4tM0Cr0VaJ
U/M+6ngqMkutMIBrr8WbS9tc0et+tOwsYfcrTMFeo04YOCv5/ek/BqxfqN0Q
meuAiveLJYRXGcBvOriy55Mthp8Z/JZKmOxqoPLN6w6urX8hw77GgFbnIvnM
7ZYo9YVn0ZxwUsfWM8p5ZhjXGXEihzDNhue5r7cxGq9z+jdIeE/73BXrPF08
E34ZfhO+Fe3F75Sniv/3/RbWa9tlxLIia/8fBwtjDw==
                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.07820268892189204, 0.03553756419343942}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.39101344460946036`, -0.17768782096719715`}]}, 
                    LineBox[{{-0.07820268892189204, 0.03553756419343942}, {
                    0.39101344460946036`, -0.17768782096719715`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}], 101->
               GraphicsBox[{{}, {InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8Vv8bP3BpUKg+oUQhowilpd0VDdJAVGSv0k5KIklGlJIt2ZK997zI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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1672#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], Thickness[0.001],
                     Opacity[1.], FaceForm[Opacity[0.3]], 
                    LineBox[CompressedData["
1:eJw123k4Vd/XAPCSFBIVFYXMERWS0rAq0WTMmEIDkoyRzPM8Zcg8zzPXHcys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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1739#1"]& ]}, {}}, 
                    {PointSize[0.025], PointBox[{0, 0}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.492155743967018, -0.10826003318371841`}]}, 
                    LineBox[{{0, 0}, {
                    0.492155743967018, -0.10826003318371841`}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0.08202595732783631, -0.018043338863953064}, 
                    0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {160., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}], 
                  InsetBox[
                   GraphicsBox[{{{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123k41F/UAPCyVEjZQ2mxlJKUFu3HnhIlLVJSlJJ9icoWIopkzxZZIluW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                    "]]},
                    
                    Annotation[#, 
                    "Charting`Private`Tag$1798#1"]& ]}, {}}, {{{}, {}, 
                    TagBox[
                    {RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6], Opacity[1.], FaceForm[Opacity[
                    0.3]], LineBox[CompressedData["
1:eJw123c8le//OHD0LpVVWhKZaaisMkIvI6VURihKkYxK9oiyIlshM7Kz9znH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                    "]]},
                    Annotation[#, "Charting`Private`Tag$1765#1"]& ]}, {}}, 
                    {PointSize[0.025], 
                    PointBox[{-0.08202595732783631, 
                    0.018043338863953064`}]}, 
                    {PointSize[0.015], 
                    PointBox[{0.4101297866391817, -0.09021669431976534}]}, 
                    LineBox[{{-0.08202595732783631, 0.018043338863953064`}, {
                    0.4101297866391817, -0.09021669431976534}}], 
                    {GrayLevel[1], EdgeForm[GrayLevel[0]], 
                    DiskBox[{0, 0}, 0.025]}},
                    Axes->None,
                    AxesLabel->{None, None},
                    AxesOrigin->{0, 0},
                    DisplayFunction->Identity,
                    FrameLabel->{{None, None}, {None, None}},
                    
                    FrameTicks->{{Automatic, Automatic}, {
                    Automatic, Automatic}},
                    GridLinesStyle->Directive[
                    GrayLevel[0.5, 0.4]],
                    ImagePadding->{{2.842170943040401*^-14, 0.}, {0., 0.}},
                    
                    Method->{
                    "DefaultGraphicsInteraction" -> {
                    "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                    "ScalingFunctions" -> None},
                    PlotRange->{{-2.2, 1.2}, {-1.2, 1.2}},
                    PlotRangeClipping->True,
                    PlotRangePadding->{{
                    Scaled[0.05], 
                    Scaled[0.05]}, {
                    Scaled[0.05], 
                    Scaled[0.05]}},
                    Ticks->{Automatic, Automatic}], {480., -111.17647058823529},
                    ImageScaled[{0.5, 0.5}], {300., 211.76470588235293}]}, {}},
                ImageSize->{
                  UpTo[600], 
                  UpTo[255]},
                PlotRange->{{0, 640.}, {-222.35294117647058`, 0}},
                PlotRangePadding->{6, 5}]}, Dynamic[$CellContext`i13$$],
               Alignment->Automatic,
               BaseStyle->"ListAnimateCore",
               ImageSize->All,
               TransitionDirection->Horizontal,
               TransitionDuration->0.5,
               TransitionEffect->Automatic],
              Identity,
              Editable->True,
              Selectable->True],
             ImageMargins->10],
            Deployed->False,
            StripOnInput->False,
            ScriptLevel->0,
            GraphicsBoxOptions->{PreserveImageOptions->True},
            Graphics3DBoxOptions->{PreserveImageOptions->True}],
           Identity,
           Editable->False,
           Selectable->False],
          Alignment->{Left, Center},
          Background->GrayLevel[1],
          Frame->1,
          FrameStyle->GrayLevel[0, 0.2],
          ItemSize->Automatic,
          StripOnInput->False]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
       GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {
           Offset[0.7], {
            Offset[0.5599999999999999]}, 
           Offset[0.7]}, "Rows" -> {
           Offset[0.4], {
            Offset[0.8]}, 
           Offset[0.4]}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.8814774286148987`*^9, 3.8814775016048193`*^9, 
  3.881477581500374*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"e0bc6eba-169a-418e-a577-4a5b061ecb9e"]
},
WindowToolbars->"MultipurposeBar",
CellGrouping->Manual,
WindowSize->{925, 638},
WindowMargins->{{116, Automatic}, {Automatic, 83}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"3bf083b2-9bb4-47fd-b5ac-79bdb0d463cc"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[531, 19, 387, 8, 53, "Text",ExpressionUUID->"6d91de60-c10c-41f5-bde9-287116780b4c"],
Cell[921, 29, 295, 4, 67, "Section",ExpressionUUID->"e0c5f5c8-6081-4d1f-b6a3-e70fbf94be83"],
Cell[1219, 35, 509, 16, 72, "Text",ExpressionUUID->"037fe9f8-0973-4de7-8f87-9d81c9d6a588"],
Cell[1731, 53, 130, 1, 30, "Input",ExpressionUUID->"74d5f28f-491d-4df9-9a98-baf58f7ca2bb"],
Cell[1864, 56, 692, 18, 76, "Text",ExpressionUUID->"15a06966-ec76-434f-8cbd-b97cea0e1abb"],
Cell[2559, 76, 220, 5, 66, "Input",ExpressionUUID->"1a2b4798-3239-4416-8e3f-8237e4351cfd"],
Cell[2782, 83, 1098, 25, 122, "Text",ExpressionUUID->"1bc8946a-0165-4c8f-a798-407bae699c3c"],
Cell[3883, 110, 611, 11, 66, "Input",ExpressionUUID->"189049c2-9419-41be-929f-57b64959f251"],
Cell[4497, 123, 663, 11, 66, "Input",ExpressionUUID->"78be983d-800c-4e63-a839-32a0d43a5c31"],
Cell[5163, 136, 676, 16, 76, "Text",ExpressionUUID->"499ef0d3-896f-43ff-ad87-a50c6bd576da"],
Cell[5842, 154, 151, 1, 30, "Input",ExpressionUUID->"e98c7a92-aae2-4838-8992-553373aaa41c"],
Cell[5996, 157, 875, 21, 76, "Text",ExpressionUUID->"038f3591-2174-494e-ae16-414cdb11af73"],
Cell[6874, 180, 865, 19, 174, "Input",ExpressionUUID->"6dc29f0b-b5a3-4d3b-abbd-998f5350a3f8"],
Cell[7742, 201, 537, 9, 53, "Text",ExpressionUUID->"7c6a061f-df2a-45cd-b45d-24af7e38b1f7"],
Cell[8282, 212, 179, 2, 30, "Input",ExpressionUUID->"23829646-9796-4147-80ef-8e664b956745"],
Cell[8464, 216, 612, 9, 53, "Text",ExpressionUUID->"38e13c9d-f70b-439d-bfae-efa7ca65c07b"],
Cell[9079, 227, 205, 2, 30, "Input",ExpressionUUID->"25ed41c2-df98-41e4-8ace-b58988592b4f"],
Cell[9287, 231, 862, 17, 53, "Text",ExpressionUUID->"17c4fb23-07c4-4a1f-b239-9a70e3e05ba2"],
Cell[10152, 250, 464, 8, 30, "Input",ExpressionUUID->"921bc2f3-947f-49de-ad90-fadf1c1b4231"],
Cell[10619, 260, 956, 16, 53, "Text",ExpressionUUID->"cf9c9ae6-a21e-42f4-a9b4-60449524145a"],
Cell[11578, 278, 403, 6, 30, "Input",ExpressionUUID->"6c569547-aadc-428e-bdeb-d50d12cfd9b1"],
Cell[11984, 286, 405, 6, 30, "Input",ExpressionUUID->"f9e35473-3695-4300-a082-610a2f24b370"],
Cell[12392, 294, 245, 4, 30, "Input",ExpressionUUID->"ceba9e33-0370-4480-9c48-437d46024358"],
Cell[12640, 300, 938, 16, 76, "Text",ExpressionUUID->"377e75f5-1ae8-46ab-ba50-f66e2c17a174"],
Cell[13581, 318, 2399, 41, 228, "Input",ExpressionUUID->"5379821f-f57f-4040-ae58-e6e690f5d55c"],
Cell[CellGroupData[{
Cell[16005, 363, 366, 6, 30, "Input",ExpressionUUID->"62895743-474f-408f-8c10-c0ea2cd2bfce"],
Cell[16374, 371, 3650729, 61181, 347, "Output",ExpressionUUID->"cc933150-8628-46ea-b751-edcc7ea3fd56"]
}, Open  ]],
Cell[3667118, 61555, 936, 16, 76, "Text",ExpressionUUID->"c29eb8c8-9051-49fd-b3cf-7d258507870f"],
Cell[3668057, 61573, 2727, 46, 246, "Input",ExpressionUUID->"07cff80a-df47-49a2-951a-4fd7d951b15c"],
Cell[CellGroupData[{
Cell[3670809, 61623, 293, 5, 30, "Input",ExpressionUUID->"e9a5b3fb-6184-40e7-995c-9c43d06e7dee"],
Cell[3671105, 61630, 3641375, 60989, 347, "Output",ExpressionUUID->"78114712-ce91-4607-bc18-d3794e1167dc"]
}, Open  ]],
Cell[7312495, 122622, 901, 13, 53, "Text",ExpressionUUID->"493a04b5-3d3c-4c4c-83ea-7fa8c5170377"],
Cell[7313399, 122637, 608, 15, 30, "Input",ExpressionUUID->"1dfdc48c-a7c3-48ff-9216-d05f95977999"],
Cell[7314010, 122654, 7370707, 123410, 307, "Output",ExpressionUUID->"e0bc6eba-169a-418e-a577-4a5b061ecb9e"]
}
]
*)

